@@ -19,10 +19,10 @@ use Getopt::Long qw(GetOptions);
 use Pod::Usage qw(pod2usage);
 use Storable;
 
-use lib dirname($0) . '/lib';
-use lib dirname(dirname($0)) . '/lib';
-use lib dirname(dirname($0)) . '/build/lib';
-use lib dirname(dirname($0)) . '/test/lib';
+use lib dirname(abs_path($0)) . '/lib';
+use lib dirname(dirname(abs_path($0))) . '/lib';
+use lib dirname(dirname(abs_path($0))) . '/build/lib';
+use lib dirname(dirname(abs_path($0))) . '/test/lib';
 
 use BackRestDoc::Common::Doc;
 use BackRestDoc::Common::DocConfig;
@@ -39,6 +39,8 @@ use pgBackRest::Storage::Local;
 use pgBackRest::Storage::Posix::Driver;
 use pgBackRest::Version;
 
+use pgBackRestTest::Common::ExecuteTest;
+
 ####################################################################################################################################
 # Usage
 ####################################################################################################################################
@@ -60,19 +62,18 @@ doc.pl [options]
    --no-exe         Should commands be executed when building help? (for testing only)
    --no-cache       Don't use execution cache
    --cache-only     Only use the execution cache - don't attempt to generate it
-   --var            Override variables defined in the XML
+   --pre            Pre-build containers for execute elements marked pre
+   --var            Override defined variable
+   --var-key        Override defined variable and use in cache key
    --doc-path       Document path to render (manifest.xml should be located here)
    --out            Output types (html, pdf, markdown)
    --require        Require only certain sections of the document (to speed testing)
    --include        Include source in generation (links will reference website)
    --exclude        Exclude source from generation (links will reference website)
 
-Keyword Options:
-   --keyword        Keyword used to filter output
-   --keyword-add    Add keyword without overriding 'default' keyword
-   --dev            Add 'dev' keyword
-   --debug          Add 'debug' keyword
-   --pre            Add 'pre' keyword
+ Variable Options:
+   --dev            Set 'dev' variable to 'y'
+   --debug          Set 'debug' variable to 'y'
 =cut
 
 ####################################################################################################################################
@@ -85,11 +86,10 @@ my $strLogLevel = 'info';
 my $bNoExe = false;
 my $bNoCache = false;
 my $bCacheOnly = false;
-my $oVariableOverride = {};
+my $rhVariableOverride = {};
+my $rhKeyVariableOverride = {};
 my $strDocPath;
 my @stryOutput;
-my @stryKeyword;
-my @stryKeywordAdd;
 my @stryRequire;
 my @stryInclude;
 my @stryExclude;
@@ -103,8 +103,6 @@ GetOptions ('help' => \$bHelp,
             'quiet' => \$bQuiet,
             'log-level=s' => \$strLogLevel,
             'out=s@' => \@stryOutput,
-            'keyword=s@' => \@stryKeyword,
-            'keyword-add=s@' => \@stryKeywordAdd,
             'require=s@' => \@stryRequire,
             'include=s@' => \@stryInclude,
             'exclude=s@' => \@stryExclude,
@@ -115,7 +113,8 @@ GetOptions ('help' => \$bHelp,
             'debug', \$bDebug,
             'pre', \$bPre,
             'cache-only', \$bCacheOnly,
-            'var=s%', $oVariableOverride,
+            'key-var=s%', $rhKeyVariableOverride,
+            'var=s%', $rhVariableOverride,
             'doc-path=s', \$strDocPath)
     or pod2usage(2);
 
@@ -127,7 +126,7 @@ eval
     # Display version and exit if requested
     if ($bHelp || $bVersion)
     {
-        print BACKREST_NAME . ' ' . BACKREST_VERSION . " Documentation Builder\n";
+        print PROJECT_NAME . ' ' . PROJECT_VERSION . " Documentation Builder\n";
 
         if ($bHelp)
         {
@@ -168,31 +167,16 @@ eval
         $strLogLevel = 'error';
     }
 
-    # If no keyword was passed then use default
-    if (@stryKeyword == 0)
-    {
-        @stryKeyword = ('default');
-    }
-
-    # Push added keywords
-    push(@stryKeyword, @stryKeywordAdd);
-
-    # If --dev passed then add the dev keyword
+    # If --dev passed then set the dev var to 'y'
     if ($bDev)
     {
-        push(@stryKeyword, 'dev');
+        $rhVariableOverride->{'dev'} = 'y';
     }
 
-    # If --debug passed then add the debug keyword
+    # If --debug passed then set the debug var to 'y'
     if ($bDebug)
     {
-        push(@stryKeyword, 'debug');
-    }
-
-    # If --pre passed then add the pre keyword
-    if ($bPre)
-    {
-        push(@stryKeyword, 'pre');
+        $rhVariableOverride->{'debug'} = 'y';
     }
 
     # Doesn't make sense to pass include and exclude
@@ -223,10 +207,21 @@ eval
             or confess &log(ERROR, "unable to create path ${strOutputPath}");
     }
 
+    # Merge key variables into the variable list and ensure there are no duplicates
+    foreach my $strKey (sort(keys(%{$rhKeyVariableOverride})))
+    {
+        if (defined($rhVariableOverride->{$strKey}))
+        {
+            confess &log(ERROR, "'${strKey}' canot be passed as --var and --key-var");
+        }
+
+        $rhVariableOverride->{$strKey} = $rhKeyVariableOverride->{$strKey};
+    }
+
     # Load the manifest
     my $oManifest = new BackRestDoc::Common::DocManifest(
-        $oStorageDoc, \@stryKeyword, \@stryRequire, \@stryInclude, \@stryExclude, $oVariableOverride, $strDocPath, $bDeploy,
-        $bCacheOnly);
+        $oStorageDoc, \@stryRequire, \@stryInclude, \@stryExclude, $rhKeyVariableOverride, $rhVariableOverride,
+        $strDocPath, $bDeploy, $bCacheOnly, $bPre);
 
     if (!$bNoCache)
     {
@@ -244,6 +239,36 @@ eval
         }
     }
 
+    # Build host containers
+    if (!$bCacheOnly && !$bNoExe)
+    {
+        foreach my $strSource ($oManifest->sourceList())
+        {
+            if ((@stryInclude == 0 || grep(/$strSource/, @stryInclude)) && !grep(/$strSource/, @stryExclude))
+            {
+                &log(INFO, "source $strSource");
+
+                foreach my $oHostDefine ($oManifest->sourceGet($strSource)->{doc}->nodeList('host-define', false))
+                {
+                    if ($oManifest->evaluateIf($oHostDefine))
+                    {
+                        my $strImage = $oManifest->variableReplace($oHostDefine->paramGet('image'));
+                        my $strFrom = $oManifest->variableReplace($oHostDefine->paramGet('from'));
+                        my $strDockerfile = "${strOutputPath}/doc-host.dockerfile";
+
+                        &log(INFO, "Build vm '${strImage}' from '${strFrom}'");
+
+                        $oStorageDoc->put(
+                            $strDockerfile,
+                            "FROM ${strFrom}\n\n" . trim($oManifest->variableReplace($oHostDefine->valueGet())) . "\n");
+                        executeTest("docker build -f ${strDockerfile} -t ${strImage} ${strBasePath}");
+                    }
+                }
+            }
+        }
+    }
+
+    # Render output
     for my $strOutput (@stryOutput)
     {
         if (!($strOutput eq 'man' && $oManifest->isBackRest()))
@@ -276,7 +301,7 @@ eval
 
             $oStorageDoc->pathCreate(
                 "${strBasePath}/output/man", {strMode => '0770', bIgnoreExists => true, bCreateParent => true});
-            $oStorageDoc->put("${strBasePath}/output/man/" . lc(BACKREST_NAME) . '.1.txt', $oDocConfig->manGet($oManifest));
+            $oStorageDoc->put("${strBasePath}/output/man/" . lc(PROJECT_NAME) . '.1.txt', $oDocConfig->manGet($oManifest));
         }
         elsif ($strOutput eq 'html')
         {
