@@ -51,7 +51,8 @@ my $oRenderTag =
         # 'exe' => [undef, ''],
         'backrest' => [undef, ''],
         'proper' => ['', ''],
-        'postgres' => ['PostgreSQL', '']
+        'postgres' => ['PostgreSQL', ''],
+        'admonition' => ["\n> **", "\n"],
     },
 
     'text' =>
@@ -77,7 +78,8 @@ my $oRenderTag =
         'exe' => [undef, ''],
         'backrest' => [undef, ''],
         'proper' => ['', ''],
-        'postgres' => ['PostgreSQL', '']
+        'postgres' => ['PostgreSQL', ''],
+        'admonition' => ["\n", "\n\n"],
     },
 
     'latex' =>
@@ -108,7 +110,8 @@ my $oRenderTag =
         # 'exe' => [undef, ''],
         'backrest' => [undef, ''],
         'proper' => ['\textnormal{\texttt{', '}}'],
-        'postgres' => ['PostgreSQL', '']
+        'postgres' => ['PostgreSQL', ''],
+        'admonition' => ["\n\\begin{leftbar}\n\\textit{\\textbf{", "}\n\\end{leftbar}\n"],
     },
 
     'html' =>
@@ -136,7 +139,8 @@ my $oRenderTag =
         'setting' => ['<span class="br-setting">', '</span>'], # ??? This will need to be fixed
         'backrest' => [undef, ''],
         'proper' => ['<span class="host">', '</span>'],
-        'postgres' => ['<span class="postgres">PostgreSQL</span>', '']
+        'postgres' => ['<span class="postgres">PostgreSQL</span>', ''],
+        'admonition' => ['<div class="admonition">', '</div>'],
     }
 };
 
@@ -219,7 +223,8 @@ sub new
 
             $self->{oDoc} =
                 (new BackRestDoc::Custom::DocCustomRelease(
-                    ${$self->{oManifest}->sourceGet('release')}{doc}, $self->{oManifest}->keywordMatch('dev')))->docGet();
+                    ${$self->{oManifest}->sourceGet('release')}{doc},
+                    defined($self->{oManifest}->variableGet('dev')) && $self->{oManifest}->variableGet('dev') eq 'y'))->docGet();
         }
         else
         {
@@ -306,10 +311,26 @@ sub variableGet
     return $self->{oManifest}->variableGet(shift);
 }
 
+####################################################################################################################################
+# Get pre-execute list for a host
+####################################################################################################################################
+sub preExecute
+{
+    my $self = shift;
+    my $strHost = shift;
+
+    if (defined($self->{preExecute}{$strHost}))
+    {
+        return @{$self->{preExecute}{$strHost}};
+    }
+
+    return;
+}
+
 ####################################################################################################################################
 # build
 #
-# Build the section map and perform keyword matching.
+# Build the section map and perform filtering.
 ####################################################################################################################################
 sub build
 {
@@ -325,7 +346,8 @@ sub build
 
     if (defined($oParent))
     {
-        if (!$self->{oManifest}->keywordMatch($oNode->paramGet('keyword', false)))
+        # Evaluate if condition -- when false the node will be removed
+        if (!$self->{oManifest}->evaluateIf($oNode))
         {
             my $strDescription;
 
@@ -337,6 +359,7 @@ sub build
             &log(DEBUG, "            filtered ${strName}" . (defined($strDescription) ? ": ${strDescription}" : ''));
 
             $oParent->nodeRemove($oNode);
+            return;
         }
     }
     else
@@ -527,6 +550,16 @@ sub build
             $iChildIdx++;
         }
     }
+    # Check for pre-execute statements
+    elsif ($strName eq 'execute')
+    {
+        if ($self->{oManifest}->{bPre} && $oNode->paramGet('pre', false, 'n') eq 'y')
+        {
+            # Add to pre-execute list
+            my $strHost = $self->variableReplace($oParent->paramGet('host'));
+            push(@{$self->{preExecute}{$strHost}}, $oNode);
+        }
+    }
 
     # Iterate all text nodes
     if (defined($oNode->textGet(false)))
@@ -548,7 +581,7 @@ sub build
             $self->build($oChild, $oNode, $strPath, $strPathPrefix);
 
             # If the child should be logged then log the parent as well so the hierarchy is complete
-            if ($oChild->nameGet() eq 'section' && $oChild->paramGet('log'))
+            if ($oChild->nameGet() eq 'section' && $oChild->paramGet('log', false, false))
             {
                 $oNode->paramSet('log', true);
             }
@@ -773,7 +806,15 @@ sub processTag
 
         $strBuffer .= $strStart;
 
-        if ($strTag eq 'p' || $strTag eq 'title' || $strTag eq 'li' || $strTag eq 'code-block' || $strTag eq 'summary')
+        # Admonitions in the reference materials are tags of the text element rather than field elements of the document so special
+        # handling is required
+        if ($strTag eq 'admonition')
+        {
+            $strBuffer .= $self->processAdmonitionStart($oTag);
+        }
+
+        if ($strTag eq 'p' || $strTag eq 'title' || $strTag eq 'li' || $strTag eq 'code-block' || $strTag eq 'summary'
+            || $strTag eq 'admonition')
         {
             $strBuffer .= $self->processText($oTag);
         }
@@ -789,6 +830,11 @@ sub processTag
             }
         }
 
+        if ($strTag eq 'admonition')
+        {
+            $strBuffer .= $self->processAdmonitionEnd($oTag);
+        }
+
         $strBuffer .= $strStop;
     }
 
@@ -800,6 +846,88 @@ sub processTag
     );
 }
 
+####################################################################################################################################
+# processAdmonitionStart
+####################################################################################################################################
+sub processAdmonitionStart
+{
+    my $self = shift;
+
+    # Assign function parameters, defaults, and log debug info
+    my
+    (
+        $strOperation,
+        $oTag
+    ) =
+        logDebugParam
+        (
+            __PACKAGE__ . '->processAdmonitionStart', \@_,
+            {name => 'oTag', trace => true}
+        );
+
+    my $strType = $self->{strType};
+    my $strBuffer = '';
+
+    # Note that any changes to the way the HTML, markdown or latex display tags may also need to be made here
+    if ($strType eq 'html')
+    {
+        my $strType = $oTag->paramGet('type');
+        $strBuffer = '<div class="' . $strType . '">' . uc($strType) . ':</div>' .
+            '<div class="' . $strType . '-text">';
+    }
+    elsif ($strType eq 'text' || $strType eq 'markdown')
+    {
+        $strBuffer = uc($oTag->paramGet('type')) . ": ";
+    }
+    elsif ($strType eq 'latex')
+    {
+        $strBuffer = uc($oTag->paramGet('type')) . ": }";
+    }
+
+    # Return from function and log return values if any
+    return logDebugReturn
+    (
+        $strOperation,
+        {name => 'strBuffer', value => $strBuffer, trace => true}
+    );
+}
+
+####################################################################################################################################
+# processAdmonitionEnd
+####################################################################################################################################
+sub processAdmonitionEnd
+{
+    my $self = shift;
+
+    # Assign function parameters, defaults, and log debug info
+    my
+    (
+        $strOperation,
+        $oTag
+    ) =
+        logDebugParam
+        (
+            __PACKAGE__ . '->processAdmonitionEnd', \@_,
+            {name => 'oTag', trace => true}
+        );
+
+    my $strType = $self->{strType};
+    my $strBuffer = '';
+
+    # Note that any changes to the way the HTML, markdown or latex display tags may also need to be made here
+    if ($strType eq 'html')
+    {
+        $strBuffer = '</div>';
+    }
+
+    # Return from function and log return values if any
+    return logDebugReturn
+    (
+        $strOperation,
+        {name => 'strBuffer', value => $strBuffer, trace => true}
+    );
+}
+
 ####################################################################################################################################
 # processText
 ####################################################################################################################################
@@ -861,6 +989,33 @@ sub processText
         $strBuffer =~ s/\<\=/\$\\leq\$/g;
         $strBuffer =~ s/\>\=/\$\\geq\$/g;
         # $strBuffer =~ s/\_/\\_/g;
+
+        # If not a code-block, which is to be taken AS IS, then escape special characters in latex
+        if ($oText->nameGet() ne 'code-block')
+        {
+            # If the previous character is not already a slash (e.g. not already escaped) then insert a slash
+            $strBuffer =~ s/(?<!\\)\#/\\#/g;
+            $strBuffer =~ s/(?<!\\)\%/\\%/g;
+            $strBuffer =~ s/(?<!\\)\_/\\_/g;
+            # $strBuffer =~ s/(?<!\\)\$/\\\$/g;
+
+            # Escape square brackest in list items since they are used for reformatting the bullet item with what is in brackets,
+            # which is not the intention.
+            if ($oText->nameGet() eq 'list-item')
+            {
+                $strBuffer =~ s/\[/\{\[/g;
+                $strBuffer =~ s/\]/\]\}/g;
+            }
+
+            $strBuffer =~ s/\&copy\;/{\\textcopyright}/g;
+            $strBuffer =~ s/\&trade\;/{\\texttrademark}/g;
+            $strBuffer =~ s/\&reg\;/{\\textregistered}/g;
+
+            $strBuffer =~ s/\&rarr\;/{\\textrightarrow}/g;
+
+            # Escape all ampersands after making any other conversions above
+            $strBuffer =~ s/(?<!\\)\&/\\&/g;
+        }
     }
 
     if ($strType eq 'text')
