@@ -83,6 +83,7 @@ sub process
 
     # Working variables
     my $oPage = $self->{oDoc};
+    my $oRender = $self->{oManifest}->renderGet(RENDER_TYPE_HTML);
 
     # Initialize page
     my $strTitle = $oPage->paramGet('title');
@@ -126,19 +127,11 @@ sub process
     {
         my $oMenuBody = $oHtmlBuilder->bodyGet()->addNew(HTML_DIV, 'page-menu')->addNew(HTML_DIV, 'menu-body');
 
-        if ($self->{strRenderOutKey} ne 'index' && defined($self->{oManifest}->renderOutGet(RENDER_TYPE_HTML, 'index', true)))
+        # Get the menu in the order listed in the manifest.xml
+        foreach my $strRenderOutKey (@{${$oRender}{stryOrder}})
         {
-            my $oRenderOut = $self->{oManifest}->renderOutGet(RENDER_TYPE_HTML, 'index');
-
-            $oMenuBody->
-                addNew(HTML_DIV, 'menu')->
-                    addNew(HTML_A, 'menu-link', {strContent => $$oRenderOut{menu}, strRef => '{[project-url-root]}'});
-        }
-
-        # ??? The sort order here is hokey and only works for backrest - will need to be changed
-        foreach my $strRenderOutKey (sort {$b cmp $a} $self->{oManifest}->renderOutList(RENDER_TYPE_HTML))
-        {
-            if ($strRenderOutKey ne $self->{strRenderOutKey} && $strRenderOutKey ne 'index')
+            # Do not output the menu item for the page the user is on (e.g. on Command page, the Command menu item will not appear)
+            if ($strRenderOutKey ne $self->{strRenderOutKey})
             {
                 my $oRenderOut = $self->{oManifest}->renderOutGet(RENDER_TYPE_HTML, $strRenderOutKey);
 
@@ -401,6 +394,68 @@ sub sectionProcess
             $oSectionBodyElement->addNew(
                 HTML_PRE, 'code-block', {strContent => $strValue, bPre => true});
         }
+        # Add table
+        elsif ($oChild->nameGet() eq 'table')
+        {
+            my $oTableTitle;
+            if ($oChild->nodeTest('title'))
+            {
+                $oTableTitle = $oChild->nodeGet('title');
+            }
+
+            my $oTableElement = $oSectionBodyElement->addNew(HTML_TABLE, 'table');
+            my @oyColumn;
+
+            # If there is a title element then add it as the caption for the table
+            if (defined($oTableTitle))
+            {
+                # Print the label (e.g. Table 1:) in front of the title if one exists
+                my $strTableTitle = $oTableTitle->paramTest('label') ?
+                    ($oTableTitle->paramGet('label') . ': '. $self->processText($oTableTitle->textGet())) :
+                    $self->processText($oTableTitle->textGet());
+
+                $oTableElement->addNew(HTML_TABLE_CAPTION, 'table-caption', {strContent => $strTableTitle});
+            }
+
+            # Build the header
+            if ($oChild->nodeTest('table-header'))
+            {
+                my $oHeader = $oChild->nodeGet('table-header');
+                @oyColumn = $oHeader->nodeList('table-column');
+
+                my $oHeaderRowElement = $oTableElement->addNew(HTML_TR, 'table-header-row');
+
+                foreach my $oColumn (@oyColumn)
+                {
+                    # Each column can have different alignment properties - if not set, then default to align left
+                    my $strAlign = $oColumn->paramGet("align", false, 'left');
+                    my $bFill = $oColumn->paramTest('fill', 'y');
+
+                    $oHeaderRowElement->addNew(
+                        HTML_TH,
+                        "table-header-${strAlign}" . ($bFill ? ",table-header-fill" : ""),
+                        {strContent => $self->processText($oColumn->textGet())});
+                }
+            }
+
+            # Build the rows
+            foreach my $oRow ($oChild->nodeGet('table-data')->nodeList('table-row'))
+            {
+                my $oRowElement = $oTableElement->addNew(HTML_TR, 'table-row');
+                my @oRowCellList = $oRow->nodeList('table-cell');
+
+                for (my $iRowCellIdx = 0; $iRowCellIdx < @oRowCellList; $iRowCellIdx++)
+                {
+                    my $oRowCell = $oRowCellList[$iRowCellIdx];
+
+                    # If a header row was defined, then get the column alignment, else default to left
+                    my $strAlign = @oyColumn > 0 ? $oyColumn[$iRowCellIdx]->paramGet("align", false, 'left') : 'left';
+
+                    $oRowElement->addNew(
+                        HTML_TD, "table-data-${strAlign}", {strContent => $self->processText($oRowCell->textGet())});
+                }
+            }
+        }
         # Add descriptive text
         elsif ($oChild->nameGet() eq 'p')
         {
@@ -497,6 +552,14 @@ sub sectionProcess
 
             $iSectionNo++;
         }
+        # Add an admonition (e.g. NOTE, WARNING, etc)
+        elsif ($oChild->nameGet() eq 'admonition')
+        {
+            my $oAdmonition = $oSectionBodyElement->addNew(HTML_DIV, 'admonition');
+            $oAdmonition->addNew(HTML_DIV, $oChild->paramGet('type'), {strContent => uc($oChild->paramGet('type')) . ": "});
+            $oAdmonition->addNew(HTML_DIV, $oChild->paramGet('type') . '-text',
+                {strContent => $self->processText($oChild->textGet())});
+        }
         # Check if the child can be processed by a parent
         else
         {
