@@ -90,7 +90,7 @@ eval
     # Display version and exit if requested
     if ($bHelp || $bVersion)
     {
-        print BACKREST_NAME . ' ' . BACKREST_VERSION . " Release Manager\n";
+        print PROJECT_NAME . ' ' . PROJECT_VERSION . " Release Manager\n";
 
         if ($bHelp)
         {
@@ -124,8 +124,8 @@ eval
         $strDocPath, new pgBackRest::Storage::Posix::Driver({bFileSync => false, bPathSync => false}));
 
     # Determine if this is a dev release
-    my $bDev = BACKREST_VERSION =~ /dev$/;
-    my $strVersion = $bDev ? 'dev' : BACKREST_VERSION;
+    my $bDev = PROJECT_VERSION =~ /dev$/;
+    my $strVersion = $bDev ? 'dev' : PROJECT_VERSION;
 
     if ($bBuild)
     {
@@ -135,11 +135,17 @@ eval
         # Remove all docker containers to get consistent IP address assignments
         executeTest('docker rm -f $(docker ps -a -q)', {bSuppressError => true});
 
+        # Generate deployment docs for RHEL/Centos 7
+        &log(INFO, "Generate RHEL/CentOS 7 documentation");
+
+        executeTest("${strDocExe} --deploy --key-var=os-type=centos7 --out=pdf", {bShowOutputAsync => true});
+        executeTest("${strDocExe} --deploy --cache-only --key-var=os-type=centos7 --out=pdf");
+
         # Generate deployment docs for RHEL/Centos 6
         &log(INFO, "Generate RHEL/CentOS 6 documentation");
 
-        executeTest("${strDocExe} --deploy --keyword=co6 --out=pdf", {bShowOutputAsync => true});
-        executeTest("${strDocExe} --deploy --cache-only --keyword=co6 --out=pdf --var=\"project-name=Crunchy BackRest\"");
+        executeTest("${strDocExe} --deploy --key-var=os-type=centos6 --out=pdf", {bShowOutputAsync => true});
+        executeTest("${strDocExe} --deploy --cache-only --key-var=os-type=centos6 --out=pdf");
 
         # Generate deployment docs for Debian
         &log(INFO, "Generate Debian/Ubuntu documentation");
@@ -157,7 +163,7 @@ eval
 
         executeTest(
             $strDocExe . ($bDev ? '' : ' --deploy --cache-only') . ' --out=html --var=project-url-root=index.html' .
-            ($bDev ? ' --keyword=default --keyword=dev --no-exe' :  ' --exclude=release'));
+            ($bDev ? ' --dev --no-exe' :  ' --exclude=release'));
 
         # Deploy to repository
         &log(INFO, '...Deploy to repository');
