@@ -125,6 +125,7 @@ sub lsnFileRange
         $strLsnStart,
         $strLsnStop,
         $strDbVersion,
+        $iWalSegmentSize,
     ) =
         logDebugParam
         (
@@ -132,6 +133,7 @@ sub lsnFileRange
             {name => 'strLsnStart'},
             {name => 'strLsnStop'},
             {name => '$strDbVersion'},
+            {name => '$iWalSegmentSize'},
         );
 
     # Working variables
@@ -142,11 +144,11 @@ sub lsnFileRange
     # Iterate through all archive logs between start and stop
     my @stryArchiveSplit = split('/', $strLsnStart);
     my $iStartMajor = hex($stryArchiveSplit[0]);
-    my $iStartMinor = hex(substr(sprintf("%08s", $stryArchiveSplit[1]), 0, 2));
+    my $iStartMinor = int(hex($stryArchiveSplit[1]) / $iWalSegmentSize);
 
     @stryArchiveSplit = split('/', $strLsnStop);
     my $iStopMajor = hex($stryArchiveSplit[0]);
-    my $iStopMinor = hex(substr(sprintf("%08s", $stryArchiveSplit[1]), 0, 2));
+    my $iStopMinor = int(hex($stryArchiveSplit[1]) / $iWalSegmentSize);
 
     $stryArchive[$iArchiveIdx] = uc(sprintf("%08x%08x", $iStartMajor, $iStartMinor));
     $iArchiveIdx += 1;
@@ -155,7 +157,7 @@ sub lsnFileRange
     {
         $iStartMinor += 1;
 
-        if ($bSkipFF && $iStartMinor == 255 || !$bSkipFF && $iStartMinor == 256)
+        if ($bSkipFF && $iStartMinor == 255 || !$bSkipFF && $iStartMinor > int(0xFFFFFFFF / $iWalSegmentSize))
         {
             $iStartMajor += 1;
             $iStartMinor = 0;
@@ -450,6 +452,7 @@ sub archiveAsyncStatusWrite
         $strWalFile,
         $iCode,
         $strMessage,
+        $bIgnoreErrorOnOk,
     ) =
         logDebugParam
         (
@@ -459,6 +462,7 @@ sub archiveAsyncStatusWrite
             {name => 'strWalFile'},
             {name => 'iCode', required => false},
             {name => 'strMessage', required => false},
+            {name => 'bIgnoreErrorOnOk', required => false, default => false},
         );
 
     # Remove any error file exists unless a new one will be written
@@ -468,25 +472,33 @@ sub archiveAsyncStatusWrite
         storageLocal()->remove("${strSpoolPath}/${strWalFile}.error", {bIgnoreMissing => true});
     }
 
-    # Write the status file
-    my $strStatus;
-
-    if (defined($iCode))
+    # If an error will be written but an ok file already exists this may be expected and will be indicated by bIgnoreErrorOnOk set
+    # to true.  In this case just return without writing the error file.
+    if (!($strType eq WAL_STATUS_ERROR && $bIgnoreErrorOnOk && storageLocal()->exists("${strSpoolPath}/${strWalFile}.ok")))
     {
-        if (!defined($strMessage))
+        # Write the status file
+        my $strStatus;
+
+        if (defined($iCode))
         {
-            confess &log(ASSERT, 'strMessage must be set when iCode is set');
+            if (!defined($strMessage))
+            {
+                confess &log(ASSERT, 'strMessage must be set when iCode is set');
+            }
+
+            $strStatus = "${iCode}\n${strMessage}";
+        }
+        elsif ($strType eq WAL_STATUS_ERROR)
+        {
+            confess &log(ASSERT, 'error status must have iCode and strMessage set');
         }
 
-        $strStatus = "${iCode}\n${strMessage}";
-    }
-    elsif ($strType eq WAL_STATUS_ERROR)
-    {
-        confess &log(ASSERT, 'error status must have iCode and strMessage set');
+        storageLocal()->put(
+            storageLocal()->openWrite("${strSpoolPath}/${strWalFile}.${strType}", {bAtomic => true}), $strStatus);
     }
 
-    storageLocal()->put(
-        storageLocal()->openWrite("${strSpoolPath}/${strWalFile}.${strType}", {bAtomic => true}), $strStatus);
+    # Return from function and log return values if any
+    return logDebugReturn($strOperation);
 }
 
 push @EXPORT, qw(archiveAsyncStatusWrite);
