@@ -67,7 +67,7 @@ sub process
         (new pgBackRest::Archive::Get::Async(
             storageSpool()->pathGet(STORAGE_SPOOL_ARCHIVE_IN), $self->{strBackRestBin}, $rstryCommandArg))->process();
     }
-    # Else push synchronously
+    # Else get synchronously
     else
     {
         # Make sure the archive file is defined
@@ -75,7 +75,7 @@ sub process
 
         if (!defined($strSourceArchive))
         {
-            confess &log(ERROR, 'WAL segment not provided', ERROR_PARAM_REQUIRED);
+            confess &log(ERROR, 'WAL segment not provided', ERROR_ASSERT);
         }
 
         # Make sure the destination file is defined
@@ -83,13 +83,10 @@ sub process
 
         if (!defined($strDestinationFile))
         {
-            confess &log(ERROR, 'WAL segment destination not provided', ERROR_PARAM_REQUIRED);
+            confess &log(ERROR, 'WAL segment destination not provided', ERROR_ASSERT);
         }
 
         $iResult = archiveGetFile($strSourceArchive, $strDestinationFile, false);
-
-        # Info for the Postgres log
-        &log(INFO, 'got WAL segment ' . $strSourceArchive);
     }
 
     # Return from function and log return values if any
