@@ -119,7 +119,7 @@ sub new
                 confess &log(ERROR, $strArchiveInfoMissingMsg, ERROR_FILE_MISSING);
             }
         }
-        elsif ($iResult == ERROR_CIPHER && $strResultMessage =~ "^unable to flush")
+        elsif ($iResult == ERROR_CRYPTO && $strResultMessage =~ "^unable to flush")
         {
             confess &log(ERROR, "unable to parse '$strArchiveInfoFile'\nHINT: Is or was the repo encrypted?", $iResult);
         }
@@ -285,7 +285,9 @@ sub archiveIdList
     # If the archive id has still not been found, then error
     if (@stryArchiveId == 0)
     {
-        confess &log(ERROR, "unable to retrieve the archive id for database version '$strDbVersion' and system-id '$ullDbSysId'");
+        confess &log(
+            ERROR, "unable to retrieve the archive id for database version '$strDbVersion' and system-id '$ullDbSysId'",
+            ERROR_ARCHIVE_MISMATCH);
     }
 
     # Return from function and log return values if any
@@ -414,7 +416,7 @@ sub reconstruct
         if (!storageRepo()->encryptionValid(storageRepo()->encrypted($strArchiveFilePath)))
         {
             confess &log(ERROR, "encryption incompatible for '$strArchiveFilePath'" .
-                "\nHINT: Is or was the repo encrypted?", ERROR_CIPHER);
+                "\nHINT: Is or was the repo encrypted?", ERROR_CRYPTO);
         }
 
         # If the file is encrypted, then the passprase from the info file is required, else getEncryptionKeySub returns undefined
