@@ -72,7 +72,11 @@ sub resumeClean
         $oStorageRepo,
         $strBackupLabel,
         $oManifest,
-        $oAbortedManifest
+        $oAbortedManifest,
+        $bOnline,
+        $bDelta,
+        $strTimelineCurrent,
+        $strTimelineLast,
     ) =
         logDebugParam
         (
@@ -80,7 +84,11 @@ sub resumeClean
             {name => 'oStorageRepo'},
             {name => 'strBackupLabel'},
             {name => 'oManifest'},
-            {name => 'oAbortedManifest'}
+            {name => 'oAbortedManifest'},
+            {name => 'bOnline'},
+            {name => 'bDelta'},
+            {name => 'strTimelineCurrent', required => false},
+            {name => 'strTimelineLast', required => false},
         );
 
     &log(DETAIL, 'clean resumed backup path: ' . $oStorageRepo->pathGet(STORAGE_REPO_BACKUP . "/${strBackupLabel}"));
@@ -91,6 +99,56 @@ sub resumeClean
     # Get compress flag
     my $bCompressed = $oAbortedManifest->boolGet(MANIFEST_SECTION_BACKUP_OPTION, MANIFEST_KEY_COMPRESS);
 
+    if (!$bDelta)
+    {
+        # Check to see if delta checksum should be enabled
+        $bDelta = $oAbortedManifest->checkDelta(
+            'resumed', $oAbortedManifest->boolTest(MANIFEST_SECTION_BACKUP_OPTION, MANIFEST_KEY_ONLINE, undef, $bOnline),
+            $strTimelineCurrent, $strTimelineLast);
+
+        # If delta is still false, check the files for anomalies
+        if (!$bDelta)
+        {
+            my @stryFileList = ();
+
+            foreach my $strName (sort(keys(%{$hFile})))
+            {
+                # Ignore files that will never be in the manifest but should be preserved
+                if ($strName eq FILE_MANIFEST_COPY ||
+                    $strName eq '.')
+                {
+                    next;
+                }
+
+                if ($hFile->{$strName}{type} eq 'f')
+                {
+                    # If the original backup was compressed then remove the extension before checking the manifest
+                    my $strFile = $strName;
+
+                    if ($bCompressed)
+                    {
+                        $strFile = substr($strFile, 0, length($strFile) - 3);
+                    }
+
+                    # To be preserved the file must exist in the new manifest and not be a reference to a previous backup and must
+                    # have a checksum
+                    if ($oManifest->test(MANIFEST_SECTION_TARGET_FILE, $strFile) &&
+                        !$oManifest->test(MANIFEST_SECTION_TARGET_FILE, $strFile, MANIFEST_SUBKEY_REFERENCE) &&
+                        $oAbortedManifest->test(MANIFEST_SECTION_TARGET_FILE, $strFile, MANIFEST_SUBKEY_CHECKSUM))
+                    {
+                        push(@stryFileList, $strFile);
+                    }
+                }
+            }
+
+            # If there are files in the list then check if delta should be enabled
+            if (@stryFileList)
+            {
+                $bDelta = $oManifest->checkDeltaFile(\@stryFileList, $oAbortedManifest, undef);
+            }
+        }
+    }
+
     # Find paths and files to delete
     my @stryFile;
 
@@ -117,7 +175,7 @@ sub resumeClean
         # Else if a file
         elsif ($cType eq 'f')
         {
-            # If the original backup was compressed the remove the extension before checking the manifest
+            # If the original backup was compressed then remove the extension before checking the manifest
             my $strFile = $strName;
 
             if ($bCompressed)
@@ -132,11 +190,16 @@ sub resumeClean
                 # To be preserved the checksum must be defined
                 my $strChecksum = $oAbortedManifest->get(MANIFEST_SECTION_TARGET_FILE, $strFile, MANIFEST_SUBKEY_CHECKSUM, false);
 
+                # If the size and timestamp match OR if the size matches and the delta option is set, then keep the file.
+                # In the latter case, if the timestamp had changed then rather than removing and recopying the file, the file
+                # will be tested in backupFile to see if the db/repo checksum still matches: if so, it is not necessary to recopy,
+                # else it will need to be copied to the new backup.
                 if (defined($strChecksum) &&
-                    $oManifest->get(MANIFEST_SECTION_TARGET_FILE, $strFile, MANIFEST_SUBKEY_TIMESTAMP) ==
-                    $oAbortedManifest->get(MANIFEST_SECTION_TARGET_FILE, $strFile, MANIFEST_SUBKEY_TIMESTAMP) &&
                     $oManifest->get(MANIFEST_SECTION_TARGET_FILE, $strFile, MANIFEST_SUBKEY_SIZE) ==
-                    $oAbortedManifest->get(MANIFEST_SECTION_TARGET_FILE, $strFile, MANIFEST_SUBKEY_SIZE))
+                    $oAbortedManifest->get(MANIFEST_SECTION_TARGET_FILE, $strFile, MANIFEST_SUBKEY_SIZE)  &&
+                    ($bDelta ||
+                    $oManifest->get(MANIFEST_SECTION_TARGET_FILE, $strFile, MANIFEST_SUBKEY_TIMESTAMP) ==
+                    $oAbortedManifest->get(MANIFEST_SECTION_TARGET_FILE, $strFile, MANIFEST_SUBKEY_TIMESTAMP)))
                 {
                     $oManifest->set(MANIFEST_SECTION_TARGET_FILE, $strFile, MANIFEST_SUBKEY_CHECKSUM, $strChecksum);
 
@@ -184,7 +247,11 @@ sub resumeClean
     }
 
     # Return from function and log return values if any
-    return logDebugReturn($strOperation);
+    return logDebugReturn
+    (
+        $strOperation,
+        {name => 'bDelta', value => $bDelta, trace => true},
+    );
 }
 
 ####################################################################################################################################
@@ -281,34 +348,24 @@ sub processManifest
 
     # Iterate all files in the manifest
     foreach my $strRepoFile (
-        sort {sprintf("%016d-${b}", $oBackupManifest->numericGet(MANIFEST_SECTION_TARGET_FILE, $b, MANIFEST_SUBKEY_SIZE)) cmp
-              sprintf("%016d-${a}", $oBackupManifest->numericGet(MANIFEST_SECTION_TARGET_FILE, $a, MANIFEST_SUBKEY_SIZE))}
+        sort {sprintf("%016d-%s", $oBackupManifest->numericGet(MANIFEST_SECTION_TARGET_FILE, $b, MANIFEST_SUBKEY_SIZE), $b) cmp
+              sprintf("%016d-%s", $oBackupManifest->numericGet(MANIFEST_SECTION_TARGET_FILE, $a, MANIFEST_SUBKEY_SIZE), $a)}
         ($oBackupManifest->keys(MANIFEST_SECTION_TARGET_FILE, INI_SORT_NONE)))
     {
-        # If the file has a reference it does not need to be copied since it can be retrieved from the referenced backup.
-        # However, if hard-linking is turned on the link will need to be created
+        # If the file has a reference it does not need to be copied since it can be retrieved from the referenced backup - unless
+        # the option to checksum all files is set.  However, if hardlinking is enabled the link will need to be created
         my $strReference = $oBackupManifest->get(MANIFEST_SECTION_TARGET_FILE, $strRepoFile, MANIFEST_SUBKEY_REFERENCE, false);
 
         if (defined($strReference))
         {
-            # If hardlinking is turned on then create a hardlink for files that have not changed since the last backup
-            if ($bHardLink)
+            # If the delta option to checksum all files is not set or it is set and the file size of the referenced file is zero
+            # then skip checking/copying this file
+            if (!cfgOption(CFGOPT_DELTA) ||
+                $oBackupManifest->numericGet(MANIFEST_SECTION_TARGET_FILE, $strRepoFile, MANIFEST_SUBKEY_SIZE) == 0)
             {
-                &log(DETAIL, "hardlink ${strRepoFile} to ${strReference}");
-
-                storageRepo()->linkCreate(
-                    STORAGE_REPO_BACKUP . "/${strReference}/${strRepoFile}" . ($bCompress ? qw{.} . COMPRESS_EXT : ''),
-                    STORAGE_REPO_BACKUP . "/${strBackupLabel}/${strRepoFile}" . ($bCompress ? qw{.} . COMPRESS_EXT : ''),
-                    {bHard => true});
+                # This file will not need to be copied
+                next;
             }
-            # Else log the reference
-            else
-            {
-                logDebugMisc($strOperation, "reference ${strRepoFile} to ${strReference}");
-            }
-
-            # This file will not need to be copied
-            next;
         }
 
         # By default put everything into a single queue
@@ -352,7 +409,8 @@ sub processManifest
                 cfgOption(CFGOPT_CHECKSUM_PAGE) ? isChecksumPage($strRepoFile) : false, $strBackupLabel, $bCompress,
                 cfgOption(CFGOPT_COMPRESS_LEVEL), $oBackupManifest->numericGet(MANIFEST_SECTION_TARGET_FILE, $strRepoFile,
                 MANIFEST_SUBKEY_TIMESTAMP, false), $bIgnoreMissing,
-                cfgOption(CFGOPT_CHECKSUM_PAGE) && isChecksumPage($strRepoFile) ? $hStartLsnParam : undef],
+                cfgOption(CFGOPT_CHECKSUM_PAGE) && isChecksumPage($strRepoFile) ? $hStartLsnParam : undef,
+                cfgOption(CFGOPT_DELTA), defined($strReference) ? true : false],
             {rParamSecure => $oBackupManifest->cipherPassSub() ? [$oBackupManifest->cipherPassSub()] : undef});
 
         # Size and checksum will be removed and then verified later as a sanity check
@@ -403,6 +461,33 @@ sub processManifest
         protocolKeepAlive();
     }
 
+    foreach my $strFile ($oBackupManifest->keys(MANIFEST_SECTION_TARGET_FILE))
+    {
+        # If the file has a reference, then it was not copied since it can be retrieved from the referenced backup. However, if
+        # hardlinking is enabled the link will need to be created.
+        my $strReference = $oBackupManifest->get(MANIFEST_SECTION_TARGET_FILE, $strFile, MANIFEST_SUBKEY_REFERENCE, false);
+
+        if ($strReference)
+        {
+            # If hardlinking is enabled then create a hardlink for files that have not changed since the last backup
+            if ($bHardLink)
+            {
+                &log(DETAIL, "hardlink ${strFile} to ${strReference}");
+
+                storageRepo()->linkCreate(
+                    STORAGE_REPO_BACKUP . "/${strReference}/${strFile}" . ($bCompress ? qw{.} . COMPRESS_EXT : ''),
+                    STORAGE_REPO_BACKUP . "/${strBackupLabel}/${strFile}" . ($bCompress ? qw{.} . COMPRESS_EXT : ''),
+                    {bHard => true});
+            }
+            # Else log the reference. With delta, it is possible that references may have been removed if a file needed to be
+            # recopied.
+            else
+            {
+                logDebugMisc($strOperation, "reference ${strFile} to ${strReference}");
+            }
+        }
+    }
+
     # Validate the manifest
     $oBackupManifest->validate();
 
@@ -481,6 +566,7 @@ sub process
     # Find the previous backup based on the type
     my $oLastManifest;
     my $strBackupLastPath;
+    my $strTimelineLast;
 
     if ($strType ne CFGOPTVAL_BACKUP_TYPE_FULL)
     {
@@ -497,6 +583,12 @@ sub process
             # If the repo is encrypted then use the passphrase in this manifest for the backup set
             $strCipherPassBackupSet = $oLastManifest->cipherPassSub();
 
+            # Get archive segment timeline for determining if a timeline switch has occurred. Only defined for prior online backup.
+            if ($oLastManifest->test(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_ARCHIVE_STOP))
+            {
+                $strTimelineLast = substr($oLastManifest->get(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_ARCHIVE_STOP), 0, 8);
+            }
+
             &log(INFO, 'last backup label = ' . $oLastManifest->get(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_LABEL) .
                        ', version = ' . $oLastManifest->get(INI_SECTION_BACKREST, INI_KEY_VERSION));
 
@@ -531,6 +623,7 @@ sub process
     my $strBackupLabel;
     my $oAbortedManifest;
     my $strBackupPath;
+    my $strTimelineAborted;
 
     foreach my $strAbortedBackup ($oStorageRepo->list(
         STORAGE_REPO_BACKUP, {strExpression => backupRegExpGet(true, true, true), strSortOrder => 'reverse'}))
@@ -561,17 +654,17 @@ sub process
                     my $strValueAborted;
 
                     # Check version
-                    if ($oAbortedManifest->get(INI_SECTION_BACKREST, INI_KEY_VERSION) ne BACKREST_VERSION)
+                    if ($oAbortedManifest->get(INI_SECTION_BACKREST, INI_KEY_VERSION) ne PROJECT_VERSION)
                     {
                         $strKey =  INI_KEY_VERSION;
-                        $strValueNew = BACKREST_VERSION;
+                        $strValueNew = PROJECT_VERSION;
                         $strValueAborted = $oAbortedManifest->get(INI_SECTION_BACKREST, INI_KEY_VERSION);
                     }
                     # Check format
-                    elsif ($oAbortedManifest->get(INI_SECTION_BACKREST, INI_KEY_FORMAT) ne BACKREST_FORMAT)
+                    elsif ($oAbortedManifest->get(INI_SECTION_BACKREST, INI_KEY_FORMAT) ne REPOSITORY_FORMAT)
                     {
                         $strKey =  INI_KEY_FORMAT;
-                        $strValueNew = BACKREST_FORMAT;
+                        $strValueNew = REPOSITORY_FORMAT;
                         $strValueAborted = $oAbortedManifest->get(INI_SECTION_BACKREST, INI_KEY_FORMAT);
                     }
                     # Check backup type
@@ -636,6 +729,17 @@ sub process
                 {
                     $strCipherPassBackupSet = $oAbortedManifest->cipherPassSub();
                 }
+
+                # Get the archive segment timeline for determining if a timeline switch has occurred. Only defined for prior online
+                # backup.
+                if ($oAbortedManifest->test(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_ARCHIVE_STOP))
+                {
+                    $strTimelineAborted = substr($oAbortedManifest->get(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_ARCHIVE_STOP), 0, 8);
+                }
+                elsif ($oAbortedManifest->test(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_ARCHIVE_START))
+                {
+                    $strTimelineAborted = substr($oAbortedManifest->get(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_ARCHIVE_START), 0, 8);
+                }
             }
             else
             {
@@ -667,7 +771,7 @@ sub process
     # Instead just instantiate it. Pass the passphrases to open the manifest and one to encrypt the backup files if the repo is
     # encrypted (undefined if not).
     my $oBackupManifest = new pgBackRest::Manifest("$strBackupPath/" . FILE_MANIFEST,
-        {bLoad => false, strDbVersion => $strDbVersion,
+        {bLoad => false, strDbVersion => $strDbVersion, iDbCatalogVersion => $iCatalogVersion,
         strCipherPass => defined($strCipherPassManifest) ? $strCipherPassManifest : undef,
         strCipherPassSub => defined($strCipherPassManifest) ? $strCipherPassBackupSet : undef});
 
@@ -687,7 +791,6 @@ sub process
     # Database settings
     $oBackupManifest->numericSet(MANIFEST_SECTION_BACKUP_DB, MANIFEST_KEY_DB_ID, undef, $iDbHistoryId);
     $oBackupManifest->numericSet(MANIFEST_SECTION_BACKUP_DB, MANIFEST_KEY_CONTROL, undef, $iControlVersion);
-    $oBackupManifest->numericSet(MANIFEST_SECTION_BACKUP_DB, MANIFEST_KEY_CATALOG, undef, $iCatalogVersion);
     $oBackupManifest->numericSet(MANIFEST_SECTION_BACKUP_DB, MANIFEST_KEY_SYSTEM_ID, undef, $ullDbSysId);
 
     # Backup from standby can only be used on PostgreSQL >= 9.1
@@ -701,8 +804,10 @@ sub process
     # Start backup (unless --no-online is set)
     my $strArchiveStart = undef;
     my $strLsnStart = undef;
+    my $iWalSegmentSize = undef;
     my $hTablespaceMap = undef;
-	my $hDatabaseMap = undef;
+    my $hDatabaseMap = undef;
+    my $strTimelineCurrent = undef;
 
     # If this is an offline backup
     if (!cfgOption(CFGOPT_ONLINE))
@@ -735,15 +840,18 @@ sub process
     else
     {
         # Start the backup
-        ($strArchiveStart, $strLsnStart) =
+        ($strArchiveStart, $strLsnStart, $iWalSegmentSize) =
             $oDbMaster->backupStart(
-                BACKREST_NAME . ' backup started at ' . timestampFormat(undef, $lTimestampStart), cfgOption(CFGOPT_START_FAST));
+                PROJECT_NAME . ' backup started at ' . timestampFormat(undef, $lTimestampStart), cfgOption(CFGOPT_START_FAST));
 
         # Record the archive start location
         $oBackupManifest->set(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_ARCHIVE_START, undef, $strArchiveStart);
         $oBackupManifest->set(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_LSN_START, undef, $strLsnStart);
         &log(INFO, "backup start archive = ${strArchiveStart}, lsn = ${strLsnStart}");
 
+        # Get the timeline from the archive
+        $strTimelineCurrent = substr($strArchiveStart, 0, 8);
+
         # Get tablespace map
         $hTablespaceMap = $oDbMaster->tablespaceMapGet();
 
@@ -802,9 +910,11 @@ sub process
     # Record checksum-page option in the manifest
     $oBackupManifest->boolSet(MANIFEST_SECTION_BACKUP_OPTION, MANIFEST_KEY_CHECKSUM_PAGE, undef, cfgOption(CFGOPT_CHECKSUM_PAGE));
 
-    # Build the manifest
-    $oBackupManifest->build($oStorageDbMaster, $strDbMasterPath, $oLastManifest, cfgOption(CFGOPT_ONLINE),
-                            $hTablespaceMap, $hDatabaseMap);
+    # Build the manifest. The delta option may have changed from false to true during the manifest build so set it to the result.
+    cfgOptionSet(CFGOPT_DELTA, $oBackupManifest->build(
+        $oStorageDbMaster, $strDbMasterPath, $oLastManifest, cfgOption(CFGOPT_ONLINE), cfgOption(CFGOPT_DELTA), $hTablespaceMap,
+        $hDatabaseMap, cfgOption(CFGOPT_EXCLUDE, false), $strTimelineCurrent, $strTimelineLast));
+
     &log(TEST, TEST_MANIFEST_BUILD);
 
     # If resuming from an aborted backup
@@ -813,8 +923,10 @@ sub process
         &log(WARN, "aborted backup ${strBackupLabel} of same type exists, will be cleaned to remove invalid files and resumed");
         &log(TEST, TEST_BACKUP_RESUME);
 
-        # Clean the backup path before resuming
-        $self->resumeClean($oStorageRepo, $strBackupLabel, $oBackupManifest, $oAbortedManifest);
+        # Clean the backup path before resuming. The delta option may have changed from false to true during the reseume clean
+        # so set it to the result.
+        cfgOptionSet(CFGOPT_DELTA, $self->resumeClean($oStorageRepo, $strBackupLabel, $oBackupManifest, $oAbortedManifest,
+            cfgOption(CFGOPT_ONLINE), cfgOption(CFGOPT_DELTA), $strTimelineCurrent, $strTimelineAborted));
     }
     # Else create the backup path
     else
@@ -823,6 +935,9 @@ sub process
         $oStorageRepo->pathCreate(STORAGE_REPO_BACKUP . "/${strBackupLabel}");
     }
 
+    # Set the delta option in the manifest
+    $oBackupManifest->boolSet(MANIFEST_SECTION_BACKUP_OPTION, MANIFEST_KEY_DELTA, undef, cfgOption(CFGOPT_DELTA));
+
     # Save the backup manifest
     $oBackupManifest->saveCopy();
 
@@ -903,7 +1018,7 @@ sub process
 
         my $oArchiveInfo = new pgBackRest::Archive::Info(storageRepo()->pathGet(STORAGE_REPO_ARCHIVE), true);
         my $strArchiveId = $oArchiveInfo->archiveId();
-        my @stryArchive = lsnFileRange($strLsnStart, $strLsnStop, $strDbVersion);
+        my @stryArchive = lsnFileRange($strLsnStart, $strLsnStop, $strDbVersion, $iWalSegmentSize);
 
         foreach my $strArchive (@stryArchive)
         {
