@@ -87,19 +87,17 @@ sub process
                 # Passing file location dev/null so that the save will fail if it is ever attempted. Pass a miscellaneus value for
                 # encryption key since the file will not be saved.
                 my $oBackupManifest = new pgBackRest::Manifest("/dev/null/manifest.chk",
-                    {bLoad => false, strDbVersion => $strDbVersion,
-                    strCipherPass => 'x',
-                    strCipherPassSub => 'x'});
+                    {bLoad => false, strDbVersion => $strDbVersion, iDbCatalogVersion => $iCatalogVersion,
+                    strCipherPass => 'x', strCipherPassSub => 'x'});
 
                 # Set required settings not set during manifest instantiation
                 $oBackupManifest->numericSet(MANIFEST_SECTION_BACKUP_DB, MANIFEST_KEY_DB_ID, undef, 1);
                 $oBackupManifest->numericSet(MANIFEST_SECTION_BACKUP_DB, MANIFEST_KEY_CONTROL, undef, $iControlVersion);
-                $oBackupManifest->numericSet(MANIFEST_SECTION_BACKUP_DB, MANIFEST_KEY_CATALOG, undef, $iCatalogVersion);
                 $oBackupManifest->numericSet(MANIFEST_SECTION_BACKUP_DB, MANIFEST_KEY_SYSTEM_ID, undef, $ullDbSysId);
 
-                $oBackupManifest->build(storageDb({iRemoteIdx => $iRemoteIdx}),
-                    cfgOption(cfgOptionIdFromIndex(CFGOPT_PG_PATH, $iRemoteIdx)), undef, cfgOption(CFGOPT_ONLINE),
-                    $oDb->tablespaceMapGet());
+                $oBackupManifest->build(
+                    storageDb({iRemoteIdx => $iRemoteIdx}), cfgOption(cfgOptionIdFromIndex(CFGOPT_PG_PATH, $iRemoteIdx)), undef,
+                    cfgOptionValid(CFGOPT_ONLINE) && cfgOption(CFGOPT_ONLINE), false, $oDb->tablespaceMapGet());
 
                 return true;
             }
