@@ -56,7 +56,7 @@ sub new
     $self->{lSize} = 0;
 
     # Initialize EOF to false
-    $self->{bEOF} = false;
+    $self->eofSet(false);
 
     # Return from function and log return values if any
     return logDebugReturn
@@ -77,6 +77,17 @@ sub eof
     return shift->{bEOF};
 }
 
+####################################################################################################################################
+# eofSet - set eof
+####################################################################################################################################
+sub eofSet
+{
+    my $self = shift;
+    my $bEOF = shift;
+
+    $self->{bEOF} = $bEOF;
+}
+
 ####################################################################################################################################
 # read - read data from handle
 ####################################################################################################################################
@@ -108,7 +119,7 @@ sub read
     $self->{lSize} += $iActualSize;
 
     # Update EOF
-    $self->{bEOF} = $iActualSize == 0 ? true : false;
+    $self->eofSet($iActualSize == 0 ? true : false);
 
     return $iActualSize;
 }
