@@ -25,6 +25,13 @@ use pgBackRest::Protocol::Helper;
 use pgBackRest::Protocol::Storage::Helper;
 use pgBackRest::Version;
 
+####################################################################################################################################
+# PostgreSQL 8.3 WAL size
+#
+# WAL segment size in 8.3 cannot be determined from pg_control, so use this constant instead.
+####################################################################################################################################
+use constant PG_WAL_SIZE_83                                         => 16777216;
+
 ####################################################################################################################################
 # Backup advisory lock
 ####################################################################################################################################
@@ -65,7 +72,7 @@ my $oPgControlVersionHash =
     },
     1100 =>
     {
-        201806231 => PG_VERSION_11,
+        201809051 => PG_VERSION_11,
     },
 };
 
@@ -212,7 +219,7 @@ sub connect
                 {
                     # Set application name for monitoring and debugging
                     $self->{hDb}->do(
-                        "set application_name = '" . BACKREST_NAME . ' [' .
+                        "set application_name = '" . PROJECT_NAME . ' [' .
                         (cfgOptionValid(CFGOPT_COMMAND) ? cfgOption(CFGOPT_COMMAND) : cfgCommandName(cfgCommandGet())) . "]'")
                         or confess &log(ERROR, $self->{hDb}->errstr, ERROR_DB_QUERY);
 
@@ -566,7 +573,7 @@ sub versionGet
     }
 
     # Get version and pg-path from
-    (my $strVersionNum, $self->{strDbPath}) =
+    my ($strVersionNum, $strDbPath) =
         $self->executeSqlRow(
             "select (select setting from pg_settings where name = 'server_version_num'), " .
                 " (select setting from pg_settings where name = 'data_directory')");
@@ -593,7 +600,7 @@ sub versionGet
     (
         $strOperation,
         {name => 'strDbVersion', value => $self->{strDbVersion}},
-        {name => 'strDbPath', value => $self->{strDbPath}}
+        {name => 'strDbPath', value => $strDbPath}
     );
 }
 
@@ -648,8 +655,8 @@ sub backupStart
     # database cluster.  This lock helps make the stop-auto option safe.
     if (!$self->executeSqlOne('select pg_try_advisory_lock(' . DB_BACKUP_ADVISORY_LOCK . ')'))
     {
-        confess &log(ERROR, 'unable to acquire ' . BACKREST_NAME . " advisory lock\n" .
-                            'HINT: is another ' . BACKREST_NAME . ' backup already running on this cluster?', ERROR_LOCK_ACQUIRE);
+        confess &log(ERROR, 'unable to acquire ' . PROJECT_NAME . " advisory lock\n" .
+                            'HINT: is another ' . PROJECT_NAME . ' backup already running on this cluster?', ERROR_LOCK_ACQUIRE);
     }
 
     # If stop-auto is enabled check for a running backup.  This feature is not supported for PostgreSQL >= 9.6 since backups are
@@ -662,7 +669,7 @@ sub backupStart
             # If a backup is currently in progress emit a warning and then stop it
             if ($self->executeSqlOne('select pg_is_in_backup()'))
             {
-                &log(WARN, 'the cluster is already in backup mode but no ' . BACKREST_NAME . ' backup process is running.' .
+                &log(WARN, 'the cluster is already in backup mode but no ' . PROJECT_NAME . ' backup process is running.' .
                            ' pg_stop_backup() will be called so a new backup can be started.');
                 $self->backupStop();
             }
@@ -680,8 +687,13 @@ sub backupStart
                "exclusive pg_start_backup() with label \"${strLabel}\": backup begins after " .
                ($bStartFast ? "the requested immediate checkpoint" : "the next regular checkpoint") . " completes");
 
-    my ($strTimestampDbStart, $strArchiveStart, $strLsnStart) = $self->executeSqlRow(
-        "select to_char(current_timestamp, 'YYYY-MM-DD HH24:MI:SS.US TZ'), pg_" . $self->walId() . "file_name(lsn), lsn::text" .
+    my ($strTimestampDbStart, $strArchiveStart, $strLsnStart, $iWalSegmentSize) = $self->executeSqlRow(
+        "select to_char(current_timestamp, 'YYYY-MM-DD HH24:MI:SS.US TZ'), pg_" . $self->walId() . "file_name(lsn), lsn::text," .
+            ($self->{strDbVersion} < PG_VERSION_84 ? PG_WAL_SIZE_83 :
+                " (select setting::int8 from pg_settings where name = 'wal_segment_size')" .
+                # In Pre-11 versions the wal_segment_sise was expressed in terms of blocks rather than total size
+                ($self->{strDbVersion} < PG_VERSION_11 ?
+                    " * (select setting::int8 from pg_settings where name = 'wal_block_size')" : '')) .
             " from pg_start_backup('${strLabel}'" .
             ($bStartFast ? ', true' : $self->{strDbVersion} >= PG_VERSION_84 ? ', false' : '') .
             ($self->{strDbVersion} >= PG_VERSION_96 ? ', false' : '') . ') as lsn');
@@ -692,6 +704,7 @@ sub backupStart
         $strOperation,
         {name => 'strArchiveStart', value => $strArchiveStart},
         {name => 'strLsnStart', value => $strLsnStart},
+        {name => 'iWalSegmentSize', value => $iWalSegmentSize},
         {name => 'strTimestampDbStart', value => $strTimestampDbStart}
     );
 }
@@ -799,11 +812,11 @@ sub configValidate
         # Check if archive_command is set
         my $strArchiveCommand = $self->executeSqlOne('show archive_command');
 
-        if (index($strArchiveCommand, BACKREST_EXE) == -1)
+        if (index($strArchiveCommand, PROJECT_EXE) == -1)
         {
             confess &log(ERROR,
                 'archive_command ' . (defined($strArchiveCommand) ? "'${strArchiveCommand}'" : '[null]') . ' must contain \'' .
-                BACKREST_EXE . '\'', ERROR_ARCHIVE_COMMAND_INVALID);
+                PROJECT_EXE . '\'', ERROR_ARCHIVE_COMMAND_INVALID);
         }
     }
 
@@ -853,7 +866,7 @@ sub walSwitch
     # the user if there have been no writes since the last WAL switch.
     if ($self->{strDbVersion} >= PG_VERSION_91)
     {
-        $self->executeSql("select pg_create_restore_point('" . BACKREST_NAME . " Archive Check');");
+        $self->executeSql("select pg_create_restore_point('" . PROJECT_NAME . " Archive Check');");
     }
 
     my $strWalFileName = $self->executeSqlOne(
