@@ -18,6 +18,7 @@ use pgBackRest::Common::Lock;
 use pgBackRest::Common::Log;
 use pgBackRest::Config::Config;
 use pgBackRest::Protocol::Helper;
+use pgBackRest::Storage::Helper;
 use pgBackRest::Version;
 
 ####################################################################################################################################
@@ -43,8 +44,9 @@ sub main
 
     # Run in eval block to catch errors
     # ------------------------------------------------------------------------------------------------------------------------------
-    my $result = 0;
-    my $message = '';
+    my $iResult = 0;
+    my $bErrorC = false;
+    my $strMessage = '';
 
     eval
     {
@@ -86,7 +88,7 @@ sub main
             require pgBackRest::Archive::Get::Get;
             pgBackRest::Archive::Get::Get->import();
 
-            $result = new pgBackRest::Archive::Get::Get()->process(\@stryCommandArg);
+            $iResult = new pgBackRest::Archive::Get::Get()->process(\@stryCommandArg);
         }
 
         # Process remote command
@@ -95,7 +97,13 @@ sub main
         {
             # Set log levels
             cfgOptionSet(CFGOPT_LOG_LEVEL_STDERR, PROTOCOL, true);
-            logLevelSet(OFF, OFF, cfgOption(CFGOPT_LOG_LEVEL_STDERR));
+            logLevelSet(cfgOption(CFGOPT_LOG_LEVEL_FILE), OFF, cfgOption(CFGOPT_LOG_LEVEL_STDERR));
+
+            logFileSet(
+                storageLocal(),
+                cfgOption(CFGOPT_LOG_PATH) . '/' . (cfgOptionTest(CFGOPT_STANZA) ? cfgOption(CFGOPT_STANZA) : 'all') . '-' .
+                    lc(cfgOption(CFGOPT_COMMAND)) . '-' . lc(cfgCommandName(cfgCommandGet())) . '-' .
+                    sprintf("%03d", cfgOption(CFGOPT_PROCESS)));
 
             if (cfgOptionTest(CFGOPT_TYPE, CFGOPTVAL_REMOTE_TYPE_BACKUP) &&
                 !cfgOptionTest(CFGOPT_REPO_TYPE, CFGOPTVAL_REPO_TYPE_S3) &&
@@ -115,7 +123,8 @@ sub main
                 cfgOption(CFGOPT_BUFFER_SIZE), cfgOption(CFGOPT_PROTOCOL_TIMEOUT));
 
             # Process remote requests
-            $oRemote->process(cfgOption(CFGOPT_LOCK_PATH), cfgOption(CFGOPT_COMMAND), cfgOption(CFGOPT_STANZA, false));
+            $oRemote->process(
+                cfgOption(CFGOPT_LOCK_PATH), cfgOption(CFGOPT_COMMAND), cfgOption(CFGOPT_STANZA, false), cfgOption(CFGOPT_PROCESS));
         }
 
         # Process local command
@@ -124,7 +133,12 @@ sub main
         {
             # Set log levels
             cfgOptionSet(CFGOPT_LOG_LEVEL_STDERR, PROTOCOL, true);
-            logLevelSet(OFF, OFF, cfgOption(CFGOPT_LOG_LEVEL_STDERR));
+            logLevelSet(cfgOption(CFGOPT_LOG_LEVEL_FILE), OFF, cfgOption(CFGOPT_LOG_LEVEL_STDERR));
+
+            logFileSet(
+                storageLocal(),
+                cfgOption(CFGOPT_LOG_PATH) . '/' . cfgOption(CFGOPT_STANZA) . '-' . lc(cfgOption(CFGOPT_COMMAND)) . '-' .
+                    lc(cfgCommandName(cfgCommandGet())) . '-' . sprintf("%03d", cfgOption(CFGOPT_PROCESS)));
 
             # Load module dynamically
             require pgBackRest::Protocol::Local::Minion;
@@ -145,7 +159,7 @@ sub main
             require pgBackRest::Check::Check;
             pgBackRest::Check::Check->import();
 
-            $result = new pgBackRest::Check::Check()->process();
+            $iResult = new pgBackRest::Check::Check()->process();
         }
 
         # Process start/stop commands
@@ -183,10 +197,6 @@ sub main
             }
             else
             {
-                # Open log file
-                require pgBackRest::Storage::Helper;
-                pgBackRest::Storage::Helper->import();
-
                 logFileSet(
                     storageLocal(),
                     cfgOption(CFGOPT_LOG_PATH) . '/' . cfgOption(CFGOPT_STANZA) . '-' . lc(cfgCommandName(cfgCommandGet())));
@@ -239,7 +249,7 @@ sub main
                         require pgBackRest::Stanza;
                         pgBackRest::Stanza->import();
 
-                        $result = new pgBackRest::Stanza()->process();
+                        $iResult = new pgBackRest::Stanza()->process();
                     }
 
                     # Process backup command
@@ -282,26 +292,27 @@ sub main
         # If a backrest exception
         if (isException(\$oException))
         {
-            $result = $oException->code();
+            $iResult = $oException->code();
+            $bErrorC = $oException->errorC();
 
             # Only return message if we are in an async process since this will not be logged to the console
             if (!$bConfigLoaded && cfgOption(CFGOPT_ARCHIVE_ASYNC))
             {
-                $message = $oException->message();
+                $strMessage = $oException->message();
             }
         }
         # Else a regular Perl exception
         else
         {
-            $result = ERROR_UNHANDLED;
-            $message =
+            $iResult = ERROR_UNHANDLED;
+            $strMessage =
                 'process terminated due to an unhandled exception' .
                 (defined($oException) ? ":\n${oException}" : ': [exception not defined]');
         }
     };
 
     # Return result and error message if the result is an error
-    return $result, $message;
+    return $iResult, $bErrorC, $strMessage;
 }
 
 ####################################################################################################################################
