@@ -109,6 +109,8 @@ use constant MANIFEST_KEY_COMPRESS                                  => 'option-'
     push @EXPORT, qw(MANIFEST_KEY_COMPRESS);
 use constant MANIFEST_KEY_ONLINE                                    => 'option-' . cfgOptionName(CFGOPT_ONLINE);
     push @EXPORT, qw(MANIFEST_KEY_ONLINE);
+use constant MANIFEST_KEY_DELTA                                     => 'option-' . cfgOptionName(CFGOPT_DELTA);
+    push @EXPORT, qw(MANIFEST_KEY_DELTA);
 
 # Information about the database that was backed up
 use constant MANIFEST_KEY_DB_ID                                     => 'db-id';
@@ -284,6 +286,7 @@ sub new
         $bLoad,
         $oStorage,
         $strDbVersion,
+        $iDbCatalogVersion,
         $strCipherPass,                                             # Passphrase to open the manifest if encrypted
         $strCipherPassSub,                                          # Passphrase to encrypt the backup files
     ) =
@@ -294,6 +297,7 @@ sub new
             {name => 'bLoad', optional => true, default => true, trace => true},
             {name => 'oStorage', optional => true, default => storageRepo(), trace => true},
             {name => 'strDbVersion', optional => true, trace => true},
+            {name => 'iDbCatalogVersion', optional => true, trace => true},
             {name => 'strCipherPass', optional => true, redact => true},
             {name => 'strCipherPassSub', optional => true, redact => true},
         );
@@ -302,17 +306,21 @@ sub new
     my $self = $class->SUPER::new($strFileName, {bLoad => $bLoad, oStorage => $oStorage, strCipherPass => $strCipherPass,
         strCipherPassSub => $strCipherPassSub});
 
-    # If manifest not loaded from a file then the db version must be set
+    # If manifest not loaded from a file then the db version and catalog version must be set
     if (!$bLoad)
     {
-        if (!defined($strDbVersion))
+        if (!(defined($strDbVersion) && defined($iDbCatalogVersion)))
         {
-            confess &log(ASSERT, 'strDbVersion must be provided with bLoad = false');
+            confess &log(ASSERT, 'strDbVersion and iDbCatalogVersion must be provided with bLoad = false');
         }
 
         $self->set(MANIFEST_SECTION_BACKUP_DB, MANIFEST_KEY_DB_VERSION, undef, $strDbVersion);
+        $self->numericSet(MANIFEST_SECTION_BACKUP_DB, MANIFEST_KEY_CATALOG, undef, $iDbCatalogVersion);
     }
 
+    # Mark the manifest as built if it was loaded from a file
+    $self->{bBuilt} = $bLoad;
+
     # Return from function and log return values if any
     return logDebugReturn
     (
@@ -548,6 +556,127 @@ sub isTargetTablespace
     return $self->test(MANIFEST_SECTION_BACKUP_TARGET, $strTarget, MANIFEST_SUBKEY_TABLESPACE_ID);
 }
 
+####################################################################################################################################
+# checkDelta
+#
+# Determine if the delta option should be enabled. Only called if delta has not yet been enabled.
+####################################################################################################################################
+sub checkDelta
+{
+    my $self = shift;
+
+    # Assign function parameters, defaults, and log debug info
+    my
+    (
+        $strOperation,
+        $strLastBackupSource,
+        $bOnlineSame,
+        $strTimelineCurrent,
+        $strTimelineLast,
+    ) =
+        logDebugParam
+        (
+            __PACKAGE__ . '->checkDelta', \@_,
+            {name => 'strLastBackupSource'},
+            {name => 'bOnlineSame'},
+            {name => 'strTimelineCurrent', required => false},
+            {name => 'strTimelineLast', required => false},
+        );
+
+    my $bDelta = false;
+
+    # Determine if a timeline switch has occurred
+    if (defined($strTimelineLast) && defined($strTimelineCurrent))
+    {
+        # If there is a prior backup, check if a timeline switch has occurred since then
+        if ($strTimelineLast ne $strTimelineCurrent)
+        {
+            &log(WARN, "a timeline switch has occurred since the ${strLastBackupSource} backup, enabling delta checksum");
+            $bDelta = true;
+        }
+    }
+
+    # If delta was not set above and there is a change in the online option, then set delta option
+    if (!$bDelta && !$bOnlineSame)
+    {
+        &log(WARN, "the online option has changed since the ${strLastBackupSource} backup, enabling delta checksum");
+        $bDelta = true;
+    }
+
+    # Return from function and log return values if any
+    return logDebugReturn
+    (
+        $strOperation,
+        {name => 'bDelta', value => $bDelta, trace => true},
+    );
+}
+
+####################################################################################################################################
+# checkDeltaFile
+#
+# Determine if the delta option should be enabled. Only called if delta has not yet been enabled.
+####################################################################################################################################
+sub checkDeltaFile
+{
+    my $self = shift;
+
+    # Assign function parameters, defaults, and log debug info
+    my
+    (
+        $strOperation,
+        $stryFileList,
+        $oPriorManifest,
+        $lTimeBegin,
+    ) =
+        logDebugParam
+        (
+            __PACKAGE__ . '->checkDeltaFile', \@_,
+            {name => 'stryFileList'},
+            {name => 'oPriorManifest', required => false},
+            {name => 'lTimeBegin', required => false},
+        );
+
+    my $bDelta = false;
+
+    # Loop though all files
+    foreach my $strName (@{$stryFileList})
+    {
+        # If $lTimeBegin is defined, then this is not an aborted manifest so check if modification time is in the future (in this
+        # backup OR the last backup) then enable delta and exit
+        if (defined($lTimeBegin) &&
+            ($self->numericGet(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_TIMESTAMP) > $lTimeBegin ||
+            (defined($oPriorManifest) &&
+             $oPriorManifest->test(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_FUTURE, 'y'))))
+        {
+            &log(WARN, "file $strName has timestamp in the future, enabling delta checksum");
+            $bDelta = true;
+            last;
+        }
+
+        # If the time on the file is earlier than the last manifest time or the size is different but the timestamp is the
+        # same, then enable delta and exit
+        if (defined($oPriorManifest) && $oPriorManifest->test(MANIFEST_SECTION_TARGET_FILE, $strName) &&
+            ($self->numericGet(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_TIMESTAMP) <
+            $oPriorManifest->numericGet(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_TIMESTAMP) ||
+            ($self->numericGet(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_SIZE) !=
+            $oPriorManifest->numericGet(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_SIZE) &&
+            $self->numericGet(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_TIMESTAMP) ==
+            $oPriorManifest->numericGet(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_TIMESTAMP))))
+        {
+            &log(WARN, "file $strName timestamp in the past or size changed but timestamp did not, enabling delta checksum");
+            $bDelta = true;
+            last;
+        }
+    }
+
+    # Return from function and log return values if any
+    return logDebugReturn
+    (
+        $strOperation,
+        {name => 'bDelta', value => $bDelta, trace => true},
+    );
+}
+
 ####################################################################################################################################
 # build
 #
@@ -565,12 +694,17 @@ sub build
         $strPath,
         $oLastManifest,
         $bOnline,
+        $bDelta,
         $hTablespaceMap,
         $hDatabaseMap,
+        $rhExclude,
+        $strTimelineCurrent,
+        $strTimelineLast,
         $strLevel,
         $bTablespace,
         $strParentPath,
-        $strFilter
+        $strFilter,
+        $iLevel,
     ) =
         logDebugParam
         (
@@ -579,16 +713,40 @@ sub build
             {name => 'strPath'},
             {name => 'oLastManifest', required => false},
             {name => 'bOnline'},
+            {name => 'bDelta'},
             {name => 'hTablespaceMap', required => false},
             {name => 'hDatabaseMap', required => false},
+            {name => 'rhExclude', required => false},
+            {name => 'strTimelineCurrent', required => false},
+            {name => 'strTimelineLast', required => false},
             {name => 'strLevel', required => false},
             {name => 'bTablespace', required => false},
             {name => 'strParentPath', required => false},
-            {name => 'strFilter', required => false}
+            {name => 'strFilter', required => false},
+            {name => 'iLevel', required => false, default => 0},
         );
 
+    # Limit recursion to something reasonable (if more then we are very likely in a link loop)
+    if ($iLevel >= 16)
+    {
+        confess &log(
+            ERROR,
+            "recursion in manifest build exceeds depth of ${iLevel}: ${strLevel}\n" .
+                'HINT: is there a link loop in $PGDATA?',
+            ERROR_FORMAT);
+    }
+
     if (!defined($strLevel))
     {
+        # Don't allow the manifest to be built more than once
+        if ($self->{bBuilt})
+        {
+            confess &log(ASSERT, "manifest has already been built");
+        }
+
+        $self->{bBuilt} = true;
+
+        # Set initial level
         $strLevel = MANIFEST_TARGET_PGDATA;
 
         # If not online then build the tablespace map from pg_tblspc path
@@ -609,6 +767,14 @@ sub build
                 $hTablespaceMap->{$strOid} = "ts${strOid}";
             }
         }
+
+        # If there is a last manifest, then check to see if delta checksum should be enabled
+        if (defined($oLastManifest) && !$bDelta)
+        {
+            $bDelta = $self->checkDelta(
+                'last', $oLastManifest->boolTest(MANIFEST_SECTION_BACKUP_OPTION, MANIFEST_KEY_ONLINE, undef, $bOnline),
+                $strTimelineCurrent, $strTimelineLast);
+        }
     }
 
     $self->set(MANIFEST_SECTION_BACKUP_TARGET, $strLevel, MANIFEST_SUBKEY_PATH, $strPath);
@@ -641,7 +807,7 @@ sub build
     }
 
     # Get the manifest for this level
-    my $hManifest = $oStorageDbMaster->manifest($strPath);
+    my $hManifest = $oStorageDbMaster->manifest($strPath, {strFilter => $strFilter});
     my $strManifestType = MANIFEST_VALUE_LINK;
 
     # Loop though all paths/files/links in the manifest
@@ -660,12 +826,6 @@ sub build
                         '\' cannot reference another link', ERROR_LINK_DESTINATION);
             }
 
-            # Make sure the current file matches the filter or any files under the filter
-            if (defined($strFilter) && $strName ne $strFilter && index($strName, "${strFilter}/") != 0)
-            {
-                next;
-            }
-
             if ($strManifestType eq MANIFEST_VALUE_LINK)
             {
                 $strFile = dirname($strFile);
@@ -726,6 +886,48 @@ sub build
             next;
         }
 
+        # If version is greater than 9.0, check for files to exclude
+        if ($self->dbVersion() >= PG_VERSION_90 && $hManifest->{$strName}{type} eq 'f')
+        {
+            # Get the directory name from the manifest; it will be used later to seach for existence in the keys
+            my $strDir = dirname($strName);
+
+            # If it is a database data directory (base or tablespace) then check for files to skip
+            if ($strDir =~ '^base\/[0-9]+$' ||
+                $strDir =~ ('^' . $self->tablespacePathGet() . '\/[0-9]+$'))
+            {
+                # Get just the filename
+                my $strBaseName = basename($strName);
+
+                # Skip temp tables (lower t followed by numbers underscore numbers and a dot (segment) or underscore (fork) and/or
+                # segment, e.g. t1234_123, t1234_123.1, t1234_123_vm, t1234_123_fsm.1
+                if ($strBaseName =~ '^t[0-9]+\_[0-9]+(|\_(fsm|vm)){0,1}(\.[0-9]+){0,1}$')
+                {
+                    next;
+                }
+
+                # If version is greater than 9.1 then check for unlogged tables to skip
+                if ($self->dbVersion() >= PG_VERSION_91)
+                {
+                    # Exclude all forks for unlogged tables except the init fork (numbers underscore init and optional dot segment)
+                    if ($strBaseName =~ '^[0-9]+(|\_(fsm|vm)){0,1}(\.[0-9]+){0,1}$')
+                    {
+                        # Get the filenode (OID)
+                        my ($strFileNode) = $strBaseName =~ '^(\d+)';
+
+                        # Add _init to the OID to see if this is an unlogged object
+                        $strFileNode = $strDir. "/" . $strFileNode . "_init";
+
+                        # If key exists in manifest then skip
+                        if (exists($hManifest->{$strFileNode}) && $hManifest->{$strFileNode}{type} eq 'f')
+                        {
+                            next;
+                        }
+                    }
+                }
+            }
+        }
+
         my $cType = $hManifest->{$strName}{type};
         my $strSection = MANIFEST_SECTION_TARGET_PATH;
 
@@ -768,6 +970,42 @@ sub build
             }
         }
 
+        # Exclude files requested by the user
+        if (defined($rhExclude))
+        {
+            # Exclusions are based on the name of the file relative to PGDATA
+            my $strPgFile = $self->dbPathGet(undef, $strFile);
+            my $bExclude = false;
+
+            # Iterate through exclusions
+            foreach my $strExclude (sort(keys(%{$rhExclude})))
+            {
+                # If the exclusion ends in / then we must do a prefix match
+                if ($strExclude =~ /\/$/)
+                {
+                    if (index($strPgFile, $strExclude) == 0)
+                    {
+                        $bExclude = true;
+                    }
+                }
+                # Else an exact match or a prefix match with / appended is required
+                elsif ($strPgFile eq $strExclude || index($strPgFile, "${strExclude}/") == 0)
+                {
+                    $bExclude = true;
+                }
+
+                # Log everything that gets excluded at a high level so it will hopefully be seen if wrong
+                if ($bExclude)
+                {
+                    &log(INFO, "exclude ${strPgFile} from backup using '${strExclude}' exclusion");
+                    last;
+                }
+            }
+
+            # Skip the file if it was excluded
+            next if $bExclude;
+        }
+
         # User and group required for all types
         if (defined($hManifest->{$strName}{user}))
         {
@@ -828,11 +1066,9 @@ sub build
                 $strFile = substr($strFile, length(MANIFEST_TARGET_PGDATA) + 1);
             }
 
-            $strPath = dirname("${strPath}/${strName}");
-
-            $self->build(
-                $oStorageDbMaster, $strLinkDestination, undef, $bOnline, $hTablespaceMap, $hDatabaseMap, $strFile, $bTablespace,
-                $strPath, $strFilter, $strLinkDestination);
+            $bDelta = $self->build(
+                $oStorageDbMaster, $strLinkDestination, undef, $bOnline, $bDelta, $hTablespaceMap, $hDatabaseMap, $rhExclude, undef,
+                undef, $strFile, $bTablespace, dirname("${strPath}/${strName}"), $strFilter, $iLevel + 1);
         }
     }
 
@@ -868,6 +1104,17 @@ sub build
                               $hDatabaseMap->{$strDbName}{&MANIFEST_KEY_DB_LAST_SYSTEM_ID});
         }
 
+        # Determine if delta checksum should be enabled
+        if (!$bDelta)
+        {
+            my @stryFileList = $self->keys(MANIFEST_SECTION_TARGET_FILE);
+
+            if (@stryFileList)
+            {
+                $bDelta = $self->checkDeltaFile(\@stryFileList, $oLastManifest, $lTimeBegin);
+            }
+        }
+
         # Loop though all files
         foreach my $strName ($self->keys(MANIFEST_SECTION_TARGET_FILE))
         {
@@ -885,38 +1132,43 @@ sub build
                     $self->set(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_FUTURE, 'y');
                 }
             }
-            # Else check if modification time and size are unchanged since last backup
+            # Else check if the size and timestamp match OR if the size matches and the delta option is set, then keep the file.
+            # In the latter case, if there had been a timestamp change then rather than removing and recopying the file, the file
+            # will be tested in backupFile to see if the db/repo checksum still matches: if so, it is not necessary to recopy,
+            # else it will need to be copied to the new backup. For zero sized files, the reference will be set and copying
+            # will be skipped later.
             elsif (defined($oLastManifest) && $oLastManifest->test(MANIFEST_SECTION_TARGET_FILE, $strName) &&
                    $self->numericGet(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_SIZE) ==
-                       $oLastManifest->get(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_SIZE) &&
+                       $oLastManifest->numericGet(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_SIZE) &&
+                   ($bDelta || ($self->numericGet(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_SIZE) == 0 ||
                    $self->numericGet(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_TIMESTAMP) ==
-                       $oLastManifest->get(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_TIMESTAMP))
+                       $oLastManifest->numericGet(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_TIMESTAMP))))
             {
                 # Copy reference from previous backup if possible
                 if ($oLastManifest->test(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_REFERENCE))
                 {
                     $self->set(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_REFERENCE,
-                               $oLastManifest->get(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_REFERENCE));
+                        $oLastManifest->get(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_REFERENCE));
                 }
                 # Otherwise the reference is to the previous backup
                 else
                 {
                     $self->set(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_REFERENCE,
-                               $oLastManifest->get(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_LABEL));
+                        $oLastManifest->get(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_LABEL));
                 }
 
-                # Copy the checksum from previous manifest
+                # Copy the checksum from previous manifest (if it exists - zero sized files don't have checksums)
                 if ($oLastManifest->test(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_CHECKSUM))
                 {
                     $self->set(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_CHECKSUM,
                                $oLastManifest->get(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_CHECKSUM));
                 }
 
-                # Copy repo size from the previous manifest
+                # Copy repo size from the previous manifest (if it exists)
                 if ($oLastManifest->test(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_REPO_SIZE))
                 {
                     $self->set(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_REPO_SIZE,
-                               $oLastManifest->get(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_REPO_SIZE));
+                        $oLastManifest->get(MANIFEST_SECTION_TARGET_FILE, $strName, MANIFEST_SUBKEY_REPO_SIZE));
                 }
 
                 # Copy master flag from the previous manifest (if it exists)
@@ -960,7 +1212,11 @@ sub build
     }
 
     # Return from function and log return values if any
-    return logDebugReturn($strOperation);
+    return logDebugReturn
+    (
+        $strOperation,
+        {name => 'bDelta', value => $bDelta, trace => true},
+    );
 }
 
 ####################################################################################################################################
