@@ -55,6 +55,8 @@ use constant OP_STORAGE_CIPHER_PASS_USER                            => 'storageC
     push @EXPORT, qw(OP_STORAGE_CIPHER_PASS_USER);
 use constant OP_STORAGE_EXISTS                                      => 'storageExists';
     push @EXPORT, qw(OP_STORAGE_EXISTS);
+use constant OP_STORAGE_HASH_SIZE                                   => 'storageHashSize';
+    push @EXPORT, qw(OP_STORAGE_HASH_SIZE);
 use constant OP_STORAGE_LIST                                        => 'storageList';
     push @EXPORT, qw(OP_STORAGE_LIST);
 use constant OP_STORAGE_MANIFEST                                    => 'storageManifest';
@@ -64,10 +66,6 @@ use constant OP_STORAGE_MOVE                                        => 'storageM
 use constant OP_STORAGE_PATH_GET                                    => 'storagePathGet';
     push @EXPORT, qw(OP_STORAGE_PATH_GET);
 
-# Info module
-use constant OP_INFO_STANZA_LIST                                    => 'infoStanzList';
-    push @EXPORT, qw(OP_INFO_STANZA_LIST);
-
 # Restore module
 use constant OP_RESTORE_FILE                                         => 'restoreFile';
     push @EXPORT, qw(OP_RESTORE_FILE);
@@ -157,7 +155,8 @@ sub protocolParam
             {name => 'strRemoteType'},
             {name => 'iRemoteIdx', default => cfgOptionValid(CFGOPT_HOST_ID) ? cfgOption(CFGOPT_HOST_ID) : 1},
             {name => 'strBackRestBin', optional => true},
-            {name => 'iProcessIdx', optional => true},
+            {name => 'iProcessIdx', optional => true,
+                default => cfgOptionValid(CFGOPT_PROCESS) ? cfgOption(CFGOPT_PROCESS, false) : undef},
         );
 
     # Return the remote when required
@@ -211,7 +210,7 @@ sub protocolParam
     my $rhCommandOption =
     {
         &CFGOPT_COMMAND => {value => $strCommand},
-        &CFGOPT_PROCESS => {value => $iProcessIdx},
+        &CFGOPT_PROCESS => {value => defined($iProcessIdx) ? $iProcessIdx : 0},
         &CFGOPT_CONFIG =>
             {value => cfgOptionValid($iOptionIdConfig) && cfgOptionSource($iOptionIdConfig) eq CFGDEF_SOURCE_DEFAULT ?
                 undef : cfgOption($iOptionIdConfig)},
@@ -226,6 +225,9 @@ sub protocolParam
         &CFGOPT_LOG_PATH => {},
         &CFGOPT_LOCK_PATH => {},
 
+        # Only enable file logging on the remote when requested
+        &CFGOPT_LOG_LEVEL_FILE => {value => cfgOption(CFGOPT_LOG_SUBPROCESS) ? cfgOption(CFGOPT_LOG_LEVEL_FILE) : lc(OFF)},
+
         # Don't pass CFGOPT_LOG_LEVEL_STDERR because in the case of the local process calling the remote process the
         # option will be set to 'protocol' which is not a valid value from the command line.
         &CFGOPT_LOG_LEVEL_STDERR => {},
@@ -303,7 +305,8 @@ sub protocolGet
             {name => 'bCache', optional => true, default => true},
             {name => 'strBackRestBin', optional => true},
             {name => 'iProcessIdx', optional => true},
-            {name => 'strCommand', optional => true, default => cfgCommandName(cfgCommandGet())},
+            {name => 'strCommand', optional => true,
+                default => cfgOptionValid(CFGOPT_COMMAND) ? cfgOption(CFGOPT_COMMAND) : cfgCommandName(cfgCommandGet())},
         );
 
     # Protocol object
