@@ -101,6 +101,11 @@ sub manifestOwnershipCheck
     else
     {
         $oOwnerTypeHash{&MANIFEST_SUBKEY_USER} = getpwuid($<);
+
+        if (!defined($oOwnerTypeHash{&MANIFEST_SUBKEY_USER}))
+        {
+            confess &log(ERROR_USER_MISSING, 'current user uid does not map to a name');
+        }
     }
 
     if ($oManifest->test(MANIFEST_SECTION_TARGET_PATH, MANIFEST_TARGET_PGDATA, MANIFEST_SUBKEY_GROUP) &&
@@ -112,6 +117,11 @@ sub manifestOwnershipCheck
     else
     {
         $oOwnerTypeHash{&MANIFEST_SUBKEY_GROUP} = getgrgid($();
+
+        if (!defined($oOwnerTypeHash{&MANIFEST_SUBKEY_GROUP}))
+        {
+            confess &log(ERROR_GROUP_MISSING, 'current user gid does not map to a name');
+        }
     }
 
     # Loop through owner types (user, group)
@@ -977,7 +987,7 @@ sub recovery
                 }
             }
 
-            # Write pause_at_recovery_target
+            # Write pause_at_recovery_target/recovery_target_action
             if (cfgOptionTest(CFGOPT_TARGET_ACTION))
             {
                 my $strTargetAction = cfgOption(CFGOPT_TARGET_ACTION);
@@ -990,6 +1000,13 @@ sub recovery
                     }
                     elsif  ($strDbVersion >= PG_VERSION_91)
                     {
+                        if ($strTargetAction eq CFGOPTVAL_RESTORE_TARGET_ACTION_SHUTDOWN)
+                        {
+                            confess &log(ERROR,
+                                cfgOptionName(CFGOPT_TARGET_ACTION) .  '=' . CFGOPTVAL_RESTORE_TARGET_ACTION_SHUTDOWN .
+                                    ' is only available in PostgreSQL >= ' . PG_VERSION_95)
+                        }
+
                         $strRecovery .= "pause_at_recovery_target = 'false'\n";
                     }
                     else
@@ -1233,8 +1250,8 @@ sub process
     my $lSizeCurrent = 0;
 
     foreach my $strRepoFile (
-        sort {sprintf("%016d-${b}", $oManifest->numericGet(MANIFEST_SECTION_TARGET_FILE, $b, MANIFEST_SUBKEY_SIZE)) cmp
-              sprintf("%016d-${a}", $oManifest->numericGet(MANIFEST_SECTION_TARGET_FILE, $a, MANIFEST_SUBKEY_SIZE))}
+        sort {sprintf("%016d-%s", $oManifest->numericGet(MANIFEST_SECTION_TARGET_FILE, $b, MANIFEST_SUBKEY_SIZE), $b) cmp
+              sprintf("%016d-%s", $oManifest->numericGet(MANIFEST_SECTION_TARGET_FILE, $a, MANIFEST_SUBKEY_SIZE), $a)}
         ($oManifest->keys(MANIFEST_SECTION_TARGET_FILE, INI_SORT_NONE)))
     {
         # Skip the tablespace_map file in versions >= 9.5 so Postgres does not rewrite links in DB_PATH_PGTBLSPC.
