@@ -90,14 +90,9 @@ sub process
         $self->stanzaUpgrade();
     }
     # Process stanza delete
-    elsif (cfgCommandTest(CFGCMD_STANZA_DELETE))
-    {
-        $self->stanzaDelete();
-    }
-    # Else error if any other command is found
     else
     {
-        confess &log(ASSERT, "stanza->process() called with invalid command: " . cfgCommandName(cfgCommandGet()));
+        $self->stanzaDelete();
     }
 
     # Return from function and log return values if any
@@ -605,7 +600,7 @@ sub infoObject
         else
         {
             # Confess unhandled exception
-            if (($iResult != ERROR_FILE_MISSING) && ($iResult != ERROR_CIPHER))
+            if (($iResult != ERROR_FILE_MISSING) && ($iResult != ERROR_CRYPTO))
             {
                 confess &log(ERROR, $strResultMessage, $iResult);
             }
