@@ -130,11 +130,13 @@ sub hashSize
     (
         $strOperation,
         $xFileExp,
+        $bIgnoreMissing,
     ) =
         logDebugParam
         (
             __PACKAGE__ . '->hashSize', \@_,
             {name => 'xFileExp'},
+            {name => 'bIgnoreMissing', optional => true, default => false},
         );
 
     # Set operation variables
@@ -142,7 +144,9 @@ sub hashSize
     my $lSize;
 
     # Is this an IO object or a file expression?
-    my $oFileIo = defined($xFileExp) ? (ref($xFileExp) ? $xFileExp : $self->openRead($self->pathGet($xFileExp))) : undef;
+    my $oFileIo =
+        defined($xFileExp) ? (ref($xFileExp) ? $xFileExp :
+            $self->openRead($self->pathGet($xFileExp), {bIgnoreMissing => $bIgnoreMissing})) : undef;
 
     if (defined($oFileIo))
     {
@@ -297,7 +301,7 @@ sub list
         logDebugParam
         (
             __PACKAGE__ . '->list', \@_,
-            {name => 'strPathExp'},
+            {name => 'strPathExp', required => false},
             {name => 'strExpression', optional => true},
             {name => 'strSortOrder', optional => true, default => 'forward'},
             {name => 'bIgnoreMissing', optional => true, default => false},
@@ -344,14 +348,16 @@ sub manifest
     (
         $strOperation,
         $strPathExp,
+        $strFilter,
     ) =
         logDebugParam
         (
             __PACKAGE__ . '->manifest', \@_,
             {name => 'strPathExp'},
+            {name => 'strFilter', optional => true, trace => true},
         );
 
-    my $hManifest = $self->driver()->manifest($self->pathGet($strPathExp));
+    my $hManifest = $self->driver()->manifest($self->pathGet($strPathExp), {strFilter => $strFilter});
 
     # Return from function and log return values if any
     return logDebugReturn
