@@ -7,6 +7,6 @@ Archive Get Command
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
-int cmdArchiveGet();
+int cmdArchiveGet(void);
 
 #endif
