@@ -19,9 +19,9 @@ Archive Push Command
 Push a WAL segment to the repository
 ***********************************************************************************************************************************/
 void
-cmdArchivePush()
+cmdArchivePush(void)
 {
-    FUNCTION_DEBUG_VOID(logLevelDebug);
+    FUNCTION_LOG_VOID(logLevelDebug);
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
@@ -42,7 +42,7 @@ cmdArchivePush()
             bool server = false;                                        // Is this the async server process?
 
             // Loop and wait for the WAL segment to be pushed
-            Wait *wait = waitNew(cfgOptionDbl(cfgOptArchiveTimeout));
+            Wait *wait = waitNew((TimeMSec)(cfgOptionDbl(cfgOptArchiveTimeout) * MSEC_PER_SEC));
 
             do
             {
@@ -68,9 +68,9 @@ cmdArchivePush()
                         cfgLoadLogSetting();
 
                         // Open the log file
-                        logFileSet(
-                            strPtr(strNewFmt("%s/%s-%s-async.log", strPtr(cfgOptionStr(cfgOptLogPath)),
-                            strPtr(cfgOptionStr(cfgOptStanza)), cfgCommandName(cfgCommand()))));
+                        cfgLoadLogFile(
+                            strNewFmt("%s/%s-%s-async.log", strPtr(cfgOptionStr(cfgOptLogPath)),
+                            strPtr(cfgOptionStr(cfgOptStanza)), cfgCommandName(cfgCommand())));
 
                         // Log command info since we are starting a new log
                         cmdBegin(true);
@@ -127,5 +127,5 @@ cmdArchivePush()
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_DEBUG_RESULT_VOID();
+    FUNCTION_LOG_RETURN_VOID();
 }
