@@ -7,6 +7,6 @@ Archive Push Command
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
-void cmdArchivePush();
+void cmdArchivePush(void);
 
 #endif
