@@ -9,7 +9,7 @@ Common Command Routines
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
-void cmdInit();
+void cmdInit(void);
 
 void cmdBegin(bool logOption);
 void cmdEnd(int code, const String *errorMessage);
