@@ -5,9 +5,8 @@ Help Command
 #include <sys/types.h>
 #include <unistd.h>
 
-#include "common/assert.h"
 #include "common/debug.h"
-#include "common/io/handle.h"
+#include "common/io/handleWrite.h"
 #include "common/memContext.h"
 #include "config/config.h"
 #include "config/define.h"
@@ -24,15 +23,15 @@ Helper function for helpRender() to make output look good on a console
 static String *
 helpRenderText(const String *text, size_t indent, bool indentFirst, size_t length)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelTrace);
-        FUNCTION_DEBUG_PARAM(STRING, text);
-        FUNCTION_DEBUG_PARAM(SIZE, indent);
-        FUNCTION_DEBUG_PARAM(BOOL, indentFirst);
-        FUNCTION_DEBUG_PARAM(SIZE, length);
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(STRING, text);
+        FUNCTION_LOG_PARAM(SIZE, indent);
+        FUNCTION_LOG_PARAM(BOOL, indentFirst);
+        FUNCTION_LOG_PARAM(SIZE, length);
+    FUNCTION_LOG_END();
 
-        FUNCTION_DEBUG_ASSERT(text != NULL);
-        FUNCTION_DEBUG_ASSERT(length > 0);
-    FUNCTION_DEBUG_END();
+    ASSERT(text != NULL);
+    ASSERT(length > 0);
 
     String *result = strNew("");
 
@@ -66,33 +65,33 @@ helpRenderText(const String *text, size_t indent, bool indentFirst, size_t lengt
         }
     }
 
-    FUNCTION_DEBUG_RESULT(STRING, result);
+    FUNCTION_LOG_RETURN(STRING, result);
 }
 
 /***********************************************************************************************************************************
 Helper function for helpRender() to output values as strings
 ***********************************************************************************************************************************/
-static String *
+static const String *
 helpRenderValue(const Variant *value)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelTrace);
-        FUNCTION_DEBUG_PARAM(VARIANT, value);
-    FUNCTION_DEBUG_END();
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(VARIANT, value);
+    FUNCTION_LOG_END();
 
-    String *result = NULL;
+    const String *result = NULL;
 
     if (value != NULL)
     {
         if (varType(value) == varTypeBool)
         {
             if (varBool(value))
-                result = strNew("y");
+                result = Y_STR;
             else
-                result = strNew("n");
+                result = N_STR;
         }
         else if (varType(value) == varTypeKeyValue)
         {
-            result = strNew("");
+            String *resultTemp = strNew("");
 
             const KeyValue *optionKv = varKv(value);
             const VariantList *keyList = kvKeyList(optionKv);
@@ -100,43 +99,47 @@ helpRenderValue(const Variant *value)
             for (unsigned int keyIdx = 0; keyIdx < varLstSize(keyList); keyIdx++)
             {
                 if (keyIdx != 0)
-                    strCat(result, ", ");
+                    strCat(resultTemp, ", ");
 
                 strCatFmt(
-                    result, "%s=%s", strPtr(varStr(varLstGet(keyList, keyIdx))),
+                    resultTemp, "%s=%s", strPtr(varStr(varLstGet(keyList, keyIdx))),
                     strPtr(varStrForce(kvGet(optionKv, varLstGet(keyList, keyIdx)))));
             }
+
+            result = resultTemp;
         }
         else if (varType(value) == varTypeVariantList)
         {
-            result = strNew("");
+            String *resultTemp = strNew("");
 
             const VariantList *list = varVarLst(value);
 
             for (unsigned int listIdx = 0; listIdx < varLstSize(list); listIdx++)
             {
                 if (listIdx != 0)
-                    strCat(result, ", ");
+                    strCat(resultTemp, ", ");
 
-                strCatFmt(result, "%s", strPtr(varStr(varLstGet(list, listIdx))));
+                strCatFmt(resultTemp, "%s", strPtr(varStr(varLstGet(list, listIdx))));
             }
+
+            result = resultTemp;
         }
         else
             result = varStrForce(value);
     }
 
-    FUNCTION_DEBUG_RESULT(STRING, result);
+    FUNCTION_LOG_RETURN_CONST(STRING, result);
 }
 
 /***********************************************************************************************************************************
 Render help to a string
 ***********************************************************************************************************************************/
 static String *
-helpRender()
+helpRender(void)
 {
-    FUNCTION_DEBUG_VOID(logLevelDebug);
+    FUNCTION_LOG_VOID(logLevelDebug);
 
-    String *result = strNew(PGBACKREST_NAME " " PGBACKREST_VERSION);
+    String *result = strNew(PROJECT_NAME " " PROJECT_VERSION);
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
@@ -151,7 +154,7 @@ helpRender()
                 " - General help\n"
                 "\n"
                 "Usage:\n"
-                "    " PGBACKREST_BIN " [options] [command]\n"
+                "    " PROJECT_BIN " [options] [command]\n"
                 "\n"
                 "Commands:\n");
 
@@ -260,8 +263,8 @@ helpRender()
                             strlen(cfgDefOptionHelpSummary(commandDefId, optionDefId)) - 1));
 
                         // Ouput current and default values if they exist
-                        String *defaultValue = helpRenderValue(cfgOptionDefault(optionId));
-                        String *value = NULL;
+                        const String *defaultValue = helpRenderValue(cfgOptionDefault(optionId));
+                        const String *value = NULL;
 
                         if (cfgOptionSource(optionId) != cfgSourceDefault)
                             value = helpRenderValue(cfgOption(optionId));
@@ -330,8 +333,8 @@ helpRender()
                     strPtr(helpRenderText(strNew(cfgDefOptionHelpDescription(commandDefId, optionDefId)), 0, true, CONSOLE_WIDTH)));
 
                 // Ouput current and default values if they exist
-                String *defaultValue = helpRenderValue(cfgOptionDefault(optionId));
-                String *value = NULL;
+                const String *defaultValue = helpRenderValue(cfgOptionDefault(optionId));
+                const String *value = NULL;
 
                 if (cfgOptionSource(optionId) != cfgSourceDefault)
                     value = helpRenderValue(cfgOption(optionId));
@@ -372,20 +375,20 @@ helpRender()
 
         // If there is more help available output a message to let the user know
         if (more != NULL)
-            strCatFmt(result, "\nUse '" PGBACKREST_BIN " help %s' for more information.\n", strPtr(more));
+            strCatFmt(result, "\nUse '" PROJECT_BIN " help %s' for more information.\n", strPtr(more));
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_DEBUG_RESULT(STRING, result);
+    FUNCTION_LOG_RETURN(STRING, result);
 }
 
 /***********************************************************************************************************************************
 Render help and output to stdout
 ***********************************************************************************************************************************/
 void
-cmdHelp()
+cmdHelp(void)
 {
-    FUNCTION_DEBUG_VOID(logLevelDebug);
+    FUNCTION_LOG_VOID(logLevelDebug);
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
@@ -393,5 +396,5 @@ cmdHelp()
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_DEBUG_RESULT_VOID();
+    FUNCTION_LOG_RETURN_VOID();
 }
