@@ -7,6 +7,6 @@ Help Command
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
-void cmdHelp();
+void cmdHelp(void);
 
 #endif
