@@ -20,7 +20,7 @@ typedef enum
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
-void exitInit();
+void exitInit(void);
 int exitSafe(int result, bool error, SignalType signalType);
 
 #endif
