@@ -7,6 +7,6 @@ Fork Handler
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
-void forkDetach();
+void forkDetach(void);
 
 #endif
