@@ -9,7 +9,6 @@ Ini Handler
 #include "common/memContext.h"
 #include "common/ini.h"
 #include "common/type/keyValue.h"
-#include "storage/helper.h"
 
 /***********************************************************************************************************************************
 Contains information about the ini
@@ -18,14 +17,13 @@ struct Ini
 {
     MemContext *memContext;                                         // Context that contains the ini
     KeyValue *store;                                                // Key value store that contains the ini data
-    String *fileName;                                               // File name (if one has been set)
 };
 
 /***********************************************************************************************************************************
-Create a new string from a zero-terminated string
+Create a new Ini object
 ***********************************************************************************************************************************/
 Ini *
-iniNew()
+iniNew(void)
 {
     Ini *this = NULL;
 
@@ -54,12 +52,12 @@ iniGetInternal(const Ini *this, const String *section, const String *key)
         FUNCTION_TEST_PARAM(INI, this);
         FUNCTION_TEST_PARAM(STRING, section);
         FUNCTION_TEST_PARAM(STRING, key);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(section != NULL);
-        FUNCTION_TEST_ASSERT(key != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+    ASSERT(section != NULL);
+    ASSERT(key != NULL);
+
     const Variant *result = NULL;
 
     MEM_CONTEXT_TEMP_BEGIN()
@@ -73,7 +71,7 @@ iniGetInternal(const Ini *this, const String *section, const String *key)
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_TEST_RESULT(CONST_VARIANT, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -86,12 +84,12 @@ iniGet(const Ini *this, const String *section, const String *key)
         FUNCTION_TEST_PARAM(INI, this);
         FUNCTION_TEST_PARAM(STRING, section);
         FUNCTION_TEST_PARAM(STRING, key);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(section != NULL);
-        FUNCTION_TEST_ASSERT(key != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+    ASSERT(section != NULL);
+    ASSERT(key != NULL);
+
     // Get the value
     const Variant *result = iniGetInternal(this, section, key);
 
@@ -99,9 +97,7 @@ iniGet(const Ini *this, const String *section, const String *key)
     if (result == NULL)
         THROW_FMT(FormatError, "section '%s', key '%s' does not exist", strPtr(section), strPtr(key));
 
-    return result;
-
-    FUNCTION_TEST_RESULT(CONST_VARIANT, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -115,12 +111,12 @@ iniGetDefault(const Ini *this, const String *section, const String *key, Variant
         FUNCTION_TEST_PARAM(STRING, section);
         FUNCTION_TEST_PARAM(STRING, key);
         FUNCTION_TEST_PARAM(VARIANT, defaultValue);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(section != NULL);
-        FUNCTION_TEST_ASSERT(key != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+    ASSERT(section != NULL);
+    ASSERT(key != NULL);
+
     // Get the value
     const Variant *result = iniGetInternal(this, section, key);
 
@@ -128,7 +124,7 @@ iniGetDefault(const Ini *this, const String *section, const String *key, Variant
     if (result == NULL)
         result = defaultValue;
 
-    FUNCTION_TEST_RESULT(CONST_VARIANT, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -140,11 +136,11 @@ iniSectionKeyList(const Ini *this, const String *section)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(INI, this);
         FUNCTION_TEST_PARAM(STRING, section);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(section != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+    ASSERT(section != NULL);
+
     StringList *result = NULL;
 
     MEM_CONTEXT_TEMP_BEGIN()
@@ -152,7 +148,7 @@ iniSectionKeyList(const Ini *this, const String *section)
         // Get the section
         KeyValue *sectionKv = varKv(kvGet(this->store, varNewStr(section)));
 
-        // Return key list of the section exists
+        // Return key list if the section exists
         if (sectionKv != NULL)
             result = strLstNewVarLst(kvKeyList(sectionKv));
         // Otherwise return an empty list
@@ -163,7 +159,33 @@ iniSectionKeyList(const Ini *this, const String *section)
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_TEST_RESULT(STRING_LIST, result);
+    FUNCTION_TEST_RETURN(result);
+}
+
+/***********************************************************************************************************************************
+Get a list of sections
+***********************************************************************************************************************************/
+StringList *
+iniSectionList(const Ini *this)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(INI, this);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+
+    StringList *result = NULL;
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        // Get the sections from the keyList
+        result = strLstNewVarLst(kvKeyList(this->store));
+
+        strLstMove(result, MEM_CONTEXT_OLD());
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -175,10 +197,10 @@ iniParse(Ini *this, const String *content)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(INI, this);
         FUNCTION_TEST_PARAM(STRING, content);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+
     MEM_CONTEXT_BEGIN(this->memContext)
     {
         kvFree(this->store);
@@ -245,37 +267,7 @@ iniParse(Ini *this, const String *content)
     }
     MEM_CONTEXT_END()
 
-    FUNCTION_TEST_RESULT_VOID();
-}
-
-/***********************************************************************************************************************************
-Load ini from a file
-***********************************************************************************************************************************/
-void
-iniLoad(Ini *this, const String *fileName)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(INI, this);
-        FUNCTION_TEST_PARAM(STRING, fileName);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(fileName != NULL);
-    FUNCTION_TEST_END();
-
-    MEM_CONTEXT_BEGIN(this->memContext)
-    {
-        // Set the filename
-        this->fileName = strDup(fileName);
-
-        MEM_CONTEXT_TEMP_BEGIN()
-        {
-            iniParse(this, strNewBuf(storageGetNP(storageNewReadNP(storageLocal(), this->fileName))));
-        }
-        MEM_CONTEXT_TEMP_END();
-    }
-    MEM_CONTEXT_END()
-
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
@@ -289,13 +281,13 @@ iniSet(Ini *this, const String *section, const String *key, const Variant *value
         FUNCTION_TEST_PARAM(STRING, section);
         FUNCTION_TEST_PARAM(STRING, key);
         FUNCTION_TEST_PARAM(VARIANT, value);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(section != NULL);
-        FUNCTION_TEST_ASSERT(key != NULL);
-        FUNCTION_TEST_ASSERT(value != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+    ASSERT(section != NULL);
+    ASSERT(key != NULL);
+    ASSERT(value != NULL);
+
     MEM_CONTEXT_TEMP_BEGIN()
     {
         Variant *sectionKey = varNewStr(section);
@@ -308,7 +300,7 @@ iniSet(Ini *this, const String *section, const String *key, const Variant *value
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
@@ -324,5 +316,5 @@ iniFree(Ini *this)
     if (this != NULL)
         memContextFree(this->memContext);
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
