@@ -15,26 +15,11 @@ Max size allowed for a single log message including header
     #define LOG_BUFFER_SIZE                                         ((size_t)(32 * 1024))
 #endif
 
-/***********************************************************************************************************************************
-Expose internal data for unit testing/debugging
-***********************************************************************************************************************************/
-#ifdef DEBUG_UNIT
-    extern LogLevel logLevelStdOut;
-    extern LogLevel logLevelStdErr;
-    extern LogLevel logLevelFile;
-
-    extern int logHandleStdOut;
-    extern int logHandleStdErr;
-    extern int logHandleFile;
-
-    extern bool logTimestamp;
-#endif
-
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
 void logInit(LogLevel logLevelStdOut, LogLevel logLevelStdErr, LogLevel logLevelFile, bool logTimestamp);
-void logFileSet(const char *logFile);
+bool logFileSet(const char *logFile);
 
 bool logWill(LogLevel logLevel);
 
@@ -69,6 +54,8 @@ do
     LOG_WILL(logLevelInfo, 0, __VA_ARGS__)
 #define LOG_DETAIL(...)                                                                                                            \
     LOG_WILL(logLevelDetail, 0, __VA_ARGS__)
+#define LOG_DEBUG(...)                                                                                                             \
+    LOG_WILL(logLevelDebug, 0, __VA_ARGS__)
 #define LOG_TRACE(...)                                                                                                             \
     LOG_WILL(logLevelTrace, 0, __VA_ARGS__)
 
