@@ -4,7 +4,6 @@ Memory Context Manager
 #include <stdlib.h>
 #include <string.h>
 
-#include "common/assert.h"
 #include "common/debug.h"
 #include "common/error.h"
 #include "common/memContext.h"
@@ -82,7 +81,7 @@ memAllocInternal(size_t size, bool zero)
         memset(buffer, 0, size);
 
     // Return the buffer
-    FUNCTION_TEST_RESULT(VOIDP, buffer);
+    FUNCTION_TEST_RETURN(buffer);
 }
 
 /***********************************************************************************************************************************
@@ -92,14 +91,14 @@ static void *
 memReAllocInternal(void *bufferOld, size_t sizeOld, size_t sizeNew, bool zeroNew)
 {
     FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(VOIDP, bufferOld);
+        FUNCTION_TEST_PARAM_P(VOID, bufferOld);
         FUNCTION_TEST_PARAM(SIZE, sizeOld);
         FUNCTION_TEST_PARAM(SIZE, sizeNew);
         FUNCTION_TEST_PARAM(BOOL, zeroNew);
-
-        FUNCTION_TEST_ASSERT(bufferOld != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(bufferOld != NULL);
+
     // Allocate memory
     void *bufferNew = realloc(bufferOld, sizeNew);
 
@@ -112,7 +111,7 @@ memReAllocInternal(void *bufferOld, size_t sizeOld, size_t sizeNew, bool zeroNew
         memset((unsigned char *)bufferNew + sizeOld, 0, sizeNew - sizeOld);
 
     // Return the buffer
-    FUNCTION_TEST_RESULT(VOIDP, bufferNew);
+    FUNCTION_TEST_RETURN(bufferNew);
 }
 
 /***********************************************************************************************************************************
@@ -122,14 +121,14 @@ static void
 memFreeInternal(void *buffer)
 {
     FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(VOIDP, buffer);
-
-        FUNCTION_TEST_ASSERT(buffer != NULL);
+        FUNCTION_TEST_PARAM_P(VOID, buffer);
     FUNCTION_TEST_END();
 
+    ASSERT(buffer != NULL);
+
     free(buffer);
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
@@ -141,10 +140,10 @@ memContextNewIndex(MemContext *memContext, bool allowFree)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(MEM_CONTEXT, memContext);
         FUNCTION_TEST_PARAM(BOOL, allowFree);
-
-        FUNCTION_TEST_ASSERT(memContext != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(memContext != NULL);
+
     // Try to find space for the new context
     unsigned int contextIdx;
 
@@ -185,7 +184,7 @@ memContextNewIndex(MemContext *memContext, bool allowFree)
         }
     }
 
-    FUNCTION_TEST_RESULT(UINT, contextIdx);
+    FUNCTION_TEST_RETURN(contextIdx);
 }
 
 /***********************************************************************************************************************************
@@ -196,10 +195,10 @@ memContextNew(const char *name)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRINGZ, name);
-
-        FUNCTION_TEST_ASSERT(name != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(name != NULL);
+
     // Check context name length
     if (strlen(name) == 0 || strlen(name) > MEM_CONTEXT_NAME_SIZE)
         THROW_FMT(AssertError, "context name length must be > 0 and <= %d", MEM_CONTEXT_NAME_SIZE);
@@ -228,7 +227,7 @@ memContextNew(const char *name)
     this->contextParent = memContextCurrent();
 
     // Return context
-    FUNCTION_TEST_RESULT(MEM_CONTEXT, this);
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -240,12 +239,12 @@ memContextCallback(MemContext *this, void (*callbackFunction)(void *), void *cal
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(MEM_CONTEXT, this);
         FUNCTION_TEST_PARAM(FUNCTIONP, callbackFunction);
-        FUNCTION_TEST_PARAM(VOIDP, callbackArgument);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(callbackFunction != NULL);
+        FUNCTION_TEST_PARAM_P(VOID, callbackArgument);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+    ASSERT(callbackFunction != NULL);
+
     // Error if context is not active
     if (this->state != memContextStateActive)
         THROW(AssertError, "cannot assign callback to inactive context");
@@ -262,7 +261,33 @@ memContextCallback(MemContext *this, void (*callbackFunction)(void *), void *cal
     this->callbackFunction = callbackFunction;
     this->callbackArgument = callbackArgument;
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
+}
+
+/***********************************************************************************************************************************
+Clear the mem context callback.  This is usually done in the object free method after resources have been freed but before
+memContextFree() is called.  The goal is to prevent the object free method from being called more than once.
+***********************************************************************************************************************************/
+void
+memContextCallbackClear(MemContext *this)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(MEM_CONTEXT, this);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+
+    // Error if context is not active or freeing
+    ASSERT(this->state == memContextStateActive || this->state == memContextStateFreeing);
+
+    // Top context cannot have a callback
+    ASSERT(this != memContextTop());
+
+    // Clear callback function and argument
+    this->callbackFunction = NULL;
+    this->callbackArgument = NULL;
+
+    FUNCTION_TEST_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
@@ -317,7 +342,7 @@ memContextAlloc(size_t size, bool zero)
     memContextCurrent()->allocList[allocIdx].buffer = memAllocInternal(size, zero);
 
     // Return buffer
-    FUNCTION_TEST_RESULT(VOIDP, memContextCurrent()->allocList[allocIdx].buffer);
+    FUNCTION_TEST_RETURN(memContextCurrent()->allocList[allocIdx].buffer);
 }
 
 /***********************************************************************************************************************************
@@ -327,11 +352,11 @@ static unsigned int
 memFind(const void *buffer)
 {
     FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(VOIDP, buffer);
-
-        FUNCTION_TEST_ASSERT(buffer != NULL);
+        FUNCTION_TEST_PARAM_P(VOID, buffer);
     FUNCTION_TEST_END();
 
+    ASSERT(buffer != NULL);
+
     // Find memory allocation
     unsigned int allocIdx;
 
@@ -343,7 +368,7 @@ memFind(const void *buffer)
     if (allocIdx == memContextCurrent()->allocListSize)
         THROW(AssertError, "unable to find allocation");
 
-    FUNCTION_TEST_RESULT(UINT, allocIdx);
+    FUNCTION_TEST_RETURN(allocIdx);
 }
 
 /***********************************************************************************************************************************
@@ -356,7 +381,7 @@ memNew(size_t size)
         FUNCTION_TEST_PARAM(SIZE, size);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(VOIDP, memContextAlloc(size, true));
+    FUNCTION_TEST_RETURN(memContextAlloc(size, true));
 }
 
 /***********************************************************************************************************************************
@@ -366,12 +391,12 @@ void *
 memGrowRaw(const void *buffer, size_t size)
 {
     FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(VOIDP, buffer);
+        FUNCTION_TEST_PARAM_P(VOID, buffer);
         FUNCTION_TEST_PARAM(SIZE, size);
-
-        FUNCTION_TEST_ASSERT(buffer != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(buffer != NULL);
+
     // Find the allocation
     MemContextAlloc *alloc = &(memContextCurrent()->allocList[memFind(buffer)]);
 
@@ -379,7 +404,7 @@ memGrowRaw(const void *buffer, size_t size)
     alloc->buffer = memReAllocInternal(alloc->buffer, alloc->size, size, false);
     alloc->size = (unsigned int)size;
 
-    FUNCTION_TEST_RESULT(VOIDP, alloc->buffer);
+    FUNCTION_TEST_RETURN(alloc->buffer);
 }
 
 /***********************************************************************************************************************************
@@ -392,7 +417,7 @@ memNewRaw(size_t size)
         FUNCTION_TEST_PARAM(SIZE, size);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(VOIDP, memContextAlloc(size, false));
+    FUNCTION_TEST_RETURN(memContextAlloc(size, false));
 }
 
 /***********************************************************************************************************************************
@@ -402,11 +427,11 @@ void
 memFree(void *buffer)
 {
     FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(VOIDP, buffer);
-
-        FUNCTION_TEST_ASSERT(buffer != NULL);
+        FUNCTION_TEST_PARAM_P(VOID, buffer);
     FUNCTION_TEST_END();
 
+    ASSERT(buffer != NULL);
+
     // Find the allocation
     MemContextAlloc *alloc = &(memContextCurrent()->allocList[memFind(buffer)]);
 
@@ -414,7 +439,7 @@ memFree(void *buffer)
     memFreeInternal(alloc->buffer);
     alloc->active = false;
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
@@ -428,12 +453,12 @@ memContextMove(MemContext *this, MemContext *parentNew)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(MEM_CONTEXT, this);
         FUNCTION_TEST_PARAM(MEM_CONTEXT, parentNew);
-
-        FUNCTION_TEST_ASSERT(parentNew != NULL);
     FUNCTION_TEST_END();
 
-    // Only move if a valid mem context is provided
-    if (this != NULL)
+    ASSERT(parentNew != NULL);
+
+    // Only move if a valid mem context is provided and the old and new parents are not the same
+    if (this != NULL && this->contextParent != parentNew)
     {
         // Find context in the old parent and NULL it out
         MemContext *parentOld = this->contextParent;
@@ -455,14 +480,14 @@ memContextMove(MemContext *this, MemContext *parentNew)
         // Find a place in the new parent context and assign it. The child list may be moved while finding a new index so store the
         // index and use it with (what might be) the new pointer.
         contextIdx = memContextNewIndex(parentNew, false);
-        ASSERT_DEBUG(parentNew->contextChildList[contextIdx] == NULL);
+        ASSERT(parentNew->contextChildList[contextIdx] == NULL);
         parentNew->contextChildList[contextIdx] = this;
 
         // Assign new parent
         this->contextParent = parentNew;
     }
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
@@ -473,10 +498,10 @@ memContextSwitch(MemContext *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(MEM_CONTEXT, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+
     // Error if context is not active
     if (this->state != memContextStateActive)
         THROW(AssertError, "cannot switch to inactive context");
@@ -484,27 +509,27 @@ memContextSwitch(MemContext *this)
     MemContext *memContextOld = memContextCurrent();
     contextCurrent = this;
 
-    FUNCTION_TEST_RESULT(MEM_CONTEXT, memContextOld);
+    FUNCTION_TEST_RETURN(memContextOld);
 }
 
 /***********************************************************************************************************************************
 Return the top context
 ***********************************************************************************************************************************/
 MemContext *
-memContextTop()
+memContextTop(void)
 {
     FUNCTION_TEST_VOID();
-    FUNCTION_TEST_RESULT(MEM_CONTEXT, &contextTop);
+    FUNCTION_TEST_RETURN(&contextTop);
 }
 
 /***********************************************************************************************************************************
 Return the current context
 ***********************************************************************************************************************************/
 MemContext *
-memContextCurrent()
+memContextCurrent(void)
 {
     FUNCTION_TEST_VOID();
-    FUNCTION_TEST_RESULT(MEM_CONTEXT, contextCurrent);
+    FUNCTION_TEST_RETURN(contextCurrent);
 }
 
 /***********************************************************************************************************************************
@@ -515,15 +540,15 @@ memContextName(MemContext *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(MEM_CONTEXT, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+
     // Error if context is not active
     if (this->state != memContextStateActive)
         THROW(AssertError, "cannot get name for inactive context");
 
-    FUNCTION_TEST_RESULT(STRINGZ, this->name);
+    FUNCTION_TEST_RETURN(this->name);
 }
 
 /***********************************************************************************************************************************
@@ -534,10 +559,10 @@ memContextFree(MemContext *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(MEM_CONTEXT, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+
     // If context is already freeing then return if memContextFree() is called again - this can happen in callbacks
     if (this->state != memContextStateFreeing)
     {
@@ -597,5 +622,5 @@ memContextFree(MemContext *this)
             memset(this, 0, sizeof(MemContext));
     }
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
