@@ -31,7 +31,7 @@ regExpError(int error)
     regerror(error, NULL, buffer, sizeof(buffer));
     THROW(FormatError, buffer);
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
@@ -42,10 +42,10 @@ regExpNew(const String *expression)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, expression);
-
-        FUNCTION_TEST_ASSERT(expression != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(expression != NULL);
+
     RegExp *this = NULL;
 
     MEM_CONTEXT_NEW_BEGIN("RegExp")
@@ -67,7 +67,7 @@ regExpNew(const String *expression)
     }
     MEM_CONTEXT_NEW_END();
 
-    FUNCTION_TEST_RESULT(REGEXP, this);
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -79,11 +79,11 @@ regExpMatch(RegExp *this, const String *string)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(REGEXP, this);
         FUNCTION_TEST_PARAM(STRING, string);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(string != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+    ASSERT(string != NULL);
+
     // Test for a match
     int result = regexec(&this->regExp, strPtr(string), 0, NULL, 0);
 
@@ -91,7 +91,7 @@ regExpMatch(RegExp *this, const String *string)
     if (result != 0 && result != REG_NOMATCH)                                   // {uncoverable - no error condition known}
         regExpError(result);                                                    // {+uncoverable}
 
-    FUNCTION_TEST_RESULT(BOOL, result == 0);
+    FUNCTION_TEST_RETURN(result == 0);
 }
 
 /***********************************************************************************************************************************
@@ -107,10 +107,12 @@ regExpFree(RegExp *this)
     if (this != NULL)
     {
         regfree(&this->regExp);
+
+        memContextCallbackClear(this->memContext);
         memContextFree(this->memContext);
     }
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
@@ -122,11 +124,11 @@ regExpMatchOne(const String *expression, const String *string)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, expression);
         FUNCTION_TEST_PARAM(STRING, string);
-
-        FUNCTION_TEST_ASSERT(expression != NULL);
-        FUNCTION_TEST_ASSERT(string != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(expression != NULL);
+    ASSERT(string != NULL);
+
     bool result = false;
     RegExp *regExp = regExpNew(expression);
 
@@ -140,5 +142,46 @@ regExpMatchOne(const String *expression, const String *string)
     }
     TRY_END();
 
-    FUNCTION_TEST_RESULT(BOOL, result);
+    FUNCTION_TEST_RETURN(result);
+}
+
+/***********************************************************************************************************************************
+Return the constant first part of the regular expression if it has a beginning anchor
+
+This works by scanning the string until the first special regex character is found so escaped characters will not be included.
+***********************************************************************************************************************************/
+String *
+regExpPrefix(const String *expression)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STRING, expression);
+    FUNCTION_TEST_END();
+
+    String *result = NULL;
+
+    // Only generate prefix if expression is defined and has a beginning anchor
+    if (expression != NULL && strPtr(expression)[0] == '^')
+    {
+        unsigned int expressionIdx = 1;
+
+        for (; expressionIdx < strSize(expression); expressionIdx++)
+        {
+            char expressionChr = strPtr(expression)[expressionIdx];
+
+            // Search for characters that will end the prefix
+            if (expressionChr == '.' || expressionChr == '^' || expressionChr == '$' || expressionChr == '*' ||
+                expressionChr == '+' || expressionChr == '-' || expressionChr == '?' || expressionChr == '(' ||
+                expressionChr == '[' || expressionChr == '{' || expressionChr == ' ' || expressionChr == '|' ||
+                expressionChr == '\\')
+            {
+                break;
+            }
+        }
+
+        // Will there be any characters in the prefix?
+        if (expressionIdx > 1)
+            result = strSubN(expression, 1, expressionIdx - 1);
+    }
+
+    FUNCTION_TEST_RETURN(result);
 }
