@@ -91,19 +91,19 @@ Flag to enable/disable test function logging
 bool stackTraceTestFlag = true;
 
 void
-stackTraceTestStart()
+stackTraceTestStart(void)
 {
     stackTraceTestFlag = true;
 }
 
 void
-stackTraceTestStop()
+stackTraceTestStop(void)
 {
     stackTraceTestFlag = false;
 }
 
 bool
-stackTraceTest()
+stackTraceTest(void)
 {
     return stackTraceTestFlag;
 }
@@ -161,15 +161,15 @@ Get parameters for the top function on the stack
 static const char *
 stackTraceParamIdx(int stackIdx)
 {
-    ASSERT_DEBUG(stackSize > 0);
-    ASSERT_DEBUG(stackIdx < stackSize);
+    ASSERT(stackSize > 0);
+    ASSERT(stackIdx < stackSize);
 
     StackTraceData *data = &stackTrace[stackIdx];
 
     if (data->paramLog)
     {
         if (data->paramOverflow)
-            return "!!! buffer overflow - parameters not available !!!";
+            return "buffer full - parameters not available";
 
         if (data->paramSize == 0)
             return "void";
@@ -177,7 +177,9 @@ stackTraceParamIdx(int stackIdx)
         return data->param;
     }
 
-    return "debug log level required for parameters";
+    // If no parameters return the log level required to get them
+    #define LOG_LEVEL_REQUIRED " log level required for parameters"
+    return data->functionLogLevel == logLevelTrace ? "trace" LOG_LEVEL_REQUIRED : "debug" LOG_LEVEL_REQUIRED;
 }
 
 const char *
@@ -192,7 +194,7 @@ Get the next location where a parameter can be added in the param buffer
 char *
 stackTraceParamBuffer(const char *paramName)
 {
-    ASSERT_DEBUG(stackSize > 0);
+    ASSERT(stackSize > 0);
 
     StackTraceData *data = &stackTrace[stackSize - 1];
     size_t paramNameSize = strlen(paramName);
@@ -234,7 +236,7 @@ Add a parameter to the function on the top of the stack
 void
 stackTraceParamAdd(size_t bufferSize)
 {
-    ASSERT_DEBUG(stackSize > 0);
+    ASSERT(stackSize > 0);
 
     StackTraceData *data = &stackTrace[stackSize - 1];
 
@@ -246,9 +248,9 @@ stackTraceParamAdd(size_t bufferSize)
 Mark that parameters are being logged -- it none appear then the function is void
 ***********************************************************************************************************************************/
 void
-stackTraceParamLog()
+stackTraceParamLog(void)
 {
-    ASSERT_DEBUG(stackSize > 0);
+    ASSERT(stackSize > 0);
 
     stackTrace[stackSize - 1].paramLog = true;
 }
@@ -259,7 +261,7 @@ Pop a function from the stack trace
 #ifdef NDEBUG
 
 void
-stackTracePop()
+stackTracePop(void)
 {
     stackSize--;
 }
@@ -269,7 +271,7 @@ stackTracePop()
 void
 stackTracePop(const char *fileName, const char *functionName)
 {
-    ASSERT_DEBUG(stackSize > 0);
+    ASSERT(stackSize > 0);
 
     stackSize--;
 
