@@ -20,6 +20,14 @@ Constants describing number of sub-units in an interval
 Functions
 ***********************************************************************************************************************************/
 void sleepMSec(TimeMSec sleepMSec);
-TimeMSec timeMSec();
+TimeMSec timeMSec(void);
+
+/***********************************************************************************************************************************
+Macros for function logging
+***********************************************************************************************************************************/
+#define FUNCTION_LOG_TIME_MSEC_TYPE                                                                                                \
+    TimeMSec
+#define FUNCTION_LOG_TIME_MSEC_FORMAT(value, buffer, bufferSize)                                                                   \
+    cvtUInt64ToZ(value, buffer, bufferSize)
 
 #endif
