@@ -14,10 +14,11 @@ typedef struct KeyValue KeyValue;
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
-KeyValue *kvNew();
+KeyValue *kvNew(void);
 KeyValue *kvDup(const KeyValue *source);
 KeyValue *kvAdd(KeyValue *this, const Variant *key, const Variant *value);
 const VariantList *kvKeyList(const KeyValue *this);
+KeyValue *kvMove(KeyValue *this, MemContext *parentNew);
 KeyValue *kvPut(KeyValue *this, const Variant *key, const Variant *value);
 KeyValue *kvPutKv(KeyValue *this, const Variant *key);
 const Variant *kvGet(const KeyValue *this, const Variant *key);
@@ -27,9 +28,9 @@ void kvFree(KeyValue *this);
 /***********************************************************************************************************************************
 Macros for function logging
 ***********************************************************************************************************************************/
-#define FUNCTION_DEBUG_KEY_VALUE_TYPE                                                                                              \
+#define FUNCTION_LOG_KEY_VALUE_TYPE                                                                                                \
     KeyValue *
-#define FUNCTION_DEBUG_KEY_VALUE_FORMAT(value, buffer, bufferSize)                                                                 \
+#define FUNCTION_LOG_KEY_VALUE_FORMAT(value, buffer, bufferSize)                                                                   \
     objToLog(value, "KeyValue", buffer, bufferSize)
 
 #endif
