@@ -40,7 +40,7 @@ lstNew(size_t itemSize)
     }
     MEM_CONTEXT_NEW_END();
 
-    FUNCTION_TEST_RESULT(LIST, this);
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -51,12 +51,53 @@ lstAdd(List *this, const void *item)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(LIST, this);
-        FUNCTION_TEST_PARAM(VOIDP, item);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(item != NULL);
+        FUNCTION_TEST_PARAM_P(VOID, item);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+    ASSERT(item != NULL);
+
+    lstInsert(this, lstSize(this), item);
+
+    FUNCTION_TEST_RETURN(this);
+}
+
+/***********************************************************************************************************************************
+Get an item from the list
+***********************************************************************************************************************************/
+void *
+lstGet(const List *this, unsigned int listIdx)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(LIST, this);
+        FUNCTION_TEST_PARAM(UINT, listIdx);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+
+    // Ensure list index is in range
+    if (listIdx >= this->listSize)
+        THROW_FMT(AssertError, "cannot get index %u from list with %u value(s)", listIdx, this->listSize);
+
+    // Return pointer to list item
+    FUNCTION_TEST_RETURN(this->list + (listIdx * this->itemSize));
+}
+
+/***********************************************************************************************************************************
+Insert an item into the list
+***********************************************************************************************************************************/
+List *
+lstInsert(List *this, unsigned int listIdx, const void *item)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(LIST, this);
+        FUNCTION_TEST_PARAM_P(VOID, item);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+    ASSERT(listIdx <= lstSize(this));
+    ASSERT(item != NULL);
+
     // If list size = max then allocate more space
     if (this->listSize == this->listSizeMax)
     {
@@ -78,31 +119,19 @@ lstAdd(List *this, const void *item)
         MEM_CONTEXT_END();
     }
 
-    memcpy(this->list + (this->listSize * this->itemSize), item, this->itemSize);
+    // If not inserting at the end then move items down to make space
+    if (listIdx != lstSize(this))
+    {
+        memmove(
+            this->list + ((listIdx + 1) * this->itemSize), this->list + (listIdx * this->itemSize),
+            (lstSize(this) - listIdx) * this->itemSize);
+    }
+
+    // Copy item into the list
+    memcpy(this->list + (listIdx * this->itemSize), item, this->itemSize);
     this->listSize++;
 
-    FUNCTION_TEST_RESULT(LIST, this);
-}
-
-/***********************************************************************************************************************************
-Get an item from the list
-***********************************************************************************************************************************/
-void *
-lstGet(const List *this, unsigned int listIdx)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(LIST, this);
-        FUNCTION_TEST_PARAM(UINT, listIdx);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-    FUNCTION_TEST_END();
-
-    // Ensure list index is in range
-    if (listIdx >= this->listSize)
-        THROW_FMT(AssertError, "cannot get index %u from list with %u value(s)", listIdx, this->listSize);
-
-    // Return pointer to list item
-    FUNCTION_TEST_RESULT(VOIDP, this->list + (listIdx * this->itemSize));
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -113,11 +142,11 @@ lstMemContext(const List *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(LIST, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(MEM_CONTEXT, this->memContext);
+    ASSERT(this != NULL);
+
+    FUNCTION_TEST_RETURN(this->memContext);
 }
 
 /***********************************************************************************************************************************
@@ -129,14 +158,14 @@ lstMove(List *this, MemContext *parentNew)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(LIST, this);
         FUNCTION_TEST_PARAM(MEM_CONTEXT, parentNew);
-
-        FUNCTION_TEST_ASSERT(parentNew != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(parentNew != NULL);
+
     if (this != NULL)
         memContextMove(this->memContext, parentNew);
 
-    FUNCTION_TEST_RESULT(LIST, this);
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -147,11 +176,11 @@ lstSize(const List *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(LIST, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(UINT, this->listSize);
+    ASSERT(this != NULL);
+
+    FUNCTION_TEST_RETURN(this->listSize);
 }
 
 /***********************************************************************************************************************************
@@ -163,38 +192,23 @@ lstSort(List *this, int (*comparator)(const void *, const void*))
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(LIST, this);
         FUNCTION_TEST_PARAM(FUNCTIONP, comparator);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(comparator != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+    ASSERT(comparator != NULL);
+
     qsort(this->list, this->listSize, this->itemSize, comparator);
 
-    FUNCTION_TEST_RESULT(LIST, this);
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
-Convert to a zero-terminated string for logging
+Render as string for logging
 ***********************************************************************************************************************************/
-size_t
-lstToLog(const List *this, char *buffer, size_t bufferSize)
+String *
+lstToLog(const List *this)
 {
-    size_t result = 0;
-
-    MEM_CONTEXT_TEMP_BEGIN()
-    {
-        String *string = NULL;
-
-        if (this == NULL)
-            string = strNew("null");
-        else
-            string = strNewFmt("{size: %u}", this->listSize);
-
-        result = (size_t)snprintf(buffer, bufferSize, "%s", strPtr(string));
-    }
-    MEM_CONTEXT_TEMP_END();
-
-    return result;
+    return strNewFmt("{size: %u}", this->listSize);
 }
 
 /***********************************************************************************************************************************
@@ -210,5 +224,5 @@ lstFree(List *this)
     if (this != NULL)
         memContextFree(this->memContext);
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
