@@ -23,6 +23,7 @@ Functions
 List *lstNew(size_t itemSize);
 List *lstAdd(List *this, const void *item);
 void *lstGet(const List *this, unsigned int listIdx);
+List *lstInsert(List *this, unsigned int listIdx, const void *item);
 MemContext *lstMemContext(const List *this);
 List *lstMove(List *this, MemContext *parentNew);
 unsigned int lstSize(const List *this);
@@ -32,11 +33,11 @@ void lstFree(List *this);
 /***********************************************************************************************************************************
 Macros for function logging
 ***********************************************************************************************************************************/
-size_t lstToLog(const List *this, char *buffer, size_t bufferSize);
+String *lstToLog(const List *this);
 
-#define FUNCTION_DEBUG_LIST_TYPE                                                                                                   \
+#define FUNCTION_LOG_LIST_TYPE                                                                                                     \
     List *
-#define FUNCTION_DEBUG_LIST_FORMAT(value, buffer, bufferSize)                                                                      \
-    lstToLog(value, buffer, bufferSize)
+#define FUNCTION_LOG_LIST_FORMAT(value, buffer, bufferSize)                                                                        \
+    FUNCTION_LOG_STRING_OBJECT_FORMAT(value, lstToLog, buffer, bufferSize)
 
 #endif
