@@ -7,19 +7,45 @@ String Handler
 #include <stdlib.h>
 #include <string.h>
 
-#include "common/assert.h"
 #include "common/debug.h"
 #include "common/memContext.h"
 #include "common/type/string.h"
 
 /***********************************************************************************************************************************
-Contains information about the string
+Constant strings that are generally useful
+***********************************************************************************************************************************/
+STRING_EXTERN(CR_STR,                                               "\r");
+STRING_EXTERN(EMPTY_STR,                                            "");
+STRING_EXTERN(FSLASH_STR,                                           "/");
+STRING_EXTERN(LF_STR,                                               "\n");
+STRING_EXTERN(N_STR,                                                "n");
+STRING_EXTERN(NULL_STR,                                             "null");
+STRING_EXTERN(Y_STR,                                                "y");
+STRING_EXTERN(ZERO_STR,                                             "0");
+
+/***********************************************************************************************************************************
+Maximum size of a string
+***********************************************************************************************************************************/
+#define STRING_SIZE_MAX                                            1073741824
+
+#define CHECK_SIZE(size)                                                                                                           \
+    do                                                                                                                             \
+    {                                                                                                                              \
+        if ((size) > STRING_SIZE_MAX)                                                                                              \
+            THROW(AssertError, "string size must be <= " MACRO_TO_STR(STRING_SIZE_MAX) " bytes");                                  \
+    }                                                                                                                              \
+    while(0)
+
+
+/***********************************************************************************************************************************
+Object type
 ***********************************************************************************************************************************/
 struct String
 {
-    MemContext *memContext;
-    size_t size;
-    char *buffer;
+    // This struct must always be declared first.  These are the fields that are shared in common with constant strings.
+    struct StringCommon common;
+
+    MemContext *memContext;                                         // Required for dynamically allocated strings
 };
 
 /***********************************************************************************************************************************
@@ -30,20 +56,24 @@ strNew(const char *string)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRINGZ, string);
-
-        FUNCTION_TEST_ASSERT(string != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(string != NULL);
+
+    // Check size
+    size_t stringSize = strlen(string);
+    CHECK_SIZE(stringSize);
+
     // Create object
     String *this = memNew(sizeof(String));
     this->memContext = memContextCurrent();
-    this->size = strlen(string);
+    this->common.size = (unsigned int)stringSize;
 
     // Allocate and assign string
-    this->buffer = memNewRaw(this->size + 1);
-    strcpy(this->buffer, string);
+    this->common.buffer = memNewRaw(this->common.size + 1);
+    strcpy(this->common.buffer, string);
 
-    FUNCTION_TEST_RESULT(STRING, this);
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -57,21 +87,24 @@ strNewBuf(const Buffer *buffer)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(BUFFER, buffer);
-
-        FUNCTION_TEST_ASSERT(buffer != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(buffer != NULL);
+
+    // Check size
+    CHECK_SIZE(bufUsed(buffer));
+
     // Create object
     String *this = memNew(sizeof(String));
     this->memContext = memContextCurrent();
-    this->size = bufSize(buffer);
+    this->common.size = (unsigned int)bufUsed(buffer);
 
     // Allocate and assign string
-    this->buffer = memNewRaw(this->size + 1);
-    memcpy(this->buffer, (char *)bufPtr(buffer), this->size);
-    this->buffer[this->size] = 0;
+    this->common.buffer = memNewRaw(this->common.size + 1);
+    memcpy(this->common.buffer, (char *)bufPtr(buffer), this->common.size);
+    this->common.buffer[this->common.size] = 0;
 
-    FUNCTION_TEST_RESULT(STRING, this);
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -82,10 +115,10 @@ strNewFmt(const char *format, ...)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRINGZ, format);
-
-        FUNCTION_TEST_ASSERT(format != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(format != NULL);
+
     // Create object
     String *this = memNew(sizeof(String));
     this->memContext = memContextCurrent();
@@ -93,16 +126,20 @@ strNewFmt(const char *format, ...)
     // Determine how long the allocated string needs to be
     va_list argumentList;
     va_start(argumentList, format);
-    this->size = (size_t)vsnprintf(NULL, 0, format, argumentList);
+    size_t formatSize = (size_t)vsnprintf(NULL, 0, format, argumentList);
     va_end(argumentList);
 
+    // Check size
+    CHECK_SIZE(formatSize);
+
     // Allocate and assign string
-    this->buffer = memNewRaw(this->size + 1);
+    this->common.size = (unsigned int)formatSize;
+    this->common.buffer = memNewRaw(this->common.size + 1);
     va_start(argumentList, format);
-    vsnprintf(this->buffer, this->size + 1, format, argumentList);
+    vsnprintf(this->common.buffer, this->common.size + 1, format, argumentList);
     va_end(argumentList);
 
-    FUNCTION_TEST_RESULT(STRING, this);
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -114,24 +151,27 @@ String *
 strNewN(const char *string, size_t size)
 {
     FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(CHARP, string);
+        FUNCTION_TEST_PARAM_P(CHARDATA, string);
         FUNCTION_TEST_PARAM(SIZE, size);
-
-        FUNCTION_TEST_ASSERT(string != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(string != NULL);
+
+    // Check size
+    CHECK_SIZE(size);
+
     // Create object
     String *this = memNew(sizeof(String));
     this->memContext = memContextCurrent();
-    this->size = size;
+    this->common.size = (unsigned int)size;
 
     // Allocate and assign string
-    this->buffer = memNewRaw(this->size + 1);
-    strncpy(this->buffer, string, this->size);
-    this->buffer[this->size] = 0;
+    this->common.buffer = memNewRaw(this->common.size + 1);
+    strncpy(this->common.buffer, string, this->common.size);
+    this->common.buffer[this->common.size] = 0;
 
     // Return buffer
-    FUNCTION_TEST_RESULT(STRING, this);
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -142,16 +182,16 @@ strBase(const String *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
-    const char *end = this->buffer + this->size;
+    ASSERT(this != NULL);
 
-    while (end > this->buffer && *(end - 1) != '/')
+    const char *end = this->common.buffer + this->common.size;
+
+    while (end > this->common.buffer && *(end - 1) != '/')
         end--;
 
-    FUNCTION_TEST_RESULT(STRING, strNew(end));
+    FUNCTION_TEST_RETURN(strNew(end));
 }
 
 /***********************************************************************************************************************************
@@ -163,12 +203,12 @@ strBeginsWith(const String *this, const String *beginsWith)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
         FUNCTION_TEST_PARAM(STRING, beginsWith);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(beginsWith != NULL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(BOOL, strBeginsWithZ(this, strPtr(beginsWith)));
+    ASSERT(this != NULL);
+    ASSERT(beginsWith != NULL);
+
+    FUNCTION_TEST_RETURN(strBeginsWithZ(this, strPtr(beginsWith)));
 }
 
 bool
@@ -177,18 +217,47 @@ strBeginsWithZ(const String *this, const char *beginsWith)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
         FUNCTION_TEST_PARAM(STRINGZ, beginsWith);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(beginsWith != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+    ASSERT(beginsWith != NULL);
+
     bool result = false;
     unsigned int beginsWithSize = (unsigned int)strlen(beginsWith);
 
-    if (this->size >= beginsWithSize)
+    if (this->common.size >= beginsWithSize)
         result = strncmp(strPtr(this), beginsWith, beginsWithSize) == 0;
 
-    FUNCTION_TEST_RESULT(BOOL, result);
+    FUNCTION_TEST_RETURN(result);
+}
+
+/***********************************************************************************************************************************
+Resize the string to allow the requested number of characters to be appended
+***********************************************************************************************************************************/
+static void
+strResize(String *this, size_t requested)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STRING, this);
+        FUNCTION_TEST_PARAM(SIZE, requested);
+    FUNCTION_TEST_END();
+
+    if (requested > this->common.extra)
+    {
+        // Check size
+        CHECK_SIZE((size_t)this->common.size + requested);
+
+        // Calculate new extra needs to satisfy request and leave extra space for new growth
+        this->common.extra = (unsigned int)requested + ((this->common.size + (unsigned int)requested) / 2);
+
+        MEM_CONTEXT_BEGIN(this->memContext)
+        {
+            this->common.buffer = memGrowRaw(this->common.buffer, this->common.size + this->common.extra + 1);
+        }
+        MEM_CONTEXT_END();
+    }
+
+    FUNCTION_TEST_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
@@ -200,25 +269,48 @@ strCat(String *this, const char *cat)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
         FUNCTION_TEST_PARAM(STRINGZ, cat);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(cat != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+    ASSERT(cat != NULL);
+
     // Determine length of string to append
     size_t sizeGrow = strlen(cat);
 
-    // Allocate and append string
-    MEM_CONTEXT_BEGIN(this->memContext)
-    {
-        this->buffer = memGrowRaw(this->buffer, this->size + sizeGrow + 1);
-    }
-    MEM_CONTEXT_END();
+    // Ensure there is enough space to grow the string
+    strResize(this, sizeGrow);
 
-    strcpy(this->buffer + this->size, cat);
-    this->size += sizeGrow;
+    // Append the string
+    strcpy(this->common.buffer + this->common.size, cat);
+    this->common.size += (unsigned int)sizeGrow;
+    this->common.extra -= (unsigned int)sizeGrow;
 
-    FUNCTION_TEST_RESULT(STRING, this);
+    FUNCTION_TEST_RETURN(this);
+}
+
+/***********************************************************************************************************************************
+Append a character
+***********************************************************************************************************************************/
+String *
+strCatChr(String *this, char cat)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STRING, this);
+        FUNCTION_TEST_PARAM(CHAR, cat);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+    ASSERT(cat != 0);
+
+    // Ensure there is enough space to grow the string
+    strResize(this, 1);
+
+    // Append the character
+    this->common.buffer[this->common.size++] = cat;
+    this->common.buffer[this->common.size] = 0;
+    this->common.extra--;
+
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -230,31 +322,29 @@ strCatFmt(String *this, const char *format, ...)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
         FUNCTION_TEST_PARAM(STRINGZ, format);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(format != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+    ASSERT(format != NULL);
+
     // Determine how long the allocated string needs to be
     va_list argumentList;
     va_start(argumentList, format);
     size_t sizeGrow = (size_t)vsnprintf(NULL, 0, format, argumentList);
     va_end(argumentList);
 
-    // Allocate and append string
-    MEM_CONTEXT_BEGIN(this->memContext)
-    {
-        this->buffer = memGrowRaw(this->buffer, this->size + sizeGrow + 1);
-    }
-    MEM_CONTEXT_END();
+    // Ensure there is enough space to grow the string
+    strResize(this, sizeGrow);
 
+    // Append the formatted string
     va_start(argumentList, format);
-    vsnprintf(this->buffer + this->size, sizeGrow + 1, format, argumentList);
+    vsnprintf(this->common.buffer + this->common.size, sizeGrow + 1, format, argumentList);
     va_end(argumentList);
 
-    this->size += sizeGrow;
+    this->common.size += (unsigned int)sizeGrow;
+    this->common.extra -= (unsigned int)sizeGrow;
 
-    FUNCTION_TEST_RESULT(STRING, this);
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -266,12 +356,12 @@ strCmp(const String *this, const String *compare)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
         FUNCTION_TEST_PARAM(STRING, compare);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(compare != NULL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(INT, strcmp(strPtr(this), strPtr(compare)));
+    ASSERT(this != NULL);
+    ASSERT(compare != NULL);
+
+    FUNCTION_TEST_RETURN(strcmp(strPtr(this), strPtr(compare)));
 }
 
 int
@@ -280,12 +370,12 @@ strCmpZ(const String *this, const char *compare)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
         FUNCTION_TEST_PARAM(STRINGZ, compare);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(compare != NULL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(INT, strcmp(strPtr(this), compare));
+    ASSERT(this != NULL);
+    ASSERT(compare != NULL);
+
+    FUNCTION_TEST_RETURN(strcmp(strPtr(this), compare));
 }
 
 /***********************************************************************************************************************************
@@ -303,7 +393,20 @@ strDup(const String *this)
     if (this != NULL)
         result = strNew(strPtr(this));
 
-    FUNCTION_TEST_RESULT(STRING, result);
+    FUNCTION_TEST_RETURN(result);
+}
+
+/***********************************************************************************************************************************
+Is the string empty?
+***********************************************************************************************************************************/
+bool
+strEmpty(const String *this)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STRING, this);
+    FUNCTION_TEST_END();
+
+    FUNCTION_TEST_RETURN(strSize(this) == 0);
 }
 
 /***********************************************************************************************************************************
@@ -315,12 +418,12 @@ strEndsWith(const String *this, const String *endsWith)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
         FUNCTION_TEST_PARAM(STRING, endsWith);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(endsWith != NULL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(BOOL, strEndsWithZ(this, strPtr(endsWith)));
+    ASSERT(this != NULL);
+    ASSERT(endsWith != NULL);
+
+    FUNCTION_TEST_RETURN(strEndsWithZ(this, strPtr(endsWith)));
 }
 
 bool
@@ -329,18 +432,18 @@ strEndsWithZ(const String *this, const char *endsWith)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
         FUNCTION_TEST_PARAM(STRINGZ, endsWith);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(endsWith != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+    ASSERT(endsWith != NULL);
+
     bool result = false;
     unsigned int endsWithSize = (unsigned int)strlen(endsWith);
 
-    if (this->size >= endsWithSize)
-        result = strcmp(strPtr(this) + (this->size - endsWithSize), endsWith) == 0;
+    if (this->common.size >= endsWithSize)
+        result = strcmp(strPtr(this) + (this->common.size - endsWithSize), endsWith) == 0;
 
-    FUNCTION_TEST_RESULT(BOOL, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -355,17 +458,17 @@ strEq(const String *this, const String *compare)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
         FUNCTION_TEST_PARAM(STRING, compare);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(compare != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+    ASSERT(compare != NULL);
+
     bool result = false;
 
-    if (this->size == compare->size)
+    if (this->common.size == compare->common.size)
         result = strcmp(strPtr(this), strPtr(compare)) == 0;
 
-    FUNCTION_TEST_RESULT(BOOL, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 bool
@@ -374,12 +477,12 @@ strEqZ(const String *this, const char *compare)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
         FUNCTION_TEST_PARAM(STRINGZ, compare);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(compare != NULL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(BOOL, strcmp(strPtr(this), compare) == 0);
+    ASSERT(this != NULL);
+    ASSERT(compare != NULL);
+
+    FUNCTION_TEST_RETURN(strcmp(strPtr(this), compare) == 0);
 }
 
 /***********************************************************************************************************************************
@@ -390,14 +493,14 @@ strFirstUpper(String *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
-    if (this->size > 0)
-        this->buffer[0] = (char)toupper(this->buffer[0]);
+    ASSERT(this != NULL);
 
-    FUNCTION_TEST_RESULT(STRING, this);
+    if (this->common.size > 0)
+        this->common.buffer[0] = (char)toupper(this->common.buffer[0]);
+
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -408,14 +511,14 @@ strFirstLower(String *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
-    if (this->size > 0)
-        this->buffer[0] = (char)tolower(this->buffer[0]);
+    ASSERT(this != NULL);
 
-    FUNCTION_TEST_RESULT(STRING, this);
+    if (this->common.size > 0)
+        this->common.buffer[0] = (char)tolower(this->common.buffer[0]);
+
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -426,15 +529,15 @@ strUpper(String *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
-    if (this->size > 0)
-        for (unsigned int idx = 0; idx <= this->size; idx++)
-            this->buffer[idx] = (char)toupper(this->buffer[idx]);
+    ASSERT(this != NULL);
 
-    FUNCTION_TEST_RESULT(STRING, this);
+    if (this->common.size > 0)
+        for (unsigned int idx = 0; idx <= this->common.size; idx++)
+            this->common.buffer[idx] = (char)toupper(this->common.buffer[idx]);
+
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -445,15 +548,15 @@ strLower(String *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
-    if (this->size > 0)
-        for (unsigned int idx = 0; idx <= this->size; idx++)
-            this->buffer[idx] = (char)tolower(this->buffer[idx]);
+    ASSERT(this != NULL);
 
-    FUNCTION_TEST_RESULT(STRING, this);
+    if (this->common.size > 0)
+        for (unsigned int idx = 0; idx <= this->common.size; idx++)
+            this->common.buffer[idx] = (char)tolower(this->common.buffer[idx]);
+
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -464,17 +567,19 @@ strPath(const String *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
-    const char *end = this->buffer + this->size;
+    ASSERT(this != NULL);
 
-    while (end > this->buffer && *(end - 1) != '/')
+    const char *end = this->common.buffer + this->common.size;
+
+    while (end > this->common.buffer && *(end - 1) != '/')
         end--;
 
-    FUNCTION_TEST_RESULT(
-        STRING, strNewN(this->buffer, end - this->buffer <= 1 ? (size_t)(end - this->buffer) : (size_t)(end - this->buffer - 1)));
+    FUNCTION_TEST_RETURN(
+        strNewN(
+            this->common.buffer,
+            end - this->common.buffer <= 1 ? (size_t)(end - this->common.buffer) : (size_t)(end - this->common.buffer - 1)));
 }
 
 /***********************************************************************************************************************************
@@ -490,9 +595,9 @@ strPtr(const String *this)
     char *result = NULL;
 
     if (this != NULL)
-        result = this->buffer;
+        result = this->common.buffer;
 
-    FUNCTION_TEST_RESULT(CHARP, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -504,12 +609,12 @@ strQuote(const String *this, const String *quote)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
         FUNCTION_TEST_PARAM(STRING, quote);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(quote != NULL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(STRING, strQuoteZ(this, strPtr(quote)));
+    ASSERT(this != NULL);
+    ASSERT(quote != NULL);
+
+    FUNCTION_TEST_RETURN(strQuoteZ(this, strPtr(quote)));
 }
 
 String *
@@ -518,12 +623,35 @@ strQuoteZ(const String *this, const char *quote)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
         FUNCTION_TEST_PARAM(STRINGZ, quote);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(quote != NULL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(STRING, strNewFmt("%s%s%s", quote, strPtr(this), quote));
+    ASSERT(this != NULL);
+    ASSERT(quote != NULL);
+
+    FUNCTION_TEST_RETURN(strNewFmt("%s%s%s", quote, strPtr(this), quote));
+}
+
+/***********************************************************************************************************************************
+Replace a character with another character
+***********************************************************************************************************************************/
+String *
+strReplaceChr(String *this, char find, char replace)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STRING, this);
+        FUNCTION_TEST_PARAM(CHAR, find);
+        FUNCTION_TEST_PARAM(CHAR, replace);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+
+    for (unsigned int stringIdx = 0; stringIdx < this->common.size; stringIdx++)
+    {
+        if (this->common.buffer[stringIdx] == find)
+            this->common.buffer[stringIdx] = replace;
+    }
+
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -535,12 +663,12 @@ strSub(const String *this, size_t start)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
         FUNCTION_TEST_PARAM(SIZE, start);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(start < this->size);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(STRING, strSubN(this, start, this->size - start));
+    ASSERT(this != NULL);
+    ASSERT(start < this->common.size);
+
+    FUNCTION_TEST_RETURN(strSubN(this, start, this->common.size - start));
 }
 
 /***********************************************************************************************************************************
@@ -553,13 +681,13 @@ strSubN(const String *this, size_t start, size_t size)
         FUNCTION_TEST_PARAM(STRING, this);
         FUNCTION_TEST_PARAM(SIZE, start);
         FUNCTION_TEST_PARAM(SIZE, size);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(start < this->size);
-        FUNCTION_TEST_ASSERT(start + size <= this->size);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(STRING, strNewN(this->buffer + start, size));
+    ASSERT(this != NULL);
+    ASSERT(start < this->common.size);
+    ASSERT(start + size <= this->common.size);
+
+    FUNCTION_TEST_RETURN(strNewN(this->common.buffer + start, size));
 }
 
 /***********************************************************************************************************************************
@@ -570,11 +698,11 @@ strSize(const String *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(SIZE, this->size);
+    ASSERT(this != NULL);
+
+    FUNCTION_TEST_RETURN(this->common.size);
 }
 
 /***********************************************************************************************************************************
@@ -585,21 +713,21 @@ strTrim(String *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+
     // Nothing to trim if size is zero
-    if (this->size > 0)
+    if (this->common.size > 0)
     {
         // Find the beginning of the string skipping all whitespace
-        char *begin = this->buffer;
+        char *begin = this->common.buffer;
 
         while (*begin != 0 && (*begin == ' ' || *begin == '\t' || *begin == '\r' || *begin == '\n'))
             begin++;
 
         // Find the end of the string skipping all whitespace
-        char *end = this->buffer + (this->size - 1);
+        char *end = this->common.buffer + (this->common.size - 1);
 
         while (end > begin && (*end == ' ' || *end == '\t' || *end == '\r' || *end == '\n'))
             end--;
@@ -607,25 +735,26 @@ strTrim(String *this)
         // Is there anything to trim?
         size_t newSize = (size_t)(end - begin + 1);
 
-        if (begin != this->buffer || newSize < strSize(this))
+        if (begin != this->common.buffer || newSize < strSize(this))
         {
             // Calculate new size
-            this->size = newSize;
+            this->common.size = (unsigned int)newSize;
 
             // Move the substr to the beginning of the buffer
-            memmove(this->buffer, begin, this->size);
-            this->buffer[this->size] = 0;
+            memmove(this->common.buffer, begin, this->common.size);
+            this->common.buffer[this->common.size] = 0;
+            this->common.extra = 0;
 
             MEM_CONTEXT_BEGIN(this->memContext)
             {
                 // Resize the buffer
-                this->buffer = memGrowRaw(this->buffer, this->size + 1);
+                this->common.buffer = memGrowRaw(this->common.buffer, this->common.size + 1);
             }
             MEM_CONTEXT_END();
         }
     }
 
-    FUNCTION_TEST_RESULT(STRING, this);
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -636,21 +765,22 @@ strChr(const String *this, char chr)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
+        FUNCTION_TEST_PARAM(CHAR, chr);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+
     int result = -1;
 
-    if (this->size > 0)
+    if (this->common.size > 0)
     {
-        const char *ptr = strchr(this->buffer, chr);
+        const char *ptr = strchr(this->common.buffer, chr);
 
         if (ptr != NULL)
-            result = (int)(ptr - this->buffer);
+            result = (int)(ptr - this->common.buffer);
     }
 
-    FUNCTION_TEST_RESULT(INT, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -661,33 +791,33 @@ strTrunc(String *this, int idx)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(idx >= 0 && (size_t)idx <= this->size);
     FUNCTION_TEST_END();
 
-    if (this->size > 0)
+    ASSERT(this != NULL);
+    ASSERT(idx >= 0 && (size_t)idx <= this->common.size);
+
+    if (this->common.size > 0)
     {
         // Reset the size to end at the index
-        this->size = (size_t)(idx);
-        this->buffer[this->size] = 0;
+        this->common.size = (unsigned int)(idx);
+        this->common.buffer[this->common.size] = 0;
+        this->common.extra = 0;
 
         MEM_CONTEXT_BEGIN(this->memContext)
         {
             // Resize the buffer
-            this->buffer = memGrowRaw(this->buffer, this->size + 1);
+            this->common.buffer = memGrowRaw(this->common.buffer, this->common.size + 1);
         }
         MEM_CONTEXT_END();
     }
 
-    FUNCTION_TEST_RESULT(STRING, this);
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
-Convert to a zero-terminated string for logging
+Convert an object to a zero-terminated string for logging
 ***********************************************************************************************************************************/
-size_t
-strToLog(const String *this, char *buffer, size_t bufferSize)
+size_t strObjToLog(const void *object, StrObjToLogFormat formatFunc, char *buffer, size_t bufferSize)
 {
     size_t result = 0;
 
@@ -695,10 +825,10 @@ strToLog(const String *this, char *buffer, size_t bufferSize)
     {
         String *string = NULL;
 
-        if (this == NULL)
+        if (object == NULL)
             string = strNew("null");
         else
-            string = strNewFmt("{\"%s\"}", strPtr(this));
+            string = formatFunc(object);
 
         result = (size_t)snprintf(buffer, bufferSize, "%s", strPtr(string));
     }
@@ -707,6 +837,55 @@ strToLog(const String *this, char *buffer, size_t bufferSize)
     return result;
 }
 
+/***********************************************************************************************************************************
+Render as string for logging
+***********************************************************************************************************************************/
+String *
+strToLog(const String *this)
+{
+    return strNewFmt("{\"%s\"}", strPtr(this));
+}
+
+/***********************************************************************************************************************************
+Format sizes (file, buffer, etc.) in human-readable form
+***********************************************************************************************************************************/
+String *
+strSizeFormat(const uint64_t size)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(UINT64, size);
+
+    FUNCTION_TEST_END();
+
+    String *result = NULL;
+
+    if (size < 1024)
+        result = strNewFmt("%" PRIu64 "B", size);
+    else if (size < (1024 * 1024))
+    {
+        if ((uint64_t)((double)size / 102.4) % 10 != 0)
+            result = strNewFmt("%.1lfKB", (double)size / 1024);
+        else
+            result = strNewFmt("%" PRIu64 "KB", size / 1024);
+    }
+    else if (size < (1024 * 1024 * 1024))
+    {
+        if ((uint64_t)((double)size / (1024 * 102.4)) % 10 != 0)
+            result = strNewFmt("%.1lfMB", (double)size / (1024 * 1024));
+        else
+            result = strNewFmt("%" PRIu64 "MB", size / (1024 * 1024));
+    }
+    else
+    {
+        if ((uint64_t)((double)size / (1024 * 1024 * 102.4)) % 10 != 0)
+            result = strNewFmt("%.1lfGB", (double)size / (1024 * 1024 * 1024));
+        else
+            result = strNewFmt("%" PRIu64 "GB", size / (1024 * 1024 * 1024));
+    }
+
+    FUNCTION_TEST_RETURN(result);
+}
+
 /***********************************************************************************************************************************
 Free the string
 ***********************************************************************************************************************************/
@@ -721,11 +900,11 @@ strFree(String *this)
     {
         MEM_CONTEXT_BEGIN(this->memContext)
         {
-            memFree(this->buffer);
+            memFree(this->common.buffer);
             memFree(this);
         }
         MEM_CONTEXT_END();
     }
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
