@@ -6,7 +6,6 @@ String List Handler
 #include <stdlib.h>
 #include <string.h>
 
-#include "common/assert.h"
 #include "common/debug.h"
 #include "common/memContext.h"
 #include "common/type/list.h"
@@ -16,10 +15,10 @@ String List Handler
 Wrapper for lstNew()
 ***********************************************************************************************************************************/
 StringList *
-strLstNew()
+strLstNew(void)
 {
     FUNCTION_TEST_VOID();
-    FUNCTION_TEST_RESULT(STRING_LIST, (StringList *)lstNew(sizeof(String *)));
+    FUNCTION_TEST_RETURN((StringList *)lstNew(sizeof(String *)));
 }
 
 /***********************************************************************************************************************************
@@ -31,11 +30,28 @@ strLstAddInternal(StringList *this, String *string)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING_LIST, this);
         FUNCTION_TEST_PARAM(STRING, string);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(STRING_LIST, (StringList *)lstAdd((List *)this, &string));
+    ASSERT(this != NULL);
+
+    FUNCTION_TEST_RETURN((StringList *)lstAdd((List *)this, &string));
+}
+
+/***********************************************************************************************************************************
+Internal insert -- the string must have been created in the list's mem context before being passed
+***********************************************************************************************************************************/
+static StringList *
+strLstInsertInternal(StringList *this, unsigned int listIdx, String *string)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STRING_LIST, this);
+        FUNCTION_TEST_PARAM(UINT, listIdx);
+        FUNCTION_TEST_PARAM(STRING, string);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+
+    FUNCTION_TEST_RETURN((StringList *)lstInsert((List *)this, listIdx, &string));
 }
 
 /***********************************************************************************************************************************
@@ -47,12 +63,12 @@ strLstNewSplit(const String *string, const String *delimiter)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, string);
         FUNCTION_TEST_PARAM(STRING, delimiter);
-
-        FUNCTION_TEST_ASSERT(string != NULL);
-        FUNCTION_TEST_ASSERT(delimiter != NULL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(STRING_LIST, strLstNewSplitZ(string, strPtr(delimiter)));
+    ASSERT(string != NULL);
+    ASSERT(delimiter != NULL);
+
+    FUNCTION_TEST_RETURN(strLstNewSplitZ(string, strPtr(delimiter)));
 }
 
 StringList *
@@ -61,11 +77,11 @@ strLstNewSplitZ(const String *string, const char *delimiter)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, string);
         FUNCTION_TEST_PARAM(STRINGZ, delimiter);
-
-        FUNCTION_TEST_ASSERT(string != NULL);
-        FUNCTION_TEST_ASSERT(delimiter != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(string != NULL);
+    ASSERT(delimiter != NULL);
+
     // Create the list
     StringList *this = strLstNew();
 
@@ -96,7 +112,7 @@ strLstNewSplitZ(const String *string, const char *delimiter)
     }
     MEM_CONTEXT_END();
 
-    FUNCTION_TEST_RESULT(STRING_LIST, this);
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -112,12 +128,12 @@ strLstNewSplitSize(const String *string, const String *delimiter, size_t size)
         FUNCTION_TEST_PARAM(STRING, string);
         FUNCTION_TEST_PARAM(STRING, delimiter);
         FUNCTION_TEST_PARAM(SIZE, size);
-
-        FUNCTION_TEST_ASSERT(string != NULL);
-        FUNCTION_TEST_ASSERT(delimiter != NULL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(STRING_LIST, strLstNewSplitSizeZ(string, strPtr(delimiter), size));
+    ASSERT(string != NULL);
+    ASSERT(delimiter != NULL);
+
+    FUNCTION_TEST_RETURN(strLstNewSplitSizeZ(string, strPtr(delimiter), size));
 }
 
 StringList *
@@ -127,11 +143,11 @@ strLstNewSplitSizeZ(const String *string, const char *delimiter, size_t size)
         FUNCTION_TEST_PARAM(STRING, string);
         FUNCTION_TEST_PARAM(STRINGZ, delimiter);
         FUNCTION_TEST_PARAM(SIZE, size);
-
-        FUNCTION_TEST_ASSERT(string != NULL);
-        FUNCTION_TEST_ASSERT(delimiter != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(string != NULL);
+    ASSERT(delimiter != NULL);
+
     // Create the list
     StringList *this = strLstNew();
 
@@ -180,7 +196,7 @@ strLstNewSplitSizeZ(const String *string, const char *delimiter, size_t size)
     }
     MEM_CONTEXT_END();
 
-    FUNCTION_TEST_RESULT(STRING_LIST, this);
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -191,22 +207,25 @@ strLstNewVarLst(const VariantList *sourceList)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(VARIANT_LIST, sourceList);
-
-        FUNCTION_TEST_ASSERT(sourceList != NULL);
     FUNCTION_TEST_END();
 
     // Create the list
-    StringList *this = strLstNew();
+    StringList *this = NULL;
 
-    // Copy variants
-    MEM_CONTEXT_BEGIN(lstMemContext((List *)this))
+    if  (sourceList != NULL)
     {
-        for (unsigned int listIdx = 0; listIdx < varLstSize(sourceList); listIdx++)
-            strLstAddInternal(this, strDup(varStr(varLstGet(sourceList, listIdx))));
-    }
-    MEM_CONTEXT_END();
+        this = strLstNew();
 
-    FUNCTION_TEST_RESULT(STRING_LIST, this);
+        // Copy variants
+        MEM_CONTEXT_BEGIN(lstMemContext((List *)this))
+        {
+            for (unsigned int listIdx = 0; listIdx < varLstSize(sourceList); listIdx++)
+                strLstAddInternal(this, strDup(varStr(varLstGet(sourceList, listIdx))));
+        }
+        MEM_CONTEXT_END();
+    }
+
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -217,10 +236,10 @@ strLstDup(const StringList *sourceList)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING_LIST, sourceList);
-
-        FUNCTION_TEST_ASSERT(sourceList != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(sourceList != NULL);
+
     // Create the list
     StringList *this = strLstNew();
 
@@ -232,7 +251,7 @@ strLstDup(const StringList *sourceList)
     }
     MEM_CONTEXT_END();
 
-    FUNCTION_TEST_RESULT(STRING_LIST, this);
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -244,10 +263,10 @@ strLstExists(const StringList *this, const String *string)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING_LIST, this);
         FUNCTION_TEST_PARAM(STRING, string);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+
     bool result = false;
 
     for (unsigned int listIdx = 0; listIdx < strLstSize(this); listIdx++)
@@ -259,7 +278,7 @@ strLstExists(const StringList *this, const String *string)
         }
     }
 
-    FUNCTION_TEST_RESULT(BOOL, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 bool
@@ -268,10 +287,10 @@ strLstExistsZ(const StringList *this, const char *cstring)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING_LIST, this);
         FUNCTION_TEST_PARAM(STRINGZ, cstring);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+
     bool result = false;
 
     for (unsigned int listIdx = 0; listIdx < strLstSize(this); listIdx++)
@@ -283,11 +302,11 @@ strLstExistsZ(const StringList *this, const char *cstring)
         }
     }
 
-    FUNCTION_TEST_RESULT(BOOL, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
-Wrapper for lstAdd()
+Add String to the list
 ***********************************************************************************************************************************/
 StringList *
 strLstAdd(StringList *this, const String *string)
@@ -295,10 +314,10 @@ strLstAdd(StringList *this, const String *string)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING_LIST, this);
         FUNCTION_TEST_PARAM(STRING, string);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+
     StringList *result = NULL;
 
     MEM_CONTEXT_BEGIN(lstMemContext((List *)this))
@@ -307,7 +326,7 @@ strLstAdd(StringList *this, const String *string)
     }
     MEM_CONTEXT_END();
 
-    FUNCTION_TEST_RESULT(STRING_LIST, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -319,10 +338,10 @@ strLstAddZ(StringList *this, const char *string)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING_LIST, this);
         FUNCTION_TEST_PARAM(STRINGZ, string);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+
     StringList *result = NULL;
 
     MEM_CONTEXT_BEGIN(lstMemContext((List *)this))
@@ -331,7 +350,7 @@ strLstAddZ(StringList *this, const char *string)
     }
     MEM_CONTEXT_END();
 
-    FUNCTION_TEST_RESULT(STRING_LIST, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -343,11 +362,62 @@ strLstGet(const StringList *this, unsigned int listIdx)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING_LIST, this);
         FUNCTION_TEST_PARAM(UINT, listIdx);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(STRING, *(String **)lstGet((List *)this, listIdx));
+    ASSERT(this != NULL);
+
+    FUNCTION_TEST_RETURN(*(String **)lstGet((List *)this, listIdx));
+}
+
+
+/***********************************************************************************************************************************
+Insert String into the list
+***********************************************************************************************************************************/
+StringList *
+strLstInsert(StringList *this, unsigned int listIdx, const String *string)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STRING_LIST, this);
+        FUNCTION_TEST_PARAM(UINT, listIdx);
+        FUNCTION_TEST_PARAM(STRING, string);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+
+    StringList *result = NULL;
+
+    MEM_CONTEXT_BEGIN(lstMemContext((List *)this))
+    {
+        result = strLstInsertInternal(this, listIdx, strDup(string));
+    }
+    MEM_CONTEXT_END();
+
+    FUNCTION_TEST_RETURN(result);
+}
+
+/***********************************************************************************************************************************
+Insert zero-terminated string into the list
+***********************************************************************************************************************************/
+StringList *
+strLstInsertZ(StringList *this, unsigned int listIdx, const char *string)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STRING_LIST, this);
+        FUNCTION_TEST_PARAM(UINT, listIdx);
+        FUNCTION_TEST_PARAM(STRINGZ, string);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+
+    StringList *result = NULL;
+
+    MEM_CONTEXT_BEGIN(lstMemContext((List *)this))
+    {
+        result = strLstInsertInternal(this, listIdx, strNew(string));
+    }
+    MEM_CONTEXT_END();
+
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -359,12 +429,12 @@ strLstJoin(const StringList *this, const char *separator)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING_LIST, this);
         FUNCTION_TEST_PARAM(STRINGZ, separator);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(separator != NULL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(STRING, strLstJoinQuote(this, separator, ""));
+    ASSERT(this != NULL);
+    ASSERT(separator != NULL);
+
+    FUNCTION_TEST_RETURN(strLstJoinQuote(this, separator, ""));
 }
 
 /***********************************************************************************************************************************
@@ -377,12 +447,12 @@ strLstJoinQuote(const StringList *this, const char *separator, const char *quote
         FUNCTION_TEST_PARAM(STRING_LIST, this);
         FUNCTION_TEST_PARAM(STRINGZ, separator);
         FUNCTION_TEST_PARAM(STRINGZ, quote);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_TEST_ASSERT(separator != NULL);
-        FUNCTION_TEST_ASSERT(quote != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+    ASSERT(separator != NULL);
+    ASSERT(quote != NULL);
+
     String *join = strNew("");
 
     for (unsigned int listIdx = 0; listIdx < strLstSize(this); listIdx++)
@@ -396,7 +466,7 @@ strLstJoinQuote(const StringList *this, const char *separator, const char *quote
             strCatFmt(join, "%s%s%s", quote, strPtr(strLstGet(this, listIdx)), quote);
     }
 
-    FUNCTION_TEST_RESULT(STRING, join);
+    FUNCTION_TEST_RETURN(join);
 }
 
 /***********************************************************************************************************************************
@@ -408,29 +478,29 @@ strLstMove(StringList *this, MemContext *parentNew)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING_LIST, this);
         FUNCTION_TEST_PARAM(MEM_CONTEXT, parentNew);
-
-        FUNCTION_TEST_ASSERT(parentNew != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(parentNew != NULL);
+
     lstMove((List *)this, parentNew);
 
-    FUNCTION_TEST_RESULT(STRING_LIST, this);
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
-Return an array of pointers to the zero-terminated strings in this list.  DO NOT override const and modify any of the strings in
-this array, though it is OK to modify the array itself.
+Return a null-terminated array of pointers to the zero-terminated strings in this list.  DO NOT override const and modify any of the
+strings in this array, though it is OK to modify the array itself.
 ***********************************************************************************************************************************/
 const char **
 strLstPtr(const StringList *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING_LIST, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
-    const char **list = memNew(strLstSize(this) * sizeof(char *));
+    ASSERT(this != NULL);
+
+    const char **list = memNew((strLstSize(this) + 1) * sizeof(char *));
 
     for (unsigned int listIdx = 0; listIdx < strLstSize(this); listIdx++)
     {
@@ -440,7 +510,9 @@ strLstPtr(const StringList *this)
             list[listIdx] = strPtr(strLstGet(this, listIdx));
     }
 
-    FUNCTION_TEST_RESULT(CONST_CHARPP, list);
+    list[strLstSize(this)] = NULL;
+
+    FUNCTION_TEST_RETURN(list);
 }
 
 /***********************************************************************************************************************************
@@ -451,11 +523,11 @@ strLstSize(const StringList *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING_LIST, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(UINT, lstSize((List *)this));
+    ASSERT(this != NULL);
+
+    FUNCTION_TEST_RETURN(lstSize((List *)this));
 }
 
 /***********************************************************************************************************************************
@@ -465,28 +537,28 @@ static int
 sortAscComparator(const void *item1, const void *item2)
 {
     FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(VOIDP, item1);
-        FUNCTION_TEST_PARAM(VOIDP, item2);
-
-        FUNCTION_TEST_ASSERT(item1 != NULL);
-        FUNCTION_TEST_ASSERT(item2 != NULL);
+        FUNCTION_TEST_PARAM_P(VOID, item1);
+        FUNCTION_TEST_PARAM_P(VOID, item2);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(INT, strCmp(*(String **)item1, *(String **)item2));
+    ASSERT(item1 != NULL);
+    ASSERT(item2 != NULL);
+
+    FUNCTION_TEST_RETURN(strCmp(*(String **)item1, *(String **)item2));
 }
 
 static int
 sortDescComparator(const void *item1, const void *item2)
 {
     FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(VOIDP, item1);
-        FUNCTION_TEST_PARAM(VOIDP, item2);
-
-        FUNCTION_TEST_ASSERT(item1 != NULL);
-        FUNCTION_TEST_ASSERT(item2 != NULL);
+        FUNCTION_TEST_PARAM_P(VOID, item1);
+        FUNCTION_TEST_PARAM_P(VOID, item2);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(INT, strCmp(*(String **)item2, *(String **)item1));
+    ASSERT(item1 != NULL);
+    ASSERT(item2 != NULL);
+
+    FUNCTION_TEST_RETURN(strCmp(*(String **)item2, *(String **)item1));
 }
 
 StringList *
@@ -495,10 +567,10 @@ strLstSort(StringList *this, SortOrder sortOrder)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING_LIST, this);
         FUNCTION_TEST_PARAM(ENUM, sortOrder);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+
     switch (sortOrder)
     {
         case sortOrderAsc:
@@ -514,31 +586,16 @@ strLstSort(StringList *this, SortOrder sortOrder)
         }
     }
 
-    FUNCTION_TEST_RESULT(STRING_LIST, this);
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
-Convert to a zero-terminated string for logging
+Render as string for logging
 ***********************************************************************************************************************************/
-size_t
-strLstToLog(const StringList *this, char *buffer, size_t bufferSize)
+String *
+strLstToLog(const StringList *this)
 {
-    size_t result = 0;
-
-    MEM_CONTEXT_TEMP_BEGIN()
-    {
-        String *string = NULL;
-
-        if (this == NULL)
-            string = strNew("null");
-        else
-            string = strNewFmt("{[%s]}", strPtr(strLstJoinQuote(this, ", ", "\"")));
-
-        result = (size_t)snprintf(buffer, bufferSize, "%s", strPtr(string));
-    }
-    MEM_CONTEXT_TEMP_END();
-
-    return result;
+    return strNewFmt("{[%s]}", strPtr(strLstJoinQuote(this, ", ", "\"")));
 }
 
 /***********************************************************************************************************************************
@@ -553,5 +610,5 @@ strLstFree(StringList *this)
 
     lstFree((List *)this);
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
