@@ -25,7 +25,7 @@ typedef enum
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
-StringList *strLstNew();
+StringList *strLstNew(void);
 StringList *strLstNewSplit(const String *string, const String *delimiter);
 StringList *strLstNewSplitZ(const String *string, const char *delimiter);
 StringList *strLstNewSplitSize(const String *string, const String *delimiter, size_t size);
@@ -37,6 +37,8 @@ StringList *strLstAdd(StringList *this, const String *string);
 StringList *strLstAddZ(StringList *this, const char *string);
 bool strLstExists(const StringList *this, const String *string);
 bool strLstExistsZ(const StringList *this, const char *cstring);
+StringList *strLstInsert(StringList *this, unsigned int listIdx, const String *string);
+StringList *strLstInsertZ(StringList *this, unsigned int listIdx, const char *string);
 String *strLstGet(const StringList *this, unsigned int listIdx);
 String *strLstJoin(const StringList *this, const char *separator);
 String *strLstJoinQuote(const StringList *this, const char *separator, const char *quote);
@@ -50,11 +52,11 @@ void strLstFree(StringList *this);
 /***********************************************************************************************************************************
 Macros for function logging
 ***********************************************************************************************************************************/
-size_t strLstToLog(const StringList *this, char *buffer, size_t bufferSize);
+String *strLstToLog(const StringList *this);
 
-#define FUNCTION_DEBUG_STRING_LIST_TYPE                                                                                            \
+#define FUNCTION_LOG_STRING_LIST_TYPE                                                                                              \
     StringList *
-#define FUNCTION_DEBUG_STRING_LIST_FORMAT(value, buffer, bufferSize)                                                               \
-    strLstToLog(value, buffer, bufferSize)
+#define FUNCTION_LOG_STRING_LIST_FORMAT(value, buffer, bufferSize)                                                                 \
+    FUNCTION_LOG_STRING_OBJECT_FORMAT(value, strLstToLog, buffer, bufferSize)
 
 #endif
