@@ -1,13 +1,14 @@
 /***********************************************************************************************************************************
 Variant Data Type
 ***********************************************************************************************************************************/
+#include <errno.h>
 #include <inttypes.h>
+#include <limits.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <strings.h>
 
-#include "common/assert.h"
 #include "common/debug.h"
 #include "common/memContext.h"
 #include "common/type/convert.h"
@@ -34,6 +35,7 @@ static const char *variantTypeName[] =
     "KeyValue",                                                     // varTypeKeyValue
     "String",                                                       // varTypeString
     "VariantList",                                                  // varTypeVariantList
+    "uint64",                                                       // varTypeUInt64
 };
 
 /***********************************************************************************************************************************
@@ -44,13 +46,13 @@ varNewInternal(VariantType type, void *data, size_t dataSize)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, type);
-        FUNCTION_TEST_PARAM(VOIDP, data);
+        FUNCTION_TEST_PARAM_P(VOID, data);
         FUNCTION_TEST_PARAM(SIZE, dataSize);
-
-        FUNCTION_TEST_ASSERT(data != NULL);
-        FUNCTION_TEST_ASSERT(dataSize > 0);
     FUNCTION_TEST_END();
 
+    ASSERT(data != NULL);
+    ASSERT(dataSize > 0);
+
     // Allocate memory for the variant and set the type
     Variant *this = memNew(sizeof(Variant) + dataSize);
     this->memContext = memContextCurrent();
@@ -59,7 +61,7 @@ varNewInternal(VariantType type, void *data, size_t dataSize)
     // Copy data
     memcpy((unsigned char *)this + sizeof(Variant), data, dataSize);
 
-    FUNCTION_TEST_RESULT(VARIANT, this);
+    FUNCTION_TEST_RETURN(this);
 }
 
 /***********************************************************************************************************************************
@@ -70,11 +72,11 @@ varData(const Variant *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(VARIANT, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(VOIDP, (void *)((unsigned char *)this + sizeof(Variant)));
+    ASSERT(this != NULL);
+
+    FUNCTION_TEST_RETURN((void *)((unsigned char *)this + sizeof(Variant)));
 }
 
 /***********************************************************************************************************************************
@@ -117,6 +119,12 @@ varDup(const Variant *this)
                 break;
             }
 
+            case varTypeUInt64:
+            {
+                result = varNewUInt64(varUInt64(this));
+                break;
+            }
+
             case varTypeKeyValue:
             {
                 KeyValue *data = kvDup(varKv(this));
@@ -138,7 +146,7 @@ varDup(const Variant *this)
         }
     }
 
-    FUNCTION_TEST_RESULT(VARIANT, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -186,6 +194,12 @@ varEq(const Variant *this1, const Variant *this2)
                     break;
                 }
 
+                case varTypeUInt64:
+                {
+                    result = varUInt64(this1) == varUInt64(this2);
+                    break;
+                }
+
                 case varTypeString:
                 {
                     result = strEq(varStr(this1), varStr(this2));
@@ -202,7 +216,7 @@ varEq(const Variant *this1, const Variant *this2)
     else
         result = this1 == NULL && this2 == NULL;
 
-    FUNCTION_TEST_RESULT(BOOL, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -213,11 +227,11 @@ varType(const Variant *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(VARIANT, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(ENUM, this->type);
+    ASSERT(this != NULL);
+
+    FUNCTION_TEST_RETURN(this->type);
 }
 
 /***********************************************************************************************************************************
@@ -230,7 +244,7 @@ varNewBool(bool data)
         FUNCTION_TEST_PARAM(BOOL, data);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(VARIANT, varNewInternal(varTypeBool, (void *)&data, sizeof(data)));
+    FUNCTION_TEST_RETURN(varNewInternal(varTypeBool, (void *)&data, sizeof(data)));
 }
 
 /***********************************************************************************************************************************
@@ -241,13 +255,13 @@ varBool(const Variant *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(VARIANT, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+
     ASSERT(this->type == varTypeBool);
 
-    FUNCTION_TEST_RESULT(BOOL, *((bool *)varData(this)));
+    FUNCTION_TEST_RETURN(*((bool *)varData(this)));
 }
 
 /***********************************************************************************************************************************
@@ -258,10 +272,10 @@ varBoolForce(const Variant *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(VARIANT, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+
     bool result = false;
 
     switch (this->type)
@@ -278,6 +292,10 @@ varBoolForce(const Variant *this)
             result = varInt64(this) != 0;
             break;
 
+        case varTypeUInt64:
+            result = varUInt64(this) != 0;
+            break;
+
         case varTypeString:
         {
             // List of false/true boolean string values.  Note that false/true values must be equal.
@@ -306,10 +324,10 @@ varBoolForce(const Variant *this)
         }
 
         default:
-            THROW_FMT(FormatError, "unable to force %s to %s", variantTypeName[this->type], variantTypeName[varTypeBool]);
+            THROW_FMT(AssertError, "unable to force %s to %s", variantTypeName[this->type], variantTypeName[varTypeBool]);
     }
 
-    FUNCTION_TEST_RESULT(BOOL, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -322,7 +340,7 @@ varNewDbl(double data)
         FUNCTION_TEST_PARAM(DOUBLE, data);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(VARIANT, varNewInternal(varTypeDouble, (unsigned char *)&data, sizeof(data)));
+    FUNCTION_TEST_RETURN(varNewInternal(varTypeDouble, (unsigned char *)&data, sizeof(data)));
 }
 
 /***********************************************************************************************************************************
@@ -333,13 +351,13 @@ varDbl(const Variant *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(VARIANT, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+
     ASSERT(this->type == varTypeDouble);
 
-    FUNCTION_TEST_RESULT(DOUBLE, *((double *)varData(this)));
+    FUNCTION_TEST_RETURN(*((double *)varData(this)));
 }
 
 /***********************************************************************************************************************************
@@ -350,10 +368,10 @@ varDblForce(const Variant *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(VARIANT, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+
     double result = 0;
 
     switch (this->type)
@@ -382,6 +400,12 @@ varDblForce(const Variant *this)
             break;
         }
 
+        case varTypeUInt64:
+        {
+            result = (double)varUInt64(this);
+            break;
+        }
+
         case varTypeString:
         {
             result = cvtZToDouble(strPtr(varStr(this)));
@@ -389,10 +413,10 @@ varDblForce(const Variant *this)
         }
 
         default:
-            THROW_FMT(FormatError, "unable to force %s to %s", variantTypeName[this->type], variantTypeName[varTypeDouble]);
+            THROW_FMT(AssertError, "unable to force %s to %s", variantTypeName[this->type], variantTypeName[varTypeDouble]);
     }
 
-    FUNCTION_TEST_RESULT(DOUBLE, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -405,7 +429,7 @@ varNewInt(int data)
         FUNCTION_TEST_PARAM(INT, data);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(VARIANT, varNewInternal(varTypeInt, (void *)&data, sizeof(data)));
+    FUNCTION_TEST_RETURN(varNewInternal(varTypeInt, (void *)&data, sizeof(data)));
 }
 
 /***********************************************************************************************************************************
@@ -416,13 +440,13 @@ varInt(const Variant *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(VARIANT, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+
     ASSERT(this->type == varTypeInt);
 
-    FUNCTION_TEST_RESULT(INT, *((int *)varData(this)));
+    FUNCTION_TEST_RETURN(*((int *)varData(this)));
 }
 
 /***********************************************************************************************************************************
@@ -433,10 +457,10 @@ varIntForce(const Variant *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(VARIANT, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+
     int result = 0;
 
     switch (this->type)
@@ -457,9 +481,24 @@ varIntForce(const Variant *this)
         {
             int64_t resultTest = varInt64(this);
 
-            if (resultTest > 2147483647 || resultTest < -2147483648)
+            // Make sure the value fits into a normal 32-bit int range since 32-bit platforms are supported
+            if (resultTest > INT32_MAX || resultTest < INT32_MIN)
                 THROW_FMT(
-                    AssertError, "unable to convert %s %" PRId64 " to %s", variantTypeName[this->type], resultTest,
+                    FormatError, "unable to convert %s %" PRId64 " to %s", variantTypeName[this->type], resultTest,
+                    variantTypeName[varTypeInt]);
+
+            result = (int)resultTest;
+            break;
+        }
+
+        case varTypeUInt64:
+        {
+            uint64_t resultTest = varUInt64(this);
+
+            // Make sure the value fits into a normal 32-bit int range
+            if (resultTest > INT32_MAX)
+                THROW_FMT(
+                    FormatError, "unable to convert %s %" PRIu64 " to %s", variantTypeName[this->type], resultTest,
                     variantTypeName[varTypeInt]);
 
             result = (int)resultTest;
@@ -473,10 +512,10 @@ varIntForce(const Variant *this)
         }
 
         default:
-            THROW_FMT(FormatError, "unable to force %s to %s", variantTypeName[this->type], variantTypeName[varTypeInt]);
+            THROW_FMT(AssertError, "unable to force %s to %s", variantTypeName[this->type], variantTypeName[varTypeInt]);
     }
 
-    FUNCTION_TEST_RESULT(INT, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -489,7 +528,7 @@ varNewInt64(int64_t data)
         FUNCTION_TEST_PARAM(INT64, data);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(VARIANT, varNewInternal(varTypeInt64, (void *)&data, sizeof(data)));
+    FUNCTION_TEST_RETURN(varNewInternal(varTypeInt64, (void *)&data, sizeof(data)));
 }
 
 /***********************************************************************************************************************************
@@ -500,13 +539,13 @@ varInt64(const Variant *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(VARIANT, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+
     ASSERT(this->type == varTypeInt64);
 
-    FUNCTION_TEST_RESULT(INT64, *((int64_t *)varData(this)));
+    FUNCTION_TEST_RETURN(*((int64_t *)varData(this)));
 }
 
 /***********************************************************************************************************************************
@@ -517,10 +556,10 @@ varInt64Force(const Variant *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(VARIANT, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+
     int64_t result = 0;
 
     switch (this->type)
@@ -543,6 +582,23 @@ varInt64Force(const Variant *this)
             break;
         }
 
+        case varTypeUInt64:
+        {
+            uint64_t resultTest = varUInt64(this);
+
+            // If max number of unsigned 64-bit integer is greater than max 64-bit signed integer can hold, then error
+            if (resultTest <= INT64_MAX)
+                result = (int64_t)resultTest;
+            else
+            {
+                THROW_FMT(
+                    FormatError, "unable to convert %s %" PRIu64 " to %s", variantTypeName[this->type], resultTest,
+                    variantTypeName[varTypeInt64]);
+            }
+
+            break;
+        }
+
         case varTypeString:
         {
             result = cvtZToInt64(strPtr(varStr(this)));
@@ -550,24 +606,129 @@ varInt64Force(const Variant *this)
         }
 
         default:
-            THROW_FMT(FormatError, "unable to force %s to %s", variantTypeName[this->type], variantTypeName[varTypeInt64]);
+            THROW_FMT(AssertError, "unable to force %s to %s", variantTypeName[this->type], variantTypeName[varTypeInt64]);
     }
 
-    FUNCTION_TEST_RESULT(INT64, result);
+    FUNCTION_TEST_RETURN(result);
+}
+
+/***********************************************************************************************************************************
+New uint64 variant
+***********************************************************************************************************************************/
+Variant *
+varNewUInt64(uint64_t data)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(UINT64, data);
+    FUNCTION_TEST_END();
+
+    FUNCTION_TEST_RETURN(varNewInternal(varTypeUInt64, (void *)&data, sizeof(data)));
+}
+
+/***********************************************************************************************************************************
+Return int64
+***********************************************************************************************************************************/
+uint64_t
+varUInt64(const Variant *this)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(VARIANT, this);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+
+    ASSERT(this->type == varTypeUInt64);
+
+    FUNCTION_TEST_RETURN(*((uint64_t *)varData(this)));
+}
+
+/***********************************************************************************************************************************
+Return uint64 regardless of variant type
+***********************************************************************************************************************************/
+uint64_t
+varUInt64Force(const Variant *this)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(VARIANT, this);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+
+    uint64_t result = 0;
+
+    switch (this->type)
+    {
+        case varTypeBool:
+        {
+            result = varBool(this);
+            break;
+        }
+
+        case varTypeInt:
+        {
+            int resultTest = varInt(this);
+
+            // If integer is a negative number, throw an error since the resulting conversion would be a different number
+            if (resultTest >= 0)
+                result = (uint64_t)resultTest;
+            else
+            {
+                THROW_FMT(
+                    FormatError, "unable to convert %s %d to %s", variantTypeName[this->type], resultTest,
+                    variantTypeName[varTypeUInt64]);
+            }
+
+            break;
+        }
+
+        case varTypeInt64:
+        {
+            int64_t resultTest = varInt64(this);
+
+            // If integer is a negative number, throw an error since the resulting conversion would be out of bounds
+            if (resultTest >= 0)
+                result = (uint64_t)resultTest;
+            else
+            {
+                THROW_FMT(
+                    FormatError, "unable to convert %s %" PRId64 " to %s", variantTypeName[this->type], resultTest,
+                    variantTypeName[varTypeUInt64]);
+            }
+
+            break;
+        }
+
+        case varTypeUInt64:
+        {
+            result = varUInt64(this);
+            break;
+        }
+
+        case varTypeString:
+        {
+            result = cvtZToUInt64(strPtr(varStr(this)));
+            break;
+        }
+
+        default:
+            THROW_FMT(AssertError, "unable to force %s to %s", variantTypeName[this->type], variantTypeName[varTypeUInt64]);
+    }
+
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
 New key/value variant
 ***********************************************************************************************************************************/
 Variant *
-varNewKv()
+varNewKv(void)
 {
     FUNCTION_TEST_VOID();
 
     // Create a new kv for the variant
     KeyValue *data = kvNew();
 
-    FUNCTION_TEST_RESULT(VARIANT, varNewInternal(varTypeKeyValue, (void *)&data, sizeof(data)));
+    FUNCTION_TEST_RETURN(varNewInternal(varTypeKeyValue, (void *)&data, sizeof(data)));
 }
 
 /***********************************************************************************************************************************
@@ -588,7 +749,7 @@ varKv(const Variant *this)
         result = *((KeyValue **)varData(this));
     }
 
-    FUNCTION_TEST_RESULT(KEY_VALUE, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -599,14 +760,12 @@ varNewStr(const String *data)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, data);
-
-        FUNCTION_TEST_ASSERT(data != NULL);
     FUNCTION_TEST_END();
 
     // Create a copy of the string for the variant
     String *dataCopy = strDup(data);
 
-    FUNCTION_TEST_RESULT(VARIANT, varNewInternal(varTypeString, (void *)&dataCopy, sizeof(dataCopy)));
+    FUNCTION_TEST_RETURN(varNewInternal(varTypeString, (void *)&dataCopy, sizeof(dataCopy)));
 }
 
 /***********************************************************************************************************************************
@@ -617,14 +776,15 @@ varNewStrZ(const char *data)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRINGZ, data);
-
-        FUNCTION_TEST_ASSERT(data != NULL);
     FUNCTION_TEST_END();
 
     // Create a string for the variant
-    String *dataCopy = strNew(data);
+    String *dataCopy = NULL;
 
-    FUNCTION_TEST_RESULT(VARIANT, varNewInternal(varTypeString, (void *)&dataCopy, sizeof(dataCopy)));
+    if (data != NULL)
+        dataCopy = strNew(data);
+
+    FUNCTION_TEST_RETURN(varNewInternal(varTypeString, (void *)&dataCopy, sizeof(dataCopy)));
 }
 
 /***********************************************************************************************************************************
@@ -645,7 +805,7 @@ varStr(const Variant *this)
         result = *((String **)varData(this));
     }
 
-    FUNCTION_TEST_RESULT(STRING, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -656,10 +816,10 @@ varStrForce(const Variant *this)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(VARIANT, this);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+
     String *result = NULL;
 
     switch (varType(this))
@@ -702,6 +862,12 @@ varStrForce(const Variant *this)
             break;
         }
 
+        case varTypeUInt64:
+        {
+            result = strNewFmt("%" PRIu64, varUInt64(this));
+            break;
+        }
+
         case varTypeString:
         {
             result = strDup(varStr(this));
@@ -713,7 +879,7 @@ varStrForce(const Variant *this)
             THROW_FMT(FormatError, "unable to force %s to %s", variantTypeName[this->type], variantTypeName[varTypeString]);
     }
 
-    FUNCTION_TEST_RESULT(STRING, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -724,14 +890,15 @@ varNewVarLst(const VariantList *data)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(VARIANT_LIST, data);
-
-        FUNCTION_TEST_ASSERT(data != NULL);
     FUNCTION_TEST_END();
 
-    // Copy variant list for the variant
-    VariantList *dataCopy = varLstDup(data);
+    VariantList *dataCopy = NULL;
 
-    FUNCTION_TEST_RESULT(VARIANT, varNewInternal(varTypeVariantList, (void *)&dataCopy, sizeof(dataCopy)));
+    // Create a copy of the variant list if it is not null
+    if (data != NULL)
+        dataCopy = varLstDup(data);
+
+    FUNCTION_TEST_RETURN(varNewInternal(varTypeVariantList, (void *)&dataCopy, sizeof(dataCopy)));
 }
 
 /***********************************************************************************************************************************
@@ -752,66 +919,49 @@ varVarLst(const Variant *this)
         result = *((VariantList **)varData(this));
     }
 
-    FUNCTION_TEST_RESULT(VARIANT_LIST, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
 Convert variant to a zero-terminated string for logging
 ***********************************************************************************************************************************/
-size_t
-varToLog(const Variant *this, char *buffer, size_t bufferSize)
+String *
+varToLog(const Variant *this)
 {
-    size_t result = 0;
+    const String *string = NULL;
 
-    MEM_CONTEXT_TEMP_BEGIN()
+    switch (varType(this))
     {
-        String *string = NULL;
-
-        if (this == NULL)
+        case varTypeString:
         {
-            string = strNew("null");
-            result = (size_t)snprintf(buffer, bufferSize, "%s", strPtr(string));
+            string = strNewFmt("\"%s\"", strPtr(varStrForce(this)));
+            break;
         }
-        else
+
+        case varTypeKeyValue:
         {
-            switch (varType(this))
-            {
-                case varTypeString:
-                {
-                    String *temp = varStrForce(this);
-                    string = strNewFmt("\"%s\"", strPtr(temp));
-                    strFree(temp);
-                    break;
-                }
+            string = STRING_CONST("KeyValue");
+            break;
+        }
 
-                case varTypeKeyValue:
-                {
-                    string = strNew("KeyValue");
-                    break;
-                }
+        case varTypeVariantList:
+        {
+            string = STRING_CONST("VariantList");
+            break;
+        }
 
-                case varTypeVariantList:
-                {
-                    string = strNew("VariantList");
-                    break;
-                }
-
-                case varTypeBool:
-                case varTypeDouble:
-                case varTypeInt:
-                case varTypeInt64:
-                {
-                    string = varStrForce(this);
-                    break;
-                }
-            }
-
-            result = (size_t)snprintf(buffer, bufferSize, "{%s}", strPtr(string));
+        case varTypeBool:
+        case varTypeDouble:
+        case varTypeInt:
+        case varTypeInt64:
+        case varTypeUInt64:
+        {
+            string = varStrForce(this);
+            break;
         }
     }
-    MEM_CONTEXT_TEMP_END();
 
-    return result;
+    return strNewFmt("{%s}", strPtr(string));
 }
 
 /***********************************************************************************************************************************
@@ -853,6 +1003,7 @@ varFree(Variant *this)
                 case varTypeDouble:
                 case varTypeInt:
                 case varTypeInt64:
+                case varTypeUInt64:
                     break;
             }
 
@@ -861,5 +1012,5 @@ varFree(Variant *this)
         MEM_CONTEXT_END();
     }
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
