@@ -1,5 +1,19 @@
 /***********************************************************************************************************************************
 Variant Data Type
+
+Variants are lightweight objects in that they do not have their own memory context, instead they exist in the current context in
+which they are instantiated. If a variant is needed outside the current memory context, the memory context must be switched to the
+old context and then back. Below is a simplified example:
+
+    Variant *result = NULL;    <--- is created in the current memory context (referred to as "old context" below)
+    MEM_CONTEXT_TEMP_BEGIN()   <--- begins a new temporary context
+    {
+        String *resultStr = strNewN("myNewStr"); <--- creates a string in the temporary memory context
+        memContextSwitch(MEM_CONTEXT_OLD()); <--- switch to old context so creation of the variant from the string is in old context
+        result = varNewUInt64(cvtZToUInt64(strPtr(resultStr))); <--- recreates variant from the string in the old context.
+        memContextSwitch(MEM_CONTEXT_TEMP()); <--- switch back to the temporary context
+    }
+    MEM_CONTEXT_TEMP_END(); <-- frees everything created inside this temporary memory context - i.e resultStr
 ***********************************************************************************************************************************/
 #ifndef COMMON_TYPE_VARIANT_H
 #define COMMON_TYPE_VARIANT_H
@@ -23,6 +37,7 @@ typedef enum
     varTypeKeyValue,
     varTypeString,
     varTypeVariantList,
+    varTypeUInt64,
 } VariantType;
 
 #include "common/type/keyValue.h"
@@ -48,7 +63,7 @@ Variant *varNewInt64(int64_t data);
 int64_t varInt64(const Variant *this);
 int64_t varInt64Force(const Variant *this);
 
-Variant *varNewKv();
+Variant *varNewKv(void);
 KeyValue *varKv(const Variant *this);
 
 Variant *varNewStr(const String *data);
@@ -56,6 +71,10 @@ Variant *varNewStrZ(const char *data);
 String *varStr(const Variant *this);
 String *varStrForce(const Variant *this);
 
+Variant *varNewUInt64(uint64_t data);
+uint64_t varUInt64(const Variant *this);
+uint64_t varUInt64Force(const Variant *this);
+
 Variant *varNewVarLst(const VariantList *data);
 VariantList *varVarLst(const Variant *this);
 
@@ -68,16 +87,11 @@ void varFree(Variant *this);
 /***********************************************************************************************************************************
 Macros for function logging
 ***********************************************************************************************************************************/
-size_t varToLog(const Variant *this, char *buffer, size_t bufferSize);
+String *varToLog(const Variant *this);
 
-#define FUNCTION_DEBUG_CONST_VARIANT_TYPE                                                                                          \
-    const FUNCTION_DEBUG_VARIANT_TYPE
-#define FUNCTION_DEBUG_CONST_VARIANT_FORMAT(value, buffer, bufferSize)                                                             \
-    FUNCTION_DEBUG_VARIANT_FORMAT(value, buffer, bufferSize)
-
-#define FUNCTION_DEBUG_VARIANT_TYPE                                                                                                \
+#define FUNCTION_LOG_VARIANT_TYPE                                                                                                  \
     Variant *
-#define FUNCTION_DEBUG_VARIANT_FORMAT(value, buffer, bufferSize)                                                                   \
-    varToLog(value, buffer, bufferSize)
+#define FUNCTION_LOG_VARIANT_FORMAT(value, buffer, bufferSize)                                                                     \
+    FUNCTION_LOG_STRING_OBJECT_FORMAT(value, varToLog, buffer, bufferSize)
 
 #endif
