@@ -4,7 +4,6 @@ Wait Handler
 #include "common/debug.h"
 #include "common/log.h"
 #include "common/memContext.h"
-#include "common/time.h"
 #include "common/wait.h"
 
 /***********************************************************************************************************************************
@@ -23,13 +22,13 @@ struct Wait
 New wait handler
 ***********************************************************************************************************************************/
 Wait *
-waitNew(double waitTime)
+waitNew(TimeMSec waitTime)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelTrace);
-        FUNCTION_DEBUG_PARAM(DOUBLE, waitTime);
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(TIMEMSEC, waitTime);
+    FUNCTION_LOG_END();
 
-        FUNCTION_DEBUG_ASSERT(waitTime >= 0.1 && waitTime <= 999999.0);
-    FUNCTION_DEBUG_END();
+    ASSERT(waitTime >= 100 && waitTime <= 999999000);
 
     // Allocate wait object
     Wait *this = NULL;
@@ -41,7 +40,7 @@ waitNew(double waitTime)
         this->memContext = MEM_CONTEXT_NEW();
 
         // Store time
-        this->waitTime = (TimeMSec)(waitTime * MSEC_PER_SEC);
+        this->waitTime = waitTime;
 
         // Calculate first sleep time -- start with 1/10th of a second for anything >= 1 second
         if (this->waitTime >= MSEC_PER_SEC)
@@ -55,7 +54,7 @@ waitNew(double waitTime)
     }
     MEM_CONTEXT_NEW_END();
 
-    FUNCTION_DEBUG_RESULT(WAIT, this);
+    FUNCTION_LOG_RETURN(WAIT, this);
 }
 
 /***********************************************************************************************************************************
@@ -64,11 +63,11 @@ Wait and return whether the caller has more time left
 bool
 waitMore(Wait *this)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelTrace);
-        FUNCTION_DEBUG_PARAM(WAIT, this);
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(WAIT, this);
+    FUNCTION_LOG_END();
 
-        FUNCTION_DEBUG_ASSERT(this != NULL);
-    FUNCTION_DEBUG_END();
+    ASSERT(this != NULL);
 
     bool result = false;
 
@@ -103,7 +102,7 @@ waitMore(Wait *this)
         result = true;
     }
 
-    FUNCTION_DEBUG_RESULT(BOOL, result);
+    FUNCTION_LOG_RETURN(BOOL, result);
 }
 
 /***********************************************************************************************************************************
@@ -112,12 +111,12 @@ Free the wait
 void
 waitFree(Wait *this)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelTrace);
-        FUNCTION_DEBUG_PARAM(WAIT, this);
-    FUNCTION_DEBUG_END();
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(WAIT, this);
+    FUNCTION_LOG_END();
 
     if (this != NULL)
         memContextFree(this->memContext);
 
-    FUNCTION_DEBUG_RESULT_VOID();
+    FUNCTION_LOG_RETURN_VOID();
 }
