@@ -9,19 +9,21 @@ Wait object
 ***********************************************************************************************************************************/
 typedef struct Wait Wait;
 
+#include "common/time.h"
+
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
-Wait *waitNew(double waitTime);
+Wait *waitNew(TimeMSec waitTime);
 bool waitMore(Wait *this);
 void waitFree(Wait *this);
 
 /***********************************************************************************************************************************
 Macros for function logging
 ***********************************************************************************************************************************/
-#define FUNCTION_DEBUG_WAIT_TYPE                                                                                                   \
+#define FUNCTION_LOG_WAIT_TYPE                                                                                                     \
     Wait *
-#define FUNCTION_DEBUG_WAIT_FORMAT(value, buffer, bufferSize)                                                                      \
+#define FUNCTION_LOG_WAIT_FORMAT(value, buffer, bufferSize)                                                                        \
     objToLog(value, "Wait", buffer, bufferSize)
 
 #endif
