@@ -3,7 +3,6 @@ Command and Option Configuration
 ***********************************************************************************************************************************/
 #include <string.h>
 
-#include "common/assert.h"
 #include "common/debug.h"
 #include "common/error.h"
 #include "common/memContext.h"
@@ -119,7 +118,7 @@ static ConfigOptionValue configOptionValue[CFG_OPTION_TOTAL];
 Initialize or reinitialize the configuration data
 ***********************************************************************************************************************************/
 void
-cfgInit()
+cfgInit(void)
 {
     FUNCTION_TEST_VOID();
 
@@ -148,17 +147,17 @@ cfgInit()
     }
     MEM_CONTEXT_END();
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
 Get/set the current command
 ***********************************************************************************************************************************/
 ConfigCommand
-cfgCommand()
+cfgCommand(void)
 {
     FUNCTION_TEST_VOID();
-    FUNCTION_TEST_RESULT(ENUM, command);
+    FUNCTION_TEST_RETURN(command);
 }
 
 void
@@ -166,23 +165,23 @@ cfgCommandSet(ConfigCommand commandParam)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, commandParam);
-
-        FUNCTION_TEST_ASSERT(commandParam <= cfgCmdNone);
     FUNCTION_TEST_END();
 
+    ASSERT(commandParam <= cfgCmdNone);
+
     command = commandParam;
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
 Was help requested?
 ***********************************************************************************************************************************/
 bool
-cfgCommandHelp()
+cfgCommandHelp(void)
 {
     FUNCTION_TEST_VOID();
-    FUNCTION_TEST_RESULT(BOOL, help);
+    FUNCTION_TEST_RETURN(help);
 }
 
 void
@@ -194,7 +193,7 @@ cfgCommandHelpSet(bool helpParam)
 
     help = helpParam;
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
@@ -208,11 +207,11 @@ cfgCommandDefIdFromId(ConfigCommand commandId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, commandId);
-
-        FUNCTION_TEST_ASSERT(commandId < cfgCmdNone);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(ENUM, (ConfigDefineCommand)commandId);
+    ASSERT(commandId < cfgCmdNone);
+
+    FUNCTION_TEST_RETURN((ConfigDefineCommand)commandId);
 }
 
 /***********************************************************************************************************************************
@@ -223,10 +222,10 @@ cfgCommandId(const char *commandName)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRINGZ, commandName);
-
-        FUNCTION_TEST_ASSERT(commandName != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(commandName != NULL);
+
     ConfigCommand commandId;
 
     for (commandId = 0; commandId < cfgCmdNone; commandId++)
@@ -236,7 +235,7 @@ cfgCommandId(const char *commandName)
     if (commandId == cfgCmdNone)
         THROW_FMT(AssertError, "invalid command '%s'", commandName);
 
-    FUNCTION_TEST_RESULT(ENUM, commandId);
+    FUNCTION_TEST_RETURN(commandId);
 }
 
 /***********************************************************************************************************************************
@@ -247,18 +246,18 @@ cfgCommandName(ConfigCommand commandId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, commandId);
-
-        FUNCTION_TEST_ASSERT(commandId < cfgCmdNone);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(STRINGZ, configCommandData[commandId].name);
+    ASSERT(commandId < cfgCmdNone);
+
+    FUNCTION_TEST_RETURN(configCommandData[commandId].name);
 }
 
 /***********************************************************************************************************************************
 Command parameters, if any
 ***********************************************************************************************************************************/
 const StringList *
-cfgCommandParam()
+cfgCommandParam(void)
 {
     FUNCTION_TEST_VOID();
 
@@ -271,7 +270,7 @@ cfgCommandParam()
         MEM_CONTEXT_END();
     }
 
-    FUNCTION_TEST_RESULT(STRING_LIST, paramList);
+    FUNCTION_TEST_RETURN(paramList);
 }
 
 void
@@ -279,27 +278,27 @@ cfgCommandParamSet(const StringList *param)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING_LIST, param);
-
-        FUNCTION_TEST_ASSERT(param != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(param != NULL);
+
     MEM_CONTEXT_BEGIN(configMemContext)
     {
         paramList = strLstDup(param);
     }
     MEM_CONTEXT_END();
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
 Command parameters, if any
 ***********************************************************************************************************************************/
 const String *
-cfgExe()
+cfgExe(void)
 {
     FUNCTION_TEST_VOID();
-    FUNCTION_TEST_RESULT(STRING, exe);
+    FUNCTION_TEST_RETURN(exe);
 }
 
 void
@@ -307,82 +306,82 @@ cfgExeSet(const String *exeParam)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRING, exeParam);
-
-        FUNCTION_TEST_ASSERT(exeParam != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(exeParam != NULL);
+
     MEM_CONTEXT_BEGIN(configMemContext)
     {
         exe = strDup(exeParam);
     }
     MEM_CONTEXT_END();
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
 Does this command require an immediate lock?
 ***********************************************************************************************************************************/
 bool
-cfgLockRequired()
+cfgLockRequired(void)
 {
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_ASSERT(command != cfgCmdNone);
-    FUNCTION_TEST_END();
+    FUNCTION_TEST_VOID();
 
-    FUNCTION_TEST_RESULT(BOOL, configCommandData[cfgCommand()].lockRequired);
+    ASSERT(command != cfgCmdNone);
+
+    FUNCTION_TEST_RETURN(configCommandData[cfgCommand()].lockRequired);
 }
 
 /***********************************************************************************************************************************
 Get the lock type required for this command
 ***********************************************************************************************************************************/
 LockType
-cfgLockType()
+cfgLockType(void)
 {
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_ASSERT(command != cfgCmdNone);
-    FUNCTION_TEST_END();
+    FUNCTION_TEST_VOID();
 
-    FUNCTION_TEST_RESULT(ENUM, (LockType)configCommandData[cfgCommand()].lockType);
+    ASSERT(command != cfgCmdNone);
+
+    FUNCTION_TEST_RETURN((LockType)configCommandData[cfgCommand()].lockType);
 }
 
 /***********************************************************************************************************************************
 Does this command log to a file?
 ***********************************************************************************************************************************/
 bool
-cfgLogFile()
+cfgLogFile(void)
 {
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_ASSERT(command != cfgCmdNone);
-    FUNCTION_TEST_END();
+    FUNCTION_TEST_VOID();
 
-    FUNCTION_TEST_RESULT(BOOL, configCommandData[cfgCommand()].logFile);
+    ASSERT(command != cfgCmdNone);
+
+    FUNCTION_TEST_RETURN(configCommandData[cfgCommand()].logFile);
 }
 
 /***********************************************************************************************************************************
 Get default log level -- used for log messages that are common to all commands
 ***********************************************************************************************************************************/
 LogLevel
-cfgLogLevelDefault()
+cfgLogLevelDefault(void)
 {
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_ASSERT(command != cfgCmdNone);
-    FUNCTION_TEST_END();
+    FUNCTION_TEST_VOID();
 
-    FUNCTION_TEST_RESULT(ENUM, (LogLevel)configCommandData[cfgCommand()].logLevelDefault);
+    ASSERT(command != cfgCmdNone);
+
+    FUNCTION_TEST_RETURN((LogLevel)configCommandData[cfgCommand()].logLevelDefault);
 }
 
 /***********************************************************************************************************************************
 Get max stderr log level -- used to suppress error output for higher log levels, e.g. local and remote commands
 ***********************************************************************************************************************************/
 LogLevel
-cfgLogLevelStdErrMax()
+cfgLogLevelStdErrMax(void)
 {
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_ASSERT(command != cfgCmdNone);
-    FUNCTION_TEST_END();
+    FUNCTION_TEST_VOID();
 
-    FUNCTION_TEST_RESULT(ENUM, (LogLevel)configCommandData[cfgCommand()].logLevelStdErrMax);
+    ASSERT(command != cfgCmdNone);
+
+    FUNCTION_TEST_RETURN((LogLevel)configCommandData[cfgCommand()].logLevelStdErrMax);
 }
 
 /***********************************************************************************************************************************
@@ -393,11 +392,11 @@ cfgOptionDefIdFromId(ConfigOption optionId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionId);
-
-        FUNCTION_TEST_ASSERT(optionId < CFG_OPTION_TOTAL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(ENUM, configOptionData[optionId].defineId);
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+
+    FUNCTION_TEST_RETURN(configOptionData[optionId].defineId);
 }
 
 /***********************************************************************************************************************************
@@ -408,10 +407,10 @@ cfgOptionDefault(ConfigOption optionId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionId);
-
-        FUNCTION_TEST_ASSERT(optionId < CFG_OPTION_TOTAL);
     FUNCTION_TEST_END();
 
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+
     if (configOptionValue[optionId].defaultValue == NULL)
     {
         ConfigDefineOption optionDefId = cfgOptionDefIdFromId(optionId);
@@ -460,7 +459,7 @@ cfgOptionDefault(ConfigOption optionId)
         }
     }
 
-    FUNCTION_TEST_RESULT(VARIANT, configOptionValue[optionId].defaultValue);
+    FUNCTION_TEST_RETURN(configOptionValue[optionId].defaultValue);
 }
 
 void
@@ -469,10 +468,10 @@ cfgOptionDefaultSet(ConfigOption optionId, const Variant *defaultValue)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionId);
         FUNCTION_TEST_PARAM(VARIANT, defaultValue);
-
-        FUNCTION_TEST_ASSERT(optionId < CFG_OPTION_TOTAL);
     FUNCTION_TEST_END();
 
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+
     MEM_CONTEXT_BEGIN(configMemContext)
     {
         if (configOptionValue[optionId].defaultValue != NULL)
@@ -490,7 +489,7 @@ cfgOptionDefaultSet(ConfigOption optionId, const Variant *defaultValue)
     }
     MEM_CONTEXT_END();
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
@@ -501,11 +500,11 @@ cfgOptionIndex(ConfigOption optionId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionId);
-
-        FUNCTION_TEST_ASSERT(optionId < CFG_OPTION_TOTAL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(UINT, configOptionData[optionId].index);
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+
+    FUNCTION_TEST_RETURN(configOptionData[optionId].index);
 }
 
 /***********************************************************************************************************************************
@@ -516,17 +515,17 @@ cfgOptionId(const char *optionName)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRINGZ, optionName);
-
-        FUNCTION_TEST_ASSERT(optionName != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(optionName != NULL);
+
     int result = -1;
 
     for (ConfigOption optionId = 0; optionId < CFG_OPTION_TOTAL; optionId++)
         if (strcmp(optionName, configOptionData[optionId].name) == 0)
             result = optionId;
 
-    FUNCTION_TEST_RESULT(INT, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -537,11 +536,11 @@ cfgOptionIndexTotal(ConfigOption optionId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionId);
-
-        FUNCTION_TEST_ASSERT(optionId < CFG_OPTION_TOTAL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(UINT, cfgDefOptionIndexTotal(configOptionData[optionId].defineId));
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+
+    FUNCTION_TEST_RETURN(cfgDefOptionIndexTotal(configOptionData[optionId].defineId));
 }
 
 /***********************************************************************************************************************************
@@ -553,11 +552,11 @@ cfgOptionIdFromDefId(ConfigDefineOption optionDefId, unsigned int index)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
         FUNCTION_TEST_PARAM(UINT, index);
-
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
-        FUNCTION_TEST_ASSERT(index < cfgDefOptionIndexTotal(optionDefId));
     FUNCTION_TEST_END();
 
+    ASSERT(optionDefId < cfgDefOptionTotal());
+    ASSERT(index < cfgDefOptionIndexTotal(optionDefId));
+
     // Search for the option
     ConfigOption optionId;
 
@@ -566,10 +565,10 @@ cfgOptionIdFromDefId(ConfigDefineOption optionDefId, unsigned int index)
             break;
 
     // If the mapping is not found then there is a bug in the code generator
-    ASSERT_DEBUG(optionId != CFG_OPTION_TOTAL);
+    ASSERT(optionId != CFG_OPTION_TOTAL);
 
     // Return with original index
-    FUNCTION_TEST_RESULT(ENUM, optionId + index);
+    FUNCTION_TEST_RETURN(optionId + index);
 }
 
 /***********************************************************************************************************************************
@@ -580,11 +579,11 @@ cfgOptionName(ConfigOption optionId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionId);
-
-        FUNCTION_TEST_ASSERT(optionId < CFG_OPTION_TOTAL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(STRINGZ, configOptionData[optionId].name);
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+
+    FUNCTION_TEST_RETURN(configOptionData[optionId].name);
 }
 
 /***********************************************************************************************************************************
@@ -595,11 +594,11 @@ cfgOptionNegate(ConfigOption optionId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionId);
-
-        FUNCTION_TEST_ASSERT(optionId < CFG_OPTION_TOTAL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(BOOL, configOptionValue[optionId].negate);
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+
+    FUNCTION_TEST_RETURN(configOptionValue[optionId].negate);
 }
 
 void
@@ -608,13 +607,13 @@ cfgOptionNegateSet(ConfigOption optionId, bool negate)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionId);
         FUNCTION_TEST_PARAM(BOOL, negate);
-
-        FUNCTION_TEST_ASSERT(optionId < CFG_OPTION_TOTAL);
     FUNCTION_TEST_END();
 
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+
     configOptionValue[optionId].negate = negate;
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
@@ -625,11 +624,11 @@ cfgOptionReset(ConfigOption optionId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionId);
-
-        FUNCTION_TEST_ASSERT(optionId < CFG_OPTION_TOTAL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(BOOL, configOptionValue[optionId].reset);
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+
+    FUNCTION_TEST_RETURN(configOptionValue[optionId].reset);
 }
 
 void
@@ -638,13 +637,13 @@ cfgOptionResetSet(ConfigOption optionId, bool reset)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionId);
         FUNCTION_TEST_PARAM(BOOL, reset);
-
-        FUNCTION_TEST_ASSERT(optionId < CFG_OPTION_TOTAL);
     FUNCTION_TEST_END();
 
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+
     configOptionValue[optionId].reset = reset;
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
@@ -655,88 +654,87 @@ cfgOption(ConfigOption optionId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionId);
-
-        FUNCTION_TEST_ASSERT(optionId < CFG_OPTION_TOTAL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(VARIANT, configOptionValue[optionId].value);
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+
+    FUNCTION_TEST_RETURN(configOptionValue[optionId].value);
 }
 
 bool
 cfgOptionBool(ConfigOption optionId)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelTrace);
-        FUNCTION_DEBUG_PARAM(ENUM, optionId);
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(ENUM, optionId);
+    FUNCTION_LOG_END();
 
-        FUNCTION_DEBUG_ASSERT(optionId < CFG_OPTION_TOTAL);
-        FUNCTION_DEBUG_ASSERT(varType(configOptionValue[optionId].value) == varTypeBool);
-    FUNCTION_DEBUG_END();
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+    ASSERT(varType(configOptionValue[optionId].value) == varTypeBool);
 
-    FUNCTION_DEBUG_RESULT(BOOL, varBool(configOptionValue[optionId].value));
+    FUNCTION_LOG_RETURN(BOOL, varBool(configOptionValue[optionId].value));
 }
 
 double
 cfgOptionDbl(ConfigOption optionId)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelTrace);
-        FUNCTION_DEBUG_PARAM(ENUM, optionId);
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(ENUM, optionId);
+    FUNCTION_LOG_END();
 
-        FUNCTION_DEBUG_ASSERT(optionId < CFG_OPTION_TOTAL);
-        FUNCTION_DEBUG_ASSERT(varType(configOptionValue[optionId].value) == varTypeDouble);
-    FUNCTION_DEBUG_END();
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+    ASSERT(varType(configOptionValue[optionId].value) == varTypeDouble);
 
-    FUNCTION_DEBUG_RESULT(DOUBLE, varDbl(configOptionValue[optionId].value));
+    FUNCTION_LOG_RETURN(DOUBLE, varDbl(configOptionValue[optionId].value));
 }
 
 int
 cfgOptionInt(ConfigOption optionId)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelTrace);
-        FUNCTION_DEBUG_PARAM(ENUM, optionId);
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(ENUM, optionId);
+    FUNCTION_LOG_END();
 
-        FUNCTION_DEBUG_ASSERT(optionId < CFG_OPTION_TOTAL);
-        FUNCTION_DEBUG_ASSERT(varType(configOptionValue[optionId].value) == varTypeInt64);
-    FUNCTION_DEBUG_END();
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+    ASSERT(varType(configOptionValue[optionId].value) == varTypeInt64);
 
-    FUNCTION_DEBUG_RESULT(INT, varIntForce(configOptionValue[optionId].value));
+    FUNCTION_LOG_RETURN(INT, varIntForce(configOptionValue[optionId].value));
 }
 
 int64_t
 cfgOptionInt64(ConfigOption optionId)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelTrace);
-        FUNCTION_DEBUG_PARAM(ENUM, optionId);
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(ENUM, optionId);
+    FUNCTION_LOG_END();
 
-        FUNCTION_DEBUG_ASSERT(optionId < CFG_OPTION_TOTAL);
-        FUNCTION_DEBUG_ASSERT(varType(configOptionValue[optionId].value) == varTypeInt64);
-    FUNCTION_DEBUG_END();
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+    ASSERT(varType(configOptionValue[optionId].value) == varTypeInt64);
 
-    FUNCTION_DEBUG_RESULT(INT64, varInt64(configOptionValue[optionId].value));
+    FUNCTION_LOG_RETURN(INT64, varInt64(configOptionValue[optionId].value));
 }
 
 const KeyValue *
 cfgOptionKv(ConfigOption optionId)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelTrace);
-        FUNCTION_DEBUG_PARAM(ENUM, optionId);
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(ENUM, optionId);
+    FUNCTION_LOG_END();
 
-        FUNCTION_DEBUG_ASSERT(optionId < CFG_OPTION_TOTAL);
-        FUNCTION_DEBUG_ASSERT(varType(configOptionValue[optionId].value) == varTypeKeyValue);
-    FUNCTION_DEBUG_END();
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+    ASSERT(varType(configOptionValue[optionId].value) == varTypeKeyValue);
 
-    FUNCTION_DEBUG_RESULT(KEY_VALUE, varKv(configOptionValue[optionId].value));
+    FUNCTION_LOG_RETURN(KEY_VALUE, varKv(configOptionValue[optionId].value));
 }
 
 const VariantList *
 cfgOptionLst(ConfigOption optionId)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelTrace);
-        FUNCTION_DEBUG_PARAM(ENUM, optionId);
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(ENUM, optionId);
+    FUNCTION_LOG_END();
 
-        FUNCTION_DEBUG_ASSERT(optionId < CFG_OPTION_TOTAL);
-        FUNCTION_DEBUG_ASSERT(
-            configOptionValue[optionId].value == NULL || varType(configOptionValue[optionId].value) == varTypeVariantList);
-    FUNCTION_DEBUG_END();
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+    ASSERT(configOptionValue[optionId].value == NULL || varType(configOptionValue[optionId].value) == varTypeVariantList);
 
     if (configOptionValue[optionId].value == NULL)
     {
@@ -747,26 +745,25 @@ cfgOptionLst(ConfigOption optionId)
         MEM_CONTEXT_END();
     }
 
-    FUNCTION_DEBUG_RESULT(VARIANT_LIST, varVarLst(configOptionValue[optionId].value));
+    FUNCTION_LOG_RETURN(VARIANT_LIST, varVarLst(configOptionValue[optionId].value));
 }
 
 const String *
 cfgOptionStr(ConfigOption optionId)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelTrace);
-        FUNCTION_DEBUG_PARAM(ENUM, optionId);
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(ENUM, optionId);
+    FUNCTION_LOG_END();
 
-        FUNCTION_DEBUG_ASSERT(optionId < CFG_OPTION_TOTAL);
-        FUNCTION_DEBUG_ASSERT(
-            configOptionValue[optionId].value == NULL || varType(configOptionValue[optionId].value) == varTypeString);
-    FUNCTION_DEBUG_END();
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+    ASSERT(configOptionValue[optionId].value == NULL || varType(configOptionValue[optionId].value) == varTypeString);
 
     const String *result = NULL;
 
     if (configOptionValue[optionId].value != NULL)
         result = varStr(configOptionValue[optionId].value);
 
-    FUNCTION_DEBUG_RESULT(CONST_STRING, result);
+    FUNCTION_LOG_RETURN_CONST(STRING, result);
 }
 
 void
@@ -776,10 +773,10 @@ cfgOptionSet(ConfigOption optionId, ConfigSource source, const Variant *value)
         FUNCTION_TEST_PARAM(ENUM, optionId);
         FUNCTION_TEST_PARAM(ENUM, source);
         FUNCTION_TEST_PARAM(VARIANT, value);
-
-        FUNCTION_TEST_ASSERT(optionId < CFG_OPTION_TOTAL);
     FUNCTION_TEST_END();
 
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+
     MEM_CONTEXT_BEGIN(configMemContext)
     {
         // Set the source
@@ -862,7 +859,7 @@ cfgOptionSet(ConfigOption optionId, ConfigSource source, const Variant *value)
     }
     MEM_CONTEXT_END();
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
@@ -873,11 +870,11 @@ cfgOptionSource(ConfigOption optionId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionId);
-
-        FUNCTION_TEST_ASSERT(optionId < CFG_OPTION_TOTAL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(ENUM, configOptionValue[optionId].source);
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+
+    FUNCTION_TEST_RETURN(configOptionValue[optionId].source);
 }
 
 /***********************************************************************************************************************************
@@ -888,11 +885,11 @@ cfgOptionTest(ConfigOption optionId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionId);
-
-        FUNCTION_TEST_ASSERT(optionId < CFG_OPTION_TOTAL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(BOOL, cfgOptionValid(optionId) && configOptionValue[optionId].value != NULL);
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+
+    FUNCTION_TEST_RETURN(cfgOptionValid(optionId) && configOptionValue[optionId].value != NULL);
 }
 
 /***********************************************************************************************************************************
@@ -903,11 +900,11 @@ cfgOptionValid(ConfigOption optionId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionId);
-
-        FUNCTION_TEST_ASSERT(optionId < CFG_OPTION_TOTAL);
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(BOOL, configOptionValue[optionId].valid);
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+
+    FUNCTION_TEST_RETURN(configOptionValue[optionId].valid);
 }
 
 void
@@ -916,11 +913,11 @@ cfgOptionValidSet(ConfigOption optionId, bool valid)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionId);
         FUNCTION_TEST_PARAM(BOOL, valid);
-
-        FUNCTION_TEST_ASSERT(optionId < CFG_OPTION_TOTAL);
     FUNCTION_TEST_END();
 
+    ASSERT(optionId < CFG_OPTION_TOTAL);
+
     configOptionValue[optionId].valid = valid;
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
