@@ -5,11 +5,15 @@ Command and Option Configuration Definition
 #include <stdint.h>
 #include <string.h>
 
-#include "common/assert.h"
 #include "common/debug.h"
 #include "common/error.h"
 #include "config/define.h"
 
+/***********************************************************************************************************************************
+Define global section name
+***********************************************************************************************************************************/
+STRING_EXTERN(CFGDEF_SECTION_GLOBAL_STR,                            CFGDEF_SECTION_GLOBAL);
+
 /***********************************************************************************************************************************
 Map command names to ids and vice versa.
 ***********************************************************************************************************************************/
@@ -184,18 +188,18 @@ cfgDefDataFind(
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, typeFind);
         FUNCTION_TEST_PARAM(ENUM, commandDefId);
-        FUNCTION_TEST_PARAM(VOIDPP, dataList);
-        FUNCTION_TEST_PARAM(BOOLP, dataDefFound);
-        FUNCTION_TEST_PARAM(INTP, dataDef);
-        FUNCTION_TEST_PARAM(VOIDPP, dataDefList);
-        FUNCTION_TEST_PARAM(VOIDPP, dataDefListSize);
-
-        FUNCTION_TEST_ASSERT(dataDefFound != NULL);
-        FUNCTION_TEST_ASSERT(dataDef != NULL);
-        FUNCTION_TEST_ASSERT(dataDefList != NULL);
-        FUNCTION_TEST_ASSERT(dataDefListSize != NULL);
+        FUNCTION_TEST_PARAM_PP(VOID, dataList);
+        FUNCTION_TEST_PARAM_P(BOOL, dataDefFound);
+        FUNCTION_TEST_PARAM_P(INT, dataDef);
+        FUNCTION_TEST_PARAM_PP(VOID, dataDefList);
+        FUNCTION_TEST_PARAM_P(UINT, dataDefListSize);
     FUNCTION_TEST_END();
 
+    ASSERT(dataDefFound != NULL);
+    ASSERT(dataDef != NULL);
+    ASSERT(dataDefList != NULL);
+    ASSERT(dataDefListSize != NULL);
+
     *dataDefFound = false;
 
     // Only proceed if there is data
@@ -244,7 +248,7 @@ cfgDefDataFind(
         while(type != configDefDataTypeEnd);
     }
 
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
 
 #define CONFIG_DEFINE_DATA_FIND(commandDefId, optionDefId, type)                                                                   \
@@ -260,17 +264,17 @@ cfgDefDataFind(
 Command and option define totals
 ***********************************************************************************************************************************/
 unsigned int
-cfgDefCommandTotal()
+cfgDefCommandTotal(void)
 {
     FUNCTION_TEST_VOID();
-    FUNCTION_TEST_RESULT(UINT, sizeof(configDefineCommandData) / sizeof(ConfigDefineCommandData));
+    FUNCTION_TEST_RETURN(sizeof(configDefineCommandData) / sizeof(ConfigDefineCommandData));
 }
 
 unsigned int
-cfgDefOptionTotal()
+cfgDefOptionTotal(void)
 {
     FUNCTION_TEST_VOID();
-    FUNCTION_TEST_RESULT(UINT, sizeof(configDefineOptionData) / sizeof(ConfigDefineOptionData));
+    FUNCTION_TEST_RETURN(sizeof(configDefineOptionData) / sizeof(ConfigDefineOptionData));
 }
 
 /***********************************************************************************************************************************
@@ -281,11 +285,11 @@ cfgDefCommandHelpDescription(ConfigDefineCommand commandDefId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, commandDefId);
-
-        FUNCTION_TEST_ASSERT(commandDefId < cfgDefCommandTotal());
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(STRINGZ, configDefineCommandData[commandDefId].helpDescription);
+    ASSERT(commandDefId < cfgDefCommandTotal());
+
+    FUNCTION_TEST_RETURN(configDefineCommandData[commandDefId].helpDescription);
 }
 
 /***********************************************************************************************************************************
@@ -296,11 +300,11 @@ cfgDefCommandHelpSummary(ConfigDefineCommand commandDefId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, commandDefId);
-
-        FUNCTION_TEST_ASSERT(commandDefId < cfgDefCommandTotal());
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(STRINGZ, configDefineCommandData[commandDefId].helpSummary);
+    ASSERT(commandDefId < cfgDefCommandTotal());
+
+    FUNCTION_TEST_RETURN(configDefineCommandData[commandDefId].helpSummary);
 }
 
 /***********************************************************************************************************************************
@@ -312,14 +316,14 @@ cfgDefOptionAllowList(ConfigDefineCommand commandDefId, ConfigDefineOption optio
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, commandDefId);
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(commandDefId < cfgDefCommandTotal());
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
+    ASSERT(commandDefId < cfgDefCommandTotal());
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
     CONFIG_DEFINE_DATA_FIND(commandDefId, optionDefId, configDefDataTypeAllowList);
 
-    FUNCTION_TEST_RESULT(BOOL, dataDefFound);
+    FUNCTION_TEST_RETURN(dataDefFound);
 }
 
 const char *
@@ -329,15 +333,15 @@ cfgDefOptionAllowListValue(ConfigDefineCommand commandDefId, ConfigDefineOption
         FUNCTION_TEST_PARAM(ENUM, commandDefId);
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
         FUNCTION_TEST_PARAM(UINT, valueId);
-
-        FUNCTION_TEST_ASSERT(commandDefId < cfgDefCommandTotal());
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
-        FUNCTION_TEST_ASSERT(valueId < cfgDefOptionAllowListValueTotal(commandDefId, optionDefId));
     FUNCTION_TEST_END();
 
+    ASSERT(commandDefId < cfgDefCommandTotal());
+    ASSERT(optionDefId < cfgDefOptionTotal());
+    ASSERT(valueId < cfgDefOptionAllowListValueTotal(commandDefId, optionDefId));
+
     CONFIG_DEFINE_DATA_FIND(commandDefId, optionDefId, configDefDataTypeAllowList);
 
-    FUNCTION_TEST_RESULT(STRINGZ, (char *)dataDefList[valueId]);
+    FUNCTION_TEST_RETURN((char *)dataDefList[valueId]);
 }
 
 unsigned int
@@ -346,14 +350,14 @@ cfgDefOptionAllowListValueTotal(ConfigDefineCommand commandDefId, ConfigDefineOp
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, commandDefId);
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(commandDefId < cfgDefCommandTotal());
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
+    ASSERT(commandDefId < cfgDefCommandTotal());
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
     CONFIG_DEFINE_DATA_FIND(commandDefId, optionDefId, configDefDataTypeAllowList);
 
-    FUNCTION_TEST_RESULT(UINT, dataDefListSize);
+    FUNCTION_TEST_RETURN(dataDefListSize);
 }
 
 // Check if the value matches a value in the allow list
@@ -364,12 +368,12 @@ cfgDefOptionAllowListValueValid(ConfigDefineCommand commandDefId, ConfigDefineOp
         FUNCTION_TEST_PARAM(ENUM, commandDefId);
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
         FUNCTION_TEST_PARAM(STRINGZ, value);
-
-        FUNCTION_TEST_ASSERT(commandDefId < cfgDefCommandTotal());
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
-        FUNCTION_TEST_ASSERT(value != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(commandDefId < cfgDefCommandTotal());
+    ASSERT(optionDefId < cfgDefOptionTotal());
+    ASSERT(value != NULL);
+
     bool result = false;
 
     for (unsigned int valueIdx = 0; valueIdx < cfgDefOptionAllowListValueTotal(commandDefId, optionDefId); valueIdx++)
@@ -378,7 +382,7 @@ cfgDefOptionAllowListValueValid(ConfigDefineCommand commandDefId, ConfigDefineOp
             result = true;
     }
 
-    FUNCTION_TEST_RESULT(BOOL, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -390,14 +394,14 @@ cfgDefOptionAllowRange(ConfigDefineCommand commandDefId, ConfigDefineOption opti
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, commandDefId);
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(commandDefId < cfgDefCommandTotal());
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
+    ASSERT(commandDefId < cfgDefCommandTotal());
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
     CONFIG_DEFINE_DATA_FIND(commandDefId, optionDefId, configDefDataTypeAllowRange);
 
-    FUNCTION_TEST_RESULT(BOOL, dataDefFound);
+    FUNCTION_TEST_RETURN(dataDefFound);
 }
 
 double
@@ -406,15 +410,15 @@ cfgDefOptionAllowRangeMax(ConfigDefineCommand commandDefId, ConfigDefineOption o
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, commandDefId);
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(commandDefId < cfgDefCommandTotal());
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
+    ASSERT(commandDefId < cfgDefCommandTotal());
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
     CONFIG_DEFINE_DATA_FIND(commandDefId, optionDefId, configDefDataTypeAllowRange);
 
-    FUNCTION_TEST_RESULT(
-        DOUBLE, ((double)(((int64_t)(intptr_t)dataDefList[2]) + (((int64_t)(intptr_t)dataDefList[3]) * 1000000000L))) / 100);
+    FUNCTION_TEST_RETURN(
+        ((double)(((int64_t)(intptr_t)dataDefList[2]) + (((int64_t)(intptr_t)dataDefList[3]) * 1000000000L))) / 100);
 }
 
 double
@@ -423,15 +427,15 @@ cfgDefOptionAllowRangeMin(ConfigDefineCommand commandDefId, ConfigDefineOption o
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, commandDefId);
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(commandDefId < cfgDefCommandTotal());
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
+    ASSERT(commandDefId < cfgDefCommandTotal());
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
     CONFIG_DEFINE_DATA_FIND(commandDefId, optionDefId, configDefDataTypeAllowRange);
 
-    FUNCTION_TEST_RESULT(
-        DOUBLE, ((double)(((int64_t)(intptr_t)dataDefList[0]) + (((int64_t)(intptr_t)dataDefList[1]) * 1000000000L))) / 100);
+    FUNCTION_TEST_RETURN(
+        ((double)(((int64_t)(intptr_t)dataDefList[0]) + (((int64_t)(intptr_t)dataDefList[1]) * 1000000000L))) / 100);
 }
 
 /***********************************************************************************************************************************
@@ -443,11 +447,11 @@ cfgDefOptionDefault(ConfigDefineCommand commandDefId, ConfigDefineOption optionD
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, commandDefId);
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(commandDefId < cfgDefCommandTotal());
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
+    ASSERT(commandDefId < cfgDefCommandTotal());
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
     CONFIG_DEFINE_DATA_FIND(commandDefId, optionDefId, configDefDataTypeDefault);
 
     char *result = NULL;
@@ -455,7 +459,7 @@ cfgDefOptionDefault(ConfigDefineCommand commandDefId, ConfigDefineOption optionD
     if (dataDefFound)
         result = (char *)dataDefList[0];
 
-    FUNCTION_TEST_RESULT(STRINGZ, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -467,14 +471,14 @@ cfgDefOptionDepend(ConfigDefineCommand commandDefId, ConfigDefineOption optionDe
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, commandDefId);
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(commandDefId < cfgDefCommandTotal());
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
+    ASSERT(commandDefId < cfgDefCommandTotal());
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
     CONFIG_DEFINE_DATA_FIND(commandDefId, optionDefId, configDefDataTypeDepend);
 
-    FUNCTION_TEST_RESULT(BOOL, dataDefFound);
+    FUNCTION_TEST_RETURN(dataDefFound);
 }
 
 ConfigDefineOption
@@ -483,14 +487,14 @@ cfgDefOptionDependOption(ConfigDefineCommand commandDefId, ConfigDefineOption op
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, commandDefId);
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(commandDefId < cfgDefCommandTotal());
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
+    ASSERT(commandDefId < cfgDefCommandTotal());
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
     CONFIG_DEFINE_DATA_FIND(commandDefId, optionDefId, configDefDataTypeDepend);
 
-    FUNCTION_TEST_RESULT(ENUM, (ConfigDefineOption)dataDef);
+    FUNCTION_TEST_RETURN((ConfigDefineOption)dataDef);
 }
 
 const char *
@@ -500,15 +504,15 @@ cfgDefOptionDependValue(ConfigDefineCommand commandDefId, ConfigDefineOption opt
         FUNCTION_TEST_PARAM(ENUM, commandDefId);
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
         FUNCTION_TEST_PARAM(UINT, valueId);
-
-        FUNCTION_TEST_ASSERT(commandDefId < cfgDefCommandTotal());
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
-        FUNCTION_TEST_ASSERT(valueId < cfgDefOptionDependValueTotal(commandDefId, optionDefId));
     FUNCTION_TEST_END();
 
+    ASSERT(commandDefId < cfgDefCommandTotal());
+    ASSERT(optionDefId < cfgDefOptionTotal());
+    ASSERT(valueId < cfgDefOptionDependValueTotal(commandDefId, optionDefId));
+
     CONFIG_DEFINE_DATA_FIND(commandDefId, optionDefId, configDefDataTypeDepend);
 
-    FUNCTION_TEST_RESULT(STRINGZ, (char *)dataDefList[valueId]);
+    FUNCTION_TEST_RETURN((char *)dataDefList[valueId]);
 }
 
 unsigned int
@@ -517,14 +521,14 @@ cfgDefOptionDependValueTotal(ConfigDefineCommand commandDefId, ConfigDefineOptio
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, commandDefId);
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(commandDefId < cfgDefCommandTotal());
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
+    ASSERT(commandDefId < cfgDefCommandTotal());
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
     CONFIG_DEFINE_DATA_FIND(commandDefId, optionDefId, configDefDataTypeDepend);
 
-    FUNCTION_TEST_RESULT(UINT, dataDefListSize);
+    FUNCTION_TEST_RETURN(dataDefListSize);
 }
 
 // Check if the value matches a value in the allow list
@@ -535,12 +539,12 @@ cfgDefOptionDependValueValid(ConfigDefineCommand commandDefId, ConfigDefineOptio
         FUNCTION_TEST_PARAM(ENUM, commandDefId);
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
         FUNCTION_TEST_PARAM(STRINGZ, value);
-
-        FUNCTION_TEST_ASSERT(commandDefId < cfgDefCommandTotal());
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
-        FUNCTION_TEST_ASSERT(value != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(commandDefId < cfgDefCommandTotal());
+    ASSERT(optionDefId < cfgDefOptionTotal());
+    ASSERT(value != NULL);
+
     bool result = false;
 
     for (unsigned int valueIdx = 0; valueIdx < cfgDefOptionDependValueTotal(commandDefId, optionDefId); valueIdx++)
@@ -549,7 +553,7 @@ cfgDefOptionDependValueValid(ConfigDefineCommand commandDefId, ConfigDefineOptio
             result = true;
     }
 
-    FUNCTION_TEST_RESULT(BOOL, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -561,11 +565,11 @@ cfgDefOptionHelpDescription(ConfigDefineCommand commandDefId, ConfigDefineOption
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, commandDefId);
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(commandDefId < cfgDefCommandTotal());
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
+    ASSERT(commandDefId < cfgDefCommandTotal());
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
     CONFIG_DEFINE_DATA_FIND(commandDefId, optionDefId, configDefDataTypeHelpDescription);
 
     const char *result = configDefineOptionData[optionDefId].helpDescription;
@@ -573,7 +577,7 @@ cfgDefOptionHelpDescription(ConfigDefineCommand commandDefId, ConfigDefineOption
     if (dataDefFound)
         result = (char *)dataDefList[0];
 
-    FUNCTION_TEST_RESULT(STRINGZ, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -584,13 +588,13 @@ cfgDefOptionHelpNameAlt(ConfigDefineOption optionDefId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
     CONFIG_DEFINE_DATA_FIND(-1, optionDefId, configDefDataTypeHelpNameAlt);
 
-    FUNCTION_TEST_RESULT(BOOL, dataDefFound);
+    FUNCTION_TEST_RETURN(dataDefFound);
 }
 
 const char *
@@ -599,14 +603,14 @@ cfgDefOptionHelpNameAltValue(ConfigDefineOption optionDefId, unsigned int valueI
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
         FUNCTION_TEST_PARAM(UINT, valueId);
-
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
-        FUNCTION_TEST_ASSERT(valueId < cfgDefOptionHelpNameAltValueTotal(optionDefId));
     FUNCTION_TEST_END();
 
+    ASSERT(optionDefId < cfgDefOptionTotal());
+    ASSERT(valueId < cfgDefOptionHelpNameAltValueTotal(optionDefId));
+
     CONFIG_DEFINE_DATA_FIND(-1, optionDefId, configDefDataTypeHelpNameAlt);
 
-    FUNCTION_TEST_RESULT(STRINGZ, (char *)dataDefList[valueId]);
+    FUNCTION_TEST_RETURN((char *)dataDefList[valueId]);
 }
 
 unsigned int
@@ -614,13 +618,13 @@ cfgDefOptionHelpNameAltValueTotal(ConfigDefineOption optionDefId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
     CONFIG_DEFINE_DATA_FIND(-1, optionDefId, configDefDataTypeHelpNameAlt);
 
-    FUNCTION_TEST_RESULT(UINT, dataDefListSize);
+    FUNCTION_TEST_RETURN(dataDefListSize);
 }
 
 /***********************************************************************************************************************************
@@ -631,11 +635,11 @@ cfgDefOptionHelpSection(ConfigDefineOption optionDefId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(STRINGZ, configDefineOptionData[optionDefId].helpSection);
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
+    FUNCTION_TEST_RETURN(configDefineOptionData[optionDefId].helpSection);
 }
 
 /***********************************************************************************************************************************
@@ -647,11 +651,11 @@ cfgDefOptionHelpSummary(ConfigDefineCommand commandDefId, ConfigDefineOption opt
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, commandDefId);
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(commandDefId < cfgDefCommandTotal());
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
+    ASSERT(commandDefId < cfgDefCommandTotal());
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
     CONFIG_DEFINE_DATA_FIND(commandDefId, optionDefId, configDefDataTypeHelpSummary);
 
     const char *result = configDefineOptionData[optionDefId].helpSummary;
@@ -659,7 +663,7 @@ cfgDefOptionHelpSummary(ConfigDefineCommand commandDefId, ConfigDefineOption opt
     if (dataDefFound)
         result = (char *)dataDefList[0];
 
-    FUNCTION_TEST_RESULT(STRINGZ, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -670,17 +674,17 @@ cfgDefOptionId(const char *optionName)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STRINGZ, optionName);
-
-        FUNCTION_TEST_ASSERT(optionName != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(optionName != NULL);
+
     int result = -1;
 
     for (ConfigDefineOption optionDefId = 0; optionDefId < cfgDefOptionTotal(); optionDefId++)
         if (strcmp(optionName, configDefineOptionData[optionDefId].name) == 0)
             result = optionDefId;
 
-    FUNCTION_TEST_RESULT(INT, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -691,11 +695,11 @@ cfgDefOptionIndexTotal(ConfigDefineOption optionDefId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(UINT, configDefineOptionData[optionDefId].indexTotal);
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
+    FUNCTION_TEST_RETURN(configDefineOptionData[optionDefId].indexTotal);
 }
 
 /***********************************************************************************************************************************
@@ -707,11 +711,11 @@ cfgDefOptionInternal(ConfigDefineCommand commandDefId, ConfigDefineOption option
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, commandDefId);
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(commandDefId < cfgDefCommandTotal());
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
+    ASSERT(commandDefId < cfgDefCommandTotal());
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
     CONFIG_DEFINE_DATA_FIND(commandDefId, optionDefId, configDefDataTypeInternal);
 
     bool result = configDefineOptionData[optionDefId].internal;
@@ -719,7 +723,24 @@ cfgDefOptionInternal(ConfigDefineCommand commandDefId, ConfigDefineOption option
     if (dataDefFound)
         result = (bool)dataDef;
 
-    FUNCTION_TEST_RESULT(BOOL, result);
+    FUNCTION_TEST_RETURN(result);
+}
+
+/***********************************************************************************************************************************
+Does the option accept multiple values?
+***********************************************************************************************************************************/
+bool
+cfgDefOptionMulti(ConfigDefineOption optionDefId)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(ENUM, optionDefId);
+    FUNCTION_TEST_END();
+
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
+    FUNCTION_TEST_RETURN(
+        configDefineOptionData[optionDefId].type == cfgDefOptTypeHash ||
+            configDefineOptionData[optionDefId].type == cfgDefOptTypeList);
 }
 
 /***********************************************************************************************************************************
@@ -730,11 +751,11 @@ cfgDefOptionName(ConfigDefineOption optionDefId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(STRINGZ, configDefineOptionData[optionDefId].name);
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
+    FUNCTION_TEST_RETURN(configDefineOptionData[optionDefId].name);
 }
 
 /***********************************************************************************************************************************
@@ -745,10 +766,10 @@ cfgDefOptionPrefix(ConfigDefineOption optionDefId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
     CONFIG_DEFINE_DATA_FIND(-1, optionDefId, configDefDataTypePrefix);
 
     char *result = NULL;
@@ -756,7 +777,7 @@ cfgDefOptionPrefix(ConfigDefineOption optionDefId)
     if (dataDefFound)
         result = (char *)dataDefList[0];
 
-    FUNCTION_TEST_RESULT(STRINGZ, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -767,11 +788,11 @@ cfgDefOptionSecure(ConfigDefineOption optionDefId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(BOOL, configDefineOptionData[optionDefId].secure);
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
+    FUNCTION_TEST_RETURN(configDefineOptionData[optionDefId].secure);
 }
 
 /***********************************************************************************************************************************
@@ -783,11 +804,11 @@ cfgDefOptionRequired(ConfigDefineCommand commandDefId, ConfigDefineOption option
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, commandDefId);
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(commandDefId < cfgDefCommandTotal());
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
+    ASSERT(commandDefId < cfgDefCommandTotal());
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
     CONFIG_DEFINE_DATA_FIND(commandDefId, optionDefId, configDefDataTypeRequired);
 
     bool result = configDefineOptionData[optionDefId].required;
@@ -795,7 +816,7 @@ cfgDefOptionRequired(ConfigDefineCommand commandDefId, ConfigDefineOption option
     if (dataDefFound)
         result = (bool)dataDef;
 
-    FUNCTION_TEST_RESULT(BOOL, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -806,11 +827,11 @@ cfgDefOptionSection(ConfigDefineOption optionDefId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(ENUM, configDefineOptionData[optionDefId].section);
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
+    FUNCTION_TEST_RETURN(configDefineOptionData[optionDefId].section);
 }
 
 /***********************************************************************************************************************************
@@ -821,11 +842,11 @@ cfgDefOptionType(ConfigDefineOption optionDefId)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(INT, configDefineOptionData[optionDefId].type);
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
+    FUNCTION_TEST_RETURN(configDefineOptionData[optionDefId].type);
 }
 
 /***********************************************************************************************************************************
@@ -837,10 +858,10 @@ cfgDefOptionValid(ConfigDefineCommand commandDefId, ConfigDefineOption optionDef
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(ENUM, commandDefId);
         FUNCTION_TEST_PARAM(ENUM, optionDefId);
-
-        FUNCTION_TEST_ASSERT(commandDefId < cfgDefCommandTotal());
-        FUNCTION_TEST_ASSERT(optionDefId < cfgDefOptionTotal());
     FUNCTION_TEST_END();
 
-    FUNCTION_TEST_RESULT(BOOL, configDefineOptionData[optionDefId].commandValid & (1 << commandDefId));
+    ASSERT(commandDefId < cfgDefCommandTotal());
+    ASSERT(optionDefId < cfgDefOptionTotal());
+
+    FUNCTION_TEST_RETURN(configDefineOptionData[optionDefId].commandValid & (1 << commandDefId));
 }
