@@ -17,16 +17,18 @@ typedef enum
 } ConfigDefSection;
 
 #include "config/define.auto.h"
+#include "common/type/string.h"
 
 /***********************************************************************************************************************************
 Define global section name
 ***********************************************************************************************************************************/
 #define CFGDEF_SECTION_GLOBAL                                       "global"
+    STRING_DECLARE(CFGDEF_SECTION_GLOBAL_STR);
 
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
-unsigned int cfgDefCommandTotal();
+unsigned int cfgDefCommandTotal(void);
 void cfgDefCommandCheck(ConfigDefineCommand commandDefId);
 const char *cfgDefCommandHelpDescription(ConfigDefineCommand commandDefId);
 const char *cfgDefCommandHelpSummary(ConfigDefineCommand commandDefId);
@@ -54,12 +56,13 @@ const char *cfgDefOptionHelpSummary(ConfigDefineCommand commandDefId, ConfigDefi
 int cfgDefOptionId(const char *optionName);
 unsigned int cfgDefOptionIndexTotal(ConfigDefineOption optionDefId);
 bool cfgDefOptionInternal(ConfigDefineCommand commandDefId, ConfigDefineOption optionDefId);
+bool cfgDefOptionMulti(ConfigDefineOption optionDefId);
 const char *cfgDefOptionName(ConfigDefineOption optionDefId);
 const char *cfgDefOptionPrefix(ConfigDefineOption optionDefId);
 bool cfgDefOptionRequired(ConfigDefineCommand commandDefId, ConfigDefineOption optionDefId);
 ConfigDefSection cfgDefOptionSection(ConfigDefineOption optionDefId);
 bool cfgDefOptionSecure(ConfigDefineOption optionDefId);
-unsigned int cfgDefOptionTotal();
+unsigned int cfgDefOptionTotal(void);
 int cfgDefOptionType(ConfigDefineOption optionDefId);
 bool cfgDefOptionValid(ConfigDefineCommand commandDefId, ConfigDefineOption optionDefId);
 
