@@ -7,6 +7,7 @@ Configuration Load
 #include "command/command.h"
 #include "common/memContext.h"
 #include "common/debug.h"
+#include "common/io/io.h"
 #include "common/lock.h"
 #include "common/log.h"
 #include "config/config.h"
@@ -17,9 +18,9 @@ Configuration Load
 Load log settings
 ***********************************************************************************************************************************/
 void
-cfgLoadLogSetting()
+cfgLoadLogSetting(void)
 {
-    FUNCTION_DEBUG_VOID(logLevelTrace);
+    FUNCTION_LOG_VOID(logLevelTrace);
 
     // Initialize logging
     LogLevel logLevelConsole = logLevelOff;
@@ -47,16 +48,16 @@ cfgLoadLogSetting()
 
     logInit(logLevelConsole, logLevelStdErr, logLevelFile, logTimestamp);
 
-    FUNCTION_DEBUG_RESULT_VOID();
+    FUNCTION_LOG_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
 Update options that have complex rules
 ***********************************************************************************************************************************/
 void
-cfgLoadUpdateOption()
+cfgLoadUpdateOption(void)
 {
-    FUNCTION_DEBUG_VOID(logLevelTrace);
+    FUNCTION_LOG_VOID(logLevelTrace);
 
     // Set default for repo-host-cmd
     if (cfgOptionTest(cfgOptRepoHost) && cfgOptionSource(cfgOptRepoHostCmd) == cfgSourceDefault)
@@ -79,6 +80,19 @@ cfgLoadUpdateOption()
         // If protocol-timeout is default then increase it to be greater than db-timeout
         if (cfgOptionSource(cfgOptProtocolTimeout) == cfgSourceDefault)
             cfgOptionSet(cfgOptProtocolTimeout, cfgSourceDefault, varNewDbl(cfgOptionDbl(cfgOptDbTimeout) + 30));
+        else if (cfgOptionSource(cfgOptDbTimeout) == cfgSourceDefault)
+        {
+            double dbTimeout = cfgOptionDbl(cfgOptProtocolTimeout) - 30;
+
+            // Normally the protocol time will be greater than 45 seconds so db timeout can be at least 15 seconds
+            if (dbTimeout >= 15)
+            {
+                cfgOptionSet(cfgOptDbTimeout, cfgSourceDefault, varNewDbl(dbTimeout));
+            }
+            // But in some test cases the protocol timeout will be very small so make db timeout half of protocol timeout
+            else
+                cfgOptionSet(cfgOptDbTimeout, cfgSourceDefault, varNewDbl(cfgOptionDbl(cfgOptProtocolTimeout) / 2));
+        }
         else
         {
             THROW_FMT(OptionInvalidValueError,
@@ -194,7 +208,18 @@ cfgLoadUpdateOption()
         }
     }
 
-    FUNCTION_DEBUG_RESULT_VOID();
+    FUNCTION_LOG_RETURN_VOID();
+}
+
+/***********************************************************************************************************************************
+Attempt to set the log file and turn file logging off if the file cannot be opened.  This is so the Perl code won't attempt to open
+the file again and error out.
+***********************************************************************************************************************************/
+void
+cfgLoadLogFile(const String *logFile)
+{
+    if (!logFileSet(strPtr(logFile)))
+        cfgOptionSet(cfgOptLogLevelFile, cfgSourceParam, varNewStrZ("off"));
 }
 
 /***********************************************************************************************************************************
@@ -203,15 +228,15 @@ Load the configuration
 void
 cfgLoad(unsigned int argListSize, const char *argList[])
 {
-    FUNCTION_DEBUG_BEGIN(logLevelDebug);
-        FUNCTION_DEBUG_PARAM(UINT, argListSize);
-        FUNCTION_DEBUG_PARAM(CHARPY, argList);
-    FUNCTION_DEBUG_END();
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(UINT, argListSize);
+        FUNCTION_LOG_PARAM(CHARPY, argList);
+    FUNCTION_LOG_END();
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
         // Parse config from command line and config file
-        configParse(argListSize, argList);
+        configParse(argListSize, argList, true);
 
         // Load the log settings
         cfgLoadLogSetting();
@@ -223,18 +248,37 @@ cfgLoad(unsigned int argListSize, const char *argList[])
         // If a command is set
         if (cfgCommand() != cfgCmdNone)
         {
+            // Set IO buffer size
+            if (cfgOptionValid(cfgOptBufferSize))
+                ioBufferSizeSet((size_t)cfgOptionInt(cfgOptBufferSize));
+
             // Open the log file if this command logs to a file
             if (cfgLogFile() && !cfgCommandHelp())
             {
-                logFileSet(
-                    strPtr(strNewFmt("%s/%s-%s.log", strPtr(cfgOptionStr(cfgOptLogPath)), strPtr(cfgOptionStr(cfgOptStanza)),
-                    cfgCommandName(cfgCommand()))));
+                // Construct log filename prefix
+                String *logFile = strNewFmt(
+                    "%s/%s-", strPtr(cfgOptionStr(cfgOptLogPath)),
+                    cfgOptionTest(cfgOptStanza) ? strPtr(cfgOptionStr(cfgOptStanza)): "all");
+
+                // If local or remote command add command name and process id
+                if (cfgCommand() == cfgCmdLocal || cfgCommand() == cfgCmdRemote)
+                {
+                    strCatFmt(
+                        logFile, "%s-%s-%03d.log", strPtr(cfgOptionStr(cfgOptCommand)), cfgCommandName(cfgCommand()),
+                        cfgOptionInt(cfgOptProcess));
+                }
+                // Else add command name
+                else
+                    strCatFmt(logFile, "%s.log", cfgCommandName(cfgCommand()));
+
+                // Set the log file name
+                cfgLoadLogFile(logFile);
             }
 
             // Begin the command
             cmdBegin(true);
 
-            // Open the log file if this command logs to a file
+            // Acquire a lock if this command requires a lock
             if (cfgLockRequired() && !cfgCommandHelp())
                 lockAcquire(cfgOptionStr(cfgOptLockPath), cfgOptionStr(cfgOptStanza), cfgLockType(), 0, true);
 
@@ -244,5 +288,5 @@ cfgLoad(unsigned int argListSize, const char *argList[])
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_DEBUG_RESULT_VOID();
+    FUNCTION_LOG_RETURN_VOID();
 }
