@@ -7,12 +7,14 @@ Main
 #include "command/archive/get/get.h"
 #include "command/archive/push/push.h"
 #include "command/help/help.h"
+#include "command/info/info.h"
 #include "command/command.h"
 #include "common/debug.h"
 #include "common/error.h"
 #include "common/exit.h"
 #include "config/config.h"
 #include "config/load.h"
+#include "postgres/interface.h"
 #include "perl/exec.h"
 #include "version.h"
 
@@ -23,10 +25,10 @@ main(int argListSize, const char *argList[])
     stackTraceInit(argList[0]);
 #endif
 
-    FUNCTION_DEBUG_BEGIN(logLevelDebug);
-        FUNCTION_DEBUG_PARAM(INT, argListSize);
-        FUNCTION_DEBUG_PARAM(CHARPY, argList);
-    FUNCTION_DEBUG_END();
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(INT, argListSize);
+        FUNCTION_LOG_PARAM(CHARPY, argList);
+    FUNCTION_LOG_END();
 
     // Initialize command with the start time
     cmdInit();
@@ -54,7 +56,7 @@ main(int argListSize, const char *argList[])
         // -------------------------------------------------------------------------------------------------------------------------
         else if (cfgCommand() == cfgCmdVersion)
         {
-            printf(PGBACKREST_NAME " " PGBACKREST_VERSION "\n");
+            printf(PROJECT_NAME " " PROJECT_VERSION "\n");
             fflush(stdout);
         }
 
@@ -76,6 +78,13 @@ main(int argListSize, const char *argList[])
         // -------------------------------------------------------------------------------------------------------------------------
         else if (cfgCommand() == cfgCmdBackup)
         {
+#ifdef DEBUG
+            // Check pg_control during testing so errors are more obvious.  Otherwise errors only happen in archive-get/archive-push
+            // and end up in the PostgreSQL log which is not output in CI.  This can be removed once backup is written in C.
+            if (cfgOptionBool(cfgOptOnline) && !cfgOptionBool(cfgOptBackupStandby) && !cfgOptionTest(cfgOptPgHost))
+                pgControlFromFile(cfgOptionStr(cfgOptPgPath));
+#endif
+
             // Run backup
             perlExec();
 
@@ -88,6 +97,13 @@ main(int argListSize, const char *argList[])
             perlExec();
         }
 
+        // Info command
+        // -------------------------------------------------------------------------------------------------------------------------
+        else if (cfgCommand() == cfgCmdInfo)
+        {
+            cmdInfo();
+        }
+
         // Execute Perl for commands not implemented in C
         // -------------------------------------------------------------------------------------------------------------------------
         else
@@ -101,5 +117,5 @@ main(int argListSize, const char *argList[])
     }
     TRY_END();
 
-    FUNCTION_DEBUG_RESULT(INT, exitSafe(result, error, 0));
+    FUNCTION_LOG_RETURN(INT, exitSafe(result, error, 0));
 }
