@@ -9,7 +9,7 @@ Perl Configuration
 Build JSON output from options
 ***********************************************************************************************************************************/
 String *
-perlOptionJson()
+perlOptionJson(void)
 {
     FUNCTION_TEST_VOID();
 
@@ -131,5 +131,5 @@ perlOptionJson()
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_TEST_RESULT(STRING, result);
+    FUNCTION_TEST_RETURN(result);
 }
