@@ -9,6 +9,6 @@ Perl Configuration
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
-String *perlOptionJson();
+String *perlOptionJson(void);
 
 #endif
