@@ -1,19 +1,19 @@
 /***********************************************************************************************************************************
 Checksum Implementation for Data Pages
 ***********************************************************************************************************************************/
-#ifndef PAGE_CHECKSUM_H
-#define PAGE_CHECKSUM_H
+#ifndef POSTGRES_PAGECHECKSUM_H
+#define POSTGRES_PAGECHECKSUM_H
 
-#include "common/type.h"
+#include <stdint.h>
 
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
-uint16 pageChecksum(const unsigned char *page, unsigned int blockNo, unsigned int pageSize);
+uint16_t pageChecksum(const unsigned char *page, unsigned int blockNo, unsigned int pageSize);
 bool pageChecksumTest(
-    const unsigned char *page, unsigned int blockNo, unsigned int pageSize, uint32 ignoreWalId, uint32 ignoreWalOffset);
+    const unsigned char *page, unsigned int blockNo, unsigned int pageSize, uint32_t ignoreWalId, uint32_t ignoreWalOffset);
 bool pageChecksumBufferTest(
     const unsigned char *pageBuffer, unsigned int pageBufferSize, unsigned int blockNoBegin, unsigned int pageSize,
-    uint32 ignoreWalId, uint32 ignoreWalOffset);
+    uint32_t ignoreWalId, uint32_t ignoreWalOffset);
 
 #endif
