@@ -1,28 +1,31 @@
 /***********************************************************************************************************************************
-Storage Manager
+Storage Interface
 ***********************************************************************************************************************************/
 #include <stdio.h>
 #include <string.h>
 
-#include "common/assert.h"
 #include "common/debug.h"
+#include "common/io/io.h"
 #include "common/log.h"
 #include "common/memContext.h"
 #include "common/wait.h"
-#include "storage/driver/posix/driver.h"
-#include "storage/storage.h"
+#include "storage/storage.intern.h"
 
 /***********************************************************************************************************************************
-Storage structure
+Object type
 ***********************************************************************************************************************************/
 struct Storage
 {
     MemContext *memContext;
-    String *path;
+    void *driver;
+    StorageInterface interface;
+    const String *type;
+
+    const String *path;
     mode_t modeFile;
     mode_t modePath;
-    size_t bufferSize;
     bool write;
+    bool pathResolve;
     StoragePathExpressionCallback pathExpressionFunction;
 };
 
@@ -30,36 +33,50 @@ struct Storage
 New storage object
 ***********************************************************************************************************************************/
 Storage *
-storageNew(const String *path, StorageNewParam param)
+storageNew(
+    const String *type, const String *path, mode_t modeFile, mode_t modePath, bool write, bool pathResolve,
+    StoragePathExpressionCallback pathExpressionFunction, void *driver, StorageInterface interface)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelDebug);
-        FUNCTION_DEBUG_PARAM(STRING, path);
-        FUNCTION_DEBUG_PARAM(MODE, param.modeFile);
-        FUNCTION_DEBUG_PARAM(MODE, param.modePath);
-        FUNCTION_DEBUG_PARAM(SIZE, param.bufferSize);
-        FUNCTION_DEBUG_PARAM(BOOL, param.write);
-        FUNCTION_DEBUG_PARAM(FUNCTIONP, param.pathExpressionFunction);
+    FUNCTION_LOG_BEGIN(logLevelTrace);
+        FUNCTION_LOG_PARAM(STRING, type);
+        FUNCTION_LOG_PARAM(STRING, path);
+        FUNCTION_LOG_PARAM(MODE, modeFile);
+        FUNCTION_LOG_PARAM(MODE, modePath);
+        FUNCTION_LOG_PARAM(BOOL, write);
+        FUNCTION_LOG_PARAM(BOOL, pathResolve);
+        FUNCTION_LOG_PARAM(FUNCTIONP, pathExpressionFunction);
+        FUNCTION_LOG_PARAM_P(VOID, driver);
+        FUNCTION_LOG_PARAM(STORAGE_INTERFACE, interface);
+    FUNCTION_LOG_END();
 
-        FUNCTION_DEBUG_ASSERT(path != NULL);
-    FUNCTION_DEBUG_END();
+    ASSERT(type != NULL);
+    ASSERT(path != NULL && strSize(path) >= 1 && strPtr(path)[0] == '/');
+    ASSERT(driver != NULL);
+    ASSERT(interface.exists != NULL);
+    ASSERT(interface.info != NULL);
+    ASSERT(interface.list != NULL);
+    ASSERT(interface.newRead != NULL);
+    ASSERT(interface.newWrite != NULL);
+    ASSERT(interface.pathCreate != NULL);
+    ASSERT(interface.pathRemove != NULL);
+    ASSERT(interface.pathSync != NULL);
+    ASSERT(interface.remove != NULL);
 
     Storage *this = NULL;
+    this = (Storage *)memNew(sizeof(Storage));
+    this->memContext = memContextCurrent();
+    this->driver = driver;
+    this->interface = interface;
+    this->type = type;
 
-    // Create the storage
-    MEM_CONTEXT_NEW_BEGIN("Storage")
-    {
-        this = (Storage *)memNew(sizeof(Storage));
-        this->memContext = MEM_CONTEXT_NEW();
-        this->path = strDup(path);
-        this->modeFile = param.modeFile == 0 ? STORAGE_FILE_MODE_DEFAULT : param.modeFile;
-        this->modePath = param.modePath == 0 ? STORAGE_PATH_MODE_DEFAULT : param.modePath;
-        this->bufferSize = param.bufferSize == 0 ? STORAGE_BUFFER_SIZE_DEFAULT : param.bufferSize;
-        this->write = param.write;
-        this->pathExpressionFunction = param.pathExpressionFunction;
-    }
-    MEM_CONTEXT_NEW_END();
+    this->path = strDup(path);
+    this->modeFile = modeFile;
+    this->modePath = modePath;
+    this->write = write;
+    this->pathResolve = pathResolve;
+    this->pathExpressionFunction = pathExpressionFunction;
 
-    FUNCTION_DEBUG_RESULT(STORAGE, this);
+    FUNCTION_LOG_RETURN(STORAGE, this);
 }
 
 /***********************************************************************************************************************************
@@ -68,37 +85,38 @@ Copy a file
 bool
 storageCopy(StorageFileRead *source, StorageFileWrite *destination)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelDebug);
-        FUNCTION_DEBUG_PARAM(STORAGE_FILE_READ, source);
-        FUNCTION_DEBUG_PARAM(STORAGE_FILE_WRITE, destination);
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(STORAGE_FILE_READ, source);
+        FUNCTION_LOG_PARAM(STORAGE_FILE_WRITE, destination);
+    FUNCTION_LOG_END();
 
-        FUNCTION_TEST_ASSERT(source != NULL);
-        FUNCTION_TEST_ASSERT(destination != NULL);
-    FUNCTION_DEBUG_END();
+    ASSERT(source != NULL);
+    ASSERT(destination != NULL);
 
     bool result = false;
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
         // Open source file
-        if (storageFileReadOpen(source))
+        if (ioReadOpen(storageFileReadIo(source)))
         {
             // Open the destination file now that we know the source file exists and is readable
-            storageFileWriteOpen(destination);
+            ioWriteOpen(storageFileWriteIo(destination));
 
             // Copy data from source to destination
-            Buffer *read = NULL;
+            Buffer *read = bufNew(ioBufferSize());
 
             do
             {
-                read = storageFileRead(source);
-                storageFileWrite(destination, read);
+                ioRead(storageFileReadIo(source), read);
+                ioWrite(storageFileWriteIo(destination), read);
+                bufUsedZero(read);
             }
-            while (read != NULL);
+            while (!ioReadEof(storageFileReadIo(source)));
 
             // Close the source and destination files
-            storageFileReadClose(source);
-            storageFileWriteClose(destination);
+            ioReadClose(storageFileReadIo(source));
+            ioWriteClose(storageFileWriteIo(destination));
 
             // Set result to indicate that the file was copied
             result = true;
@@ -106,29 +124,28 @@ storageCopy(StorageFileRead *source, StorageFileWrite *destination)
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_DEBUG_RESULT(BOOL, result);
+    FUNCTION_LOG_RETURN(BOOL, result);
 }
 
 /***********************************************************************************************************************************
-Does a file/path exist?
+Does a file exist? This function is only for files, not directories.
 ***********************************************************************************************************************************/
 bool
 storageExists(const Storage *this, const String *pathExp, StorageExistsParam param)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelDebug);
-        FUNCTION_DEBUG_PARAM(STORAGE, this);
-        FUNCTION_DEBUG_PARAM(STRING, pathExp);
-        FUNCTION_DEBUG_PARAM(DOUBLE, param.timeout);
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(STORAGE, this);
+        FUNCTION_LOG_PARAM(STRING, pathExp);
+        FUNCTION_LOG_PARAM(TIMEMSEC, param.timeout);
+    FUNCTION_LOG_END();
 
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_DEBUG_ASSERT(param.timeout >= 0);
-    FUNCTION_DEBUG_END();
+    ASSERT(this != NULL);
 
     bool result = false;
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        // Build the path
+        // Build the path to the file
         String *path = storagePathNP(this, pathExp);
 
         // Create Wait object of timeout > 0
@@ -138,56 +155,75 @@ storageExists(const Storage *this, const String *pathExp, StorageExistsParam par
         do
         {
             // Call driver function
-            result = storageDriverPosixExists(path);
+            result = this->interface.exists(this->driver, path);
         }
         while (!result && wait != NULL && waitMore(wait));
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_DEBUG_RESULT(BOOL, result);
+    FUNCTION_LOG_RETURN(BOOL, result);
 }
 
 /***********************************************************************************************************************************
 Read from storage into a buffer
 ***********************************************************************************************************************************/
 Buffer *
-storageGet(StorageFileRead *file)
+storageGet(StorageFileRead *file, StorageGetParam param)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelDebug);
-        FUNCTION_DEBUG_PARAM(STORAGE_FILE_READ, file);
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(STORAGE_FILE_READ, file);
+        FUNCTION_LOG_PARAM(SIZE, param.exactSize);
+    FUNCTION_LOG_END();
 
-        FUNCTION_TEST_ASSERT(file != NULL);
-    FUNCTION_DEBUG_END();
+    ASSERT(file != NULL);
 
     Buffer *result = NULL;
 
     // If the file exists
-    if (storageFileReadOpen(file))
+    if (ioReadOpen(storageFileReadIo(file)))
     {
         MEM_CONTEXT_TEMP_BEGIN()
         {
-            result = bufNew(0);
-            Buffer *read = NULL;
-
-            do
+            // If exact read
+            if (param.exactSize > 0)
             {
-                // Read data
-                read = storageFileRead(file);
+                result = bufNew(param.exactSize);
+                ioRead(storageFileReadIo(file), result);
 
-                // Add to result and free read buffer
-                bufCat(result, read);
-                bufFree(read);
+                // If an exact read make sure the size is as expected
+                if (bufUsed(result) != param.exactSize)
+                {
+                    THROW_FMT(
+                        FileReadError, "unable to read %zu byte(s) from '%s'", param.exactSize, strPtr(storageFileReadName(file)));
+                }
             }
-            while (read != NULL);
+            // Else read entire file
+            else
+            {
+                result = bufNew(0);
+                Buffer *read = bufNew(ioBufferSize());
 
+                do
+                {
+                    // Read data
+                    ioRead(storageFileReadIo(file), read);
+
+                    // Add to result and free read buffer
+                    bufCat(result, read);
+                    bufUsedZero(read);
+                }
+                while (!ioReadEof(storageFileReadIo(file)));
+            }
+
+            // Move buffer to parent context on success
             bufMove(result, MEM_CONTEXT_OLD());
         }
         MEM_CONTEXT_TEMP_END();
 
-        storageFileReadClose(file);
+        ioReadClose(storageFileReadIo(file));
     }
 
-    FUNCTION_DEBUG_RESULT(BUFFER, result);
+    FUNCTION_LOG_RETURN(BUFFER, result);
 }
 
 /***********************************************************************************************************************************
@@ -196,13 +232,13 @@ File/path info
 StorageInfo
 storageInfo(const Storage *this, const String *fileExp, StorageInfoParam param)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelDebug);
-        FUNCTION_DEBUG_PARAM(STORAGE, this);
-        FUNCTION_DEBUG_PARAM(STRING, fileExp);
-        FUNCTION_DEBUG_PARAM(BOOL, param.ignoreMissing);
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(STORAGE, this);
+        FUNCTION_LOG_PARAM(STRING, fileExp);
+        FUNCTION_LOG_PARAM(BOOL, param.ignoreMissing);
+    FUNCTION_LOG_END();
 
-        FUNCTION_TEST_ASSERT(this != NULL);
-    FUNCTION_DEBUG_END();
+    ASSERT(this != NULL);
 
     StorageInfo result = {0};
 
@@ -212,11 +248,11 @@ storageInfo(const Storage *this, const String *fileExp, StorageInfoParam param)
         String *file = storagePathNP(this, fileExp);
 
         // Call driver function
-        result = storageDriverPosixInfo(file, param.ignoreMissing);
+        result = this->interface.info(this->driver, file, param.ignoreMissing);
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_DEBUG_RESULT(STORAGE_INFO, result);
+    FUNCTION_LOG_RETURN(STORAGE_INFO, result);
 }
 
 /***********************************************************************************************************************************
@@ -225,14 +261,14 @@ Get a list of files from a directory
 StringList *
 storageList(const Storage *this, const String *pathExp, StorageListParam param)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelDebug);
-        FUNCTION_DEBUG_PARAM(STORAGE, this);
-        FUNCTION_DEBUG_PARAM(STRING, pathExp);
-        FUNCTION_DEBUG_PARAM(BOOL, param.errorOnMissing);
-        FUNCTION_DEBUG_PARAM(STRING, param.expression);
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(STORAGE, this);
+        FUNCTION_LOG_PARAM(STRING, pathExp);
+        FUNCTION_LOG_PARAM(BOOL, param.errorOnMissing);
+        FUNCTION_LOG_PARAM(STRING, param.expression);
+    FUNCTION_LOG_END();
 
-        FUNCTION_TEST_ASSERT(this != NULL);
-    FUNCTION_DEBUG_END();
+    ASSERT(this != NULL);
 
     StringList *result = NULL;
 
@@ -242,48 +278,52 @@ storageList(const Storage *this, const String *pathExp, StorageListParam param)
         String *path = storagePathNP(this, pathExp);
 
         // Move list up to the old context
-        result = strLstMove(storageDriverPosixList(path, param.errorOnMissing, param.expression), MEM_CONTEXT_OLD());
+        result = strLstMove(this->interface.list(this->driver, path, param.errorOnMissing, param.expression), MEM_CONTEXT_OLD());
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_DEBUG_RESULT(STRING_LIST, result);
+    FUNCTION_LOG_RETURN(STRING_LIST, result);
 }
 
 /***********************************************************************************************************************************
 Move a file
 ***********************************************************************************************************************************/
 void
-storageMove(StorageFileRead *source, StorageFileWrite *destination)
+storageMove(const Storage *this, StorageFileRead *source, StorageFileWrite *destination)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelDebug);
-        FUNCTION_DEBUG_PARAM(STORAGE_FILE_READ, source);
-        FUNCTION_DEBUG_PARAM(STORAGE_FILE_WRITE, destination);
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(STORAGE_FILE_READ, source);
+        FUNCTION_LOG_PARAM(STORAGE_FILE_WRITE, destination);
+    FUNCTION_LOG_END();
 
-        FUNCTION_TEST_ASSERT(source != NULL);
-        FUNCTION_TEST_ASSERT(destination != NULL);
-        FUNCTION_DEBUG_ASSERT(!storageFileReadIgnoreMissing(source));
-    FUNCTION_DEBUG_END();
+    ASSERT(this->interface.move != NULL);
+    ASSERT(source != NULL);
+    ASSERT(destination != NULL);
+    ASSERT(!storageFileReadIgnoreMissing(source));
+    ASSERT(strEq(this->type, storageFileReadType(source)));
+    ASSERT(strEq(storageFileReadType(source), storageFileWriteType(destination)));
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
         // If the file can't be moved it will need to be copied
-        if (!storageDriverPosixMove(storageFileReadFileDriver(source), storageFileWriteFileDriver(destination)))
+        if (!this->interface.move(this->driver, storageFileReadDriver(source), storageFileWriteFileDriver(destination)))
         {
             // Perform the copy
             storageCopyNP(source, destination);
 
             // Remove the source file
-            storageDriverPosixRemove(storageFileReadName(source), false);
+            this->interface.remove(this->driver, storageFileReadName(source), false);
 
             // Sync source path if the destination path was synced.  We know the source and destination paths are different because
-            // the move did not succeed.  This will need updating when drivers other than Posix/CIFS are implemented.
+            // the move did not succeed.  This will need updating when drivers other than Posix/CIFS are implemented becaue there's
+            // no way to get coverage on it now.
             if (storageFileWriteSyncPath(destination))
-                storageDriverPosixPathSync(strPath(storageFileReadName(source)), false);
+                this->interface.pathSync(this->driver, strPath(storageFileReadName(source)), false);
         }
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_DEBUG_RESULT_VOID();
+    FUNCTION_LOG_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
@@ -292,26 +332,29 @@ Open a file for reading
 StorageFileRead *
 storageNewRead(const Storage *this, const String *fileExp, StorageNewReadParam param)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelTrace);
-        FUNCTION_DEBUG_PARAM(STORAGE, this);
-        FUNCTION_DEBUG_PARAM(STRING, fileExp);
-        FUNCTION_DEBUG_PARAM(BOOL, param.ignoreMissing);
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(STORAGE, this);
+        FUNCTION_LOG_PARAM(STRING, fileExp);
+        FUNCTION_LOG_PARAM(BOOL, param.ignoreMissing);
+        FUNCTION_LOG_PARAM(IO_FILTER_GROUP, param.filterGroup);
+    FUNCTION_LOG_END();
 
-        FUNCTION_TEST_ASSERT(this != NULL);
-    FUNCTION_DEBUG_END();
+    ASSERT(this != NULL);
 
     StorageFileRead *result = NULL;
 
-    MEM_CONTEXT_NEW_BEGIN("StorageFileRead")
+    MEM_CONTEXT_TEMP_BEGIN()
     {
-        String *fileName = storagePathNP(this, fileExp);
+        result = this->interface.newRead(this->driver, storagePathNP(this, fileExp), param.ignoreMissing);
 
-        // Create the file
-        result = storageFileReadMove(storageFileReadNew(fileName, param.ignoreMissing, this->bufferSize), MEM_CONTEXT_OLD());
+        if (param.filterGroup != NULL)
+            ioReadFilterGroupSet(storageFileReadIo(result), param.filterGroup);
+
+        storageFileReadMove(result, MEM_CONTEXT_OLD());
     }
-    MEM_CONTEXT_NEW_END();
+    MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_DEBUG_RESULT(STORAGE_FILE_READ, result);
+    FUNCTION_LOG_RETURN(STORAGE_FILE_READ, result);
 }
 
 /***********************************************************************************************************************************
@@ -320,37 +363,38 @@ Open a file for writing
 StorageFileWrite *
 storageNewWrite(const Storage *this, const String *fileExp, StorageNewWriteParam param)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelTrace);
-        FUNCTION_DEBUG_PARAM(STORAGE, this);
-        FUNCTION_DEBUG_PARAM(STRING, fileExp);
-        FUNCTION_DEBUG_PARAM(MODE, param.modeFile);
-        FUNCTION_DEBUG_PARAM(MODE, param.modePath);
-        FUNCTION_DEBUG_PARAM(BOOL, param.noCreatePath);
-        FUNCTION_DEBUG_PARAM(BOOL, param.noSyncFile);
-        FUNCTION_DEBUG_PARAM(BOOL, param.noSyncPath);
-        FUNCTION_DEBUG_PARAM(BOOL, param.noAtomic);
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(STORAGE, this);
+        FUNCTION_LOG_PARAM(STRING, fileExp);
+        FUNCTION_LOG_PARAM(MODE, param.modeFile);
+        FUNCTION_LOG_PARAM(MODE, param.modePath);
+        FUNCTION_LOG_PARAM(BOOL, param.noCreatePath);
+        FUNCTION_LOG_PARAM(BOOL, param.noSyncFile);
+        FUNCTION_LOG_PARAM(BOOL, param.noSyncPath);
+        FUNCTION_LOG_PARAM(BOOL, param.noAtomic);
+        FUNCTION_LOG_PARAM(IO_FILTER_GROUP, param.filterGroup);
+    FUNCTION_LOG_END();
 
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_DEBUG_ASSERT(this->write);
-    FUNCTION_DEBUG_END();
+    ASSERT(this != NULL);
+    ASSERT(this->write);
 
     StorageFileWrite *result = NULL;
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        String *fileName = storagePathNP(this, fileExp);
+        result = this->interface.newWrite(
+            this->driver, storagePathNP(this, fileExp), param.modeFile != 0 ? param.modeFile : this->modeFile,
+            param.modePath != 0 ? param.modePath : this->modePath, !param.noCreatePath, !param.noSyncFile, !param.noSyncPath,
+            !param.noAtomic);
 
-        // Create the file
-        result = storageFileWriteMove(
-            storageFileWriteNew(
-                fileName, param.modeFile != 0 ? param.modeFile : this->modeFile,
-                param.modePath != 0 ? param.modePath : this->modePath, param.noCreatePath, param.noSyncFile, param.noSyncPath,
-                param.noAtomic),
-            MEM_CONTEXT_OLD());
+        if (param.filterGroup != NULL)
+            ioWriteFilterGroupSet(storageFileWriteIo(result), param.filterGroup);
+
+        storageFileWriteMove(result, MEM_CONTEXT_OLD());
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_DEBUG_RESULT(STORAGE_FILE_WRITE, result);
+    FUNCTION_LOG_RETURN(STORAGE_FILE_WRITE, result);
 }
 
 /***********************************************************************************************************************************
@@ -362,14 +406,19 @@ storagePath(const Storage *this, const String *pathExp)
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM(STORAGE, this);
         FUNCTION_TEST_PARAM(STRING, pathExp);
-
-        FUNCTION_TEST_ASSERT(this != NULL);
     FUNCTION_TEST_END();
 
+    ASSERT(this != NULL);
+
     String *result = NULL;
 
-    // If there there is no path expression then return the base storage path
-    if (pathExp == NULL)
+    // If the path will not be resolved here then just make a copy
+    if (!this->pathResolve)
+    {
+        result = strDup(pathExp);
+    }
+    // If there is no path expression then return the base storage path
+    else if (pathExp == NULL)
     {
         result = strDup(this->path);
     }
@@ -452,7 +501,7 @@ storagePath(const Storage *this, const String *pathExp)
         }
     }
 
-    FUNCTION_TEST_RESULT(STRING, result);
+    FUNCTION_TEST_RETURN(result);
 }
 
 /***********************************************************************************************************************************
@@ -461,21 +510,20 @@ Create a path
 void
 storagePathCreate(const Storage *this, const String *pathExp, StoragePathCreateParam param)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelDebug);
-        FUNCTION_DEBUG_PARAM(STORAGE, this);
-        FUNCTION_DEBUG_PARAM(STRING, pathExp);
-        FUNCTION_DEBUG_PARAM(BOOL, param.errorOnExists);
-        FUNCTION_DEBUG_PARAM(BOOL, param.noParentCreate);
-        FUNCTION_DEBUG_PARAM(MODE, param.mode);
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(STORAGE, this);
+        FUNCTION_LOG_PARAM(STRING, pathExp);
+        FUNCTION_LOG_PARAM(BOOL, param.errorOnExists);
+        FUNCTION_LOG_PARAM(BOOL, param.noParentCreate);
+        FUNCTION_LOG_PARAM(MODE, param.mode);
+    FUNCTION_LOG_END();
 
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_DEBUG_ASSERT(this->write);
+    ASSERT(this != NULL);
+    ASSERT(this->write);
 
-        // It doesn't make sense to combine these parameters because if we are creating missing parent paths why error when they
-        // exist? If this somehow wasn't caught in testing, the worst case is that the path would not be created and an error would
-        // be thrown.
-        FUNCTION_TEST_ASSERT(!(param.noParentCreate && param.errorOnExists));
-    FUNCTION_DEBUG_END();
+    // It doesn't make sense to combine these parameters because if we are creating missing parent paths why error when they exist?
+    // If this somehow wasn't caught in testing, the worst case is that the path would not be created and an error would be thrown.
+    ASSERT(!(param.noParentCreate && param.errorOnExists));
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
@@ -483,12 +531,12 @@ storagePathCreate(const Storage *this, const String *pathExp, StoragePathCreateP
         String *path = storagePathNP(this, pathExp);
 
         // Call driver function
-        storageDriverPosixPathCreate(
-            path, param.errorOnExists, param.noParentCreate, param.mode != 0 ? param.mode : this->modePath);
+        this->interface.pathCreate(
+            this->driver, path, param.errorOnExists, param.noParentCreate, param.mode != 0 ? param.mode : this->modePath);
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_DEBUG_RESULT_VOID();
+    FUNCTION_LOG_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
@@ -497,15 +545,15 @@ Remove a path
 void
 storagePathRemove(const Storage *this, const String *pathExp, StoragePathRemoveParam param)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelDebug);
-        FUNCTION_DEBUG_PARAM(STORAGE, this);
-        FUNCTION_DEBUG_PARAM(STRING, pathExp);
-        FUNCTION_DEBUG_PARAM(BOOL, param.errorOnMissing);
-        FUNCTION_DEBUG_PARAM(BOOL, param.recurse);
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(STORAGE, this);
+        FUNCTION_LOG_PARAM(STRING, pathExp);
+        FUNCTION_LOG_PARAM(BOOL, param.errorOnMissing);
+        FUNCTION_LOG_PARAM(BOOL, param.recurse);
+    FUNCTION_LOG_END();
 
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_DEBUG_ASSERT(this->write);
-    FUNCTION_DEBUG_END();
+    ASSERT(this != NULL);
+    ASSERT(this->write);
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
@@ -513,11 +561,11 @@ storagePathRemove(const Storage *this, const String *pathExp, StoragePathRemoveP
         String *path = storagePathNP(this, pathExp);
 
         // Call driver function
-        storageDriverPosixPathRemove(path, param.errorOnMissing, param.recurse);
+        this->interface.pathRemove(this->driver, path, param.errorOnMissing, param.recurse);
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_DEBUG_RESULT_VOID();
+    FUNCTION_LOG_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
@@ -525,14 +573,14 @@ Sync a path
 ***********************************************************************************************************************************/
 void storagePathSync(const Storage *this, const String *pathExp, StoragePathSyncParam param)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelDebug);
-        FUNCTION_DEBUG_PARAM(STORAGE, this);
-        FUNCTION_DEBUG_PARAM(STRING, pathExp);
-        FUNCTION_DEBUG_PARAM(BOOL, param.ignoreMissing);
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(STORAGE, this);
+        FUNCTION_LOG_PARAM(STRING, pathExp);
+        FUNCTION_LOG_PARAM(BOOL, param.ignoreMissing);
+    FUNCTION_LOG_END();
 
-        FUNCTION_TEST_ASSERT(this != NULL);
-        FUNCTION_DEBUG_ASSERT(this->write);
-    FUNCTION_DEBUG_END();
+    ASSERT(this != NULL);
+    ASSERT(this->write);
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
@@ -540,11 +588,11 @@ void storagePathSync(const Storage *this, const String *pathExp, StoragePathSync
         String *path = storagePathNP(this, pathExp);
 
         // Call driver function
-        storageDriverPosixPathSync(path, param.ignoreMissing);
+        this->interface.pathSync(this->driver, path, param.ignoreMissing);
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_DEBUG_RESULT_VOID();
+    FUNCTION_LOG_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
@@ -553,18 +601,18 @@ Write a buffer to storage
 void
 storagePut(StorageFileWrite *file, const Buffer *buffer)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelDebug);
-        FUNCTION_DEBUG_PARAM(STORAGE_FILE_WRITE, file);
-        FUNCTION_DEBUG_PARAM(BUFFER, buffer);
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(STORAGE_FILE_WRITE, file);
+        FUNCTION_LOG_PARAM(BUFFER, buffer);
+    FUNCTION_LOG_END();
 
-        FUNCTION_DEBUG_ASSERT(file != NULL);
-    FUNCTION_DEBUG_END();
+    ASSERT(file != NULL);
 
-    storageFileWriteOpen(file);
-    storageFileWrite(file, buffer);
-    storageFileWriteClose(file);
+    ioWriteOpen(storageFileWriteIo(file));
+    ioWrite(storageFileWriteIo(file), buffer);
+    ioWriteClose(storageFileWriteIo(file));
 
-    FUNCTION_DEBUG_RESULT_VOID();
+    FUNCTION_LOG_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
@@ -573,14 +621,14 @@ Remove a file
 void
 storageRemove(const Storage *this, const String *fileExp, StorageRemoveParam param)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelDebug);
-        FUNCTION_DEBUG_PARAM(STORAGE, this);
-        FUNCTION_DEBUG_PARAM(STRING, fileExp);
-        FUNCTION_DEBUG_PARAM(BOOL, param.errorOnMissing);
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(STORAGE, this);
+        FUNCTION_LOG_PARAM(STRING, fileExp);
+        FUNCTION_LOG_PARAM(BOOL, param.errorOnMissing);
+    FUNCTION_LOG_END();
 
-        FUNCTION_DEBUG_ASSERT(this != NULL);
-        FUNCTION_DEBUG_ASSERT(this->write);
-    FUNCTION_DEBUG_END();
+    ASSERT(this != NULL);
+    ASSERT(this->write);
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
@@ -588,35 +636,21 @@ storageRemove(const Storage *this, const String *fileExp, StorageRemoveParam par
         String *file = storagePathNP(this, fileExp);
 
         // Call driver function
-        storageDriverPosixRemove(file, param.errorOnMissing);
+        this->interface.remove(this->driver, file, param.errorOnMissing);
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_DEBUG_RESULT_VOID();
+    FUNCTION_LOG_RETURN_VOID();
 }
 
 /***********************************************************************************************************************************
-Convert to a zero-terminated string for logging
+Render as string for logging
 ***********************************************************************************************************************************/
-size_t
-storageToLog(const Storage *this, char *buffer, size_t bufferSize)
+String *
+storageToLog(const Storage *this)
 {
-    size_t result = 0;
-
-    MEM_CONTEXT_TEMP_BEGIN()
-    {
-        String *string = NULL;
-
-        if (this == NULL)
-            string = strNew("null");
-        else
-            string = strNewFmt("{path: %s, write: %s}", strPtr(strQuoteZ(this->path, "\"")), this->write ? "true" : "false");
-
-        result = (size_t)snprintf(buffer, bufferSize, "%s", strPtr(string));
-    }
-    MEM_CONTEXT_TEMP_END();
-
-    return result;
+    return strNewFmt(
+        "{type: %s, path: %s, write: %s}", strPtr(this->type), strPtr(strToLog(this->path)), cvtBoolToConstZ(this->write));
 }
 
 /***********************************************************************************************************************************
@@ -625,12 +659,12 @@ Free storage
 void
 storageFree(const Storage *this)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelDebug);
-        FUNCTION_DEBUG_PARAM(STORAGE, this);
-    FUNCTION_DEBUG_END();
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(STORAGE, this);
+    FUNCTION_LOG_END();
 
     if (this != NULL)
         memContextFree(this->memContext);
 
-    FUNCTION_DEBUG_RESULT_VOID();
+    FUNCTION_LOG_RETURN_VOID();
 }
