@@ -1,5 +1,5 @@
 /***********************************************************************************************************************************
-Storage Manager
+Storage Interface
 ***********************************************************************************************************************************/
 #ifndef STORAGE_STORAGE_H
 #define STORAGE_STORAGE_H
@@ -7,54 +7,18 @@ Storage Manager
 #include <sys/types.h>
 
 /***********************************************************************************************************************************
-Storage object
+Object type
 ***********************************************************************************************************************************/
 typedef struct Storage Storage;
 
 #include "common/type/buffer.h"
 #include "common/type/stringList.h"
+#include "common/io/filter/group.h"
+#include "common/time.h"
 #include "storage/fileRead.h"
 #include "storage/fileWrite.h"
 #include "storage/info.h"
 
-/***********************************************************************************************************************************
-Default buffer size
-
-Generally buffer size should be pulled out of options but some storage is created without access to options.  In those cases we'll
-assume they are not doing any heavy lifting and have a moderate default.
-***********************************************************************************************************************************/
-#define STORAGE_BUFFER_SIZE_DEFAULT                                 (64 * 1024)
-
-/***********************************************************************************************************************************
-Default file and path modes
-***********************************************************************************************************************************/
-#define STORAGE_FILE_MODE_DEFAULT                                   0640
-#define STORAGE_PATH_MODE_DEFAULT                                   0750
-
-/***********************************************************************************************************************************
-Path expression callback function type - used to modify paths based on expressions enclosed in <>
-***********************************************************************************************************************************/
-typedef String *(*StoragePathExpressionCallback)(const String *expression, const String *path);
-
-/***********************************************************************************************************************************
-storageNew
-***********************************************************************************************************************************/
-typedef struct StorageNewParam
-{
-    mode_t modeFile;
-    mode_t modePath;
-    size_t bufferSize;
-    bool write;
-    StoragePathExpressionCallback pathExpressionFunction;
-} StorageNewParam;
-
-#define storageNewP(path, ...)                                                                                                     \
-    storageNew(path, (StorageNewParam){__VA_ARGS__})
-#define storageNewNP(path)                                                                                                         \
-    storageNew(path, (StorageNewParam){0})
-
-Storage *storageNew(const String *path, StorageNewParam param);
-
 /***********************************************************************************************************************************
 storageCopy
 ***********************************************************************************************************************************/
@@ -68,7 +32,7 @@ storageExists
 ***********************************************************************************************************************************/
 typedef struct StorageExistsParam
 {
-    double timeout;
+    TimeMSec timeout;
 } StorageExistsParam;
 
 #define storageExistsP(this, pathExp, ...)                                                                                         \
@@ -81,10 +45,17 @@ bool storageExists(const Storage *this, const String *pathExp, StorageExistsPara
 /***********************************************************************************************************************************
 storageGet
 ***********************************************************************************************************************************/
-#define storageGetNP(file)                                                                                                         \
-    storageGet(file)
+typedef struct StorageGetParam
+{
+    size_t exactSize;
+} StorageGetParam;
 
-Buffer *storageGet(StorageFileRead *file);
+#define storageGetP(file, ...)                                                                                                     \
+    storageGet(file, (StorageGetParam){__VA_ARGS__})
+#define storageGetNP(file)                                                                                                         \
+    storageGet(file, (StorageGetParam){0})
+
+Buffer *storageGet(StorageFileRead *file, StorageGetParam param);
 
 /***********************************************************************************************************************************
 storageInfo
@@ -120,10 +91,10 @@ StringList *storageList(const Storage *this, const String *pathExp, StorageListP
 /***********************************************************************************************************************************
 storageMove
 ***********************************************************************************************************************************/
-#define storageMoveNP(source, destination)                                                                                         \
-    storageMove(source, destination)
+#define storageMoveNP(this, source, destination)                                                                                   \
+    storageMove(this, source, destination)
 
-void storageMove(StorageFileRead *source, StorageFileWrite *destination);
+void storageMove(const Storage *this, StorageFileRead *source, StorageFileWrite *destination);
 
 /***********************************************************************************************************************************
 storageNewRead
@@ -131,6 +102,7 @@ storageNewRead
 typedef struct StorageNewReadParam
 {
     bool ignoreMissing;
+    IoFilterGroup *filterGroup;
 } StorageNewReadParam;
 
 #define storageNewReadP(this, pathExp, ...)                                                                                        \
@@ -151,6 +123,7 @@ typedef struct StorageNewWriteParam
     bool noSyncFile;
     bool noSyncPath;
     bool noAtomic;
+    IoFilterGroup *filterGroup;
 } StorageNewWriteParam;
 
 #define storageNewWriteP(this, pathExp, ...)                                                                                       \
@@ -239,22 +212,14 @@ typedef struct StorageRemoveParam
 
 void storageRemove(const Storage *this, const String *fileExp, StorageRemoveParam param);
 
-/***********************************************************************************************************************************
-storageFree
-***********************************************************************************************************************************/
-#define storageFreeNP(this)                                                                                                        \
-    storageFree(this)
-
-void storageFree(const Storage *this);
-
 /***********************************************************************************************************************************
 Macros for function logging
 ***********************************************************************************************************************************/
-size_t storageToLog(const Storage *this, char *buffer, size_t bufferSize);
+String *storageToLog(const Storage *this);
 
-#define FUNCTION_DEBUG_STORAGE_TYPE                                                                                                \
+#define FUNCTION_LOG_STORAGE_TYPE                                                                                                  \
     Storage *
-#define FUNCTION_DEBUG_STORAGE_FORMAT(value, buffer, bufferSize)                                                                   \
-    (size_t)storageToLog(value, buffer, bufferSize)
+#define FUNCTION_LOG_STORAGE_FORMAT(value, buffer, bufferSize)                                                                     \
+    FUNCTION_LOG_STRING_OBJECT_FORMAT(value, storageToLog, buffer, bufferSize)
 
 #endif
