@@ -40,6 +40,7 @@ sub new
         $self->{strOS},
         $self->{stryMount},
         $self->{strOption},
+        $self->{strParam},
     ) =
         logDebugParam
         (
@@ -51,6 +52,7 @@ sub new
             {name => 'strOS', trace => true},
             {name => 'stryMount', required => false, trace => true},
             {name => 'strOption', required => false, trace => true},
+            {name => 'strParam', required => false, trace => true},
         );
 
     executeTest("docker rm -f $self->{strContainer}", {bSuppressError => true});
@@ -58,7 +60,7 @@ sub new
     executeTest("docker run -itd -h $self->{strName} --name=$self->{strContainer}" .
                 (defined($self->{strOption}) ? ' ' . $self->{strOption} : '') .
                 (defined($self->{stryMount}) ? ' -v ' . join(' -v ', @{$self->{stryMount}}) : '') .
-                " $self->{strImage}",
+                " $self->{strImage} " . (defined($self->{strParam}) ? ' ' . $self->{strParam} : ''),
                 {bSuppressStdErr => true});
 
     # Get IP Address
@@ -107,14 +109,18 @@ sub execute
         $strOperation,
         $strCommand,
         $oParam,
-        $strUser
+        $strUser,
+        $bLoadEnv,
+        $bBashWrap,
     ) =
         logDebugParam
         (
             __PACKAGE__ . '->execute', \@_,
             {name => 'strCommand'},
-            {name => 'oParam', required=> false},
-            {name => 'strUser', required => false}
+            {name => 'oParam', required => false},
+            {name => 'strUser', required => false},
+            {name => 'bLoadEnv', optional => true, default => true},
+            {name => 'bBashWrap', optional => true, default => true},
         );
 
     # Set the user
@@ -126,7 +132,8 @@ sub execute
     $strCommand =~ s/'/'\\''/g;
 
     my $oExec = new pgBackRestTest::Common::ExecuteTest(
-        "docker exec -u ${strUser} $self->{strContainer} bash -l -c '${strCommand}'" , $oParam);
+        "docker exec -u ${strUser} $self->{strContainer}" .
+        ($bBashWrap ? " bash" . ($bLoadEnv ? ' -l' : '') . " -c '${strCommand}'" : " ${strCommand}"), $oParam);
 
     # Return from function and log return values if any
     return logDebugReturn
@@ -149,17 +156,21 @@ sub executeSimple
         $strOperation,
         $strCommand,
         $oParam,
-        $strUser
+        $strUser,
+        $bLoadEnv,
+        $bBashWrap,
     ) =
         logDebugParam
         (
             __PACKAGE__ . '->executeSimple', \@_,
             {name => 'strCommand', trace => true},
             {name => 'oParam', required=> false, trace => true},
-            {name => 'strUser', required => false, trace => true}
+            {name => 'strUser', required => false, trace => true},
+            {name => 'bLoadEnv', optional => true, default => true, trace => true},
+            {name => 'bBashWrap', optional => true, default => true},
         );
 
-    my $oExec = $self->execute($strCommand, $oParam, $strUser);
+    my $oExec = $self->execute($strCommand, $oParam, $strUser, {bLoadEnv => $bLoadEnv});
     $oExec->begin();
     $oExec->end();
 
