@@ -28,6 +28,8 @@ use constant TEST_C                                                 => 'c';
     push @EXPORT, qw(TEST_C);
 use constant TEST_CDEF                                              => 'cdef';
     push @EXPORT, qw(TEST_CDEF);
+use constant TEST_CTESTDEF                                          => 'ctestdef';
+    push @EXPORT, qw(TEST_CTESTDEF);
 use constant TEST_CONTAINER                                         => 'container';
     push @EXPORT, qw(TEST_CONTAINER);
 use constant TEST_DEBUG_UNIT_SUPPRESS                               => TESTDEF_DEBUG_UNIT_SUPPRESS;
@@ -151,6 +153,7 @@ sub testListGet
                                         &TEST_VM => $strTestOS,
                                         &TEST_C => coalesce($hTest->{&TESTDEF_C}, $hModule->{&TESTDEF_C}, false),
                                         &TEST_CDEF => $hTest->{&TESTDEF_DEFINE},
+                                        &TEST_CTESTDEF => $hTest->{&TESTDEF_DEFINE_TEST},
                                         &TEST_DEBUG_UNIT_SUPPRESS => $hTest->{&TEST_DEBUG_UNIT_SUPPRESS},
                                         &TEST_CONTAINER => defined($hTest->{&TESTDEF_CONTAINER}) ?
                                             $hTest->{&TESTDEF_CONTAINER} : $hModule->{&TESTDEF_CONTAINER},
