@@ -162,7 +162,7 @@ sub process
         $self->coverage(), $self->{strBackRestExeC}, $self->{strBackRestExeHelper}, dirname($self->testPath()), $self->basePath(),
         $self->module(), $self->moduleTest(), true);
 
-    backrestBinSet($self->{strBackRestExe});
+    projectBinSet($self->{strBackRestExe});
 
     # Init, run, and end the test(s)
     $self->initModule();
@@ -606,7 +606,7 @@ sub archBits {return vmArchBits(shift->{strVm})}
 sub backrestExe {return shift->{strBackRestExe}}
 sub backrestUser {return shift->{strBackRestUser}}
 sub basePath {return shift->{strBasePath}}
-sub coverage {vmCoverage(shift->{strVm})}
+sub coverage {vmCoveragePerl(shift->{strVm})}
 sub dataPath {return shift->basePath() . '/test/data'}
 sub doCleanup {return shift->{bCleanup}}
 sub doExpect {return shift->{bExpect}}
