@@ -34,6 +34,11 @@ use pgBackRestTest::Common::ExecuteTest;
 use pgBackRestTest::Common::HostGroupTest;
 use pgBackRestTest::Common::RunTest;
 
+####################################################################################################################################
+# Test WAL size
+####################################################################################################################################
+use constant PG_WAL_SIZE_TEST                                       => 16777216;
+
 ####################################################################################################################################
 # Host defaults
 ####################################################################################################################################
@@ -117,6 +122,7 @@ sub archivePush
         $iArchiveNo,
         $iExpectedError,
         $bAsync,
+        $strOptionalParam,
     ) =
         logDebugParam
         (
@@ -126,6 +132,7 @@ sub archivePush
             {name => 'iArchiveNo', required => false},
             {name => 'iExpectedError', required => false},
             {name => 'bAsync', default => true},
+            {name => 'strOptionalParam', required => false},
         );
 
     my $strSourceFile;
@@ -143,11 +150,12 @@ sub archivePush
     $self->executeSimple(
         $self->backrestExe() .
         ' --config=' . $self->backrestConfig() .
-        ' --log-level-console=warn --archive-push-queue-max=' . int(2 * PG_WAL_SIZE) .
+        ' --log-level-console=warn --archive-push-queue-max=' . int(2 * PG_WAL_SIZE_TEST) .
         ' --stanza=' . $self->stanza() .
         (defined($iExpectedError) && $iExpectedError == ERROR_FILE_READ ? ' --repo1-host=bogus' : '') .
         ($bAsync ? '' : ' --no-archive-async') .
-        " archive-push" . (defined($strSourceFile) ? " ${strSourceFile}" : ''),
+        " archive-push" . (defined($strSourceFile) ? " ${strSourceFile}" : '') .
+        (defined($strOptionalParam) ? " ${strOptionalParam}" : ''),
         {iExpectedExitStatus => $iExpectedError, oLogTest => $self->{oLogTest}, bLogOutput => $self->synthetic()});
 
     # Return from function and log return values if any
