@@ -34,6 +34,11 @@ use pgBackRestTest::Common::ExecuteTest;
 use pgBackRestTest::Env::Host::HostBackupTest;
 use pgBackRestTest::Common::RunTest;
 
+####################################################################################################################################
+# Test WAL size
+####################################################################################################################################
+use constant PG_WAL_SIZE_TEST                                       => 16777216;
+
 ####################################################################################################################################
 # initModule
 ####################################################################################################################################
@@ -294,7 +299,7 @@ sub run
     if ($self->begin("ArchivePush->dropList()"))
     {
         my $oPushAsync = new pgBackRest::Archive::Push::Async($self->{strWalPath}, $self->{strSpoolPath});
-        $self->optionTestSet(CFGOPT_ARCHIVE_PUSH_QUEUE_MAX, PG_WAL_SIZE * 4);
+        $self->optionTestSet(CFGOPT_ARCHIVE_PUSH_QUEUE_MAX, PG_WAL_SIZE_TEST * 4);
         $self->configTestLoad(CFGCMD_ARCHIVE_PUSH);
 
         my $iWalTimeline = 1;
@@ -302,16 +307,24 @@ sub run
         my $iWalMinor = 1;
 
         #---------------------------------------------------------------------------------------------------------------------------
-        storageTest()->put("$self->{strWalStatusPath}/" . $self->walSegment($iWalTimeline, $iWalMajor, $iWalMinor++) . '.ready');
-        storageTest()->put("$self->{strWalStatusPath}/" . $self->walSegment($iWalTimeline, $iWalMajor, $iWalMinor++) . '.ready');
-        storageTest()->put("$self->{strWalStatusPath}/" . $self->walSegment($iWalTimeline, $iWalMajor, $iWalMinor++) . '.ready');
+        my $strSegment = $self->walSegment($iWalTimeline, $iWalMajor, $iWalMinor++);
+        storageTest()->put("$self->{strWalStatusPath}/${strSegment}.ready");
+        $self->walGenerate($self->{strWalPath}, PG_VERSION_94, 1, $strSegment);
+
+        $strSegment = $self->walSegment($iWalTimeline, $iWalMajor, $iWalMinor++);
+        storageTest()->put("$self->{strWalStatusPath}/${strSegment}.ready");
+        $self->walGenerate($self->{strWalPath}, PG_VERSION_94, 1, $strSegment);
+
+        $strSegment = $self->walSegment($iWalTimeline, $iWalMajor, $iWalMinor++);
+        storageTest()->put("$self->{strWalStatusPath}/${strSegment}.ready");
+        $self->walGenerate($self->{strWalPath}, PG_VERSION_94, 1, $strSegment);
 
         $self->testResult(
             sub {$oPushAsync->dropList($oPushAsync->readyList())}, '()',
             'WAL files not dropped');
 
         #---------------------------------------------------------------------------------------------------------------------------
-        $self->optionTestSet(CFGOPT_ARCHIVE_PUSH_QUEUE_MAX, PG_WAL_SIZE * 2);
+        $self->optionTestSet(CFGOPT_ARCHIVE_PUSH_QUEUE_MAX, PG_WAL_SIZE_TEST * 2);
         $self->configTestLoad(CFGCMD_ARCHIVE_PUSH);
 
         $self->testResult(
@@ -472,7 +485,7 @@ sub run
         $self->configTestLoad(CFGCMD_ARCHIVE_PUSH);
 
         #---------------------------------------------------------------------------------------------------------------------------
-        $self->optionTestSet(CFGOPT_ARCHIVE_PUSH_QUEUE_MAX, PG_WAL_SIZE * 2);
+        $self->optionTestSet(CFGOPT_ARCHIVE_PUSH_QUEUE_MAX, PG_WAL_SIZE_TEST * 2);
         $self->configTestLoad(CFGCMD_ARCHIVE_PUSH);
 
         # Generate WAL to test queue limits
@@ -489,7 +502,7 @@ sub run
         }
 
         # Process and check results
-        $self->testResult(sub {$oPushAsync->processQueue()}, '(3, 3, 1, 0)', "process and drop files");
+        $self->testResult(sub {$oPushAsync->processQueue()}, '(0, 3, 0, 0)', "process and drop files");
 
         $self->testResult(
             sub {storageSpool()->list($self->{strSpoolPath})}, '(' . join('.ok, ', @strySegment) . '.ok)',
@@ -499,21 +512,20 @@ sub run
         {
             $self->testResult(
                 sub {${storageSpool()->get("$self->{strSpoolPath}/${strSegment}.ok")}},
-                $strSegment eq $strySegment[0] ? undef :
-                    "0\ndropped WAL file ${strSegment} because archive queue exceeded " . cfgOption(CFGOPT_ARCHIVE_PUSH_QUEUE_MAX) .
-                        ' bytes',
+                "0\ndropped WAL file ${strSegment} because archive queue exceeded " . cfgOption(CFGOPT_ARCHIVE_PUSH_QUEUE_MAX) .
+                    ' bytes',
                 "verify ${strSegment} status");
 
             $self->walRemove($self->{strWalPath}, $strSegment);
         }
 
-        $self->optionTestClear(CFGOPT_ARCHIVE_PUSH_QUEUE_MAX);
-        $self->configTestLoad(CFGCMD_ARCHIVE_PUSH);
-
         #---------------------------------------------------------------------------------------------------------------------------
         $self->testResult(sub {$oPushAsync->processQueue()}, '(0, 0, 0, 0)', "final process to remove ok files");
 
         $self->testResult(sub {storageSpool()->list($self->{strSpoolPath})}, "[undef]", "ok files removed");
+
+        $self->optionTestClear(CFGOPT_ARCHIVE_PUSH_QUEUE_MAX);
+        $self->configTestLoad(CFGCMD_ARCHIVE_PUSH);
     }
 
     ################################################################################################################################
@@ -571,7 +583,7 @@ sub run
             "${strSegment} WAL in archive");
 
         # Set more realistic queue max and allow segment to push
-        $self->optionTestSet(CFGOPT_ARCHIVE_PUSH_QUEUE_MAX, PG_WAL_SIZE * 4);
+        $self->optionTestSet(CFGOPT_ARCHIVE_PUSH_QUEUE_MAX, PG_WAL_SIZE_TEST * 4);
         $self->configTestLoad(CFGCMD_ARCHIVE_PUSH);
 
         $self->testResult(sub {$oPush->process("$self->{strWalPath}/${strSegment}")}, undef, "${strSegment} WAL pushed");
