@@ -81,7 +81,7 @@ sub run
 
     foreach my $bS3 (false, true)
     {
-    foreach my $bRemote ($bS3 ? (true) : (false, true))
+    foreach my $bRemote ($bS3 ? (false) : (false, true))
     {
         my $bRepoEncrypt = !$bRemote && !$bS3 ? true : false;
 
@@ -152,16 +152,26 @@ sub run
         my $strArchiveFile = $self->walGenerate($strWalPath, PG_VERSION_94, 2, $strSourceFile);
 
         $oHostDbMaster->executeSimple(
-            $strCommandPush . ($bRemote ? ' --cmd-ssh=/usr/bin/ssh' : '') . " ${strLogDebug} ${strWalPath}/${strSourceFile}",
+            $strCommandPush . ($bRemote ? ' --cmd-ssh=/usr/bin/ssh' : '') . " --compress ${strLogDebug} ${strWalPath}/${strSourceFile}",
             {oLogTest => $self->expect()});
-        push(@stryExpectedWAL, "${strSourceFile}-${strArchiveChecksum}");
+        push(@stryExpectedWAL, "${strSourceFile}-${strArchiveChecksum}.gz");
 
         # Test that the WAL was pushed
-        $self->archiveCheck($strSourceFile, $strArchiveChecksum, false);
+        $self->archiveCheck($strSourceFile, $strArchiveChecksum, true);
+
+        # Remove from archive_status
+        storageTest()->remove("${strWalPath}/archive_status/${strSourceFile}.ready");
 
         # Remove WAL
         storageTest()->remove("${strWalPath}/${strSourceFile}", {bIgnoreMissing => false});
 
+        #---------------------------------------------------------------------------------------------------------------------------
+        &log(INFO, '    get missing WAL');
+
+        $oHostDbMaster->executeSimple(
+            $strCommandGet . " ${strLogDebug} 700000007000000070000000 ${strWalPath}/RECOVERYXLOG",
+            {iExpectedExitStatus => 1, oLogTest => $self->expect()});
+
         #---------------------------------------------------------------------------------------------------------------------------
         &log(INFO, '    get first WAL');
 
@@ -240,9 +250,29 @@ sub run
         # Test that the WAL was pushed
         $self->archiveCheck($strSourceFile, $strArchiveChecksum, true, $oHostDbMaster->spoolPath());
 
+        # Remove from archive_status
+        storageTest()->remove("${strWalPath}/archive_status/${strSourceFile}.ready");
+
         # Remove from spool
         storageTest()->remove($oHostDbMaster->spoolPath() . '/archive/' . $self->stanza() . "/out/${strSourceFile}.ok");
 
+        #---------------------------------------------------------------------------------------------------------------------------
+        &log(INFO, '    push history file');
+
+        storageTest()->put("${strWalPath}/00000002.history", 'HISTORYDATA');
+        storageTest()->put("${strWalPath}/archive_status/00000002.history.ready", undef);
+
+        $oHostDbMaster->executeSimple(
+            "${strCommandPush} --archive-async ${strWalPath}/00000002.history",
+            {oLogTest => $self->expect()});
+
+        if (!storageRepo()->exists(STORAGE_REPO_ARCHIVE . qw{/} . PG_VERSION_94 . '-1/00000002.history'))
+        {
+            confess 'unable to find history file in archive';
+        }
+
+        storageTest()->remove("${strWalPath}/archive_status/00000002.history.ready");
+
         #---------------------------------------------------------------------------------------------------------------------------
         &log(INFO, '    db version mismatch in db section only - archive-push errors but archive-get succeeds');
 
@@ -286,7 +316,7 @@ sub run
 
         $oHostDbMaster->executeSimple(
             $strCommandGet . " ${strSourceFile1} ${strWalPath}/RECOVERYXLOG",
-            {iExpectedExitStatus => ERROR_UNKNOWN, oLogTest => $self->expect()});
+            {iExpectedExitStatus => ERROR_ARCHIVE_MISMATCH, oLogTest => $self->expect()});
 
         # Restore the file to its original condition
         $oHostBackup->infoRestore(storageRepo()->pathGet(STORAGE_REPO_ARCHIVE . qw{/} . ARCHIVE_INFO_FILE));
@@ -305,7 +335,7 @@ sub run
 
         $oHostDbMaster->executeSimple(
             $strCommandGet . " ${strSourceFile1} ${strWalPath}/RECOVERYXLOG",
-            {iExpectedExitStatus => ERROR_UNKNOWN, oLogTest => $self->expect()});
+            {iExpectedExitStatus => ERROR_ARCHIVE_MISMATCH, oLogTest => $self->expect()});
 
         # Restore the file to its original condition
         $oHostBackup->infoRestore(storageRepo()->pathGet(STORAGE_REPO_ARCHIVE . qw{/} . ARCHIVE_INFO_FILE));
@@ -348,8 +378,8 @@ sub run
         &log(INFO, "    get second WAL (${strSourceFile})");
 
         $oHostDbMaster->executeSimple(
-            $strCommandGet . ($bRemote ? ' --cmd-ssh=/usr/bin/ssh' : '') .
-                " --archive-async --archive-timeout=5 ${strSourceFile} ${strWalPath}/RECOVERYXLOG",
+            $strCommandGet . ($bRemote ? ' --cmd-ssh=/usr/bin/ssh' : '') . " --archive-async" . (!$bS3 ? " --repo-type=cifs" : '') .
+                " --archive-timeout=5 ${strSourceFile} ${strWalPath}/RECOVERYXLOG",
             {oLogTest => $self->expect()});
 
         # Check that the destination file exists
@@ -367,6 +397,22 @@ sub run
             confess "archive file '${strWalPath}/RECOVERYXLOG' is not in destination";
         }
 
+        #---------------------------------------------------------------------------------------------------------------------------
+        &log(INFO, "    get history file");
+
+        $oHostDbMaster->executeSimple(
+            $strCommandGet . " --archive-async 00000001.history ${strWalPath}/00000001.history",
+            {iExpectedExitStatus => 1, oLogTest => $self->expect()});
+
+        $oHostDbMaster->executeSimple(
+            $strCommandGet . " --archive-async 00000002.history ${strWalPath}/00000002.history",
+            {oLogTest => $self->expect()});
+
+        if (${storageDb()->get("${strWalPath}/00000002.history")} ne 'HISTORYDATA')
+        {
+            confess 'history contents do not match original';
+        }
+
         #---------------------------------------------------------------------------------------------------------------------------
         &log(INFO, '    .partial WAL');
 
