@@ -119,6 +119,7 @@ sub run
 
         # Create a manifest with the pg version to get version-specific paths
         my $oManifest = new pgBackRest::Manifest(BOGUS, {bLoad => false, strDbVersion => $self->pgVersion(),
+            iDbCatalogVersion => $self->dbCatalogVersion($self->pgVersion()),
             strCipherPass => $strCipherPass, strCipherPassSub => $bRepoEncrypt ? ENCRYPTION_KEY_BACKUPSET : undef});
 
         # Static backup parameters
@@ -618,10 +619,12 @@ sub run
             $oHostDbMaster->sqlSelectOne("select pg_start_backup('test backup that will be restarted', true)");
         }
 
+        # Exercise --delta checksum option
         $oExecuteBackup = $oHostBackup->backupBegin(
             CFGOPTVAL_BACKUP_TYPE_INCR, 'update during backup',
             {strTest => TEST_MANIFEST_BUILD, fTestDelay => $fTestDelay,
-                strOptionalParam => '--' . cfgOptionName(CFGOPT_STOP_AUTO) . ' --' . cfgOptionName(CFGOPT_BUFFER_SIZE) . '=32768'});
+                strOptionalParam => '--' . cfgOptionName(CFGOPT_STOP_AUTO) . ' --' . cfgOptionName(CFGOPT_BUFFER_SIZE) . '=32768' .
+                ' --delta'});
 
         # Drop a table
         $oHostDbMaster->sqlExecute('drop table test_remove');
@@ -631,9 +634,9 @@ sub run
         # Check that application name is set
         if ($oHostDbMaster->pgVersion() >= PG_VERSION_APPLICATION_NAME)
         {
-            my $strApplicationNameExpected = BACKREST_NAME . ' [' . cfgCommandName(CFGCMD_BACKUP) . ']';
+            my $strApplicationNameExpected = PROJECT_NAME . ' [' . cfgCommandName(CFGCMD_BACKUP) . ']';
             my $strApplicationName = $oHostDbMaster->sqlSelectOne(
-                "select application_name from pg_stat_activity where application_name like '" . BACKREST_NAME . "%'");
+                "select application_name from pg_stat_activity where application_name like '" . PROJECT_NAME . "%'");
 
             if (!defined($strApplicationName) || $strApplicationName ne $strApplicationNameExpected)
             {
