@@ -107,15 +107,11 @@ sub run
     ################################################################################################################################
     if ($self->begin("Stanza::process()"))
     {
-        #---------------------------------------------------------------------------------------------------------------------------
-        $self->configTestLoad(CFGCMD_CHECK);
+        $self->optionTestSetBool(CFGOPT_ONLINE, false);
+        $self->configTestLoad(CFGCMD_STANZA_CREATE);
+
         my $oStanza = new pgBackRest::Stanza();
 
-        $self->testException(sub {$oStanza->process()}, ERROR_ASSERT,
-            "stanza->process() called with invalid command: " . cfgCommandName(CFGCMD_CHECK));
-
-        #---------------------------------------------------------------------------------------------------------------------------
-        $self->configTestLoad(CFGCMD_STANZA_CREATE);
         rmdir($self->{strArchivePath});
         rmdir($self->{strBackupPath});
         $self->testResult(sub {$oStanza->process()}, 0, 'parent paths recreated successfully');
@@ -272,7 +268,8 @@ sub run
         my $strBackupPath = storageRepo->pathGet(STORAGE_REPO_BACKUP . "/${strBackupLabel}");
 
         my $strBackupManifestFile = "$strBackupPath/" . FILE_MANIFEST;
-        my $oBackupManifest = new pgBackRest::Manifest($strBackupManifestFile, {bLoad => false, strDbVersion => PG_VERSION_94});
+        my $oBackupManifest = new pgBackRest::Manifest($strBackupManifestFile, {bLoad => false, strDbVersion => PG_VERSION_94,
+            iDbCatalogVersion => $self->dbCatalogVersion(PG_VERSION_94)});
         storageRepo()->pathCreate($strBackupPath);
         $oBackupManifest->save();
 
@@ -338,12 +335,13 @@ sub run
         #---------------------------------------------------------------------------------------------------------------------------
         # Try to create a manifest without a passphrase in an encrypted storage
         $self->testException(sub {new pgBackRest::Manifest($strBackupManifestFile,
-            {bLoad => false, strDbVersion => PG_VERSION_94})}, ERROR_CIPHER,
-            'passphrase is required when storage is encrypted');
+            {bLoad => false, strDbVersion => PG_VERSION_94, iDbCatalogVersion => $self->dbCatalogVersion(PG_VERSION_94)})},
+            ERROR_CRYPTO, 'passphrase is required when storage is encrypted');
 
         # Get the encryption passphrase and create the new manifest
         my $oBackupInfo = new pgBackRest::Backup::Info($self->{strBackupPath});
         $oBackupManifest = new pgBackRest::Manifest($strBackupManifestFile, {bLoad => false, strDbVersion => PG_VERSION_94,
+            iDbCatalogVersion => $self->dbCatalogVersion(PG_VERSION_94),
             strCipherPass => $oBackupInfo->cipherPassSub(), strCipherPassSub => cipherPassGen()});
 
         $oBackupManifest->set(MANIFEST_SECTION_BACKUP, MANIFEST_KEY_LABEL, undef, $strBackupLabel);
@@ -527,7 +525,7 @@ sub run
         $self->optionTestSet(CFGOPT_REPO_CIPHER_PASS, 'x');
         $self->configTestLoad(CFGCMD_STANZA_UPGRADE);
 
-        $self->testException(sub {$oStanza->stanzaUpgrade()}, ERROR_CIPHER,
+        $self->testException(sub {$oStanza->stanzaUpgrade()}, ERROR_CRYPTO,
             "unable to parse '" . $self->{strArchivePath} . "/archive.info'" .
             "\nHINT: Is or was the repo encrypted?");
 
@@ -550,7 +548,7 @@ sub run
         $self->optionTestSet(CFGOPT_REPO_CIPHER_PASS, 'y');
         $self->configTestLoad(CFGCMD_STANZA_UPGRADE);
 
-        $self->testException(sub {$oStanza->stanzaUpgrade()}, ERROR_CIPHER,
+        $self->testException(sub {$oStanza->stanzaUpgrade()}, ERROR_CRYPTO,
             "unable to parse '" . $self->{strArchivePath} . "/archive.info'" .
             "\nHINT: Is or was the repo encrypted?");
 
@@ -797,6 +795,7 @@ sub run
         my $oBackupInfo = new pgBackRest::Backup::Info($self->{strBackupPath});
 
         $self->testResult(sub {(new pgBackRest::Manifest($strBackupManifestFile, {bLoad => false, strDbVersion => PG_VERSION_94,
+            iDbCatalogVersion => $self->dbCatalogVersion(PG_VERSION_94),
             strCipherPass => $oBackupInfo->cipherPassSub(), strCipherPassSub => 'x'}))->save()},
             "[undef]", '    manifest saved');
 
