@@ -6,29 +6,33 @@ C Test Harness
 
 #include <inttypes.h>
 
+#include "common/debug.h"
 #include "common/error.h"
 
-// Bogus values
+/***********************************************************************************************************************************
+Constants
+***********************************************************************************************************************************/
 #define BOGUS_STR                                                   "BOGUS"
 
-// Functions
+/***********************************************************************************************************************************
+Functions
+***********************************************************************************************************************************/
 void testAdd(int run, bool selected);
 bool testBegin(const char *name);
-void testComplete();
+void testComplete(void);
 
-const char *testExe();
+uint64_t testTimeMSec(void);
+uint64_t testTimeMSecBegin(void);
+
+const char *testExe(void);
 void testExeSet(const char *testExe);
 
-const char *testPath();
+const char *testPath(void);
 void testPathSet(const char *testPath);
-
-/***********************************************************************************************************************************
-Convert a macro to a string -- handy for testing debug macros
-***********************************************************************************************************************************/
-#define MACRO_TO_STR_INNER(macro)                                                                                                  \
-    #macro
-#define MACRO_TO_STR(macro)                                                                                                        \
-    MACRO_TO_STR_INNER(macro)
+const char *testExpectPath(void);
+void testExpectPathSet(const char *testExpectPath);
+const char *testRepoPath(void);
+void testRepoPathSet(const char *testRepoPath);
 
 /***********************************************************************************************************************************
 Maximum size of a formatted result in the TEST_RESULT macro.  Strings don't count as they are output directly, so this only applies
@@ -43,7 +47,10 @@ Test that an expected error is actually thrown and error when it isn't
 {                                                                                                                                  \
     bool TEST_ERROR_catch = false;                                                                                                 \
                                                                                                                                    \
-    printf("    l%04d - expect %s: %s\n", __LINE__, errorTypeName(&errorTypeExpected), errorMessageExpected);                      \
+    printf(                                                                                                                        \
+        "    %03u.%03us l%04d - expect %s: %s\n", (unsigned int)((testTimeMSec() - testTimeMSecBegin()) / 1000),                   \
+        (unsigned int)((testTimeMSec() - testTimeMSecBegin()) % 1000), __LINE__, errorTypeName(&errorTypeExpected),                \
+        errorMessageExpected);                                                                                                     \
     fflush(stdout);                                                                                                                \
                                                                                                                                    \
     TRY_BEGIN()                                                                                                                    \
@@ -56,7 +63,7 @@ Test that an expected error is actually thrown and error when it isn't
                                                                                                                                    \
         if (strcmp(errorMessage(), errorMessageExpected) != 0 || errorType() != &errorTypeExpected)                                \
             THROW_FMT(                                                                                                             \
-                AssertError, "EXECTED %s: %s\n\nBUT GOT %s: %s\n\nTHROWN AT:\n%s", errorTypeName(&errorTypeExpected),              \
+                AssertError, "EXPECTED %s: %s\n\n BUT GOT %s: %s\n\nTHROWN AT:\n%s", errorTypeName(&errorTypeExpected),            \
                 errorMessageExpected, errorName(), errorMessage(), errorStackTrace());                                             \
     }                                                                                                                              \
     TRY_END();                                                                                                                     \
@@ -124,7 +131,9 @@ Compare types
 Output information about the test
 ***********************************************************************************************************************************/
 #define TEST_RESULT_INFO(...)                                                                                                      \
-    printf("    l%04d - ", __LINE__);                                                                                              \
+    printf(                                                                                                                        \
+        "    %03u.%03us l%04d - ", (unsigned int)((testTimeMSec() - testTimeMSecBegin()) / 1000),                                  \
+        (unsigned int)((testTimeMSec() - testTimeMSecBegin()) % 1000), __LINE__);                                                  \
     printf(__VA_ARGS__);                                                                                                           \
     printf("\n");                                                                                                                  \
     fflush(stdout);
@@ -194,7 +203,9 @@ Test that a void statement returns and does not throw an error
     CATCH_ANY()                                                                                                                    \
     {                                                                                                                              \
         /* No errors were expected so error */                                                                                     \
-        THROW_FMT(AssertError, "statement '%s' threw error %s, '%s' but void expected", #statement, errorName(), errorMessage());  \
+        THROW_FMT(                                                                                                                 \
+            AssertError, "EXPECTED VOID RESULT FROM STATEMENT: %s\n\nBUT GOT %s: %s\n\nTHROWN AT:\n%s", #statement, errorName(),   \
+            errorMessage(), errorStackTrace());                                                                                    \
     }                                                                                                                              \
     TRY_END();                                                                                                                     \
 }
@@ -215,7 +226,9 @@ Test that a statement does not error and assign it to the specified variable if
     CATCH_ANY()                                                                                                                    \
     {                                                                                                                              \
         /* No errors were expected so error */                                                                                     \
-        THROW_FMT(AssertError, "statement '%s' threw error %s, '%s' but result expected", #statement, errorName(), errorMessage());\
+        THROW_FMT(                                                                                                                 \
+            AssertError, "EXPECTED ASSIGNMENT FROM STATEMENT: %s\n\nBUT GOT %s: %s\n\nTHROWN AT:\n%s", #statement, errorName(),    \
+            errorMessage(), errorStackTrace());                                                                                    \
     }                                                                                                                              \
     TRY_END();                                                                                                                     \
 }
@@ -254,6 +267,13 @@ Macros to ease the use of common data types
 #define TEST_RESULT_PTR_NE(statement, resultExpected, ...)                                                                         \
     TEST_RESULT_PTR_PARAM(statement, resultExpected, !=, __VA_ARGS__);
 
+#define TEST_RESULT_SIZE_PARAM(statement, resultExpected, typeOp, ...)                                                             \
+    TEST_RESULT(statement, resultExpected, size_t, "%zu", TEST_TYPE_FORMAT, typeOp, TEST_TYPE_COMPARE, __VA_ARGS__);
+#define TEST_RESULT_SIZE(statement, resultExpected, ...)                                                                           \
+    TEST_RESULT_SIZE_PARAM(statement, resultExpected, ==, __VA_ARGS__);
+#define TEST_RESULT_SIZE_NE(statement, resultExpected, ...)                                                                        \
+    TEST_RESULT_SIZE_PARAM(statement, resultExpected, !=, __VA_ARGS__);
+
 #define TEST_RESULT_STR_PARAM(statement, resultExpected, typeOp, ...)                                                              \
     TEST_RESULT(statement, resultExpected, char *, "%s", TEST_TYPE_FORMAT_PTR, typeOp, TEST_TYPE_COMPARE_STR, __VA_ARGS__);
 #define TEST_RESULT_STR(statement, resultExpected, ...)                                                                            \
@@ -264,4 +284,32 @@ Macros to ease the use of common data types
 #define TEST_RESULT_U16_HEX(statement, resultExpected, ...)                                                                        \
     TEST_RESULT(statement, resultExpected, uint16_t, "%04X", TEST_TYPE_FORMAT, ==, TEST_TYPE_COMPARE, __VA_ARGS__);
 
+#define TEST_RESULT_UINT_PARAM(statement, resultExpected, typeOp, ...)                                                             \
+    TEST_RESULT(statement, resultExpected, uint64_t, "%" PRIu64, TEST_TYPE_FORMAT, typeOp, TEST_TYPE_COMPARE, __VA_ARGS__);
+#define TEST_RESULT_UINT(statement, resultExpected, ...)                                                                           \
+    TEST_RESULT_UINT_PARAM(statement, resultExpected, ==, __VA_ARGS__);
+#define TEST_RESULT_UINT_NE(statement, resultExpected, ...)                                                                        \
+    TEST_RESULT_UINT_PARAM(statement, resultExpected, !=, __VA_ARGS__);
+
+/***********************************************************************************************************************************
+Logging macros
+***********************************************************************************************************************************/
+#define TEST_LOG(message)                                                                                                          \
+    do                                                                                                                             \
+    {                                                                                                                              \
+        printf(                                                                                                                    \
+            "    %03u.%03us       %s\n", (unsigned int)((testTimeMSec() - testTimeMSecBegin()) / 1000),                            \
+            (unsigned int)((testTimeMSec() - testTimeMSecBegin()) % 1000), message);                                               \
+        fflush(stdout);                                                                                                            \
+    } while(0)
+
+#define TEST_LOG_FMT(format, ...)                                                                                                  \
+    do                                                                                                                             \
+    {                                                                                                                              \
+        printf(                                                                                                                    \
+            "    %03u.%03us       " format "\n", (unsigned int)((testTimeMSec() - testTimeMSecBegin()) / 1000),                    \
+            (unsigned int)((testTimeMSec() - testTimeMSecBegin()) % 1000), __VA_ARGS__);                                           \
+        fflush(stdout);                                                                                                            \
+    } while(0)
+
 #endif
