@@ -1,18 +1,21 @@
 /***********************************************************************************************************************************
 Test Archive Push Command
 ***********************************************************************************************************************************/
+#include "storage/driver/posix/storage.h"
+
 #include "common/harnessConfig.h"
 
 /***********************************************************************************************************************************
 Test Run
 ***********************************************************************************************************************************/
 void
-testRun()
+testRun(void)
 {
     FUNCTION_HARNESS_VOID();
 
     // Create default storage object for testing
-    Storage *storageTest = storageNewP(strNew(testPath()), .write = true);
+    Storage *storageTest = storageDriverPosixInterface(
+        storageDriverPosixNew(strNew(testPath()), STORAGE_MODE_FILE_DEFAULT, STORAGE_MODE_PATH_DEFAULT, true, NULL));
 
     // *****************************************************************************************************************************
     if (testBegin("cmdArchivePush()"))
@@ -22,13 +25,13 @@ testRun()
         strLstAddZ(argList, "--archive-timeout=1");
         strLstAddZ(argList, "--stanza=db");
         strLstAddZ(argList, "archive-push");
-        cfgLoad(strLstSize(argList), strLstPtr(argList));
+        harnessCfgLoad(strLstSize(argList), strLstPtr(argList));
 
         TEST_ERROR(cmdArchivePush(), ParamRequiredError, "WAL segment to push required");
 
         // -------------------------------------------------------------------------------------------------------------------------
         strLstAddZ(argList, "000000010000000100000001");
-        cfgLoad(strLstSize(argList), strLstPtr(argList));
+        harnessCfgLoad(strLstSize(argList), strLstPtr(argList));
 
         TEST_ERROR(cmdArchivePush(), AssertError, "archive-push in C does not support synchronous mode");
 
@@ -48,7 +51,7 @@ testRun()
             "unable to push WAL segment '000000010000000100000001' asynchronously after 1 second(s)");
 
         // Wait for the lock to release
-        lockAcquire(cfgOptionStr(cfgOptLockPath), cfgOptionStr(cfgOptStanza), cfgLockType(), 30, true);
+        lockAcquire(cfgOptionStr(cfgOptLockPath), cfgOptionStr(cfgOptStanza), cfgLockType(), 30000, true);
         lockRelease(true);
 
         // Write out a bogus .error file to make sure it is ignored on the first loop
@@ -57,7 +60,7 @@ testRun()
         storagePathRemoveNP(storageTest, strNewFmt("%s/db/archive_status", testPath()));
 
         String *errorFile = storagePathNP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_OUT "/000000010000000100000001.error"));
-        storagePutNP(storageNewWriteNP(storageSpool(), errorFile), bufNewStr(strNew("25\n" BOGUS_STR)));
+        storagePutNP(storageNewWriteNP(storageSpoolWrite(), errorFile), bufNewZ("25\n" BOGUS_STR));
 
         TEST_ERROR(cmdArchivePush(), AssertError, BOGUS_STR);
 
@@ -66,19 +69,19 @@ testRun()
         // Write out a valid ok file and test for success
         // -------------------------------------------------------------------------------------------------------------------------
         storagePutNP(
-            storageNewWriteNP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_OUT "/000000010000000100000001.ok")),
-            bufNewStr(strNew("")));
+            storageNewWriteNP(storageSpoolWrite(), strNew(STORAGE_SPOOL_ARCHIVE_OUT "/000000010000000100000001.ok")), bufNew(0));
 
         TEST_RESULT_VOID(cmdArchivePush(), "successful push");
-        testLogResult("P00   INFO: pushed WAL segment 000000010000000100000001 asynchronously");
+        harnessLogResult("P00   INFO: pushed WAL segment 000000010000000100000001 asynchronously");
 
-        storageRemoveP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_OUT "/000000010000000100000001.ok"), .errorOnMissing = true);
+        storageRemoveP(
+            storageSpoolWrite(), strNew(STORAGE_SPOOL_ARCHIVE_OUT "/000000010000000100000001.ok"), .errorOnMissing = true);
 
         // Make sure the process times out when there is nothing to archive and it can't get a lock.  This test MUST go last since
         // the lock is lost and cannot be closed by the main process.
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_RESULT_VOID(
-            lockAcquire(cfgOptionStr(cfgOptLockPath), cfgOptionStr(cfgOptStanza), cfgLockType(), 30, true), "acquire lock");
+            lockAcquire(cfgOptionStr(cfgOptLockPath), cfgOptionStr(cfgOptStanza), cfgLockType(), 30000, true), "acquire lock");
         TEST_RESULT_VOID(lockClear(true), "clear lock");
 
         TEST_ERROR(
