@@ -11,7 +11,7 @@ Test Common Command Routines
 Test Run
 ***********************************************************************************************************************************/
 void
-testRun()
+testRun(void)
 {
     FUNCTION_HARNESS_VOID();
 
@@ -32,15 +32,15 @@ testRun()
         cfgCommandParamSet(commandParamList);
 
         TEST_RESULT_VOID(cmdBegin(true), "command begin with command parameter");
-        testLogResult(
-            "P00   INFO: archive-get command begin " PGBACKREST_VERSION ": [param1] --compress");
+        harnessLogResult(
+            "P00   INFO: archive-get command begin " PROJECT_VERSION ": [param1] --compress");
 
         strLstAddZ(commandParamList, "param 2");
         cfgCommandParamSet(commandParamList);
 
         TEST_RESULT_VOID(cmdBegin(true), "command begin with command parameters");
-        testLogResult(
-            "P00   INFO: archive-get command begin " PGBACKREST_VERSION ": [param1, \"param 2\"] --compress");
+        harnessLogResult(
+            "P00   INFO: archive-get command begin " PROJECT_VERSION ": [param1, \"param 2\"] --compress");
 
         cfgInit();
         cfgCommandSet(cfgCmdArchiveGet);
@@ -69,7 +69,6 @@ testRun()
         strLstAddZ(list, "db2");
         cfgOptionSet(cfgOptDbInclude, cfgSourceParam, varNewVarLst(varLstNewStrLst(list)));
 
-        // !!! WHY DO WE STILL NEED TO CREATE THE VAR KV EMPTY?
         cfgOptionValidSet(cfgOptRecoveryOption, true);
         Variant *recoveryVar = varNewKv();
         KeyValue *recoveryKv = varKv(recoveryVar);
@@ -78,32 +77,32 @@ testRun()
         cfgOptionSet(cfgOptRecoveryOption, cfgSourceParam, recoveryVar);
 
         TEST_RESULT_VOID(cmdBegin(true), "command begin with option logging");
-        testLogResult(
-            "P00   INFO: archive-get command begin " PGBACKREST_VERSION ": --no-config --db-include=db1 --db-include=db2"
+        harnessLogResult(
+            "P00   INFO: archive-get command begin " PROJECT_VERSION ": --no-config --db-include=db1 --db-include=db2"
                 " --recovery-option=standby_mode=on --recovery-option=primary_conn_info=blah --reset-repo1-host"
                 " --repo1-path=\"/path/to the/repo\" --repo1-s3-key=<redacted>");
 
         TEST_RESULT_VOID(cmdBegin(false), "command begin no option logging");
-        testLogResult(
+        harnessLogResult(
             "P00   INFO: archive-get command begin");
 
         // Nothing should be logged for command begin when the log level is too low
         // -------------------------------------------------------------------------------------------------------------------------
-        logInit(logLevelWarn, logLevelOff, logLevelOff, false);
+        harnessLogLevelSet(logLevelWarn);
         TEST_RESULT_VOID(cmdBegin(true), "command begin no logging");
 
         // Nothing should be logged for command end when the log level is too low
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_RESULT_VOID(cmdEnd(0, NULL), "command end no logging");
-        logInit(logLevelInfo, logLevelOff, logLevelOff, false);
+        harnessLogLevelReset();
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_RESULT_VOID(cmdEnd(25, strNew("aborted with exception [025]")), "command end with error");
-        testLogResult("P00   INFO: archive-get command end: aborted with exception [025]");
+        harnessLogResult("P00   INFO: archive-get command end: aborted with exception [025]");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_RESULT_VOID(cmdEnd(0, NULL), "command end with success");
-        testLogResult("P00   INFO: archive-get command end: completed successfully");
+        harnessLogResult("P00   INFO: archive-get command end: completed successfully");
 
         // Make sure time output is covered but don't do expect testing since the output is variable
         // -------------------------------------------------------------------------------------------------------------------------
@@ -111,12 +110,12 @@ testRun()
         cfgOptionSet(cfgOptLogTimestamp, cfgSourceParam, varNewBool(false));
 
         TEST_RESULT_VOID(cmdEnd(0, NULL), "command end with success");
-        testLogResult("P00   INFO: archive-get command end: completed successfully");
+        harnessLogResult("P00   INFO: archive-get command end: completed successfully");
 
         cfgOptionSet(cfgOptLogTimestamp, cfgSourceParam, varNewBool(true));
 
         TEST_RESULT_VOID(cmdEnd(0, NULL), "command end with success");
-        testLogResultRegExp("P00   INFO\\: archive-get command end: completed successfully \\([0-9]+ms\\)");
+        harnessLogResultRegExp("P00   INFO\\: archive-get command end: completed successfully \\([0-9]+ms\\)");
     }
 
     FUNCTION_HARNESS_RESULT_VOID();
