@@ -3,45 +3,49 @@ Test Debug Macros and Routines
 ***********************************************************************************************************************************/
 #include "common/log.h"
 
-#include "common/logTest.h"
+#include "common/harnessLog.h"
 
 static void
-testFunction3()
+testFunction3(void)
 {
     FUNCTION_TEST_VOID();
-    FUNCTION_TEST_RESULT_VOID();
+    FUNCTION_TEST_RETURN_VOID();
 }
 
 static void
-testFunction2()
+testFunction2(void)
 {
-    FUNCTION_DEBUG_VOID(logLevelTrace);
+    FUNCTION_LOG_VOID(logLevelTrace);
 
     testFunction3();
 
-    FUNCTION_DEBUG_RESULT_VOID();
+    FUNCTION_LOG_RETURN_VOID();
 }
 
 static int
-testFunction1(int paramInt, bool paramBool, double paramDouble, mode_t paramMode)
+testFunction1(
+    int paramInt, bool paramBool, bool *paramBoolP, bool **paramBoolPP, void *paramVoidP, double paramDouble, mode_t paramMode)
 {
-    FUNCTION_DEBUG_BEGIN(logLevelDebug);
-        FUNCTION_DEBUG_PARAM(INT, paramInt);
-        FUNCTION_DEBUG_PARAM(BOOL, paramBool);
-        FUNCTION_DEBUG_PARAM(DOUBLE, paramDouble);
-        FUNCTION_DEBUG_PARAM(MODE, paramMode);
-    FUNCTION_DEBUG_END();
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(INT, paramInt);
+        FUNCTION_LOG_PARAM(BOOL, paramBool);
+        FUNCTION_LOG_PARAM_P(BOOL, paramBoolP);
+        FUNCTION_LOG_PARAM_PP(BOOL, paramBoolPP);
+        FUNCTION_LOG_PARAM_P(VOID, paramVoidP);
+        FUNCTION_LOG_PARAM(DOUBLE, paramDouble);
+        FUNCTION_LOG_PARAM(MODE, paramMode);
+    FUNCTION_LOG_END();
 
     testFunction2();
 
-    FUNCTION_DEBUG_RESULT(INT, 1);
+    FUNCTION_LOG_RETURN(INT, 1);
 }
 
 /***********************************************************************************************************************************
 Test Run
 ***********************************************************************************************************************************/
 void
-testRun()
+testRun(void)
 {
     FUNCTION_HARNESS_VOID();
 
@@ -109,24 +113,50 @@ testRun()
     }
 
     // *****************************************************************************************************************************
-    if (testBegin("FUNCTION_DEBUG() and FUNCTION_DEBUG_RESULT()"))
+    if (testBegin("FUNCTION_DEBUG() and FUNCTION_LOG_RETURN()"))
     {
-        logInit(logLevelTrace, logLevelOff, logLevelOff, false);
-        testFunction1(99, false, 1.17, 0755);
+        harnessLogLevelSet(logLevelTrace);
+        testFunction1(99, false, NULL, NULL, NULL, 1.17, 0755);
 
-        testLogResult(
-            "P00  DEBUG:     module/common/debugOnTest::testFunction1: (paramInt: 99, paramBool: false, paramDouble: 1.17"
-                ", paramMode: 0755)\n"
-            "P00  TRACE:         module/common/debugOnTest::testFunction2: (void)\n"
-            "P00  TRACE:         module/common/debugOnTest::testFunction2: => void\n"
-            "P00  DEBUG:     module/common/debugOnTest::testFunction1: => 1");
-        logInit(logLevelTrace, logLevelOff, logLevelOff, false);
+        harnessLogResult(
+            "P00  DEBUG:     test/module/common/debugOnTest::testFunction1: (paramInt: 99, paramBool: false, paramBoolP: null"
+                ", paramBoolPP: null, paramVoidP: null, paramDouble: 1.17, paramMode: 0755)\n"
+            "P00  TRACE:         test/module/common/debugOnTest::testFunction2: (void)\n"
+            "P00  TRACE:         test/module/common/debugOnTest::testFunction2: => void\n"
+            "P00  DEBUG:     test/module/common/debugOnTest::testFunction1: => 1");
 
         // -------------------------------------------------------------------------------------------------------------------------
-        logInit(logLevelInfo, logLevelOff, logLevelOff, false);
-        testFunction1(55, true, 0.99, 0755);
+        bool testBool = true;
+        bool *testBoolP = &testBool;
+        bool **testBoolPP = &testBoolP;
+        void *testVoidP = NULL;
 
-        testLogResult("");
+        testFunction1(99, false, testBoolP, testBoolPP, testVoidP, 1.17, 0755);
+
+        harnessLogResult(
+            "P00  DEBUG:     test/module/common/debugOnTest::testFunction1: (paramInt: 99, paramBool: false, paramBoolP: *true"
+                ", paramBoolPP: **true, paramVoidP: null, paramDouble: 1.17, paramMode: 0755)\n"
+            "P00  TRACE:         test/module/common/debugOnTest::testFunction2: (void)\n"
+            "P00  TRACE:         test/module/common/debugOnTest::testFunction2: => void\n"
+            "P00  DEBUG:     test/module/common/debugOnTest::testFunction1: => 1");
+
+        testBoolP = NULL;
+        testVoidP = (void *)1;
+
+        testFunction1(99, false, testBoolP, testBoolPP, testVoidP, 1.17, 0755);
+
+        harnessLogResult(
+            "P00  DEBUG:     test/module/common/debugOnTest::testFunction1: (paramInt: 99, paramBool: false, paramBoolP: null"
+                ", paramBoolPP: *null, paramVoidP: *void, paramDouble: 1.17, paramMode: 0755)\n"
+            "P00  TRACE:         test/module/common/debugOnTest::testFunction2: (void)\n"
+            "P00  TRACE:         test/module/common/debugOnTest::testFunction2: => void\n"
+            "P00  DEBUG:     test/module/common/debugOnTest::testFunction1: => 1");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        harnessLogLevelReset();
+        testFunction1(55, true, NULL, NULL, NULL, 0.99, 0755);
+
+        harnessLogResult("");
     }
 
     FUNCTION_HARNESS_RESULT_VOID();
