@@ -6,11 +6,11 @@ Test Binary to String Encode/Decode
 Test Run
 ***********************************************************************************************************************************/
 void
-testRun()
+testRun(void)
 {
     FUNCTION_HARNESS_VOID();
 
-    // -----------------------------------------------------------------------------------------------------------------------------
+    // *****************************************************************************************************************************
     if (testBegin("base64"))
     {
         unsigned char *encode = (unsigned char *)"string_to_encode\r\n";
