@@ -2,6 +2,7 @@
 Test Lock Handler
 ***********************************************************************************************************************************/
 #include "common/time.h"
+#include "storage/driver/posix/storage.h"
 
 #include "common/harnessFork.h"
 
@@ -9,12 +10,13 @@ Test Lock Handler
 Test Run
 ***********************************************************************************************************************************/
 void
-testRun()
+testRun(void)
 {
     FUNCTION_HARNESS_VOID();
 
     // Create default storage object for testing
-    Storage *storageTest = storageNewP(strNew(testPath()), .write = true);
+    Storage *storageTest = storageDriverPosixInterface(
+        storageDriverPosixNew(strNew(testPath()), STORAGE_MODE_FILE_DEFAULT, STORAGE_MODE_PATH_DEFAULT, true, NULL));
 
     // *****************************************************************************************************************************
     if (testBegin("lockAcquireFile() and lockReleaseFile()"))
@@ -68,7 +70,7 @@ testRun()
         TEST_RESULT_INT(system(strPtr(strNewFmt("sudo mkdir -p 700 %s", strPtr(strPath(noPermLock))))), 0, "create noperm dir");
 
         TEST_ERROR(
-            lockAcquireFile(noPermLock, .1, true), LockAcquireError,
+            lockAcquireFile(noPermLock, 100, true), LockAcquireError,
             strPtr(
                 strNewFmt(
                     "unable to acquire lock on file '%s': Permission denied\n"
@@ -159,7 +161,7 @@ testRun()
         TEST_RESULT_BOOL(storageExistsNP(storageTest, backupLockFile), true, "backup lock file was created");
         TEST_ERROR(
             lockAcquire(lockPath, stanza, lockTypeAll, 0, false), AssertError,
-            "debug assertion 'failOnNoLock || lockType != lockTypeAll' failed");
+            "assertion 'failOnNoLock || lockType != lockTypeAll' failed");
         TEST_RESULT_VOID(lockRelease(true), "release all lock");
 
         // -------------------------------------------------------------------------------------------------------------------------
