@@ -28,11 +28,11 @@ testFree(MemContext *this)
 Test Run
 ***********************************************************************************************************************************/
 void
-testRun()
+testRun(void)
 {
     FUNCTION_HARNESS_VOID();
 
-    // -----------------------------------------------------------------------------------------------------------------------------
+    // *****************************************************************************************************************************
     if (testBegin("memAllocInternal(), memReAllocInternal(), and memFreeInternal()"))
     {
         // Test too large allocation -- only test this on 64-bit systems since 32-bit systems tend to work with any value that
@@ -40,7 +40,7 @@ testRun()
         if (sizeof(size_t) == 8)
         {
             TEST_ERROR(memAllocInternal((size_t)5629499534213120, false), MemoryError, "unable to allocate 5629499534213120 bytes");
-            TEST_ERROR(memFreeInternal(NULL), AssertError, "function test assertion 'buffer != NULL' failed");
+            TEST_ERROR(memFreeInternal(NULL), AssertError, "assertion 'buffer != NULL' failed");
 
             // Check that bad realloc is caught
             void *buffer = memAllocInternal(sizeof(size_t), false);
@@ -85,7 +85,7 @@ testRun()
         memFreeInternal(buffer2);
     }
 
-    // -----------------------------------------------------------------------------------------------------------------------------
+    // *****************************************************************************************************************************
     if (testBegin("memContextNew() and memContextFree()"))
     {
         // Make sure top context was created
@@ -163,7 +163,7 @@ testRun()
         TEST_RESULT_VOID(memContextFree(noAllocation), "free context with no allocations");
     }
 
-    // -----------------------------------------------------------------------------------------------------------------------------
+    // *****************************************************************************************************************************
     if (testBegin("memContextAlloc(), memNew*(), memGrow(), and memFree()"))
     {
         memContextSwitch(memContextTop());
@@ -211,7 +211,7 @@ testRun()
             memFree(memContextCurrent()->allocList[MEM_CONTEXT_ALLOC_INITIAL_SIZE].buffer), AssertError,
             "unable to find allocation");
 
-        TEST_ERROR(memFree(NULL), AssertError, "function test assertion 'buffer != NULL' failed");
+        TEST_ERROR(memFree(NULL), AssertError, "assertion 'buffer != NULL' failed");
         TEST_ERROR(memFree((void *)0x01), AssertError, "unable to find allocation");
         memFree(buffer);
 
@@ -219,7 +219,7 @@ testRun()
         memContextFree(memContext);
     }
 
-    // -----------------------------------------------------------------------------------------------------------------------------
+    // *****************************************************************************************************************************
     if (testBegin("memContextCallback()"))
     {
         TEST_ERROR(
@@ -232,11 +232,15 @@ testRun()
             memContextCallback(memContext, (MemContextCallback)testFree, memContext),
             AssertError, "callback is already set for context 'test-callback'");
 
+        // Clear and reset it
+        memContextCallbackClear(memContext);
+        memContextCallback(memContext, (MemContextCallback)testFree, memContext);
+
         memContextFree(memContext);
         TEST_RESULT_PTR(memContextCallbackArgument, memContext, "callback argument is context");
     }
 
-    // -----------------------------------------------------------------------------------------------------------------------------
+    // *****************************************************************************************************************************
     if (testBegin("MEM_CONTEXT_BEGIN() and MEM_CONTEXT_END()"))
     {
         memContextSwitch(memContextTop());
@@ -264,7 +268,7 @@ testRun()
         TEST_RESULT_STR(memContextName(memContextCurrent()), "TOP", "context is now top");
     }
 
-    // -----------------------------------------------------------------------------------------------------------------------------
+    // *****************************************************************************************************************************
     if (testBegin("MEM_CONTEXT_NEW_BEGIN() and MEM_CONTEXT_NEW_END()"))
     {
         // ------------------------------------------------------------------------------------------------------------------------
@@ -310,7 +314,7 @@ testRun()
         TEST_RESULT_BOOL(memContext->state == memContextStateFree, true, "new mem context is not active");
     }
 
-    // -----------------------------------------------------------------------------------------------------------------------------
+    // *****************************************************************************************************************************
     if (testBegin("memContextMove()"))
     {
         TEST_RESULT_VOID(memContextMove(NULL, memContextTop()), "move NULL context");
@@ -339,9 +343,10 @@ testRun()
                 memContextCurrent()->contextChildList[1] = NULL;
                 TEST_ERROR(memContextMove(memContext, MEM_CONTEXT_OLD()), AssertError, "unable to find mem context in old parent");
 
-                // Set it back so the move will fail
+                // Set it back so the move will succeed
                 memContextCurrent()->contextChildList[1] = memContext;
                 TEST_RESULT_VOID(memContextMove(memContext, MEM_CONTEXT_OLD()), "move context");
+                TEST_RESULT_VOID(memContextMove(memContext, MEM_CONTEXT_OLD()), "move context again");
             }
             MEM_CONTEXT_TEMP_END();
 
