@@ -7,7 +7,7 @@ Test Stack Trace Handler
 Test Run
 ***********************************************************************************************************************************/
 void
-testRun()
+testRun(void)
 {
     FUNCTION_HARNESS_VOID();
 
@@ -64,7 +64,7 @@ testRun()
         stackTraceInit(testExe());
 #endif
 
-        TEST_ERROR(stackTracePop("file1", "function1"), AssertError, "debug assertion 'stackSize > 0' failed");
+        TEST_ERROR(stackTracePop("file1", "function1"), AssertError, "assertion 'stackSize > 0' failed");
 
         assert(stackTracePush("file1", "function1", logLevelDebug) == logLevelDebug);
         assert(stackSize == 1);
@@ -103,9 +103,10 @@ testRun()
                 "    check stack trace");
 #endif
 
-            assert(stackTracePush("file1.c", "function2", logLevelDebug) == logLevelDebug);
+            assert(stackTracePush("file1.c", "function2", logLevelTrace) == logLevelTrace);
             stackTrace[stackSize - 2].fileLine = 7777;
-            assert(strcmp(stackTraceParam(), "debug log level required for parameters") == 0);
+            assert(strcmp(stackTraceParam(), "trace log level required for parameters") == 0);
+            stackTrace[stackSize - 1].functionLogLevel = logLevelDebug;
 
             TRY_BEGIN()
             {
@@ -147,14 +148,14 @@ testRun()
                 stackTrace[stackSize - 1].param += 1;
                 stackTrace[stackSize - 1].paramSize = 0;
                 stackTraceParamAdd((size_t)snprintf(stackTraceParamBuffer("param1"), STACK_TRACE_PARAM_MAX, "value1"));
-                assert(strcmp(stackTraceParam(), "!!! buffer overflow - parameters not available !!!") == 0);
+                assert(strcmp(stackTraceParam(), "buffer full - parameters not available") == 0);
 
                 stackTraceToZ(buffer, sizeof(buffer), "file4.c", "function4", 99);
 
 #ifdef WITH_BACKTRACE
                 TEST_RESULT_STR(
                     buffer,
-                    "file4:function4:99:(!!! buffer overflow - parameters not available !!!)\n"
+                    "file4:function4:99:(buffer full - parameters not available)\n"
                     "file3:function3:7777:(param1: value1, param2: value2)\n"
                     "file2:function2:7777:(param1: value1)\n"
                     "file1:function2:7777:(debug log level required for parameters)\n"
@@ -163,7 +164,7 @@ testRun()
 #else
                 TEST_RESULT_STR(
                     buffer,
-                    "file4:function4:99:(!!! buffer overflow - parameters not available !!!)\n"
+                    "file4:function4:99:(buffer full - parameters not available)\n"
                     "file3:function3:(param1: value1, param2: value2)\n"
                     "file2:function2:(param1: value1)\n"
                     "file1:function2:(debug log level required for parameters)\n"
