@@ -6,12 +6,12 @@ Test Buffers
 Test Run
 ***********************************************************************************************************************************/
 void
-testRun()
+testRun(void)
 {
     FUNCTION_HARNESS_VOID();
 
     // *****************************************************************************************************************************
-    if (testBegin("bufNew(), bugNewC, bufNewStr(), bufMove(), bufSize(), bufPtr(), and bufFree()"))
+    if (testBegin("bufNew(), bugNewC, bufNewStr(), bufNewZ(), bufMove(), bufSize(), bufPtr(), and bufFree()"))
     {
         Buffer *buffer = NULL;
 
@@ -28,6 +28,9 @@ testRun()
         TEST_ASSIGN(buffer, bufNewStr(strNew("TEST-STR")), "new buffer from string");
         TEST_RESULT_BOOL(memcmp(bufPtr(buffer), "TEST-STR", 8) == 0, true, "check buffer");
 
+        TEST_ASSIGN(buffer, bufNewZ("TEST-STRZ"), "new buffer from zero-terminated string");
+        TEST_RESULT_BOOL(memcmp(bufPtr(buffer), "TEST-STRZ", 9) == 0, true, "check buffer");
+
         TEST_RESULT_VOID(bufFree(buffer), "free buffer");
         TEST_RESULT_VOID(bufFree(bufNew(0)), "free empty buffer");
         TEST_RESULT_VOID(bufFree(NULL), "free null buffer");
@@ -42,7 +45,7 @@ testRun()
     }
 
     // *****************************************************************************************************************************
-    if (testBegin("bufResize()"))
+    if (testBegin("bufResize(), bufFull(), bufLimit*(), bufRemains*(), and bufUsed*()"))
     {
         Buffer *buffer = NULL;
         unsigned char *bufferPtr = NULL;
@@ -51,6 +54,8 @@ testRun()
         TEST_RESULT_INT(bufSize(buffer), 0, "check size");
         TEST_RESULT_PTR(bufResize(buffer, 256), buffer, "resize buffer");
         TEST_RESULT_INT(bufSize(buffer), 256, "check size");
+        TEST_RESULT_VOID(bufUsedSet(buffer, 256), "set used size");
+        TEST_RESULT_BOOL(bufFull(buffer), true, "check buffer full");
 
         // Load data
         TEST_ASSIGN(bufferPtr, bufPtr(buffer), "buffer pointer");
@@ -62,6 +67,12 @@ testRun()
         TEST_ASSIGN(bufferPtr, bufPtr(bufResize(buffer, 512)), "increase buffer size");
         TEST_ASSIGN(bufferPtr, bufPtr(bufResize(buffer, 512)), "set to same size");
         TEST_RESULT_INT(bufSize(buffer), 512, "check size");
+        TEST_RESULT_INT(bufUsed(buffer), 256, "check used size");
+        TEST_RESULT_BOOL(bufFull(buffer), false, "check buffer not full");
+        TEST_RESULT_INT(bufRemains(buffer), 256, "check remaining buffer space");
+        TEST_RESULT_PTR(bufRemainsPtr(buffer), bufPtr(buffer) + 256, "check remaining buffer space pointer");
+        TEST_RESULT_VOID(bufUsedInc(buffer, 256), "set used size");
+        TEST_RESULT_BOOL(bufFull(buffer), true, "check buffer full");
 
         // Test that no bytes have changed in the original data
         unsigned int sameTotal = 0;
@@ -83,27 +94,65 @@ testRun()
 
         TEST_RESULT_INT(sameTotal, 128, "original bytes match");
 
+        // Use limits to change size reporting
+        TEST_RESULT_VOID(bufLimitSet(buffer, 64), "set limit");
+        TEST_RESULT_INT(bufSize(buffer), 64, "    check limited size");
+        TEST_RESULT_VOID(bufLimitClear(buffer), "    clear limit");
+        TEST_RESULT_INT(bufSize(buffer), 128, "    check unlimited size");
+
         // Resize to zero buffer
-        TEST_ASSIGN(bufferPtr, bufPtr(bufResize(buffer, 0)), "decrease to zero");
+        TEST_RESULT_VOID(bufUsedZero(buffer), "set used to 0");
+        TEST_RESULT_INT(bufUsed(buffer), 0, "check used is zero");
+
+        TEST_RESULT_VOID(bufLimitSet(buffer, 64), "set limit to make sure it gets reduced with the resize");
+        TEST_RESULT_VOID(bufResize(buffer, 32), "decrease size to 32");
+        TEST_RESULT_INT(bufSize(buffer), 32, "check size");
+        TEST_RESULT_VOID(bufLimitSet(buffer, 0), "set limit so that it won't need to be resized");
+        TEST_RESULT_VOID(bufResize(buffer, 0), "decrease size to zero");
         TEST_RESULT_INT(bufSize(buffer), 0, "check size");
-        TEST_ASSIGN(bufferPtr, bufPtr(bufResize(buffer, 0)), "decrease to zero again");
+        TEST_RESULT_VOID(bufResize(buffer, 0), "decrease size to zero again");
         TEST_RESULT_INT(bufSize(buffer), 0, "check size");
     }
 
     // *****************************************************************************************************************************
     if (testBegin("bufEq()"))
     {
-        TEST_RESULT_BOOL(bufEq(bufNewStr(strNew("123")), bufNewStr(strNew("1234"))), false, "buffer sizes not equal");
-        TEST_RESULT_BOOL(bufEq(bufNewStr(strNew("321")), bufNewStr(strNew("123"))), false, "buffer sizes equal");
-        TEST_RESULT_BOOL(bufEq(bufNewStr(strNew("123")), bufNewStr(strNew("123"))), true, "buffers equal");
+        TEST_RESULT_BOOL(bufEq(bufNewZ("123"), bufNewZ("1234")), false, "buffer sizes not equal");
+        TEST_RESULT_BOOL(bufEq(bufNewZ("321"), bufNewZ("123")), false, "buffer sizes equal");
+        TEST_RESULT_BOOL(bufEq(bufNewZ("123"), bufNewZ("123")), true, "buffers equal");
     }
 
     // *****************************************************************************************************************************
-    if (testBegin("bufCat()"))
+    if (testBegin("bufHex()"))
     {
-        TEST_RESULT_STR(strPtr(strNewBuf(bufCat(bufNewStr(strNew("123")), NULL))), "123", "cat null buffer");
-        TEST_RESULT_STR(strPtr(strNewBuf(bufCat(bufNewStr(strNew("123")), bufNew(0)))), "123", "cat empty buffer");
-        TEST_RESULT_STR(strPtr(strNewBuf(bufCat(bufNewStr(strNew("123")), bufNewStr(strNew("ABC"))))), "123ABC", "cat buffer");
+        TEST_RESULT_STR(strPtr(bufHex(bufNewZ("ABC-CBA"))), "4142432d434241", "buffer to hex");
+    }
+
+    // *****************************************************************************************************************************
+    if (testBegin("bufCat*()"))
+    {
+        TEST_RESULT_STR(strPtr(strNewBuf(bufCat(bufNewZ("123"), NULL))), "123", "cat null buffer");
+        TEST_RESULT_STR(strPtr(strNewBuf(bufCat(bufNewZ("123"), bufNew(0)))), "123", "cat empty buffer");
+        TEST_RESULT_STR(strPtr(strNewBuf(bufCat(bufNewZ("123"), bufNewZ("ABC")))), "123ABC", "cat buffer");
+
+        TEST_RESULT_STR(strPtr(strNewBuf(bufCatSub(bufNewZ("123"), NULL, 0, 0))), "123", "cat sub null buffer");
+        TEST_RESULT_STR(strPtr(strNewBuf(bufCatSub(bufNewZ("123"), bufNew(0), 0, 0))), "123", "cat sub empty buffer");
+        TEST_RESULT_STR(
+            strPtr(strNewBuf(bufCatSub(bufNewZ("123"), bufNewZ("ABC"), 1, 2))), "123BC", "cat sub buffer");
+
+        Buffer *buffer = NULL;
+        TEST_ASSIGN(buffer, bufNew(2), "new buffer with space");
+        TEST_RESULT_STR(strPtr(strNewBuf(bufCat(buffer, bufNewZ("AB")))), "AB", "cat buffer with space");
+    }
+
+    // *****************************************************************************************************************************
+    if (testBegin("bufToLog()"))
+    {
+        Buffer *buffer = bufNew(100);
+        TEST_RESULT_STR(strPtr(bufToLog(buffer)), "{used: 0, size: 100, limit: <off>}", "buf to log");
+
+        bufLimitSet(buffer, 50);
+        TEST_RESULT_STR(strPtr(bufToLog(buffer)), "{used: 0, size: 100, limit: 50}", "buf to log");
     }
 
     FUNCTION_HARNESS_RESULT_VOID();
