@@ -6,7 +6,7 @@ Test Key Value Data Type
 Test Run
 ***********************************************************************************************************************************/
 void
-testRun()
+testRun(void)
 {
     FUNCTION_HARNESS_VOID();
 
@@ -29,7 +29,13 @@ testRun()
     {
         KeyValue *store = NULL;
 
-        TEST_ASSIGN(store, kvNew(), "new store");
+        MEM_CONTEXT_TEMP_BEGIN()
+        {
+            TEST_ASSIGN(store, kvNew(), "new store");
+            TEST_RESULT_PTR(kvMove(NULL, MEM_CONTEXT_OLD()), NULL, "move null to old context");
+            TEST_RESULT_PTR(kvMove(store, MEM_CONTEXT_OLD()), store, "move kv to old context");
+        }
+        MEM_CONTEXT_TEMP_END();
 
         // Set various data types
         // -------------------------------------------------------------------------------------------------------------------------
