@@ -7,11 +7,11 @@ Test Variant Data Type
 Test Run
 ***********************************************************************************************************************************/
 void
-testRun()
+testRun(void)
 {
     FUNCTION_HARNESS_VOID();
 
-    // -----------------------------------------------------------------------------------------------------------------------------
+    // *****************************************************************************************************************************
     if (testBegin("bool"))
     {
         Variant *boolean = varNewBool(false);
@@ -29,8 +29,9 @@ testRun()
         TEST_RESULT_BOOL(varBoolForce(varNewBool(false)), false, "force bool to bool");
         TEST_RESULT_BOOL(varBoolForce(varNewInt(1)), true, "force int to bool");
         TEST_RESULT_BOOL(varBoolForce(varNewInt64(false)), false, "force int64 to bool");
+        TEST_RESULT_BOOL(varBoolForce(varNewUInt64(12)), true, "force uint64 to bool");
 
-        TEST_ERROR(varBoolForce(varNewVarLst(varLstNew())), FormatError, "unable to force VariantList to bool");
+        TEST_ERROR(varBoolForce(varNewVarLst(varLstNew())), AssertError, "unable to force VariantList to bool");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_RESULT_VOID(varFree(NULL), "ok to free null variant");
@@ -45,7 +46,7 @@ testRun()
         TEST_RESULT_BOOL(varEq(varNewBool(false), varNewBool(true)), false, "bool, bool not eq");
     }
 
-    // -----------------------------------------------------------------------------------------------------------------------------
+    // *****************************************************************************************************************************
     if (testBegin("double"))
     {
         Variant *var = varNewDbl(44.44);
@@ -60,11 +61,14 @@ testRun()
         TEST_RESULT_DOUBLE(varDblForce(varNewBool(false)), 0, "force bool to double");
         TEST_RESULT_DOUBLE(varDblForce(varNewInt(123)), 123, "force int to double");
         TEST_RESULT_DOUBLE(varDblForce(varNewInt64(999999999999)), 999999999999, "force int64 to double");
+        TEST_RESULT_DOUBLE(varDblForce(varNewUInt64(9223372036854775807U)), 9223372036854775807U, "force uint64 to double");
         TEST_RESULT_DOUBLE(varDblForce(varNewStr(strNew("879.01"))), 879.01, "force String to double");
         TEST_RESULT_DOUBLE(varDblForce(varNewStr(strNew("0"))), 0, "force String to double");
+        TEST_RESULT_DOUBLE(
+            varDblForce(varNewUInt64(UINT64_MAX)), 18446744073709551616.0, "force max uint64 to double (it will be rounded)");
 
         TEST_ERROR(varDblForce(varNewStr(strNew("AAA"))), FormatError, "unable to convert string 'AAA' to double");
-        TEST_ERROR(varDblForce(varNewVarLst(varLstNew())), FormatError, "unable to force VariantList to double");
+        TEST_ERROR(varDblForce(varNewVarLst(varLstNew())), AssertError, "unable to force VariantList to double");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_RESULT_DOUBLE(varDbl(varDup(varNewDbl(3.1415))), 3.1415, "dup double");
@@ -74,7 +78,7 @@ testRun()
         TEST_RESULT_BOOL(varEq(varNewDbl(4.321), varNewDbl(1.234)), false, "double, double not eq");
     }
 
-    // -----------------------------------------------------------------------------------------------------------------------------
+    // *****************************************************************************************************************************
     if (testBegin("int"))
     {
         Variant *integer = varNewInt(44);
@@ -84,10 +88,12 @@ testRun()
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_RESULT_INT(varIntForce(varNewBool(true)), 1, "force bool to int");
-        TEST_ERROR(varIntForce(varNewVarLst(varLstNew())), FormatError, "unable to force VariantList to int");
+        TEST_ERROR(varIntForce(varNewVarLst(varLstNew())), AssertError, "unable to force VariantList to int");
         TEST_RESULT_INT(varIntForce(varNewInt64(999)), 999, "force int64 to int");
-        TEST_ERROR(varIntForce(varNewInt64(2147483648)), AssertError, "unable to convert int64 2147483648 to int");
-        TEST_ERROR(varIntForce(varNewInt64(-2147483649)), AssertError, "unable to convert int64 -2147483649 to int");
+        TEST_ERROR(varIntForce(varNewInt64(2147483648)), FormatError, "unable to convert int64 2147483648 to int");
+        TEST_ERROR(varIntForce(varNewInt64(-2147483649)), FormatError, "unable to convert int64 -2147483649 to int");
+        TEST_RESULT_INT(varIntForce(varNewUInt64(12345)), 12345, "force uint64 to int");
+        TEST_ERROR(varIntForce(varNewUInt64(2147483648)), FormatError, "unable to convert uint64 2147483648 to int");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_ERROR(varInt(varNewStrZ("string")), AssertError, "assertion 'this->type == varTypeInt' failed");
@@ -104,7 +110,7 @@ testRun()
         TEST_RESULT_BOOL(varEq(varNewInt(444), varNewInt(123)), false, "int, int not eq");
     }
 
-    // -----------------------------------------------------------------------------------------------------------------------------
+    // *****************************************************************************************************************************
     if (testBegin("int64"))
     {
         Variant *integer = varNewInt64(44);
@@ -116,11 +122,14 @@ testRun()
         TEST_RESULT_INT(varInt64Force(varNewBool(true)), 1, "force bool to int64");
         TEST_RESULT_INT(varInt64Force(varNewInt(2147483647)), 2147483647, "force int to int64");
         TEST_RESULT_INT(varInt64Force(varNewStrZ("9223372036854775807")), 9223372036854775807L, "force str to int64");
+        TEST_RESULT_INT(varInt64Force(varNewUInt64(9223372036854775807U)), 9223372036854775807L, "force uint64 to int64");
 
         TEST_ERROR(
-            varInt64Force(varNewStrZ("9923372036854775807")), FormatError,
-            "unable to convert string '9923372036854775807' to int64");
-        TEST_ERROR(varInt64Force(varNewVarLst(varLstNew())), FormatError, "unable to force VariantList to int64");
+            varInt64Force(varNewStrZ("9223372036854775808")), FormatError,
+            "unable to convert base 10 string '9223372036854775808' to int64");
+        TEST_ERROR(varInt64Force(varNewVarLst(varLstNew())), AssertError, "unable to force VariantList to int64");
+        TEST_ERROR(varInt64Force(varNewUInt64(9223372036854775808U)), FormatError,
+            "unable to convert uint64 9223372036854775808 to int64");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_ERROR(varInt64(varNewStrZ("string")), AssertError, "assertion 'this->type == varTypeInt64' failed");
@@ -136,7 +145,44 @@ testRun()
         TEST_RESULT_BOOL(varEq(varNewInt64(444), varNewInt64(123)), false, "int64, int64 not eq");
     }
 
-    // -----------------------------------------------------------------------------------------------------------------------------
+    // *****************************************************************************************************************************
+    if (testBegin("uint64"))
+    {
+        Variant *uint64 = varNewUInt64(44);
+        TEST_RESULT_DOUBLE(varUInt64(uint64), 44, "uint64 variant");
+        TEST_RESULT_DOUBLE(varUInt64Force(uint64), 44, "force uint64 to uint64");
+        varFree(uint64);
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_RESULT_DOUBLE(varUInt64Force(varNewBool(true)), 1, "force bool to uint64");
+        TEST_RESULT_DOUBLE(varUInt64Force(varNewInt(2147483647)), 2147483647, "force int to uint64");
+        TEST_RESULT_DOUBLE(varUInt64Force(varNewInt64(2147483647)), 2147483647, "force int64 to uint64");
+        TEST_RESULT_DOUBLE(varUInt64Force(varNewStrZ("18446744073709551615")), 18446744073709551615U, "force str to uint64");
+        TEST_RESULT_DOUBLE(varUInt64Force(varNewUInt64(18446744073709551615U)), 18446744073709551615U, "force uint64 to uint64");
+
+        TEST_ERROR(
+            varUInt64Force(varNewStrZ("18446744073709551616")), FormatError,
+            "unable to convert base 10 string '18446744073709551616' to uint64");   // string value is out of bounds for uint64
+        TEST_ERROR(varUInt64Force(varNewStrZ(" 16")), FormatError,"unable to convert base 10 string ' 16' to uint64");
+        TEST_ERROR(varUInt64Force(varNewVarLst(varLstNew())), AssertError, "unable to force VariantList to uint64");
+        TEST_ERROR(varUInt64Force(varNewInt64(-1)), FormatError, "unable to convert int64 -1 to uint64");
+        TEST_ERROR(varUInt64Force(varNewInt(-1)), FormatError, "unable to convert int -1 to uint64");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_ERROR(varUInt64(varNewStrZ("string")), AssertError, "assertion 'this->type == varTypeUInt64' failed");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_RESULT_DOUBLE(varUInt64(varDup(varNewUInt64(88976))), 88976, "dup uint64");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_RESULT_BOOL(varEq(NULL, NULL), true, "null, null eq");
+        TEST_RESULT_BOOL(varEq(NULL, varNewUInt64(123)), false, "null, uint64 not eq");
+
+        TEST_RESULT_BOOL(varEq(varNewUInt64(9223372036854775807L), varNewUInt64(9223372036854775807L)), true, "uint64, uint64 eq");
+        TEST_RESULT_BOOL(varEq(varNewUInt64(444), varNewUInt64(123)), false, "uint64, uint64 not eq");
+    }
+
+    // *****************************************************************************************************************************
     if (testBegin("keyValue"))
     {
         TEST_ERROR(varKv(varNewInt(66)), AssertError, "assertion 'this->type == varTypeKeyValue' failed");
@@ -162,10 +208,10 @@ testRun()
         TEST_ERROR(varEq(varNewKv(), varNewKv()), AssertError, "unable to test equality for KeyValue");
     }
 
-    // -----------------------------------------------------------------------------------------------------------------------------
+    // *****************************************************************************************************************************
     if (testBegin("String"))
     {
-        TEST_ERROR(varNewStr(NULL), AssertError, "function test assertion 'data != NULL' failed");
+        TEST_RESULT_PTR(strPtr(varStr(varNewStr(NULL))), NULL, "new null str");
 
         // -------------------------------------------------------------------------------------------------------------------------
         Variant *string = varNewStr(strNew("test-str"));
@@ -198,17 +244,18 @@ testRun()
         TEST_RESULT_STR(strPtr(varStrForce(varNewDbl((double)999999999.123456))), "999999999.123456", "force double to string");
         TEST_RESULT_STR(strPtr(varStrForce(varNewBool(true))), "true", "force bool to string");
         TEST_RESULT_STR(strPtr(varStrForce(varNewBool(false))), "false", "force bool to string");
+        TEST_RESULT_STR(strPtr(varStrForce(varNewUInt64(18446744073709551615U))), "18446744073709551615", "force uint64 to string");
 
         TEST_ERROR(varStrForce(varNewKv()), FormatError, "unable to force KeyValue to String");
 
         // -------------------------------------------------------------------------------------------------------------------------
         string = varNewStr(strNew("not-an-int"));
-        TEST_ERROR(varIntForce(string), FormatError, "unable to convert string 'not-an-int' to int");
+        TEST_ERROR(varIntForce(string), FormatError, "unable to convert base 10 string 'not-an-int' to int");
         varFree(string);
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_RESULT_STR(strPtr(varStr(varNewStrZ("test-z-str"))), "test-z-str", "new zero-terminated string");
-        TEST_ERROR(varNewStrZ(NULL), AssertError, "function test assertion 'data != NULL' failed");
+        TEST_RESULT_PTR(strPtr(varStr(varNewStrZ(NULL))), NULL, "new null strz");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_RESULT_STR(strPtr(varStr(varDup(varNewStr(strNew("yabba-dabba-doo"))))), "yabba-dabba-doo", "dup string");
@@ -219,7 +266,7 @@ testRun()
         TEST_RESULT_BOOL(varEq(varNewStr(strNew("Y")), varNewStr(strNew("X"))), false, "string, string not eq");
     }
 
-    // -----------------------------------------------------------------------------------------------------------------------------
+    // *****************************************************************************************************************************
     if (testBegin("VariantList"))
     {
         TEST_ERROR(varVarLst(varNewInt(66)), AssertError, "assertion 'this->type == varTypeVariantList' failed");
@@ -227,6 +274,7 @@ testRun()
         // -------------------------------------------------------------------------------------------------------------------------
         Variant *listVar = NULL;
 
+        TEST_RESULT_PTR(varVarLst(varNewVarLst(NULL)), NULL, "new null");
         TEST_ASSIGN(listVar, varNewVarLst(varLstNew()), "new empty");
 
         TEST_RESULT_INT(varLstSize(varVarLst(listVar)), 0, "    empty size");
@@ -257,25 +305,68 @@ testRun()
         TEST_ERROR(varEq(varNewVarLst(varLstNew()), varNewVarLst(varLstNew())), AssertError, "unable to test equality for VariantList");
     }
 
-    // -----------------------------------------------------------------------------------------------------------------------------
+    // *****************************************************************************************************************************
     if (testBegin("varToLog"))
     {
-        char buffer[STACK_TRACE_PARAM_MAX];
+        TEST_RESULT_STR(strPtr(varToLog(varNewStrZ("testme"))), "{\"testme\"}", "format String");
+        TEST_RESULT_STR(strPtr(varToLog(varNewBool(false))), "{false}", "format bool");
+        TEST_RESULT_STR(strPtr(varToLog(varNewKv())), "{KeyValue}", "format KeyValue");
+        TEST_RESULT_STR(strPtr(varToLog(varNewVarLst(varLstNew()))), "{VariantList}", "format VariantList");
+    }
 
-        TEST_RESULT_INT(varToLog(NULL, buffer, 4), 4, "format truncated null");
-        TEST_RESULT_STR(buffer, "nul", "    check buffer");
+    // *****************************************************************************************************************************
+    if (testBegin("varLstNew(), varLstAdd(), varLstSize(), varLstGet(), and varListFree()"))
+    {
+        VariantList *list = NULL;
 
-        TEST_RESULT_INT(varToLog(varNewStrZ("testme"), buffer, STACK_TRACE_PARAM_MAX), 10, "format String");
-        TEST_RESULT_STR(buffer, "{\"testme\"}", "    check buffer");
+        MEM_CONTEXT_TEMP_BEGIN()
+        {
+            TEST_ASSIGN(list, varLstNew(), "new list");
+            TEST_RESULT_PTR(varLstMove(NULL, MEM_CONTEXT_OLD()), NULL, "move null to old context");
+            TEST_RESULT_PTR(varLstMove(list, MEM_CONTEXT_OLD()), list, "move var list to old context");
+        }
+        MEM_CONTEXT_TEMP_END();
 
-        TEST_RESULT_INT(varToLog(varNewBool(false), buffer, STACK_TRACE_PARAM_MAX), 7, "format bool");
-        TEST_RESULT_STR(buffer, "{false}", "    check buffer");
+        TEST_RESULT_PTR(varLstAdd(list, varNewInt(27)), list, "add int");
+        TEST_RESULT_PTR(varLstAdd(list, varNewStr(strNew("test-str"))), list, "add string");
 
-        TEST_RESULT_INT(varToLog(varNewKv(), buffer, STACK_TRACE_PARAM_MAX), 10, "format KeyValue");
-        TEST_RESULT_STR(buffer, "{KeyValue}", "    check buffer");
+        TEST_RESULT_INT(varLstSize(list), 2, "list size");
 
-        TEST_RESULT_INT(varToLog(varNewVarLst(varLstNew()), buffer, STACK_TRACE_PARAM_MAX), 13, "format VariantList");
-        TEST_RESULT_STR(buffer, "{VariantList}", "    check buffer");
+        TEST_RESULT_INT(varInt(varLstGet(list, 0)), 27, "check int");
+        TEST_RESULT_STR(strPtr(varStr(varLstGet(list, 1))), "test-str", "check string");
+
+        TEST_RESULT_VOID(varLstFree(list), "free list");
+        TEST_RESULT_VOID(varLstFree(NULL), "free null list");
+    }
+
+    // *****************************************************************************************************************************
+    if (testBegin("varLstDup()"))
+    {
+        VariantList *list = varLstNew();
+
+        varLstAdd(list, varNewStr(strNew("string1")));
+        varLstAdd(list, varNewStr(strNew("string2")));
+
+        TEST_RESULT_STR(
+            strPtr(strLstJoin(strLstNewVarLst(varLstDup(list)), ", ")),
+            "string1, string2", "duplicate variant list");
+
+        TEST_RESULT_PTR(varLstDup(NULL), NULL, "duplicate null list");
+    }
+
+    // *****************************************************************************************************************************
+    if (testBegin("varLstNewStrLst()"))
+    {
+        StringList *listStr = strLstNew();
+
+        strLstAdd(listStr, strNew("string1"));
+        strLstAdd(listStr, strNew("string2"));
+
+        TEST_RESULT_STR(
+            strPtr(strLstJoin(strLstNewVarLst(varLstNewStrLst(listStr)), ", ")),
+            "string1, string2", "variant list from string list");
+
+        TEST_RESULT_PTR(varLstNewStrLst(NULL), NULL, "variant list from null string list");
     }
 
     FUNCTION_HARNESS_RESULT_VOID();
