@@ -6,14 +6,14 @@ Test Configuration Command and Option Definition
 Test run
 ***********************************************************************************************************************************/
 void
-testRun()
+testRun(void)
 {
     FUNCTION_HARNESS_VOID();
 
     // Static tests against known values -- these may break as options change so will need to be kept up to date.  The tests have
     // generally been selected to favor values that are not expected to change but adjustments are welcome as long as the type of
     // test is not drastically changed.
-    // -----------------------------------------------------------------------------------------------------------------------------
+    // *****************************************************************************************************************************
     if (testBegin("check known values"))
     {
         TEST_RESULT_STR(cfgDefOptionName(cfgDefOptConfig), "config", "option name");
@@ -34,7 +34,7 @@ testRun()
         TEST_RESULT_STR(cfgDefOptionAllowListValue(cfgDefCmdBackup, cfgDefOptType, 2), "incr", "allow list value 2");
         TEST_ERROR(
             cfgDefOptionAllowListValue(cfgDefCmdBackup, cfgDefOptType, 3), AssertError,
-            "function test assertion 'valueId < cfgDefOptionAllowListValueTotal(commandDefId, optionDefId)' failed");
+            "assertion 'valueId < cfgDefOptionAllowListValueTotal(commandDefId, optionDefId)' failed");
 
         TEST_RESULT_BOOL(
             cfgDefOptionAllowListValueValid(cfgDefCmdBackup, cfgDefOptType, "diff"), true, "allow list value valid");
@@ -52,10 +52,10 @@ testRun()
 
         TEST_ERROR(
             cfgDefOptionDefault(cfgDefCommandTotal(), cfgDefOptCompressLevel), AssertError,
-            "function test assertion 'commandDefId < cfgDefCommandTotal()' failed");
+            "assertion 'commandDefId < cfgDefCommandTotal()' failed");
         TEST_ERROR(cfgDefOptionDefault(
             cfgDefCmdBackup, cfgDefOptionTotal()), AssertError,
-            "function test assertion 'optionDefId < cfgDefOptionTotal()' failed");
+            "assertion 'optionDefId < cfgDefOptionTotal()' failed");
         TEST_RESULT_STR(cfgDefOptionDefault(cfgDefCmdBackup, cfgDefOptCompressLevel), "6", "option default exists");
         TEST_RESULT_STR(cfgDefOptionDefault(cfgDefCmdRestore, cfgDefOptType), "default", "command default exists");
         TEST_RESULT_STR(cfgDefOptionDefault(cfgDefCmdLocal, cfgDefOptType), NULL, "command default does not exist");
@@ -73,7 +73,7 @@ testRun()
         TEST_RESULT_STR(cfgDefOptionDependValue(cfgDefCmdRestore, cfgDefOptTarget, 2), "xid", "depend option value 2");
         TEST_ERROR(
             cfgDefOptionDependValue(cfgDefCmdRestore, cfgDefOptTarget, 3), AssertError,
-            "function test assertion 'valueId < cfgDefOptionDependValueTotal(commandDefId, optionDefId)' failed");
+            "assertion 'valueId < cfgDefOptionDependValueTotal(commandDefId, optionDefId)' failed");
 
         TEST_RESULT_BOOL(
                 cfgDefOptionDependValueValid(cfgDefCmdRestore, cfgDefOptTarget, "time"), true, "depend option value valid");
@@ -82,7 +82,7 @@ testRun()
 
         TEST_ERROR(
             cfgDefOptionIndexTotal(cfgDefOptionTotal()), AssertError,
-            "function test assertion 'optionDefId < cfgDefOptionTotal()' failed");
+            "assertion 'optionDefId < cfgDefOptionTotal()' failed");
         TEST_RESULT_INT(cfgDefOptionIndexTotal(cfgDefOptPgPath), 8, "index total > 1");
         TEST_RESULT_INT(cfgDefOptionIndexTotal(cfgDefOptRepoPath), 1, "index total == 1");
 
@@ -90,6 +90,9 @@ testRun()
         TEST_RESULT_BOOL(cfgDefOptionInternal(cfgDefCmdRestore, cfgDefOptPgHost), true, "option pg-host is internal");
         TEST_RESULT_BOOL(cfgDefOptionInternal(cfgDefCmdRestore, cfgDefOptTest), true, "option test is internal");
 
+        TEST_RESULT_BOOL(cfgDefOptionMulti(cfgDefOptRecoveryOption), true, "recovery-option is multi");
+        TEST_RESULT_BOOL(cfgDefOptionMulti(cfgDefOptStartFast), false, "start-fast is not multi");
+
         TEST_RESULT_STR(cfgDefOptionPrefix(cfgDefOptPgHost), "pg", "option prefix");
         TEST_RESULT_STR(cfgDefOptionPrefix(cfgDefOptType), NULL, "option has no prefix");
 
@@ -109,12 +112,12 @@ testRun()
 
         TEST_ERROR(
             cfgDefOptionValid(cfgDefCmdInfo, cfgDefOptionTotal()), AssertError,
-            "function test assertion 'optionDefId < cfgDefOptionTotal()' failed");
+            "assertion 'optionDefId < cfgDefOptionTotal()' failed");
         TEST_RESULT_BOOL(cfgDefOptionValid(cfgDefCmdBackup, cfgDefOptType), true, "option valid");
         TEST_RESULT_BOOL(cfgDefOptionValid(cfgDefCmdInfo, cfgDefOptType), false, "option not valid");
     }
 
-    // -----------------------------------------------------------------------------------------------------------------------------
+    // *****************************************************************************************************************************
     if (testBegin("cfgDefCommandHelp*() and cfgDefOptionHelp*()"))
     {
         TEST_RESULT_BOOL(cfgDefOptionHelpNameAlt(cfgDefOptRepoHost), true, "name alt exists");
@@ -123,7 +126,7 @@ testRun()
         TEST_RESULT_STR(cfgDefOptionHelpNameAltValue(cfgDefOptRepoHost, 0), "backup-host", "name alt value 0");
         TEST_ERROR(
             cfgDefOptionHelpNameAltValue(cfgDefOptRepoHost, 1), AssertError,
-            "function test assertion 'valueId < cfgDefOptionHelpNameAltValueTotal(optionDefId)' failed");
+            "assertion 'valueId < cfgDefOptionHelpNameAltValueTotal(optionDefId)' failed");
 
         TEST_RESULT_STR(cfgDefCommandHelpSummary(cfgDefCmdBackup), "Backup a database cluster.", "backup command help summary");
         TEST_RESULT_STR(
