@@ -1,16 +1,25 @@
 /***********************************************************************************************************************************
 Test Configuration Load
 ***********************************************************************************************************************************/
+#include "common/io/io.h"
 #include "common/log.h"
 #include "version.h"
 
 #include "common/harnessConfig.h"
 
+/***********************************************************************************************************************************
+Expose log internal data for unit testing/debugging
+***********************************************************************************************************************************/
+extern LogLevel logLevelStdOut;
+extern LogLevel logLevelStdErr;
+extern LogLevel logLevelFile;
+extern bool logTimestamp;
+
 /***********************************************************************************************************************************
 Test run
 ***********************************************************************************************************************************/
 void
-testRun()
+testRun(void)
 {
     FUNCTION_HARNESS_VOID();
 
@@ -125,6 +134,18 @@ testRun()
             "'50.5' is not valid for 'protocol-timeout' option\n"
                 "HINT 'protocol-timeout' option (50.5) should be greater than 'db-timeout' option (100000).");
 
+        cfgOptionSet(cfgOptProtocolTimeout, cfgSourceParam, varNewDbl(45));
+        cfgOptionSet(cfgOptDbTimeout, cfgSourceDefault, varNewDbl(3600));
+        TEST_RESULT_VOID(cfgLoadUpdateOption(), "set default pg timeout to be less than protocol timeout");
+        TEST_RESULT_DOUBLE(cfgOptionDbl(cfgOptProtocolTimeout), 45, "    check protocol timeout");
+        TEST_RESULT_DOUBLE(cfgOptionDbl(cfgOptDbTimeout), 15, "    check db timeout");
+
+        cfgOptionSet(cfgOptProtocolTimeout, cfgSourceParam, varNewDbl(11));
+        cfgOptionSet(cfgOptDbTimeout, cfgSourceDefault, varNewDbl(3600));
+        TEST_RESULT_VOID(cfgLoadUpdateOption(), "set default pg timeout to be less than test protocol timeout");
+        TEST_RESULT_DOUBLE(cfgOptionDbl(cfgOptProtocolTimeout), 11, "    check protocol timeout");
+        TEST_RESULT_DOUBLE(cfgOptionDbl(cfgOptDbTimeout), 5.5, "    check db timeout");
+
         // -------------------------------------------------------------------------------------------------------------------------
         cfgInit();
         cfgCommandSet(cfgCmdBackup);
@@ -143,13 +164,12 @@ testRun()
         StringList *argList = strLstNew();
         strLstAdd(argList, strNew("pgbackrest"));
         strLstAdd(argList, strNew("--stanza=db"));
-        strLstAdd(argList, strNew("--log-level-console=info"));
-        strLstAdd(argList, strNew("--log-level-stderr=off"));
         strLstAdd(argList, strNew("--no-log-timestamp"));
         strLstAdd(argList, strNew("expire"));
 
+        harnessLogLevelSet(logLevelWarn);
         TEST_RESULT_VOID(harnessCfgLoad(strLstSize(argList), strLstPtr(argList)), "load config for retention warning");
-        testLogResult(
+        harnessLogResult(
             "P00   WARN: option repo1-retention-full is not set, the repository may run out of space\n"
             "            HINT: to retain full backups indefinitely (without warning), set option"
                 " 'repo1-retention-full' to the maximum.");
@@ -167,14 +187,12 @@ testRun()
         argList = strLstNew();
         strLstAdd(argList, strNew("pgbackrest"));
         strLstAdd(argList, strNew("--stanza=db"));
-        strLstAdd(argList, strNew("--log-level-console=info"));
-        strLstAdd(argList, strNew("--log-level-stderr=off"));
         strLstAdd(argList, strNew("--no-log-timestamp"));
         strLstAdd(argList, strNew("--repo1-retention-archive-type=incr"));
         strLstAdd(argList, strNew("expire"));
 
         TEST_RESULT_VOID(harnessCfgLoad(strLstSize(argList), strLstPtr(argList)), "load config for retention warning");
-        testLogResult(
+        harnessLogResult(
             "P00   WARN: option repo1-retention-full is not set, the repository may run out of space\n"
                 "            HINT: to retain full backups indefinitely (without warning), set option 'repo1-retention-full'"
                 " to the maximum.\n"
@@ -185,14 +203,12 @@ testRun()
         argList = strLstNew();
         strLstAdd(argList, strNew("pgbackrest"));
         strLstAdd(argList, strNew("--stanza=db"));
-        strLstAdd(argList, strNew("--log-level-console=info"));
-        strLstAdd(argList, strNew("--log-level-stderr=off"));
         strLstAdd(argList, strNew("--no-log-timestamp"));
         strLstAdd(argList, strNew("--repo1-retention-archive-type=diff"));
         strLstAdd(argList, strNew("expire"));
 
         TEST_RESULT_VOID(harnessCfgLoad(strLstSize(argList), strLstPtr(argList)), "load config for retention warning");
-        testLogResult(
+        harnessLogResult(
             "P00   WARN: option repo1-retention-full is not set, the repository may run out of space\n"
             "            HINT: to retain full backups indefinitely (without warning), set option"
                 " 'repo1-retention-full' to the maximum.\n"
@@ -203,7 +219,7 @@ testRun()
         strLstAdd(argList, strNew("--repo1-retention-diff=2"));
 
         TEST_RESULT_VOID(harnessCfgLoad(strLstSize(argList), strLstPtr(argList)), "load config for retention warning");
-        testLogResult(
+        harnessLogResult(
             "P00   WARN: option repo1-retention-full is not set, the repository may run out of space\n"
             "            HINT: to retain full backups indefinitely (without warning), set option"
                 " 'repo1-retention-full' to the maximum.");
@@ -212,8 +228,6 @@ testRun()
         argList = strLstNew();
         strLstAdd(argList, strNew("pgbackrest"));
         strLstAdd(argList, strNew("--stanza=db"));
-        strLstAdd(argList, strNew("--log-level-console=info"));
-        strLstAdd(argList, strNew("--log-level-stderr=off"));
         strLstAdd(argList, strNew("--no-log-timestamp"));
         strLstAdd(argList, strNew("--repo1-retention-archive-type=diff"));
         strLstAdd(argList, strNew("--repo1-retention-archive=3"));
@@ -221,12 +235,24 @@ testRun()
         strLstAdd(argList, strNew("expire"));
 
         TEST_RESULT_VOID(harnessCfgLoad(strLstSize(argList), strLstPtr(argList)), "load config for retention warning");
-        testLogResult(
+        harnessLogResult(
             "P00   WARN: option 'repo1-retention-diff' is not set for 'repo1-retention-archive-type=diff'\n"
             "            HINT: to retain differential backups indefinitely (without warning), set option 'repo1-retention-diff'"
                 " to the maximum.");
     }
 
+    // *****************************************************************************************************************************
+    if (testBegin("cfgLoadLogFile()"))
+    {
+        cfgInit();
+        cfgOptionValidSet(cfgOptLogLevelFile, true);
+        cfgOptionSet(cfgOptLogLevelFile, cfgSourceParam, varNewStrZ("detail"));
+
+        // On the error case is tested here, success is tested in cfgLoad()
+        TEST_RESULT_VOID(cfgLoadLogFile(strNew("/BOGUS")), "attempt to open bogus log file");
+        TEST_RESULT_STR(strPtr(cfgOptionStr(cfgOptLogLevelFile)), "off", "log-level-file should now be off");
+    }
+
     // *****************************************************************************************************************************
     if (testBegin("cfgLoad()"))
     {
@@ -243,6 +269,9 @@ testRun()
         argList = strLstNew();
         strLstAdd(argList, strNew("pgbackrest"));
         strLstAdd(argList, strNew("--stanza=db"));
+        strLstAdd(argList, strNew("--log-level-console=off"));
+        strLstAdd(argList, strNew("--log-level-stderr=off"));
+        strLstAdd(argList, strNew("--log-level-file=off"));
         strLstAdd(argList, strNew("archive-get"));
 
         umask(0111);
@@ -255,6 +284,9 @@ testRun()
         strLstAdd(argList, strNew("pgbackrest"));
         strLstAdd(argList, strNew("--stanza=db"));
         strLstAdd(argList, strNew("--no-neutral-umask"));
+        strLstAdd(argList, strNew("--log-level-console=off"));
+        strLstAdd(argList, strNew("--log-level-stderr=off"));
+        strLstAdd(argList, strNew("--log-level-file=off"));
         strLstAdd(argList, strNew("archive-get"));
 
         umask(0111);
@@ -268,27 +300,79 @@ testRun()
 
         TEST_RESULT_VOID(cfgLoad(strLstSize(argList), strLstPtr(argList)), "no command");
 
-        // Help command
+        // Help command only
+        // -------------------------------------------------------------------------------------------------------------------------
+        argList = strLstNew();
+        strLstAdd(argList, strNew("pgbackrest"));
+        strLstAdd(argList, strNew("help"));
+
+        ioBufferSizeSet(333);
+        TEST_RESULT_VOID(cfgLoad(strLstSize(argList), strLstPtr(argList)), "help command");
+        TEST_RESULT_SIZE(ioBufferSize(), 333, "buffer size not updated by help command");
+
+        // Help command for backup
         // -------------------------------------------------------------------------------------------------------------------------
         argList = strLstNew();
         strLstAdd(argList, strNew("pgbackrest"));
         strLstAdd(argList, strNew("help"));
         strLstAdd(argList, strNew("backup"));
+        strLstAdd(argList, strNew("--log-level-console=off"));
+        strLstAdd(argList, strNew("--log-level-stderr=off"));
+        strLstAdd(argList, strNew("--log-level-file=off"));
         strLstAdd(argList, strNew("--repo1-retention-full=2"));
 
-        TEST_RESULT_VOID(cfgLoad(strLstSize(argList), strLstPtr(argList)), "help command");
+        TEST_RESULT_VOID(cfgLoad(strLstSize(argList), strLstPtr(argList)), "help command for backup");
+        TEST_RESULT_SIZE(ioBufferSize(), 4 * 1024 * 1024, "buffer size set to option default");
 
         // Command takes lock and opens log file
         // -------------------------------------------------------------------------------------------------------------------------
+        struct stat statLog;
+
         argList = strLstNew();
         strLstAdd(argList, strNew("pgbackrest"));
         strLstAdd(argList, strNew("--stanza=db"));
         strLstAdd(argList, strNew("--pg1-path=/path"));
         strLstAdd(argList, strNew("--repo1-retention-full=1"));
         strLstAdd(argList, strNewFmt("--log-path=%s", testPath()));
+        strLstAdd(argList, strNew("--log-level-console=off"));
+        strLstAdd(argList, strNew("--log-level-stderr=off"));
+        strLstAdd(argList, strNew("--log-level-file=warn"));
         strLstAdd(argList, strNew("backup"));
 
         TEST_RESULT_VOID(cfgLoad(strLstSize(argList), strLstPtr(argList)), "lock and open log file");
+        TEST_RESULT_INT(lstat(strPtr(strNewFmt("%s/db-backup.log", testPath())), &statLog), 0, "   check log file exists");
+
+        // Local command opens log file with special filename
+        // -------------------------------------------------------------------------------------------------------------------------
+        argList = strLstNew();
+        strLstAdd(argList, strNew("pgbackrest"));
+        strLstAdd(argList, strNew("--stanza=db"));
+        strLstAdd(argList, strNew("--command=backup"));
+        strLstAdd(argList, strNewFmt("--log-path=%s", testPath()));
+        strLstAdd(argList, strNew("--process=1"));
+        strLstAdd(argList, strNew("--host-id=1"));
+        strLstAdd(argList, strNew("--type=backup"));
+        strLstAdd(argList, strNew("--log-level-file=warn"));
+        strLstAdd(argList, strNew("local"));
+
+        TEST_RESULT_VOID(cfgLoad(strLstSize(argList), strLstPtr(argList)), "open log file");
+        TEST_RESULT_INT(
+            lstat(strPtr(strNewFmt("%s/db-backup-local-001.log", testPath())), &statLog), 0, "   check log file exists");
+
+        // Remote command opens log file with special filename
+        // -------------------------------------------------------------------------------------------------------------------------
+        argList = strLstNew();
+        strLstAdd(argList, strNew("pgbackrest"));
+        strLstAdd(argList, strNew("--command=backup"));
+        strLstAdd(argList, strNewFmt("--log-path=%s", testPath()));
+        strLstAdd(argList, strNew("--type=backup"));
+        strLstAdd(argList, strNew("--log-level-file=warn"));
+        strLstAdd(argList, strNew("--process=0"));
+        strLstAdd(argList, strNew("remote"));
+
+        TEST_RESULT_VOID(cfgLoad(strLstSize(argList), strLstPtr(argList)), "open log file");
+        TEST_RESULT_INT(
+            lstat(strPtr(strNewFmt("%s/all-backup-remote-000.log", testPath())), &statLog), 0, "   check log file exists");
     }
 
     FUNCTION_HARNESS_RESULT_VOID();
