@@ -2,6 +2,7 @@
 Test Help Command
 ***********************************************************************************************************************************/
 #include "config/parse.h"
+#include "storage/driver/posix/storage.h"
 #include "storage/storage.h"
 #include "version.h"
 
@@ -9,12 +10,12 @@ Test Help Command
 Test Run
 ***********************************************************************************************************************************/
 void
-testRun()
+testRun(void)
 {
     FUNCTION_HARNESS_VOID();
 
     // Program name a version are used multiple times
-    const char *helpVersion = PGBACKREST_NAME " " PGBACKREST_VERSION;
+    const char *helpVersion = PROJECT_NAME " " PROJECT_VERSION;
 
     // General help text is used in more than one test
     const char *generalHelp = strPtr(strNewFmt(
@@ -84,13 +85,13 @@ testRun()
         // -------------------------------------------------------------------------------------------------------------------------
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
-        TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList)), "help from empty command line");
+        TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList), false), "help from empty command line");
         TEST_RESULT_STR(strPtr(helpRender()), generalHelp, "    check text");
 
         argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
         strLstAddZ(argList, "help");
-        TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList)), "help from help command");
+        TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList), false), "help from help command");
         TEST_RESULT_STR(strPtr(helpRender()), generalHelp, "    check text");
 
         // -------------------------------------------------------------------------------------------------------------------------
@@ -107,7 +108,7 @@ testRun()
         strLstAddZ(argList, "/path/to/pgbackrest");
         strLstAddZ(argList, "help");
         strLstAddZ(argList, "version");
-        TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList)), "help for version command");
+        TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList), false), "help for version command");
         TEST_RESULT_STR(strPtr(helpRender()), commandHelp, "    check text");
 
         // This test is broken up into multiple strings because C99 does not require compilers to support const strings > 4095 bytes
@@ -126,7 +127,6 @@ testRun()
             "\n"
             "  --db-include                     restore only specified databases\n"
             "                                   [current=db1, db2]\n"
-            "  --delta                          restore using delta [default=n]\n"
             "  --force                          force a restore [default=n]\n"
             "  --link-all                       restore all symlinks [default=n]\n"
             "  --link-map                       modify the destination of a symlink\n"
@@ -161,6 +161,7 @@ testRun()
             "                                   files [default=/etc/pgbackrest/conf.d]\n"
             "  --config-path                    base path of pgBackRest configuration files\n"
             "                                   [default=/etc/pgbackrest]\n"
+            "  --delta                          restore or backup using checksums [default=n]\n"
             "  --lock-path                      path where lock files are stored\n"
             "                                   [default=/tmp/pgbackrest]\n"
             "  --neutral-umask                  use a neutral umask [default=y]\n"
@@ -176,6 +177,7 @@ testRun()
             "  --log-level-stderr               level for stderr logging [default=warn]\n"
             "  --log-path                       path where log files are stored\n"
             "                                   [default=/var/log/pgbackrest]\n"
+            "  --log-subprocess                 enable logging in subprocesses [default=n]\n"
             "  --log-timestamp                  enable timestamp in logging [default=y]\n"
             "\n",
             "Repository Options:\n"
@@ -227,7 +229,7 @@ testRun()
         strLstAddZ(argList, "--link-map=/link2=/dest2");
         strLstAddZ(argList, "--db-include=db1");
         strLstAddZ(argList, "--db-include=db2");
-        TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList)), "help for restore command");
+        TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList), false), "help for restore command");
         TEST_RESULT_STR(strPtr(helpRender()), commandHelp, "    check text");
 
         // -------------------------------------------------------------------------------------------------------------------------
@@ -237,7 +239,7 @@ testRun()
         strLstAddZ(argList, "archive-push");
         strLstAddZ(argList, "buffer-size");
         strLstAddZ(argList, "buffer-size");
-        TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList)), "parse too many options");
+        TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList), false), "parse too many options");
         TEST_ERROR(helpRender(), ParamInvalidError, "only one option allowed for option help");
 
         argList = strLstNew();
@@ -245,7 +247,7 @@ testRun()
         strLstAddZ(argList, "help");
         strLstAddZ(argList, "archive-push");
         strLstAddZ(argList, BOGUS_STR);
-        TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList)), "parse bogus option");
+        TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList), false), "parse bogus option");
         TEST_ERROR(helpRender(), OptionInvalidError, "option 'BOGUS' is not valid for command 'archive-push'");
 
         // -------------------------------------------------------------------------------------------------------------------------
@@ -259,7 +261,11 @@ testRun()
             "maximum of 256K per process may be used for zlib buffers.\n"
             "\n"
             "Size can be entered in bytes (default) or KB, MB, GB, TB, or PB where the\n"
-            "multiplier is a power of 1024.\n",
+            "multiplier is a power of 1024. For example, the case-insensitive value 32k (or\n"
+            "32KB) can be used instead of 32768.\n"
+            "\n"
+            "Allowed values, in bytes, are 16384, 32768, 65536, 131072, 262144, 524288,\n"
+            "1048576, 2097152, 4194304, 8388608, and 16777216.\n",
             helpVersion));
 
         argList = strLstNew();
@@ -267,11 +273,13 @@ testRun()
         strLstAddZ(argList, "help");
         strLstAddZ(argList, "archive-push");
         strLstAddZ(argList, "buffer-size");
-        TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList)), "help for archive-push command, buffer-size option");
+        TEST_RESULT_VOID(
+            configParse(strLstSize(argList), strLstPtr(argList), false), "help for archive-push command, buffer-size option");
         TEST_RESULT_STR(strPtr(helpRender()), strPtr(strNewFmt("%s\ndefault: 4194304\n", optionHelp)), "    check text");
 
         strLstAddZ(argList, "--buffer-size=32768");
-        TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList)), "help for archive-push command, buffer-size option");
+        TEST_RESULT_VOID(
+            configParse(strLstSize(argList), strLstPtr(argList), false), "help for archive-push command, buffer-size option");
         TEST_RESULT_STR(
             strPtr(helpRender()), strPtr(strNewFmt("%s\ncurrent: 32768\ndefault: 4194304\n", optionHelp)), "    check text");
 
@@ -290,13 +298,13 @@ testRun()
         strLstAddZ(argList, "archive-push");
         strLstAddZ(argList, "repo1-s3-host");
         TEST_RESULT_VOID(
-            configParse(strLstSize(argList), strLstPtr(argList)), "help for archive-push command, repo1-s3-host option");
+            configParse(strLstSize(argList), strLstPtr(argList), false), "help for archive-push command, repo1-s3-host option");
         TEST_RESULT_STR(strPtr(helpRender()), optionHelp, "    check text");
 
         strLstAddZ(argList, "--repo1-type=s3");
         strLstAddZ(argList, "--repo1-s3-host=s3-host");
         TEST_RESULT_VOID(
-            configParse(strLstSize(argList), strLstPtr(argList)), "help for archive-push command, repo1-s3-host option");
+            configParse(strLstSize(argList), strLstPtr(argList), false), "help for archive-push command, repo1-s3-host option");
         TEST_RESULT_STR(
             strPtr(helpRender()), strPtr(strNewFmt("%s\ncurrent: s3-host\n", optionHelp)), "    check text");
 
@@ -321,8 +329,42 @@ testRun()
         strLstAddZ(argList, "help");
         strLstAddZ(argList, "backup");
         strLstAddZ(argList, "repo-hardlink");
-        TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList)), "help for backup command, repo-hardlink option");
+        TEST_RESULT_VOID(
+            configParse(strLstSize(argList), strLstPtr(argList), false), "help for backup command, repo-hardlink option");
         TEST_RESULT_STR(strPtr(helpRender()), optionHelp, "    check text");
+
+        // Check admonition
+        // -------------------------------------------------------------------------------------------------------------------------
+        optionHelp = strPtr(strNewFmt(
+            "%s - 'backup' command - 'repo-retention-archive' option help\n"
+            "\n"
+            "Number of backups worth of continuous WAL to retain.\n"
+            "\n"
+            "NOTE: WAL segments required to make a backup consistent are always retained\n"
+            "until the backup is expired regardless of how this option is configured.\n"
+            "\n"
+            "If this value is not set, then the archive to expire will default to the\n"
+            "repo-retention-full (or repo-retention-diff) value corresponding to the\n"
+            "repo-retention-archive-type if set to full (or diff). This will ensure that WAL\n"
+            "is only expired for backups that are already expired.\n"
+            "\n"
+            "This option must be set if repo-retention-archive-type is set to incr. If disk\n"
+            "space is at a premium, then this setting, in conjunction with\n"
+            "repo-retention-archive-type, can be used to aggressively expire WAL segments.\n"
+            "However, doing so negates the ability to perform PITR from the backups with\n"
+            "expired WAL and is therefore not recommended.\n"
+            "\n"
+            "deprecated name: retention-archive\n",
+            helpVersion));
+
+        argList = strLstNew();
+        strLstAddZ(argList, "/path/to/pgbackrest");
+        strLstAddZ(argList, "help");
+        strLstAddZ(argList, "backup");
+        strLstAddZ(argList, "repo-retention-archive");
+        TEST_RESULT_VOID(
+            configParse(strLstSize(argList), strLstPtr(argList), false), "help for backup command, repo-retention-archive option");
+        TEST_RESULT_STR(strPtr(helpRender()), optionHelp, "    check admonition text");
     }
 
     // *****************************************************************************************************************************
@@ -330,7 +372,7 @@ testRun()
     {
         StringList *argList = strLstNew();
         strLstAddZ(argList, "/path/to/pgbackrest");
-        TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList)), "parse help from empty command line");
+        TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList), false), "parse help from empty command line");
 
         // Redirect stdout to a file
         int stdoutSave = dup(STDOUT_FILENO);
@@ -345,7 +387,8 @@ testRun()
         // Restore normal stdout
         dup2(stdoutSave, STDOUT_FILENO);
 
-        Storage *storage = storageNewNP(strNew(testPath()));
+        Storage *storage = storageDriverPosixInterface(
+            storageDriverPosixNew(strNew(testPath()), STORAGE_MODE_FILE_DEFAULT, STORAGE_MODE_PATH_DEFAULT, false, NULL));
         TEST_RESULT_STR(strPtr(strNewBuf(storageGetNP(storageNewReadNP(storage, stdoutFile)))), generalHelp, "    check text");
     }
 
