@@ -7,11 +7,11 @@ Test Perl Exec
 Test Run
 ***********************************************************************************************************************************/
 void
-testRun()
+testRun(void)
 {
     FUNCTION_HARNESS_VOID();
 
-    // -----------------------------------------------------------------------------------------------------------------------------
+    // *****************************************************************************************************************************
     if (testBegin("perlOptionJson()"))
     {
         cfgInit();
@@ -76,7 +76,7 @@ testRun()
         cfgOptionSet(cfgOptDbInclude, cfgSourceParam, varNewVarLst(varLstNewStrLst(includeList)));
 
         cfgOptionValidSet(cfgOptRecoveryOption, true);
-        // !!! WHY DO WE STILL NEED TO CREATE THE VAR KV EMPTY?
+
         Variant *recoveryVar = varNewKv();
         KeyValue *recoveryKv = varKv(recoveryVar);
         kvPut(recoveryKv, varNewStr(strNew("standby_mode")), varNewStr(strNew("on")));
