@@ -8,11 +8,11 @@ Test Perl Exec
 Test Run
 ***********************************************************************************************************************************/
 void
-testRun()
+testRun(void)
 {
     FUNCTION_HARNESS_VOID();
 
-    // -----------------------------------------------------------------------------------------------------------------------------
+    // *****************************************************************************************************************************
     if (testBegin("perlMain()"))
     {
         // -------------------------------------------------------------------------------------------------------------------------
@@ -20,7 +20,8 @@ testRun()
         cfgCommandSet(cfgCmdInfo);
         cfgExeSet(strNew("/path/to/pgbackrest"));
 
-        TEST_RESULT_STR(strPtr(perlMain()), "($result, $message) = pgBackRest::Main::main('info')", "command with no options");
+        TEST_RESULT_STR(
+            strPtr(perlMain()), "($iResult, $bErrorC, $strMessage) = pgBackRest::Main::main('info')", "command with no options");
 
         // -------------------------------------------------------------------------------------------------------------------------
         cfgOptionValidSet(cfgOptCompress, true);
@@ -32,11 +33,11 @@ testRun()
         cfgCommandParamSet(commandParamList);
 
         TEST_RESULT_STR(
-            strPtr(perlMain()), "($result, $message) = pgBackRest::Main::main('info','A','B')",
+            strPtr(perlMain()), "($iResult, $bErrorC, $strMessage) = pgBackRest::Main::main('info','A','B')",
             "command with one option and params");
     }
 
-    // -----------------------------------------------------------------------------------------------------------------------------
+    // *****************************************************************************************************************************
     if (testBegin("perlInit(), perlExec(), and perlFree()"))
     {
         StringList *argList = strLstNew();
@@ -44,6 +45,7 @@ testRun()
         strLstAdd(argList, strNew("--stanza=db"));
         strLstAdd(argList, strNew("--log-level-console=off"));
         strLstAdd(argList, strNew("--log-level-stderr=off"));
+        strLstAdd(argList, strNew("--log-level-file=off"));
         strLstAdd(argList, strNew("archive-push"));
 
         TEST_RESULT_VOID(cfgLoad(strLstSize(argList), strLstPtr(argList)), "load archive-push config");
