@@ -3,6 +3,20 @@ C Test Wrapper
 
 This wrapper runs the the C unit tests.
 ***********************************************************************************************************************************/
+
+/***********************************************************************************************************************************
+C files to be tested
+
+The files are included directly so the test can see and manipulate variables and functions in the module without the need to extern.
+If a .c file does not exist for a module then the header file will be included instead.  They are included first so they won't see
+the includes which are required for the test code.
+***********************************************************************************************************************************/
+{[C_INCLUDE]}
+
+/***********************************************************************************************************************************
+The test code is included directly so it can freely interact with the included C files
+***********************************************************************************************************************************/
+#include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -17,24 +31,14 @@ This wrapper runs the the C unit tests.
 #include "common/harnessTest.h"
 
 #ifndef NO_LOG
-    #include "common/logTest.h"
+    #include "common/harnessLog.h"
+    void harnessLogLevelDefaultSet(LogLevel logLevel);
 #endif
 
 #ifndef NO_MEM_CONTEXT
     #include "common/memContext.h"
 #endif
 
-/***********************************************************************************************************************************
-C files to be tested
-
-The files are included directly so the test can see and manipulate variables and functions in the module without the need to extern.
-If a .c file does not exist for a module then the header file will be included instead.
-***********************************************************************************************************************************/
-{[C_INCLUDE]}
-
-/***********************************************************************************************************************************
-The test code is included directly so it can freely interact with the included C files
-***********************************************************************************************************************************/
 {[C_TEST_INCLUDE]}
 
 /***********************************************************************************************************************************
@@ -69,9 +73,19 @@ main(int argListSize, const char *argList[])
     // Set neutral umask for testing
     umask(0000);
 
+    // Ignore SIGPIPE and check for EPIPE errors on write() instead
+    signal(SIGPIPE, SIG_IGN);
+
     // Set globals
     testExeSet(argList[0]);
     testPathSet("{[C_TEST_PATH]}");
+    testRepoPathSet("{[C_TEST_REPO_PATH]}");
+    testExpectPathSet("{[C_TEST_EXPECT_PATH]}");
+
+    // Set default test log level
+#ifndef NO_LOG
+    harnessLogLevelDefaultSet({[C_LOG_LEVEL_TEST]});
+#endif
 
     // Initialize tests
     //      run, selected
