@@ -28,11 +28,9 @@ use lib dirname(dirname($0)) . '/build/lib';
 use lib dirname(dirname($0)) . '/doc/lib';
 
 use pgBackRest::Common::Exception;
-use pgBackRest::Common::Ini;
 use pgBackRest::Common::Log;
 use pgBackRest::Common::String;
 use pgBackRest::Common::Wait;
-use pgBackRest::DbVersion;
 use pgBackRest::Storage::Posix::Driver;
 use pgBackRest::Storage::Local;
 use pgBackRest::Version;
@@ -49,6 +47,7 @@ use pgBackRestBuild::Error::Data;
 use pgBackRestTest::Common::BuildTest;
 use pgBackRestTest::Common::CodeCountTest;
 use pgBackRestTest::Common::ContainerTest;
+use pgBackRestTest::Common::CoverageTest;
 use pgBackRestTest::Common::CiTest;
 use pgBackRestTest::Common::DefineTest;
 use pgBackRestTest::Common::ExecuteTest;
@@ -101,7 +100,8 @@ test.pl [options]
  Configuration Options:
    --psql-bin           path to the psql executables (e.g. /usr/lib/postgresql/9.3/bin/)
    --test-path          path where tests are executed (defaults to ./test)
-   --log-level          log level to use for tests (defaults to INFO)
+   --log-level          log level to use for test harness (and Perl tests) (defaults to INFO)
+   --log-level-test     log level to use for C tests (defaults to OFF)
    --quiet, -q          equivalent to --log-level=off
 
  VM Options:
@@ -120,6 +120,7 @@ test.pl [options]
 # Command line parameters
 ####################################################################################################################################
 my $strLogLevel = lc(INFO);
+my $strLogLevelTest = lc(OFF);
 my $bVmOut = false;
 my @stryModule;
 my @stryModuleTest;
@@ -166,6 +167,7 @@ GetOptions ('q|quiet' => \$bQuiet,
             'pgsql-bin=s' => \$strPgSqlBin,
             'test-path=s' => \$strTestPath,
             'log-level=s' => \$strLogLevel,
+            'log-level-test=s' => \$strLogLevelTest,
             'vm=s' => \$strVm,
             'vm-host=s' => \$strVmHost,
             'vm-out' => \$bVmOut,
@@ -213,7 +215,7 @@ eval
     # Display version and exit if requested
     if ($bVersion || $bHelp)
     {
-        syswrite(*STDOUT, BACKREST_NAME . ' ' . BACKREST_VERSION . " Test Engine\n");
+        syswrite(*STDOUT, PROJECT_NAME . ' ' . PROJECT_VERSION . " Test Engine\n");
 
         if ($bHelp)
         {
@@ -318,7 +320,7 @@ eval
         {
             confess &log(ERROR, "select a single Debian-based VM for coverage testing");
         }
-        elsif (!vmCoverage($strVm))
+        elsif (!vmCoveragePerl($strVm))
         {
             confess &log(ERROR, "only Debian-based VMs can be used for coverage testing");
         }
@@ -355,7 +357,51 @@ eval
     ################################################################################################################################
     if (!defined($iVmId))
     {
+        # Make a copy of the repo to track which files have been changed.  Eventually all builds will be done from this directory.
+        #---------------------------------------------------------------------------------------------------------------------------
+        my $strRepoCachePath = "${strTestPath}/repo";
+        my $strRepoCacheManifest = 'repo.manifest';
+
+        # Create the repo path -- this should hopefully prevent obvious rsync errors below
+        $oStorageTest->pathCreate("${strTestPath}/repo", {strMode => '0770', bIgnoreExists => true, bCreateParent => true});
+
+        # Check if there are any files existing already.  If none, that means a full copy is happening and we shouldn't report
+        # modified files
+        my @stryExistingList = $oStorageTest->list($strRepoCachePath, {bIgnoreMissing => true});
+
+        # First check if there is an old manifest that has not been cleared.  This indicates that an error happened before all new
+        # files could be processed, which means they should be processed again.
+        my @stryModifiedList;
+        my $rstrModifiedList = $oStorageTest->get(
+            $oStorageTest->openRead("${strRepoCachePath}/${strRepoCacheManifest}", {bIgnoreMissing => true}));
+
+        if (defined($rstrModifiedList))
+        {
+            @stryModifiedList = split("\n", trim($$rstrModifiedList));
+        }
+
+        push(
+            @stryModifiedList,
+            split(
+                "\n",
+                trim(
+                    executeTest(
+                        "git -C ${strBackRestBase} ls-files -c --others --exclude-standard |" .
+                            " rsync -rtW --out-format=\"\%n\" --delete --ignore-missing-args --exclude=repo.manifest" .
+                            " ${strBackRestBase}/ --files-from=- ${strRepoCachePath}"))));
+
+        if (@stryModifiedList > 0)
+        {
+            $oStorageTest->put("${strRepoCachePath}/${strRepoCacheManifest}", join("\n", @stryModifiedList));
+
+            if (@stryExistingList > 0)
+            {
+                &log(INFO, "modified since last run: " . join(', ', @stryModifiedList));
+            }
+        }
+
         # Generate code counts
+        #---------------------------------------------------------------------------------------------------------------------------
         if ($bCodeCount)
         {
             &log(INFO, "classify code files");
@@ -368,15 +414,13 @@ eval
         #---------------------------------------------------------------------------------------------------------------------------
         if (!$bNoGen)
         {
+            my @stryBuiltAll;
             &log(INFO, "check code autogenerate");
 
             # Auto-generate C files
             #-----------------------------------------------------------------------------------------------------------------------
-            if (!$bSmart || buildLastModTime($oStorageBackRest, "${strBackRestBase}", ['build']) >
-                buildLastModTime($oStorageBackRest, "${strBackRestBase}", ['src'], '\.auto\.c$'))
+            if (!$bSmart || grep(/^build\//, @stryModifiedList))
             {
-                &log(INFO, "    autogenerate C code");
-
                 errorDefineLoad(${$oStorageBackRest->get("build/error.yaml")});
 
                 my $rhBuild =
@@ -406,7 +450,14 @@ eval
                     },
                 };
 
-                buildAll("${strBackRestBase}/src", $rhBuild);
+                my @stryBuilt = buildAll("${strBackRestBase}/src", $rhBuild);
+                &log(INFO, "    autogenerated C code: " . (@stryBuilt ? join(', ', @stryBuilt) : 'no changes'));
+
+                if (@stryBuilt)
+                {
+                    push(@stryBuiltAll, @stryBuilt);
+                    push(@stryModifiedList, @stryBuilt);
+                }
             }
 
             # Auto-generate Perl code
@@ -414,23 +465,24 @@ eval
             use lib dirname(dirname($0)) . '/libc/build/lib';
             use pgBackRestLibC::Build;                                      ## no critic (Modules::ProhibitConditionalUseStatements)
 
-            if (!$bSmart || buildLastModTime($oStorageBackRest, "${strBackRestBase}", ['build', 'libc/build']) >
-                buildLastModTime($oStorageBackRest, "${strBackRestBase}", ['lib'], 'Auto\.pm$'))
+            if (!$bSmart || grep(/^(build|libc\/build)\//, @stryModifiedList))
             {
-                &log(INFO, "    autogenerate Perl code");
-
                 errorDefineLoad(${$oStorageBackRest->get("build/error.yaml")});
 
-                buildXsAll("${strBackRestBase}/libc");
+                my @stryBuilt = buildXsAll("${strBackRestBase}/libc");
+                &log(INFO, "    autogenerated Perl code: " . (@stryBuilt ? join(', ', @stryBuilt) : 'no changes'));
+
+                if (@stryBuilt)
+                {
+                    push(@stryBuiltAll, @stryBuilt);
+                    push(@stryModifiedList, @stryBuilt);
+                }
             }
 
             # Auto-generate C library code to embed in the binary
             #-----------------------------------------------------------------------------------------------------------------------
-            if (!$bSmart || buildLastModTime($oStorageBackRest, "${strBackRestBase}", ['libc']) >
-                buildLastModTime($oStorageBackRest, "${strBackRestBase}", ['src/perl'], '^libc\.auto\.c$'))
+            if (!$bSmart || grep(/^libc\//, @stryModifiedList))
             {
-                &log(INFO, "    autogenerate embedded C code");
-
                 my $strLibC = executeTest(
                     "cd ${strBackRestBase}/libc && " .
                     "perl /usr/share/perl/5.26/ExtUtils/xsubpp -typemap /usr/share/perl/5.26/ExtUtils/typemap" .
@@ -444,16 +496,23 @@ eval
                 $strLibC =~ s/^\#line .*\n//mg;
 
                 # Save into the bin src dir
-                $oStorageBackRest->put("${strBackRestBase}/src/perl/libc.auto.c", $strLibC);
+                my @stryBuilt;
+                my $strBuilt = 'src/perl/libc.auto.c';
+
+                if (buildPutDiffers($oStorageBackRest, "${strBackRestBase}/${strBuilt}", $strLibC))
+                {
+                    push(@stryBuilt, $strBuilt);
+                    push(@stryBuiltAll, @stryBuilt);
+                    push(@stryModifiedList, @stryBuilt);
+                }
+
+                &log(INFO, "    autogenerated embedded C code: " . (@stryBuilt ? join(', ', @stryBuilt) : 'no changes'));
             }
 
             # Auto-generate embedded Perl code
             #-----------------------------------------------------------------------------------------------------------------------
-            if (!$bSmart || buildLastModTime($oStorageBackRest, "${strBackRestBase}", ['lib']) >
-                buildLastModTime($oStorageBackRest, "${strBackRestBase}", ['src/perl'], 'embed\.auto\.c'))
+            if (!$bSmart || grep(/^lib\//, @stryModifiedList))
             {
-                &log(INFO, "    autogenerate embedded Perl code");
-
                 my $rhBuild =
                 {
                     'embed' =>
@@ -463,22 +522,44 @@ eval
                     },
                 };
 
-                buildAll("${strBackRestBase}/src", $rhBuild);
+                my @stryBuilt = buildAll("${strBackRestBase}/src", $rhBuild);
+                &log(INFO, "    autogenerated embedded Perl code: " . (@stryBuilt ? join(', ', @stryBuilt) : 'no changes'));
+
+                if (@stryBuilt)
+                {
+                    push(@stryBuiltAll, @stryBuilt);
+                    push(@stryModifiedList, @stryBuilt);
+                }
             }
 
             # Auto-generate C Makefile
             #-----------------------------------------------------------------------------------------------------------------------
-            if (!$bSmart || buildLastModTime($oStorageBackRest, "${strBackRestBase}", ['libc', 'src']) >
-                buildLastModTime($oStorageBackRest, "${strBackRestBase}", ['src'], 'Makefile'))
+            if (!$bSmart || grep(/^(src|libc)\//, @stryModifiedList))
             {
-                &log(INFO, "    autogenerate C Makefile");
+                my @stryBuilt;
+                my $strBuilt = 'src/Makefile';
 
-                $oStorageBackRest->put(
-                    "src/Makefile",
+                if (buildPutDiffers(
+                    $oStorageBackRest,
+                    $strBuilt,
                     buildMakefile(
                         $oStorageBackRest,
                         ${$oStorageBackRest->get("src/Makefile")},
-                        {rhOption => {'postgres/pageChecksum.o' => '-funroll-loops -ftree-vectorize'}}));
+                        {rhOption => {'postgres/pageChecksum.o' => '-funroll-loops -ftree-vectorize'}})))
+                {
+                    push(@stryBuilt, $strBuilt);
+                    push(@stryBuiltAll, @stryBuilt);
+                    push(@stryModifiedList, @stryBuilt);
+                }
+
+                &log(INFO, "    autogenerated C Makefile: " . (@stryBuilt ? join(', ', @stryBuilt) : 'no changes'));
+            }
+
+            # Copy all the files that were auto-generate so they won't show as modified in the next run
+            #-----------------------------------------------------------------------------------------------------------------------
+            foreach my $strBuilt (@stryBuiltAll)
+            {
+                executeTest("cp -p ${strBackRestBase}/${strBuilt} ${strRepoCachePath}/${strBuilt}");
             }
 
             if ($bGenOnly)
@@ -523,14 +604,14 @@ eval
                 $bVersionDev = true;
                 $strVersionBase = substr($strVersion, 0, length($strVersion) - 3);
 
-                if (BACKREST_VERSION !~ /dev$/ && $oRelease->nodeTest('release-core-list'))
+                if (PROJECT_VERSION !~ /dev$/ && $oRelease->nodeTest('release-core-list'))
                 {
                     confess "dev release ${strVersion} must match the program version when core changes have been made";
                 }
             }
-            elsif ($strVersion ne BACKREST_VERSION)
+            elsif ($strVersion ne PROJECT_VERSION)
             {
-                confess 'unable to find version ' . BACKREST_VERSION . " as the most recent release in ${strReleaseFile}";
+                confess 'unable to find version ' . PROJECT_VERSION . " as the most recent release in ${strReleaseFile}";
             }
 
             # Update version for the C code based on the current Perl version
@@ -541,9 +622,9 @@ eval
 
             foreach my $strLine (split("\n", $strCVersionOld))
             {
-                if ($strLine =~ /^#define PGBACKREST_VERSION/)
+                if ($strLine =~ /^#define PROJECT_VERSION/)
                 {
-                    $strLine = '#define PGBACKREST_VERSION' . (' ' x 42) . '"' . BACKREST_VERSION . '"';
+                    $strLine = '#define PROJECT_VERSION' . (' ' x 45) . '"' . PROJECT_VERSION . '"';
                 }
 
                 $strCVersionNew .= "${strLine}\n";
@@ -573,23 +654,27 @@ eval
                 push(@{$oyProcess}, undef);
             }
 
-            executeTest("sudo umount ${strTestPath}", {bSuppressError => true});
-            executeTest("sudo rm -rf ${strTestPath}/*");
-            $oStorageTest->pathCreate($strTestPath, {strMode => '0770', bIgnoreExists => true});
-            executeTest("sudo mount -t tmpfs -o size=2560M test ${strTestPath}");
-            $oStorageTest->pathCreate($strCoveragePath, {strMode => '0770', bIgnoreMissing => true, bCreateParent => true});
+            executeTest(
+                "sudo rm -rf ${strTestPath}/cover_db ${strTestPath}/test-* ${strTestPath}/expect-*" .
+                ($bDev ? '' : " ${strTestPath}/gcov-*"));
+            $oStorageTest->pathCreate($strCoveragePath, {strMode => '0770', bIgnoreExists => true, bCreateParent => true});
 
             # Remove old coverage dirs -- do it this way so the dirs stay open in finder/explorer, etc.
-            executeTest("rm -rf ${strBackRestBase}/test/coverage/c/*");
-            executeTest("rm -rf ${strBackRestBase}/test/coverage/perl/*");
+            executeTest("rm -rf ${strBackRestBase}/test/coverage/c/* ${strBackRestBase}/test/coverage/perl/*");
+
+            # Overwrite the C coverage report so it will load but not show old coverage
+            $oStorageTest->pathCreate("${strBackRestBase}/test/coverage", {strMode => '0770', bIgnoreExists => true});
+            $oStorageBackRest->put(
+                "${strBackRestBase}/test/coverage/c-coverage.html", "<center>[ Generating New Report ]</center>");
 
             # Copy C code for coverage tests
-            if (vmCoverage($strVm) && !$bDryRun)
+            if (vmCoverageC($strVm) && !$bDryRun)
             {
                 $oStorageTest->pathCreate("${strCodePath}/test", {strMode => '0770', bIgnoreExists => true, bCreateParent => true});
 
-                executeTest("rsync -rt --delete --exclude=test ${strBackRestBase}/src/ ${strCodePath}");
-                executeTest("rsync -rt --delete ${strBackRestBase}/test/src/module/ ${strCodePath}/test");
+                executeTest(
+                    "rsync -rt --delete --exclude=test ${strBackRestBase}/src/ ${strCodePath} && " .
+                    "rsync -rt --delete ${strBackRestBase}/test/src/module/ ${strCodePath}/test");
             }
         }
 
@@ -718,7 +803,7 @@ eval
                             " --include=" . join('/*** --include=', @stryBinSrcPath) . '/*** --exclude=*' .
                             " ${strBackRestBase}/ ${strBinPath}/${strBuildVM}");
 
-                        if (vmCoverage($strVm) && !$bNoLint)
+                        if (vmLintC($strVm) && !$bNoLint)
                         {
                             &log(INFO, "    clang static analyzer ${strBuildVM} (${strBuildPath})");
                         }
@@ -731,7 +816,7 @@ eval
 
                         executeTest(
                             'docker exec -i test-build' .
-                            (vmCoverage($strVm) && !$bNoLint ? ' scan-build-6.0' : '') .
+                            (vmLintC($strVm) && !$bNoLint ? ' scan-build-6.0' : '') .
                             " make --silent --directory ${strBuildPath} CEXTRA=${strCExtra} LDEXTRA=${strLdExtra} ${strCDebug}",
                             {bShowOutputAsync => $bLogDetail});
 
@@ -827,7 +912,7 @@ eval
 
                             executeTest(
                                 ($bContainerExists ? "docker exec -i test-build bash -c '" : '') .
-                                "cd ${strBuildPath} && perl Makefile.PL INSTALLMAN1DIR=none INSTALLMAN3DIR=none" .
+                                "cd ${strBuildPath} && perl ${strBuildPath}/Makefile.PL INSTALLMAN1DIR=none INSTALLMAN3DIR=none" .
                                 ($bContainerExists ? "'" : ''),
                                 {bSuppressStdErr => true, bShowOutputAsync => $bLogDetail});
                         }
@@ -1035,6 +1120,10 @@ eval
             exit 0 if $bBuildOnly;
         }
 
+        # Remove repo.manifest now that all processing that depends on modified files has been completed
+        #---------------------------------------------------------------------------------------------------------------------------
+        $oStorageTest->remove("${strRepoCachePath}/${strRepoCacheManifest}");
+
         # Perform static source code analysis
         #---------------------------------------------------------------------------------------------------------------------------
         if (!$bDryRun)
@@ -1136,7 +1225,7 @@ eval
                 {
                     my $oJob = new pgBackRestTest::Common::JobTest(
                         $oStorageTest, $strBackRestBase, $strTestPath, $strCoveragePath, $$oyTestRun[$iTestIdx], $bDryRun, $bVmOut,
-                        $iVmIdx, $iVmMax, $iTestIdx, $iTestMax, $strLogLevel, $bLogForce, $bShowOutputAsync, $bNoCleanup, $iRetry,
+                        $iVmIdx, $iVmMax, $iTestIdx, $iTestMax, $strLogLevel, $strLogLevelTest, $bLogForce, $bShowOutputAsync, $bNoCleanup, $iRetry,
                         !$bNoValgrind, !$bNoCoverage, !$bNoOptimize, $bBackTrace, $bProfile, !$bNoDebug);
                     $iTestIdx++;
 
@@ -1155,83 +1244,86 @@ eval
         #---------------------------------------------------------------------------------------------------------------------------
         my $iUncoveredCodeModuleTotal = 0;
 
-        if (vmCoverage($strVm) && !$bNoCoverage && !$bDryRun)
+        if ((vmCoverageC($strVm) || vmCoveragePerl($strVm)) && !$bNoCoverage && !$bDryRun && $iTestFail == 0)
         {
-            &log(INFO, 'writing coverage report');
-            executeTest("cp -rp ${strCoveragePath} ${strCoveragePath}_temp");
-            executeTest(
-                "cd ${strCoveragePath}_temp && " .
-                LIB_COVER_EXE . " -report json -outputdir ${strBackRestBase}/test/coverage/perl ${strCoveragePath}_temp",
-                {bSuppressStdErr => true});
-            executeTest("sudo rm -rf ${strCoveragePath}_temp");
-            executeTest("sudo cp -rp ${strCoveragePath} ${strCoveragePath}_temp");
-            executeTest(
-                "cd ${strCoveragePath}_temp && " .
-                LIB_COVER_EXE . " -outputdir ${strBackRestBase}/test/coverage/perl ${strCoveragePath}_temp",
-                {bSuppressStdErr => true});
-            executeTest("sudo rm -rf ${strCoveragePath}_temp");
-
             # Determine which modules were covered (only check coverage if all tests were successful)
             #-----------------------------------------------------------------------------------------------------------------------
-            if ($iTestFail == 0)
+            my $hModuleTest;                                        # Everything that was run
+
+            # Build a hash of all modules, tests, and runs that were executed
+            foreach my $hTestRun (@{$oyTestRun})
             {
-                my $hModuleTest;                                        # Everything that was run
+                # Get coverage for the module
+                my $strModule = $hTestRun->{&TEST_MODULE};
+                my $hModule = testDefModule($strModule);
 
-                # Build a hash of all modules, tests, and runs that were executed
-                foreach my $hTestRun (@{$oyTestRun})
+                # Get coverage for the test
+                my $strTest = $hTestRun->{&TEST_NAME};
+                my $hTest = testDefModuleTest($strModule, $strTest);
+
+                # If no tests are listed it means all of them were run
+                if (@{$hTestRun->{&TEST_RUN}} == 0)
                 {
-                    # Get coverage for the module
-                    my $strModule = $hTestRun->{&TEST_MODULE};
-                    my $hModule = testDefModule($strModule);
+                    $hModuleTest->{$strModule}{$strTest} = true;
+                }
+            }
 
-                    # Get coverage for the test
-                    my $strTest = $hTestRun->{&TEST_NAME};
-                    my $hTest = testDefModuleTest($strModule, $strTest);
+            # Now compare against code modules that should have full coverage
+            my $hCoverageList = testDefCoverageList();
+            my $hCoverageType = testDefCoverageType();
+            my $hCoverageActual;
 
-                    # If no tests are listed it means all of them were run
-                    if (@{$hTestRun->{&TEST_RUN}} == 0)
+            foreach my $strCodeModule (sort(keys(%{$hCoverageList})))
+            {
+                if (@{$hCoverageList->{$strCodeModule}} > 0)
+                {
+                    my $iCoverageTotal = 0;
+
+                    foreach my $hTest (@{$hCoverageList->{$strCodeModule}})
                     {
-                        $hModuleTest->{$strModule}{$strTest} = true;
+                        if (!defined($hModuleTest->{$hTest->{strModule}}{$hTest->{strTest}}))
+                        {
+                            next;
+                        }
+
+                        $iCoverageTotal++;
+                    }
+
+                    if (@{$hCoverageList->{$strCodeModule}} == $iCoverageTotal)
+                    {
+                        $hCoverageActual->{testRunName($strCodeModule, false)} = $hCoverageType->{$strCodeModule};
                     }
                 }
+            }
+
+            if (keys(%{$hCoverageActual}) == 0)
+            {
+                &log(INFO, 'no code modules had all tests run required for coverage');
+            }
+
+            # Generate Perl coverage report
+            #-----------------------------------------------------------------------------------------------------------------------
+            if (vmCoveragePerl($strVm))
+            {
+                &log(INFO, 'writing Perl coverage report');
+
+                executeTest("cp -rp ${strCoveragePath} ${strCoveragePath}_temp");
+                executeTest(
+                    "cd ${strCoveragePath}_temp && " .
+                    LIB_COVER_EXE . " -report json -outputdir ${strBackRestBase}/test/coverage/perl ${strCoveragePath}_temp",
+                    {bSuppressStdErr => true});
+                executeTest("sudo rm -rf ${strCoveragePath}_temp");
+                executeTest("sudo cp -rp ${strCoveragePath} ${strCoveragePath}_temp");
+                executeTest(
+                    "cd ${strCoveragePath}_temp && " .
+                    LIB_COVER_EXE . " -outputdir ${strBackRestBase}/test/coverage/perl ${strCoveragePath}_temp",
+                    {bSuppressStdErr => true});
+                executeTest("sudo rm -rf ${strCoveragePath}_temp");
 
                 # Load the results of coverage testing from JSON
                 my $oJSON = JSON::PP->new()->allow_nonref();
                 my $hCoverageResult = $oJSON->decode(${$oStorageBackRest->get('test/coverage/perl/cover.json')});
 
-                # Now compare against code modules that should have full coverage
-                my $hCoverageList = testDefCoverageList();
-                my $hCoverageType = testDefCoverageType();
-                my $hCoverageActual;
-
-                foreach my $strCodeModule (sort(keys(%{$hCoverageList})))
-                {
-                    if (@{$hCoverageList->{$strCodeModule}} > 0)
-                    {
-                        my $iCoverageTotal = 0;
-
-                        foreach my $hTest (@{$hCoverageList->{$strCodeModule}})
-                        {
-                            if (!defined($hModuleTest->{$hTest->{strModule}}{$hTest->{strTest}}))
-                            {
-                                next;
-                            }
-
-                            $iCoverageTotal++;
-                        }
-
-                        if (@{$hCoverageList->{$strCodeModule}} == $iCoverageTotal)
-                        {
-                            $hCoverageActual->{testRunName($strCodeModule, false)} = $hCoverageType->{$strCodeModule};
-                        }
-                    }
-                }
-
-                if (keys(%{$hCoverageActual}) == 0)
-                {
-                    &log(INFO, 'no code modules had all tests run required for coverage');
-                }
-
                 foreach my $strCodeModule (sort(keys(%{$hCoverageActual})))
                 {
                     # If the first char of the module is lower case then it's a c module
@@ -1241,7 +1333,7 @@ eval
                     }
 
                     # Create code module path -- where the file is located on disk
-                    my $strCodeModulePath = "${strBackRestBase}/lib/" . BACKREST_NAME . "/${strCodeModule}.pm";
+                    my $strCodeModulePath = "${strBackRestBase}/lib/" . PROJECT_NAME . "/${strCodeModule}.pm";
 
                     # Get summary results
                     my $hCoverageResultAll = $hCoverageResult->{'summary'}{$strCodeModulePath}{total};
@@ -1288,7 +1380,7 @@ eval
                             &log(ERROR, ('-' x 80));
                             executeTest(
                                 "/usr/bin/cover -report text ${strCoveragePath} --select ${strBackRestBase}/lib/" .
-                                BACKREST_NAME . "/${strCodeModule}.pm",
+                                PROJECT_NAME . "/${strCodeModule}.pm",
                                 {bShowOutputAsync => true});
                             &log(ERROR, ('-' x 80));
                         }
@@ -1305,9 +1397,14 @@ eval
                         }
                     }
                 }
+            }
+
+            # Generate C coverage report
+            #---------------------------------------------------------------------------------------------------------------------------
+            if (vmCoverageC($strVm))
+            {
+                &log(INFO, 'writing C coverage report');
 
-                # Generate C coverage with lcov
-                #---------------------------------------------------------------------------------------------------------------------------
                 my $strLCovFile = "${strBackRestBase}/test/.vagrant/code/all.lcov";
 
                 if ($oStorageBackRest->exists($strLCovFile))
@@ -1369,6 +1466,10 @@ eval
                             }
                         }
                     }
+
+                $oStorageBackRest->remove("${strBackRestBase}/test/.vagrant/code/all.lcov", {bIgnoreMissing => true});
+                coverageGenerate(
+                    $oStorageBackRest, "${strBackRestBase}/test/.vagrant/code", "${strBackRestBase}/test/coverage/c-coverage.html");
                 }
                 else
                 {
@@ -1405,8 +1506,8 @@ eval
         $strVm, $iVmId,                                             # Vm info
         $strBackRestBase,                                           # Base backrest directory
         $strTestPath,                                               # Path where the tests will run
-        '/usr/bin/' . BACKREST_EXE,                                 # Path to the backrest executable
-        "${strBackRestBase}/bin/" . BACKREST_EXE,                   # Path to the backrest Perl helper
+        '/usr/bin/' . PROJECT_EXE,                                  # Path to the backrest executable
+        "${strBackRestBase}/bin/" . PROJECT_EXE,                    # Path to the backrest Perl helper
         $strPgVersion ne 'minimal' ? $strPgSqlBin: undef,           # Pg bin path
         $strPgVersion ne 'minimal' ? $strPgVersion: undef,          # Pg version
         $stryModule[0], $stryModuleTest[0], \@iyModuleTestRun,      # Module info
